/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(yb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function wb(xb){var r=xb.env||xb;var s=r.a;var t=s.buffer;s.grow=ub;var u=new Int8Array(t);var v=new Int16Array(t);var w=new Int32Array(t);var x=new Uint8Array(t);var y=new Uint16Array(t);var z=new Uint32Array(t);var A=new Float32Array(t);var B=new Float64Array(t);var C=Math.imul;var D=Math.fround;var E=Math.abs;var F=Math.clz32;var G=Math.min;var H=Math.max;var I=Math.floor;var J=Math.ceil;var K=Math.trunc;var L=Math.sqrt;var M=r.abort;var N=NaN;var O=Infinity;var P=r.b;var Q=r.c;var R=r.d;var S=r.e;var T=r.f;var U=r.g;var V=r.h;var W=r.i;var X=r.j;var Y=r.k;var Z=r.l;var _=r.m;var $=r.n;var aa=r.o;var ba=r.p;var ca=r.q;var da=r.r;var ea=r.s;var fa=r.t;var ga=r.u;var ha=r.v;var ia=r.w;var ja=r.x;var ka=r.y;var la=r.z;var ma=r.A;var na=r.B;var oa=r.C;var pa=r.D;var qa=r.E;var ra=r.F;var sa=r.G;var ta=r.H;var ua=r.I;var va=r.J;var wa=r.K;var xa=r.L;var ya=r.M;var za=r.N;var Aa=r.O;var Ba=r.P;var Ca=r.Q;var Da=r.R;var Ea=r.S;var Fa=r.T;var Ga=r.U;var Ha=r.V;var Ia=r.W;var Ja=r.X;var Ka=r.Y;var La=r.Z;var Ma=r._;var Na=r.$;var Oa=r.aa;var Pa=r.ba;var Qa=r.ca;var Ra=r.da;var Sa=r.ea;var Ta=r.fa;var Ua=r.ga;var Va=r.ha;var Wa=r.ia;var Xa=r.ja;var Ya=r.ka;var Za=r.la;var _a=r.ma;var $a=r.na;var ab=r.oa;var bb=r.pa;var cb=r.qa;var db=r.ra;var eb=r.sa;var fb=r.ta;var gb=r.ua;var hb=r.va;var ib=r.wa;var jb=5705168;var kb=0;var lb=0;var mb=0;var nb=0;
// EMSCRIPTEN_START_FUNCS
function ki(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,B=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,T=0,V=0,W=0,X=0,Y=0,Z=D(0),_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=D(0),Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;ra=jb-16|0;jb=ra;a:{b:{if(!w[a+24620>>2]){break b}e=w[a+24624>>2];if(e>>>0>4|!(1<<e&22)){break b}e=w[a+24632>>2];if(e>>>0>4){break b}if((e|0)!=3){break a}}w[ra+8>>2]=207;w[ra+12>>2]=0;w[ra+4>>2]=8830;w[ra>>2]=5063;f=jb-176|0;jb=f;g=Hb(f+120|0,13483);w[114256]=0;Q(5,f+160|0,13085)|0;e=w[114256];w[114256]=0;c:{d:{if((e|0)==1){a=P()|0;break d}w[114256]=0;U(6,f+104|0,1,f+160|0);e=w[114256];w[114256]=0;e:{f:{g:{if((e|0)!=1){if(u[f+171|0]<0){zb(w[f+160>>2])}w[114256]=0;e=u[f+115|0];h=(e|0)<0;e=S(2,g|0,(h?w[f+104>>2]:f+104|0)|0,(h?w[f+108>>2]:e&255)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break g}w[f+152>>2]=w[e+8>>2];h=w[e+4>>2];w[f+144>>2]=w[e>>2];w[f+148>>2]=h;w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;w[114256]=0;ga(1434,f+88|0,ra|0,1,9407,f+144|0);e=w[114256];w[114256]=0;if((e|0)==1){break f}if(u[f+155|0]<0){zb(w[f+144>>2])}if(u[f+115|0]<0){zb(w[f+104>>2])}if(u[g+11|0]>=0){break c}zb(w[g>>2]);break c}a=P()|0;if(u[f+171|0]>=0){break d}zb(w[f+160>>2]);break d}a=P()|0;break e}a=P()|0;if(u[f+155|0]>=0){break e}zb(w[f+144>>2])}if(u[f+115|0]>=0){break d}zb(w[f+104>>2])}if(u[g+11|0]<0){zb(w[g>>2])}R(a|0);M()}jb=f+176|0}f=w[a+480208>>2];h:{if(!b|f&512){break h}za=a+8204|0;J=a+393352|0;la=a+12|0;e=w[a+1074380>>2];while(1){i:{if(e){break i}e=f|512;j:{if(f&256){break j}F=0;q=jb-32|0;jb=q;f=a+1074392|0;e=w[f>>2]+1|0;w[f>>2]=e;k:{l:{m:{h=w[a+1074416>>2];f=w[a+1074396>>2];n:{if(e>>>0<C(h+w[a+1074400>>2]|0,f?f:1)>>>0){break n}e=!f;n=a+1074984|0;m=a+1304360|0;s=a+484360|0;o=a+1074438|0;k=a+1074424|0;B=a+1074314|0;p=a+480210|0;while(1){g=0;o:{if(e&1){break o}g=0;if(!(x[p|0]&8)){break o}g=w[a+480180>>2]==1}e=w[a+1074428>>2];p:{q:{if(e){if(!(x[p|0]&8)){break p}if(w[a+480180>>2]==2){break q}break p}if(w[a+480180>>2]!=2){break p}}f=y[a+480188>>1];if(!f){break p}h=0;while(1){w[(C(h,896)+a|0)+1075788>>2]=0;h=h+1|0;if((f|0)!=(h|0)){continue}break}}w[a+1074400>>2]=0;w[a+1074392>>2]=0;w[a+1074396>>2]=0;w[a+1074424>>2]=e;e=y[a+1074440>>1];v[a+1074438>>1]=e;r:{if(x[a+480208|0]&32){l=w[a+484344>>2];f=w[a+484348>>2];h=y[a+1074436>>1];break r}G=w[a+484360>>2];t=x[a+484376|0];f=G+(t<<5)|0;i=w[f+4>>2];j=w[f>>2];s:{t:{if(i-j>>1>>>0<=e>>>0){h=65535;v[a+1074436>>1]=65535;break t}h=y[(e<<1)+j>>1];v[a+1074436>>1]=h;f=w[a+484348>>2];l=w[a+484344>>2];r=(f-l|0)/52&65535;u:{if(r>>>0<=h>>>0){break u}L=C(h,52)+l|0;if(w[L>>2]!=w[L+4>>2]){break u}h=65534;v[a+1074436>>1]=65534}if(h>>>0<r>>>0){break s}}while(1){v:{w:{if((h&65535)!=65535){h=i-j>>1;if(h>>>0>(e&65535)>>>0){break w}}r=(t<<5)+G|0;h=y[r+28>>1];x:{if(h){l=i-j>>1;break x}h=0;f=e&65535;l=i-j>>1;if(!f|f>>>0>l>>>0){break x}while(1){f=e;e=e-1|0;i=e&65535;if(!i){break x}if(y[(i<<1)+j>>1]!=65535){continue}break}h=f}v[a+1074438>>1]=h;w[a+480208>>2]=w[a+480208>>2]&-524289;e=h&65535;if(l>>>0<=e>>>0){break l}while(1){if(y[(e<<1)+j>>1]==65534){h=h+1|0;v[o>>1]=h;e=h&65535;if(l>>>0>e>>>0){continue}break l}break}if(!nh(r,h&65535)){break l}G=w[a+484360>>2];t=x[a+484376|0];e=G+(t<<5)|0;i=w[e+4>>2];j=w[e>>2];h=i-j>>1;e=y[a+1074438>>1];break v}e=e+1|0;v[o>>1]=e}f=e&65535;y:{if(f>>>0>=h>>>0){h=65535;v[a+1074436>>1]=65535;f=w[a+484348>>2];l=w[a+484344>>2];r=(f-l|0)/52|0;break y}h=y[(f<<1)+j>>1];v[a+1074436>>1]=h;f=w[a+484348>>2];l=w[a+484344>>2];r=(f-l|0)/52|0;if((r&65535)>>>0<=h>>>0){break y}L=C(h,52)+l|0;if(w[L>>2]!=w[L+4>>2]){break y}h=65534;v[a+1074436>>1]=65534}if((r&65535)>>>0<=h>>>0){continue}break}}v[a+1074440>>1]=e}e=0;j=(f-l|0)/52&65535;f=h&65535;if(j>>>0<=f>>>0){break k}f=C(f,52)+l|0;if(w[f>>2]==w[f+4>>2]){break k}e=w[k>>2];if(e>>>0>=z[f+12>>2]){w[k>>2]=0;e=0}if(g){e=w[m+16>>2];if((e|0)==w[m+12>>2]){f=-1}else{f=w[e-4>>2]}e=w[k>>2];f=(f|0)==(e|0)}else{f=1}z:{if(!f|(x[a+480208|0]&32)>>>5&w[a+480272>>2]!=-1){break z}if(!io(m,y[o>>1],e,1)){break z}e=w[a+480272>>2];if(e){if((e|0)>0){w[a+480272>>2]=e-1}Te(m,1);ti(m,y[o>>1],w[k>>2],1);break z}if(!(x[p|0]&64)){break m}if(!ho(m,o,k,1)){w[a+1074424>>2]=0;w[a+1074428>>2]=0;v[a+1074438>>1]=0;v[a+1074440>>1]=0;e=x[a+484376|0];if((e|0)>=((w[a+484364>>2]-w[a+484360>>2]>>>5&255)-1|0)){zk(s,0);Te(m,1);e=0;break k}zk(s,e+1&255);Te(m,1)}h=0;while(1){ug((C(h,896)+a|0)+1074984|0,7,a,h&65535,1024);h=h+1|0;if((h|0)!=256){continue}break}h=a+946300|0;f=a+906300|0;while(1){e=w[f>>2];A:{if(!e){break A}if(!(ob[w[w[e>>2]+112>>2]](e)|0)){break A}ob[w[w[e>>2]+92>>2]](e)}f=f+160|0;if((h|0)!=(f|0)){continue}break}w[a+1074416>>2]=w[a+480196>>2];w[a+1074420>>2]=w[a+480204>>2];w[a+1074444>>2]=w[a+480200>>2];e=y[a+1074438>>1];v[a+1074440>>1]=e;h=w[a+1074424>>2];w[a+1074428>>2]=h;j=w[a+484360>>2]+(x[a+484376|0]<<5)|0;f=w[j>>2];if(e>>>0<w[j+4>>2]-f>>1>>>0){v[a+1074436>>1]=y[f+(e<<1)>>1]}ti(m,e,h,1);e=0;h=y[a+1074436>>1];f=w[a+484344>>2];if(h>>>0>=((w[a+484348>>2]-f|0)/52&65535)>>>0){break k}f=f+C(h,52)|0;if(w[f>>2]==w[f+4>>2]){break k}}f=w[a+1074424>>2];h=f+1|0;w[a+1074428>>2]=h;e=w[a+484344>>2]+C(y[a+1074436>>1],52)|0;B:{if(h>>>0<z[e+12>>2]){break B}if(!(x[a+480208|0]&32)){v[a+1074440>>1]=y[a+1074438>>1]+1}w[a+1074428>>2]=0;if(w[a+1074316>>2]>=0){break B}h=w[a+1074432>>2];w[a+1074432>>2]=0;w[a+1074428>>2]=h}h=ld(e);j=y[a+480188>>1];if(j){i=n+C(j,896)|0;e=w[e>>2]+C(C(f,h),6)|0;h=n;while(1){j=w[a+1074320>>2];if(!(!(j&262144)|x[h+827|0]!=1|(x[e+3|0]&254)!=2)){Oa=h,Pa=md(a,x[h+822|0],w[h+768>>2],w[h+704>>2]),w[Oa+700>>2]=Pa;j=w[a+1074320>>2]}C:{if(!(j&134217728)|(x[e|0]-1&255)>>>0<120){break C}f=x[h+810|0];if(x[h+813|0]!=19|(f-1&255)>>>0>119){break C}l=x[h+815|0];if((l&240)!=208|z[a+1074416>>2]>(l&15)>>>0){break C}Oa=h,Pa=md(a,f,w[h+768>>2],0),w[Oa+700>>2]=Pa;j=w[a+1074320>>2]}if(!(!(j&268435456)|x[a+1074312|0]&32|(w[a+1074416>>2]!=1|x[h+813|0]!=17))){f=x[h+815|0];w[a+1074420>>2]=C(f>>>0<=1?1:f,1e4)}f=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);u[h+810|0]=f;u[h+811|0]=f>>>8;u[h+812|0]=f>>>16;u[h+813|0]=f>>>24;f=x[e+4|0]|x[e+5|0]<<8;u[h+814|0]=f;u[h+815|0]=f>>>8;f=w[h+676>>2];w[h+20>>2]=w[h+672>>2];w[h+24>>2]=f;w[h+88>>2]=w[h+88>>2]&-393217;if(!(x[B|0]&32)){u[h+851|0]=0}w[h+884>>2]=0;u[h+827|0]=0;e=e+6|0;h=h+896|0;if((i|0)!=(h|0)){continue}break}}D:{E:{f=y[a+1074436>>1];e=w[a+484344>>2];if(f>>>0<((w[a+484348>>2]-e|0)/52&65535)>>>0){f=e+C(f,52)|0;e=w[f+16>>2];h=w[f+20>>2];if((e|0)!=(0-h|0)){break E}}w[a+1074408>>2]=w[a+480216>>2];h=w[a+480220>>2];break D}w[a+1074408>>2]=e}w[a+1074412>>2]=h;h=w[a+1074416>>2];if(!g){break n}g=h+1|0;w[a+1074392>>2]=g;f=w[a+1074396>>2];e=!f;if(g>>>0>=C(w[a+1074400>>2]+h|0,f?f:1)>>>0){continue}break}}if(!h){w[a+1074416>>2]=1;h=1}e=w[a+480208>>2];f=w[a+1074392>>2];F:{G:{if(f){w[a+480208>>2]=e&-4097;g=w[a+480180>>2];if(g&1048580|!(e&2097152)&(g|0)==1){break F}g=w[a+1074396>>2];j=g?g:1;g=w[a+1074400>>2]+h|0;if(f>>>0>=C(j,g)>>>0){break F}if(!((f>>>0)%(g>>>0)|0)){break G}break F}e=e&-528385}w[a+480208>>2]=e|4096}j=0;t=0;ba=jb-16|0;jb=ba;H:{if(!y[a+480188>>1]){m=-1;W=65535;i=-1;break H}da=a+1075821|0;ha=a+1074376|0;_=a+480209|0;ia=a+1074313|0;H=a+1074321|0;ja=a+1074325|0;oa=a+1074318|0;ka=a+1074322|0;pa=a+1074317|0;i=-1;m=-1;W=65535;while(1){p=C(t,896)+a|0;X=p+1075794|0;T=z[a+1074392>>2]%(w[a+1074400>>2]+w[a+1074416>>2]>>>0)|0;n=p+1075799|0;g=p+1075798|0;V=p+1075796|0;l=x[V|0];Y=p+1075795|0;j=1;I:{J:{o=p+1075797|0;s=x[o|0];switch(s-4|0){case 0:case 2:break I;default:break J}}j=(l|0)==11}k=x[n|0];e=x[Y|0];B=x[g|0];h=p+1075856|0;u[h|0]=w[a+480208>>2]>>>12&1|x[h|0]&254;f=x[X|0];K:{L:{M:{if((f|0)==252){if((e-1&255)>>>0>249){break M}f=w[(C(e,160)+a|0)+906140>>2];if(!f){break M}ob[w[w[f>>2]+44>>2]](f,l<<8|B,D(D((s<<8|k)>>>0)*D(.0010010009864345193)));f=x[X|0]}if((f|0)==251){break L}}if(A[p+1075868>>2]==D(0)|s){break K}}r=w[a+480208>>2]&4096;N:{if(!r){f=x[p+1075878|0];break N}f=x[Y|0];u[p+1075878|0]=f}if((f-1&255)>>>0>249){break K}L=(C(f,160)+a|0)+906140|0;f=w[L>>2];if(!f){break K}O:{if(!r){G=w[a+1074400>>2]+w[a+1074416>>2]|0;g=y[p+1075876>>1];o=w[a+1074396>>2];break O}g=x[g|0]|x[V|0]<<8;v[p+1075876>>1]=g;Z=D(D((x[n|0]|x[o|0]<<8)>>>0)*D(.0010010009864345193));A[p+1075872>>2]=Z;Z=D(Z-D(ob[w[w[f>>2]+48>>2]](f,g)));G=w[a+1074400>>2]+w[a+1074416>>2]|0;o=w[a+1074396>>2];A[p+1075868>>2]=Z/D(C(G,o?o:1)>>>0)}f=w[L>>2];n=g;g=(w[a+1074392>>2]+1|0)==(C(o?o:1,G)|0);ob[w[w[f>>2]+(g?44:100)>>2]](f,n,A[(g?p+1075872|0:p+1075868|0)>>2])}n=p+1074984|0;P:{Q:{R:{S:{T:{if((x[X|0]+5&255)>>>0>=2){if(x[_|0]&16){break T}break S}e=0;v[X>>1]=0;v[X+2>>1]=0;v[X+4>>1]=0;l=0;B=0;s=0;k=0;j=0;if(!(x[_|0]&16)){break S}o=0;break Q}if(!e){e=0;break R}w[p+1075768>>2]=0;break R}Un(a,n)}if((s|0)==33){o=k>>>4|0;ok(a,t&65535,o+(k&15)|0,(w[a+1074312>>2]&1073741824)>>>30|0);s=33;break Q}o=0;if((s-19&255)>>>0>1){break Q}U:{if(!(!(w[a+480180>>2]&16777250)|k)){k=x[p+1075837|0];break U}u[p+1075837|0]=k}V:{f=k&240;if((f|0)==208){f=k&15;if(!f){f=w[a+480180>>2];if(f&16777248){o=1;break Q}if((f|0)!=2){break Q}break P}if(!(x[ia|0]&64)|f>>>0<w[a+1074400>>2]+w[a+1074416>>2]>>>0){break V}if(!e){break P}u[p+1075809|0]=e;break P}if(!(x[_|0]&16)){break Q}W:{if((f|0)==96&(s|0)==19|(f|0)==176&(s|0)==20){if(x[((t<<5)+a|0)+480281|0]&4?x[H|0]&32:0){break Q}g=0;r=k&15;X:{Y:{if(r){f=x[n+861|0];Z:{if(f){f=f-1|0;u[n+861|0]=f;if(f&255){break Z}if(!(u[a+1074314|0]&1)&w[a+480180>>2]!=2){break Y}w[n+804>>2]=w[a+1074424>>2]+1;f=-1;break X}_:{if(x[a+1074314|0]&2|x[a+480180|0]&3){break _}G=y[a+480188>>1];if(!G){break _}f=a+1074984|0;while(1){if(x[f+861|0]?(f|0)!=(n|0):0){break Y}f=f+896|0;g=g+1|0;if(G>>>0>(g&65535)>>>0){continue}break}}u[n+861|0]=r}f=w[n+804>>2];w[a+1074432>>2]=f;break X}w[n+804>>2]=w[a+1074424>>2]}f=-1}$:{if((f|0)==-1){f=m;break $}i=(i|0)==-1?-1:x[a+1074320|0]&16?f:i;W=x[a+1074324|0]&128?-1:W}if(w[a+480180>>2]!=2){break W}g=y[a+480188>>1];if(!g){break W}m=p+1075845|0;r=p+1075788|0;G=0;while(1){L=C(G,896)+a|0;w[L+1075788>>2]=w[r>>2];u[L+1075845|0]=x[m|0];G=G+1|0;if((g|0)!=(G|0)){continue}break}break W}if((f|0)!=224){break Q}f=w[a+480180>>2];if(w[a+1074396>>2]?f&16777250:0){break Q}g=f&2;f=k&15;if(f?0:g){break Q}w[a+1074396>>2]=f+1;break Q}m=f;break Q}o=f}K=w[a+480180>>2];g=(K|0)==16&(s|0)==19&(k&240)==208;L=g?0:o;if(!(!L|x[X|0]!=255|(!(x[H|0]&4)|x[V|0]!=2))){u[V|0]=0}I=k&15;f=w[a+1074392>>2];G=w[a+1074320>>2];aa:{if(G&256){r=0;if(L>>>0>=z[a+1074416>>2]){break aa}}r=(f|0)==(L|0);if(!(G&16777216)|!L){break aa}r=(L|0)==(T|0)|(f|0)==(L|0)}k=g?I|144:k;aa=w[a+1074316>>2];if(aa&4096){g=x[h|0]&-2|(L|0)==(T|0)}else{g=x[h|0]}u[h|0]=g&253|(r?2:0);h=(!(G&4)|!L)&j;ea=w[a+480208>>2];ba:{ca:{da:{if(!(f|(!(ea&2097152)|!e))){w[p+1075644>>2]=0;if(r){j=x[X|0];break da}f=p+1074992|0;if(!(w[f>>2]|w[f+4>>2])){break ba}u[p+1075809|0]=e;if(y[a+480190>>1]<e>>>0){break ba}e=C(e,104)+a|0;w[p+1075672>>2]=y[e+484410>>1];w[p+1075752>>2]=u[e+484417|0];break ba}if(!r){break ba}j=x[X|0];if(!e){break ca}}u[p+1075809|0]=e}ea:{if(!(!(G&8)|(j-121&255)>>>0<136)){g=w[p+1075756>>2];fa:{if(!e|h){break fa}o=y[a+480192>>1];ga:{if(o){f=65535;if(e>>>0>o>>>0){break ga}o=w[((e<<2)+a|0)+900380>>2];if(!o){break ga}f=y[(o+((j&255)<<1)|0)+234>>1];break ga}f=e}f=f&65535;if(f>>>0>y[a+480190>>1]){break fa}g=u[(C(f,104)+a|0)+484416|0]}j=((j&255)+g|0)-132>>>0>=4294967176?j:0;break ea}if(!(K&25165856)){break ea}f=y[a+480192>>1];if(!f|(j&255)>>>0>120){break ea}g=e?e:x[p+1075810|0];if(!g|(w[((g<<2)+a|0)+900380>>2]?f>>>0>=g>>>0:0)){break ea}j=0;e=0}f=aa&8388608;g=!k&(s|0)==25;e=g?f?0:e:e;ma=(e|0)!=0;g=g?f?0:j:j;N=1;o=G>>>1|0;ha:{if(K&16777248|x[ja|0]&8){break ha}N=0;if(!(G&2097152)){break ha}j=p+1074992|0;if(w[j>>2]|w[j+4>>2]){break ha}N=1;j=w[p+1075088>>2];if(!j){break ha}N=!w[j+20>>2]|!w[j>>2]}T=g&255;o=o&ma;ia:{ja:{ka:{la:{ma:{na:{if(!(K&1048580)){break na}oa:{if(!(f?!e&(l|0)!=1&(s|0)!=13:1)|(T|0)!=255){break oa}f=w[p+1075640>>2];if(u[f+60|0]&1?f:0){break oa}w[p+1075672>>2]=0;e=p+1075072|0;f=w[e>>2];w[e>>2]=f|2097152;if(!(!(ea&4096)|!(G&4194304))){w[e>>2]=f|2101248}f=1;e=0;j=0;aa=0;if(o){break ka}f=0;break ia}if(!(aa&134217728)|ea&4096){break na}if(!T){j=x[p+1075803|0]-x[p+1075756|0]|0;h=0;f=o;break ma}if(T>>>0>250){f=1;h=0;j=0;N=0;break ma}pa:{if(e){break pa}h=0;if(!(x[a+1074324|0]&4)){break pa}e=0;j=g;f=o;break ma}f=1;h=0;j=g;N=1;break ma}j=0;f=o;aa=0;if(!(ma&!T)){break la}}aa=1;g=j;if(!(G&2)){break ka}}o=f;f=1;j=g;if(o){break ka}break ja}qa:{if(!y[a+480192>>1]){if(y[a+480190>>1]<e>>>0){break ja}g=(C(e,104)+a|0)+484380|0;break qa}g=w[p+1075088>>2];if(!g){break ja}}if(!((!w[g+20>>2]|!w[g>>2])&(K|0)==2|v[g+34>>1]<0)){w[p+1075672>>2]=y[g+30>>1]}if(!f){break ja}Bi(n,y[g+28>>1],a);G=w[a+1074320>>2]}f=(e|0)!=0;if(!(G&128)|!e){break ia}u[p+1075843|0]=32;f=1}o=y[a+480192>>1];ra:{if(!o|((f&x[a+1074324|0]>>>4)!=1|(j-1&255)>>>0<120)){break ra}f=w[a+480208>>2];sa:{if(h){if(f&8){break sa}break ra}if(!(f&4)){break ra}}f=p+1075736|0;w[f>>2]=0;w[f+4>>2]=-1;f=p+1075724|0;w[f>>2]=0;w[f+4>>2]=-1;f=p+1075712|0;w[f>>2]=0;w[f+4>>2]=-1;w[p+1075680>>2]=65536;f=p+1075072|0;w[f>>2]=w[f>>2]|2097152}if(aa){g=w[a+480180>>2];ta:{ua:{if(!(!(x[ia|0]&8)&(g|0)!=268435456)){f=0;if(G&8388608){f=p+1074992|0;f=!(w[f>>2]|w[f+4>>2])}if(o){if((f^-1)&w[p+1075640>>2]==w[((e<<2)+a|0)+900380>>2]|e>>>0>o>>>0){break ua}j=x[p+1075803|0];break ua}if((f^-1)&w[p+1075088>>2]==((C(e,104)+a|0)+484380|0)){break ta}j=x[p+1075803|0];break ta}if(!o){break ta}}if(!(g&1048588)){break ta}f=p+1075736|0;w[f>>2]=0;w[f+4>>2]=-1;f=p+1075724|0;w[f>>2]=0;w[f+4>>2]=-1;f=p+1075712|0;w[f>>2]=0;w[f+4>>2]=-1;u[p+1075822|0]=0;w[p+1075764>>2]=0;w[p+1075680>>2]=65536;f=p+1075072|0;g=w[f>>2]&-2101249|2097152;w[f>>2]=g;if(!(G&4194304)){break ta}w[f>>2]=g&-6145}e=N?e:0}va:{wa:{xa:{ya:{za:{Aa:{g=j&255;Ba:{Ca:{if(g>>>0>=251){Da:{if(!(x[oa|0]&4)|!e){break Da}if(o){if(e>>>0>o>>>0){break Da}f=w[((e<<2)+a|0)+900380>>2];if(!f){break Da}j=x[p+1075805|0];if((j-1&255)>>>0>119){break Da}f=y[(f+(j<<1)|0)+234>>1]}else{f=e}f=f&65535;if(!f|f>>>0>y[a+480190>>1]){break Da}f=C(f,104)+a|0;if(v[f+484414>>1]<0){break Da}w[p+1075672>>2]=y[f+484410>>1]}G=0;j=1;if(!(x[a+1074324|0]&16)){break Ba}f=0;if(x[a+480208|0]&4){break Ca}break Ba}f=0;if((j-1&255)>>>0>119){break Ca}u[p+1075808|0]=j;u[p+1075805|0]=j;if(!h){Wn(a,t&65535,e,g,0)}Ho(n);f=1}if(e){j=p+1075088|0;o=w[j>>2];fh(a,n,e,h,1,1);e=w[j>>2];Ea:{if(!e|!(x[e+35|0]&2)){break Ea}G=w[a+1304392>>2];if(!G){break Ea}wk(G,t&65535,e+68|0)}Fa:{Ga:{e=w[a+480180>>2];Ha:{Ia:{if((e|0)==1){if(!h|!(x[ka|0]&32)){break Ia}break Ha}G=w[a+1074316>>2];if((f^-1)&(G&262144)>>>18){break Ga}}u[p+1075809|0]=0}if(!(x[pa|0]&4)){break Fa}if(!f|(o|0)==w[j>>2]){break ya}w[n>>2]=0;w[n+4>>2]=0;break ya}if(G&1024){break ya}}if(e&16777248){e=0;if(f&(o|0)!=w[j>>2]){break xa}}if(!(x[ja|0]&8)|(o|0)==w[j>>2]){break Aa}e=0;if((f^1|h)!=1){break za}e=p+1075060|0;if(z[e>>2]>=z[n+4>>2]){break Aa}w[e>>2]=0;break ya}if(!g){e=h;break va}j=1;G=0;K=p+1075809|0;e=x[K|0];if(!e|f^1){break Ba}fh(a,n,e,h,!(w[p+1075088>>2]?1:w[p+1075640>>2]),!(w[a+480180>>2]&1048580));u[K|0]=0;G=1}e=h;break wa}e=h}if(!(x[ka|0]&32)){break xa}f=p+1074992|0;if(w[f>>2]|w[f+4>>2]){break xa}w[n>>2]=0;w[n+4>>2]=0;break xa}e=h}j=0;G=0;if(!g){break va}}o=p+1075088|0;h=w[o>>2];Ja:{if(!h|!(x[h+35|0]&2)){break Ja}f=w[a+1304392>>2];if(!f){break Ja}if(!G){if((po(f,t&65535)|0)!=255){break Ja}h=w[o>>2];f=w[a+1304392>>2]}wk(f,t&65535,h+68|0)}f=t&65535;qi(a,n,g,e,!(w[a+480180>>2]&1048580),0,f);if(!(!e|(!(w[a+480180>>2]&1048580)|j))){u[p+1075822|0]=0;w[p+1075764>>2]=0;h=p+1075736|0;w[h>>2]=0;w[h+4>>2]=-1;h=p+1075724|0;w[h>>2]=0;w[h+4>>2]=-1;h=p+1075712|0;w[h>>2]=0;w[h+4>>2]=-1;h=p+1075072|0;w[h>>2]=w[h>>2]|2097152}if(!(x[p+1075073|0]&2)){break va}h=w[a+1304392>>2];if(!h|(x[a+1074324|0]&8|(g|0)!=253?g>>>0<=253:0)){break va}Ue(h,f)}Ka:{La:{switch(l-1|0){case 0:B=B>>>0>=64?64:B;w[p+1075672>>2]=B<<2;f=p+1075072|0;w[f>>2]=w[f>>2]|2097152;break Ka;case 1:break La;default:break Ka}}Hf(a,n,B,6)}if(y[a+480192>>1]){yw(a,t&65535)}h=e}f=w[a+1074320>>2];if(x[((t<<5)+a|0)+480281|0]&4?f&8192:0){break P}Ma:{Na:{Oa:{Pa:{g=w[a+1074392>>2];e=g>>>0>=L>>>0;Qa:{if(!(f&2048)|!L){break Qa}if(!g){break Pa}e=1;if((g|0)!=(L|0)){break Qa}e=!x[Y|0]&(l|0)!=11}if(!e|l>>>0<3){break Pa}if((l|0)==11){qk(ba+8|0,a,X,L);e=x[ba+12|0];og(a,n,w[ba+8>>2]);if(e){break Na}e=11;break Oa}f=w[a+1074316>>2];j=f&1073741824;Ra:{if(!(!j|B)){B=0;e=0;Sa:{switch(l-8|0){case 0:break Ra;case 1:break Sa;default:break Oa}}if(x[_|0]&16){break Oa}w[p+1075676>>2]=0;break Oa}if(f&512){break Ra}if(B){u[p+1075838|0]=B;break Ra}B=x[p+1075838|0]}Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{e=l;switch(e-3|0){case 12:break Ta;case 10:break Ua;case 9:break Va;case 7:break Wa;case 6:break Xa;case 5:break Ya;case 4:break Za;case 3:break _a;case 2:break $a;case 0:case 1:break ab;default:break Oa}}bb:{if(!(!(f&512)|B)){B=x[p+1075838|0];if(B){break bb}B=0;break Pa}u[p+1075838|0]=B}rg(a,n,((l|0)==3?B<<4:B)&255);break Pa}e=5;f=f&512;if(f?(g|0)!=(L|0):0){break Oa}dh(a,n,B,(f|0)!=0);break Oa}e=6;f=f&512;if(f?(g|0)!=(L|0):0){break Oa}ch(a,n,B,(f|0)!=0);break Oa}if(f&2097152){u[p+1075827|0]=B&15;e=7;break Oa}e=B&15;if(e){u[p+1075827|0]=e}e=p+1075072|0;w[e>>2]=w[e>>2]|131072;e=7;break Oa}e=B&15;if(e){u[p+1075828|0]=e<<2}if(B&240){u[p+1075827|0]=B>>>4}e=p+1075072|0;w[e>>2]=w[e>>2]|131072;e=8;break Oa}nk(a,n,B,!j);e=9;break Oa}nk(a,n,B<<4&240,!j);e=10;break Oa}e=12;Tn(a,t&65535,B<<2&252,(w[a+1074312>>2]&4096)>>>12|0);break Oa}Rn(a,t&65535,B<<2&252,(w[a+1074312>>2]&4096)>>>12|0);e=13;break Oa}e=15;if(!r){break Oa}f=w[p+1075088>>2];if(!f|B>>>0>9){break Oa}cb:{if(!B){o=w[p+1075648>>2];break cb}o=w[(f+(B<<2)|0)- -64>>2];w[p+1075648>>2]=o}Gf(a,n,o);break Oa}e=l}db:{eb:{fb:{gb:{switch(s-1|0){case 12:if(!(x[a+480209|0]&16)){break Na}e=C(t,896)+a|0;w[e+1075672>>2]=k>>>0>=64?256:k<<2;e=e+1075072|0;w[e>>2]=w[e>>2]|2097152;break Na;case 1:if(!k&(u[a+480180|0]&1)){break Ma}Tn(a,t&65535,k,0);break Na;case 2:if(!k&(u[a+480180|0]&1)){break Ma}Rn(a,t&65535,k,0);break Na;case 10:if(!k&w[a+480180>>2]==1){break Ma}rg(a,n,k);break Na;case 3:og(a,n,k);break Na;case 5:if(!(!k&w[a+480180>>2]==1)){rg(a,n,k)}og(a,n,0);break Na;case 4:if(I){u[(C(t,896)+a|0)+1075828|0]=I<<2}if(k&240){u[(C(t,896)+a|0)+1075827|0]=k>>>4}e=(C(t,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|131072;break Na;case 6:if(!(!k&w[a+480180>>2]==1)){rg(a,n,k)}e=(C(t,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|131072;break Na;case 15:if(!(x[a+480209|0]&16)){break Na}break db;case 16:if(x[a+1074312|0]&32){if(!(x[a+480209|0]&16)){break Na}if(k){break db}break Na}k=gh(a,y[a+1074436>>1],w[a+1074424>>2],t&65535,0);hb:{if(!(w[a+480180>>2]&16777250)){break hb}if(k){u[(C(t,896)+a|0)+1075839|0]=k;break hb}k=x[(C(t,896)+a|0)+1075839|0]}f=w[a+8>>2];g=w[a+480208>>2]&4096;e=C(k,1e4);h=C(w[w[a+8>>2]+24>>2],1e4);e=e>>>0<h>>>0?e:h;ib:{if(e>>>0>=(y[a+480180>>1]&16392?1e4:32e4)>>>0){if(((x[a+1074323|0]&16)>>>4|0)==((g|0)!=0|0)){break ib}f=C(w[f+24>>2],1e4);w[a+1074420>>2]=e>>>0>f>>>0?f:e;break ib}if(g){break ib}h=a+1074420|0;e=(e>>>0)/1e4|0;g=C(e&15,1e4);g=w[h>>2]+((e&240)==16?g:0-g|0)|0;w[h>>2]=g;e=C(w[f+20>>2],1e4);f=u[a+1074313|0]&1?255e4:C(w[f+24>>2],1e4);if(e>>>0>f>>>0){break ib}if(e>>>0<=g>>>0){e=f;if(g>>>0<=e>>>0){break ib}}w[a+1074420>>2]=e}break Na;case 9:if(!r|w[a+480180>>2]==4&h){break Na}u[ba+7|0]=0;e=gh(a,y[a+1074436>>1],w[a+1074424>>2],t&65535,ba+7|0);f=a;if(!x[ba+7|0]){g=(C(t,896)+a|0)+1075648|0;s=e<<8;jb:{if(s){w[g>>2]=s;break jb}s=w[g>>2]}e=(x[(C(t,896)+a|0)+1075840|0]<<16)+s|0}Gf(f,n,e);break Na;case 40:if(!r){break Na}e=BV(w[(C(t,896)+a|0)+1075060>>2],0,k,0);Gf(a,n,(nb&255)<<24|e>>>8);break Na;case 0:if(w[a+1074392>>2]){break Na}e=C(t,896)+a|0;kb:{if(x[e+1075803|0]?w[e+1075684>>2]:0){break kb}e=w[e+1075640>>2];if(x[a+1074313|0]&32|((x[e+31|0]-1&255)>>>0<17?e:0)){break kb}if(w[a+480180>>2]&16777248){break Na}}if(!k){if(x[a+480180|0]&5){break Ma}u[(C(t,896)+a|0)+1075811|0]=1;break Ma}e=C(t,896)+a|0;u[e+1075812|0]=k;u[e+1075811|0]=1;break Na;case 14:if(w[a+480180>>2]&1048580){k=k&240?k:y[(C(t,896)+a|0)+1075784>>1]&240|k;if(!(k&15)){k=y[(C(t,896)+a|0)+1075784>>1]&15|k}k=k|256}if(x[a+1074314|0]&128){lb:{if(!k){s=y[(C(t,896)+a|0)+1075784>>1];break lb}s=k&255;v[(C(t,896)+a|0)+1075784>>1]=s}mk(a,t&65535,s<<16>>16,(e|0)==15?B+1|0:0);break Na}mb:{if(k){v[(C(t,896)+a|0)+1075784>>1]=k&255;break mb}k=v[(C(t,896)+a|0)+1075784>>1]}mk(a,t&65535,k,(e|0)==15?B+1|0:0);break Na;case 17:e=w[a+480208>>2];if(!(e&4096)){break Na}nb:{ob:{if(x[a+1074314|0]&64){if(!k){k=0;break ob}if(e&4){break ob}e=k&240?k-16|0:k;k=e-((e&15)!=0)|0;u[(C(t,896)+a|0)+1075844|0]=k;break ob}if(!(x[a+1074320|0]&128)){break nb}}e=(C(t,896)+a|0)+1075843|0;u[e|0]=x[e|0]|128}e=C(t,896)+a|0;u[e+1075811|0]=18;if(!k){break Ma}u[e+1075844|0]=k;break Na;case 22:if(!(x[a+480209|0]&16)){break Na}e=w[a+480180>>2];k=k<<!(e&59593760);if(k>>>0<=128){w[a+1074444>>2]=k<<1;break Na}if(e&16777250){break Na}w[a+1074444>>2]=256;break Na;case 23:if(x[a+1074313|0]&2){Qn(a,k,(C(t,896)+a|0)+1075821|0);break Na}Qn(a,k,da);break Na;case 8:if(!(x[a+480209|0]&16)){break Na}Hf(a,n,k,8);break Na;case 28:nk(a,n,k,1);break Na;case 7:if(I){u[(C(t,896)+a|0)+1075831|0]=I<<2}if(k&240){u[(C(t,896)+a|0)+1075830|0]=k>>>4}e=(C(t,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|262144;break Na;case 25:$n(a,n,k);break Na;case 18:e=k&15;f=t&65535;h=C(f,896)+a|0;g=h+1074984|0;pb:{qb:{switch(k>>>4|0){case 0:f=y[a+480188>>1];if(!f){break pb}g=(k&1)<<14;e=0;while(1){h=(C(e,896)+a|0)+1075072|0;w[h>>2]=(g|w[h>>2]&-16385)^16384;e=e+1|0;if((f|0)!=(e|0)){continue}break};break pb;case 1:if(!(e|w[a+480180>>2]&1048580)){break pb}Kn(a,g,e);break pb;case 2:if(!(e|w[a+480180>>2]&1048580)){break pb}In(a,g,e);break pb;case 3:f=h+1075072|0;w[f>>2]=w[f>>2]&-1048577|((e|0)!=0)<<20;break pb;case 4:u[h+1075826|0]=k&7;break pb;case 5:if(!(x[a+480209|0]&16)){break pb}h=w[a+480180>>2];if(h&69206025){g=C(f,896)+a|0;e=e<<28>>24;w[g+1075752>>2]=e;h=g+1075684|0;if(!w[h>>2]|(x[g+1075794|0]-1&255)>>>0>119){break pb}f=C(f,896)+a|0;Oa=h,Pa=md(a,x[f+1075803|0],e,w[f+1075688>>2]),w[Oa>>2]=Pa;break pb}g=x[(C(f,896)+a|0)+1075794|0]-1|0;if((h|0)==16){if((g&255)>>>0>119){break pb}g=C(f,896)+a|0;h=w[g+1075088>>2];if(!h){break pb}u[h+37|0]=e;w[g+1075752>>2]=e;g=g+1075684|0;if(!w[g>>2]){break pb}f=C(f,896)+a|0;Oa=g,Pa=md(a,x[f+1075803|0],e,w[f+1075688>>2]),w[Oa>>2]=Pa;break pb}if((g&255)>>>0>119){break pb}e=C(f,896)+a|0;f=k<<28>>24^-128;w[e+1075752>>2]=f;g=e+1075684|0;if(!w[g>>2]){break pb}Oa=g,Pa=md(a,x[e+1075803|0],f,w[e+1075688>>2]),w[Oa>>2]=Pa;break pb;case 7:u[h+1075829|0]=k&7;break pb;case 8:if(!(x[a+480209|0]&16)){break pb}Hf(a,g,e,4);break pb;case 9:mk(a,f,e,0);break pb;case 10:if(!(e|w[a+480180>>2]&1048580)){break pb}dh(a,g,e,0);break pb;case 11:if(!(e|w[a+480180>>2]&1048580)){break pb}ch(a,g,e,0);break pb;case 12:ok(a,f,e,0);break pb;case 15:break qb;default:break pb}}if(w[a+480180>>2]==1){u[(C(f,896)+a|0)+1075850|0]=e;if(!(x[a+480209|0]&16)){break pb}Un(a,g);break pb}u[(C(f,896)+a|0)+1075848|0]=e}break Na;case 19:Pn(a,t&65535,k);break Na;case 24:if(x[a+1074318|0]&128){if(w[a+1074392>>2]!=(k|0)){break Na}e=w[(C(t,896)+a|0)+1075640>>2];if(u[e+60|0]&1?e:0){break eb}if(!(!(x[Y|0]|x[V|0])|k)){e=(C(t,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|4096;break eb}e=C(t,896)+a|0;w[e+1075672>>2]=0;e=e+1075072|0;w[e>>2]=w[e>>2]|2097152;break eb}if(x[a+480209|0]&16){break eb}break Na;case 27:e=(k&240)-16>>>4|0;if(e>>>0>9){break Na}if(!(1<<e&880)){if(!e){break fb}if((e|0)!=1){break Na}On(a,n,k&15);break Na}if(x[a+1074319|0]&4){break Na}Pn(a,t&65535,k);break Na;case 20:if(!(x[a+480209|0]&16)|k>>>0>64){break Na}e=C(t,896)+a|0;w[e+1075744>>2]=k;e=e+1075072|0;w[e>>2]=w[e>>2]|2097152;break Na;case 21:e=k;rb:{if(e){u[n+836|0]=e;break rb}e=x[n+836|0]}f=e&15;g=e&255;sb:{tb:{if(!((f|0)!=15|g>>>0<16)){if(!(x[a+480209|0]&16)){break sb}e=g>>>4|0;break tb}h=w[a+480208>>2]&4096;j=g&240;if(!(!f|(j|0)!=240)){if(!h){break sb}e=0-f|0;break tb}if(h){break sb}if(f){e=0-f|0;if(!(w[a+480180>>2]&25690144)|!j){break tb}break sb}if((e&255)>>>0<16){break sb}e=g>>>4|0}e=e+w[n+760>>2]|0;e=(e|0)>=64?64:e;w[n+760>>2]=(e|0)>0?e:0}break Na;case 26:if(I){u[(C(t,896)+a|0)+1075834|0]=I}if(!(k&240)){break Na}u[(C(t,896)+a|0)+1075833|0]=k>>>4;break Na;case 29:if(!(x[a+480209|0]&16)){break Na}e=C(t,896)+a|0;w[e+1075712>>2]=k;if(x[e+1075708|0]&4?0:x[a+1074319|0]&16){break Na}w[e+1075736>>2]=k;w[e+1075724>>2]=k;break Na;case 11:w[a+1074432>>2]=0;W=gh(a,y[a+1074436>>1],w[a+1074424>>2],t&65535,0);i=x[a+480180|0]&5?(i|0)==-1?i:0:i;break Na;case 13:e=ao(a,ha,t&65535,k);if((e|0)==-1){break Na}W=x[a+480208|0]&32?y[a+1074438>>1]:W;i=e;break Na;case 34:case 35:case 36:case 37:f=(s|0)==35|(s|0)==37;g=(s-37&255)>>>0<2;h=w[a+480208>>2]&4096;ub:{vb:{if(h){e=k&240;if(e){u[n+869|0]=e>>>4}e=k&15;if(e){u[n+870|0]=e}e=x[n+869|0];u[n+868|0]=e;if(w[a+480180>>2]==32768){break vb}break ub}if(w[a+480180>>2]==32768){e=x[n+869|0];if(h|(e|0)==16){break vb}break ub}e=x[n+868|0]-1|0;u[n+868|0]=e;if(e&255){break ub}e=x[n+869|0]}u[n+868|0]=e;e=x[n+870|0];e=f?e:0-e|0;wb:{xb:{f=w[n+656>>2];if(!f){break xb}f=w[f+44>>2];if(!f){break xb}w[n+876>>2]=w[n+876>>2]+C(e,w[f+36>>2]);break wb}Oa=n,Pa=md(a,oi(a,w[n+700>>2],0,w[n+704>>2])+e|0,0,w[n+704>>2]),w[Oa+700>>2]=Pa}if(!g){break ub}w[n>>2]=0;w[n+4>>2]=0}break Na;case 38:_n(n,k);break Na;case 39:break gb;default:break Na}}if(w[a+1074392>>2]|I>>>0>1|k>>>0>47){break Na}e=(k&240)==16;s=e?0:t;f=e?y[a+480188>>1]-1|0:t;if((s&65535)>>>0>(f&65535)>>>0){break Na}e=((I|0)==1)<<26;while(1){g=s&65535;h=((g<<5)+a|0)+480280|0;w[h>>2]=e|w[h>>2]&-67108865;g=(C(g,896)+a|0)+1075072|0;w[g>>2]=e|w[g>>2]&-67108865;s=s+1|0;if((s&65535)>>>0<=(f&65535)>>>0){continue}break}break Na}Nn(a,n,k&15);break Na}pg(a,n);break Na}rk(a,ha,k)}if(!(x[H|0]&64)|!k){break Ma}u[p+1075844|0]=k;u[p+1075816|0]=k;u[p+1075815|0]=k;u[p+1075813|0]=k;u[p+1075812|0]=k;u[p+1075831|0]=k<<2&60;e=k&255;v[p+1075784>>1]=e;u[p+1075837|0]=k;u[p+1075830|0]=e>>>4}e=x[Y|0];if(!e){break P}u[p+1075810|0]=e}j=y[a+480188>>1];t=t+1|0;if(j>>>0>t>>>0){continue}break}}e=w[a+480208>>2];yb:{if(!(e&4096)){break yb}zb:{if(!((i|0)==-1&(W&65535)==65535)){if(!(x[a+1074320|0]&16|(m|0)==-1|((W&65535)!=65535?x[a+1074324|0]&128:0))){if(!(x[a+1074318|0]&2)|(W&65535)==65535){break zb}}w[a+480208>>2]=e|524288;g=y[a+1074438>>1];o=(W&65535)!=65535?W:g+1|0;f=w[a+484360>>2]+(x[a+484376|0]<<5)|0;if((o&65535)>>>0>=w[f+4>>2]-w[f>>2]>>1>>>0){o=y[f+28>>1]}f=(i|0)!=-1?i:0;if(!(x[a+1074315|0]&4|(g|0)==(o&65535)|(x[a+1074320|0]&16|(!j|w[a+480180>>2]==1)))){s=0;while(1){u[(C(s,896)+a|0)+1075845|0]=0;s=s+1|0;if((s|0)!=(j|0)){continue}break}}w[a+1074428>>2]=f;if(e&32){break yb}v[a+1074440>>1]=o;break yb}if((m|0)==-1){break yb}}w[a+1074428>>2]=m;g=y[a+1074438>>1];v[a+1074440>>1]=g;Ab:{if(!w[a+1074396>>2]){break Ab}e=w[a+480180>>2];if((e|0)==2|(x[a+1074324|0]&128?(e|0)==32:0)){break Ab}w[a+1074428>>2]=m+1}if(z[(w[a+484344>>2]+C(y[a+1074436>>1],52)|0)+12>>2]<=m>>>0){w[a+1074428>>2]=0;v[a+1074440>>1]=g+1}e=a+1304360|0;Bb:{if((m|0)==-1){break Bb}f=w[e+16>>2];if((f|0)==w[e+12>>2]){break Bb}while(1){f=f-4|0;h=w[f>>2];ti(e,g,h,0);if((h|0)==(m|0)){break Bb}if(w[e+12>>2]!=(f|0)){continue}break}}}jb=ba+16|0;e=1;break k}Te(m,1);e=0;break k}Te(m,1);e=0}_=!w[a+1074420>>2]|e^1;Cb:{if(_){break Cb}e=xn(a,a+1074376|0);w[a+1074380>>2]=e;w[a+1074404>>2]=e;Db:{if(x[a+1074369|0]){e=y[a+480188>>1];f=e?e>>>0>=31?31:e:1;e=w[a+24628>>2];if((e|0)>=129){e=((C(e-128|0,f+4&65535)|0)/16|0)+128|0}o=((C(w[a+480228>>2],e)<<1&-128)>>>0)/x[(f>>>1|0)+25712|0]|0;break Db}o=w[a+480228>>2]}v[a+480212>>1]=0;X=a+480210|0;I=a+480209|0;V=a+1074322|0;while(1){k=C(F,896)+a|0;p=k+1075072|0;g=w[p>>2];if(!(u[a+1074320|0]&1|(!(g&4096)|(w[k+1075008>>2]|(w[k+1075004>>2]|w[k+1075680>>2]))))){w[k+1075060>>2]=0;e=k+1075076|0;w[e>>2]=0;w[e+4>>2]=0}e=y[a+480188>>1];Eb:{if(w[k+1075060>>2]|e>>>0>F>>>0?g&1024:1){if(e>>>0>F>>>0){tn(a,F&65535)}v[k+1075846>>1]=0;break Eb}j=0;ba=k+1075704|0;w[ba>>2]=0;G=k+1075664|0;w[G>>2]=0;m=k+1074992|0;f=m;w[f>>2]=0;w[f+4>>2]=0;w[k+1075084>>2]=0;w[q+24>>2]=1065353216;v[q+22>>1]=0;h=0;B=k+1075684|0;h=w[B>>2]?w[k+1075060>>2]!=0:h;n=k+1074984|0;L=k+1075640|0;W=w[L>>2];Fb:{Gb:{Hb:{if(e>>>0<=F>>>0){break Hb}if(x[((F<<5)+a|0)+480288|0]){break Gb}if(!W){break Hb}j=x[W+34|0]!=0}if((h|j)!=1){break Fb}}w[q+12>>2]=w[k+1075672>>2];w[q+8>>2]=w[k+1075748>>2];f=w[a+1074312>>2]&268435456?q+8|0:q+12|0;g=w[a+1074312>>2];Ib:{if(g&268435456){g=w[f>>2]+v[n+788>>1]|0;w[f>>2]=g;e=0;if((g|0)>=0){e=64;if(g>>>0<65){break Ib}}w[f>>2]=e;break Ib}e=v[n+788>>1];if(g&2){g=e+w[f>>2]|0;w[f>>2]=g;e=0;if((g|0)>=0){e=256;if(g>>>0<257){break Ib}}w[f>>2]=e;break Ib}e=e+w[n+688>>2]|0;w[n+688>>2]=e;g=0;Jb:{if((e|0)>=0){g=256;if(e>>>0<257){break Jb}}w[n+688>>2]=g;e=g}w[f>>2]=e;v[n+788>>1]=0}e=0;Kb:{if(w[a+1074312>>2]&268435458){f=w[n+692>>2]+v[n+790>>1]|0;w[n+684>>2]=f;if((f|0)>=0){e=256;if(f>>>0<257){break Kb}}w[n+684>>2]=e;break Kb}g=w[n+692>>2]+v[n+790>>1]|0;w[n+692>>2]=g;Lb:{if((g|0)>=0){e=256;if(g>>>0<257){break Lb}}w[n+692>>2]=e;g=e}w[n+684>>2]=g;v[n+790>>1]=0}Mb:{if(!(x[n+90|0]&4)){break Mb}e=w[a+480208>>2];if((e&2101248)==2101248){break Mb}g=w[a+1074312>>2]&2097152;if(!(!g&w[q+12>>2]<=0)){j=w[a+480180>>2];e=on(a,x[n+845|0],x[n+840|0]);if(!(!(x[a+1074323|0]&2)|(x[n+845|0]&3)!=1)){e=x[n+839|0];i=x[n+840|0];f=i<<2&124;e=(!(x[n+90|0]&2)|x[a+480209|0]&16?e:x[n+843|0]+e|0)&32?f^127:f;e=i&32?0-e|0:e}if(w[a+480180>>2]!=131072){e=w[q+12>>2]+((C(x[n+847|0],e)|0)/((g|j&5?32:64)|0)|0)|0}else{f=64-e|0;e=w[q+12>>2];e=((C(x[n+847|0],C(f,e))|0)/-8192|0)+e|0}w[q+12>>2]=e;e=w[a+480208>>2]}if(!(w[a+480180>>2]&16777248)|e&4?e&4096:0){break Mb}e=x[n+846|0];f=x[n+840|0];g=w[a+1074312>>2]&2097152;u[n+840|0]=(g?e<<2:f)+(g?f:e)}i=F&65535;Nb:{if(x[a+1074320|0]&128){e=(C(i,896)+a|0)+1075843|0;g=u[e|0];if((g|0)>=0){break Nb}if(!(x[a+480209|0]&16|x[(C(i,896)+a|0)+1075811|0]!=18)){f=g&-33;u[e|0]=f;Ob:{Pb:{if((f|0)!=-64){f=g&223;if((f|0)!=128){break Pb}g=x[(C(i,896)+a|0)+1075844|0]>>>4|-64;break Ob}g=x[(C(i,896)+a|0)+1075844|0]&15|-128;break Ob}g=f-1|0}u[e|0]=g;e=(C(i,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|2097152}if((g&224)!=128){break Nb}w[q+12>>2]=0;break Nb}if(x[(C(i,896)+a|0)+1075811|0]!=18){break Nb}Qb:{if(x[a+1074314|0]&64){j=C(i,896)+a|0;e=j+1075843|0;f=x[e|0];g=f<<24>>24;if(!((g|0)>=0|!w[j+1075060>>2])){Rb:{Sb:{if((f|0)!=192){if((f|0)!=128){break Sb}g=x[(C(i,896)+a|0)+1075844|0]>>>4|-64;break Rb}g=x[(C(i,896)+a|0)+1075844|0]&15|-128;break Rb}g=g-1|0}u[e|0]=g}if((g&192)!=128){break Qb}w[q+12>>2]=0;break Qb}e=x[(C(i,896)+a|0)+1075844|0];j=e>>>4|0;l=j+(e&15)|0;f=w[a+480180>>2];if(!(x[a+480208|0]&4?0:f&16777248)){l=l+2|0;j=j+1|0}e=(C(i,896)+a|0)+1075843|0;g=x[e|0];if(!(f&4)){f=(g&255)>>>0<l>>>0?g:0;if((f&255)>>>0>=j>>>0){w[q+12>>2]=0}u[e|0]=f+1;break Qb}Tb:{if(x[a+480209|0]&16){g=g&255?g-1|0:0;break Tb}u[e|0]=g+1}if(((g&255)>>>0)%(l>>>0)>>>0<j>>>0){break Qb}w[q+12>>2]=0}e=(C(i,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|2097152}e=C(i,896)+a|0;Ub:{if(x[e+1075811|0]!=18){break Ub}f=w[e+1075640>>2];if(!f){break Ub}e=x[f+34|0];if(!e|x[f+15|0]&2){break Ub}g=C(i,896)+a|0;if(w[g+1075072>>2]&134218752){break Ub}g=g+1075805|0;j=x[g|0];if((j-1&255)>>>0>119){break Ub}e=w[(C(e,160)+a|0)+906140>>2];if(!e){break Ub}j=ob[w[w[e>>2]+96>>2]](e,j,i)|0;l=w[q+12>>2];if(!(!j|l)){ob[w[w[e>>2]+88>>2]](e,f,x[g|0]+255|0,0,i);break Ub}if(j|!l){break Ub}ob[w[w[e>>2]+88>>2]](e,f,x[g|0],y[(C(i,896)+a|0)+1075672>>1],i)}f=0;g=w[q+12>>2];Vb:{if((g|0)>=0){f=256;if(g>>>0<257){break Vb}}g=f}g=g<<6;w[q+12>>2]=g;Wb:{Xb:{if(W){if(w[a+1074312>>2]<0){ji(a,n)}e=q+12|0;Yb:{if(!nn(a,n,0)){break Yb}f=w[n+728>>2];j=w[a+1074312>>2];if(!f&(j|0)<0){break Yb}g=w[n+656>>2];l=f+(j>>31)|0;f=oh(g+48|0,l,256,64);r=x[g+65|0];Zb:{_b:{if((r|0)==255){break _b}j=w[n+732>>2];if((j|0)==-1){break _b}r=w[g+48>>2]+(r<<2)|0;s=x[r+2|0];g=s<<2;f=(l|0)==y[r>>1]?g:f;if(x[a+1074323|0]&64){f=j+(f-g<<1)|0;break _b}l=0;if(!s){break Zb}f=(C(f,j)|0)/(g|0)|0}f=(f|0)>=512?512:f;l=(f|0)>0?f:0}w[e>>2]=(C(l,w[e>>2])|0)/256}sn(n,e);$b:{if(!nn(a,n,1)){break $b}e=w[n+740>>2];f=w[a+1074312>>2];if(!e&(f|0)<0){break $b}f=oh(w[n+656>>2]+68|0,e+(f>>31)|0,64,64)-32|0;e=w[n+684>>2];e=((C(f,(e|0)>127?256-e|0:e)|0)/32|0)+e|0;e=(e|0)>=256?256:e;w[n+684>>2]=(e|0)>0?e:0}e=w[n+656>>2];f=x[e+26|0];ac:{if(!f){break ac}g=x[n+819|0];if(!g){break ac}e=w[n+684>>2]+((C(g+(x[e+27|0]^-1)|0,f<<24>>24)<<16>>16)/2<<16>>16)|0;e=(e|0)>=256?256:e;w[n+684>>2]=(e|0)>0?e:0}g=w[q+12>>2];break Xb}if(!(x[p+1|0]&16)){break Xb}g=0;w[k+1075680>>2]=0;w[q+12>>2]=0;break Wb}if(!g){g=0;break Wb}if(x[p+3|0]&8){w[G>>2]=0;break Wb}if(x[a+1074368|0]){e=C(w[q+8>>2],w[k+1075744>>2]);f=e;j=e>>31;e=g<<8;f=CV(BV(f,j,e,e>>31),nb,1048576,0);j=f;e=nb;f=(e|0)>=0&f>>>0>=2147483647|(e|0)>0;j=f?2147483647:j;e=f?0:e;w[G>>2]=(e|0)<0&j>>>0<=2147483648|(e|0)<-1?-2147483648:j;break Wb}e=C(w[q+8>>2],w[k+1075744>>2]);f=e;j=e>>31;e=C(w[a+1074444>>2],g);f=CV(BV(f,j,e,e>>31),nb,1048576,0);j=f;e=nb;f=(e|0)>=0&f>>>0>=2147483647|(e|0)>0;j=f?2147483647:j;e=f?0:e;w[G>>2]=(e|0)<0&j>>>0<=2147483648|(e|0)<-1?-2147483648:j}w[ba>>2]=g;g=w[B>>2];e=w[a+480260>>2];bc:{if((g|0)>=(e|0)){break bc}f=w[a+480180>>2];if((f|0)==2|!(!(x[a+480208|0]&16)|!(x[a+1074312|0]&128))&(f|0)!=4){break bc}w[B>>2]=e;g=e}w[q+16>>2]=g;cc:{if((w[p>>2]&1572864)!=1572864){break cc}e=w[a+480208>>2];dc:{if(!(e&2097152)){break dc}ec:{switch(x[k+1075797|0]-4|0){default:if(x[k+1075796|0]!=11){break cc}if(!(e&4096)){break dc}break cc;case 0:case 2:break ec}}if(e&4096){break cc}}e=k+1075696|0;fc:{if(w[e>>2]==(g|0)){g=w[k+1075700>>2];break fc}w[e>>2]=g;e=k+1075752|0;f=k+1075688|0;g=md(a,oi(a,g,w[e>>2],w[f>>2]),w[e>>2],w[f>>2]);w[k+1075700>>2]=g}w[q+16>>2]=g}s=C(i,896)+a|0;Y=s+1075640|0;f=w[Y>>2];gc:{if(!f){break gc}e=x[f+34|0];if(!e|x[f+15|0]&2|(!w[(C(e,160)+a|0)+906140>>2]|w[(C(i,896)+a|0)+1075072>>2]&134218752)){break gc}g=C(i,896)+a|0;t=g+1075797|0;r=x[t|0];e=0;j=x[g+1075805|0];if((j-1&255)>>>0<=119){e=x[(f+j|0)+107|0]}l=g+1075794|0;hc:{ic:{if((r|0)==1){j=0;jc:{kc:{switch((z[a+1074392>>2]%3|0)-1|0){case 0:j=x[(C(i,896)+a|0)+1075812|0]>>>4|0;break jc;case 1:break kc;default:break jc}}j=x[(C(i,896)+a|0)+1075812|0]&15}f=C(i,896)+a|0;u[f+1075807|0]=e;if(x[f+1075806|0]==(e+j|0)){break hc}f=e;if(!(x[a+480209|0]&16)){break ic}f=e;if((x[l|0]-1&255)>>>0>=120){break ic}break hc}j=0;if(x[l|0]){break hc}f=C(i,896)+a|0;if(!x[f+1075806|0]){break hc}f=x[f+1075807|0]}Ff(a,i,(f&255)+j|0,y[(C(i,896)+a|0)+1075672>>1])}f=(C(i,896)+a|0)+1075806|0;g=x[f|0];lc:{if(!g){if(!(x[a+480209|0]&16)|(r|0)!=1|(x[l|0]-121&255)>>>0>135){break lc}g=e;if((e-1&255)>>>0>119){break lc}}Ff(a,i,(g&255)+255|0,0)}u[f|0]=x[t|0]==1?x[(C(i,896)+a|0)+1075807|0]+j|0:0}mc:{if(x[s+1075811|0]!=1){break mc}e=w[Y>>2];if(!(!e|!w[e+44>>2])){j=0;nc:{oc:{pc:{switch(z[a+1074392>>2]%3|0){case 1:j=x[(C(i,896)+a|0)+1075812|0]>>>4|0;break oc;case 0:break oc;case 2:break pc;default:break nc}}j=x[(C(i,896)+a|0)+1075812|0]&15}v[q+22>>1]=j}e=(C(i,896)+a|0)+1075856|0;u[e|0]=x[e|0]|24;break mc}if(!(!(x[a+480209|0]&16)|w[a+480180>>2]!=1048576)){e=C(i,896)+a|0;f=md(a,x[e+1075803|0],w[e+1075752>>2],w[e+1075688>>2]);w[q+16>>2]=f;w[e+1075684>>2]=f}j=w[a+1074312>>2];if(j&8192){e=x[(C(i,896)+a|0)+1075812|0];if(!e){break mc}f=65536;qc:{switch(((z[a+1074392>>2]%(w[a+1074400>>2]+w[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:e=e<<4;case 0:f=w[((e&240)<<2)+30256>>2];break;default:break qc}}e=w[q+16>>2];g=e;e=e>>31;rc:{if(!(!(x[a+480208|0]&16)|!(j&128)|w[a+480180>>2]==4)){f=BV(g,e,f,f>>31)+32768|0;e=nb;e=CV(f,f>>>0<32768?e+1|0:e,65536,0);f=nb;break rc}j=(f|0)/2|0;i=j>>31;l=e<<16|g>>>16;g=g<<16;e=g+j|0;s=i+l|0;e=CV(e,e>>>0<g>>>0?s+1|0:s,f,f>>31);f=nb}g=e;e=(f|0)>=0&e>>>0>=2147483647|(f|0)>0;g=e?2147483647:g;e=e?0:f;w[q+16>>2]=(e|0)<0&g>>>0<=2147483648|(e|0)<-1?-2147483648:g;break mc}if(x[a+1074318|0]&8){if(x[a+480209|0]&16){break mc}sc:{tc:{e=w[a+1074416>>2];f=e-(z[a+1074392>>2]%(e>>>0)|0)|0;if((f|0)>16){break tc}if((f|0)==16){break mc}e=0;uc:{switch((f|0)%3|0){case 0:break mc;case 2:break tc;case 1:break uc;default:break sc}}e=x[(C(i,896)+a|0)+1075812|0]>>>4|0;break sc}e=x[(C(i,896)+a|0)+1075812|0]&15}g=e;e=C(i,896)+a|0;f=e+1075752|0;e=e+1075688|0;g=g+oi(a,w[q+16>>2],w[f>>2],w[e>>2])|0;f=md(a,g,w[f>>2],w[e>>2]);w[q+16>>2]=f;if(g>>>0<109){break mc}e=md(a,109,0,w[e>>2]);w[q+16>>2]=e>>>0<f>>>0?f:e;break mc}f=w[a+1074392>>2];e=w[a+480180>>2];vc:{if((e|0)!=1){j=x[(C(i,896)+a|0)+1075803|0];break vc}e=C(i,896)+a|0;j=oi(a,w[q+16>>2],w[e+1075752>>2],w[e+1075688>>2]);e=w[a+480180>>2]}wc:{xc:{switch((((e&67633152?f+2|0:f)>>>0)%3|0)-1|0){case 0:j=(x[(C(i,896)+a|0)+1075812|0]>>>4|0)+j|0;break wc;case 1:break xc;default:break wc}}j=(x[(C(i,896)+a|0)+1075812|0]&15)+j|0}if(!(e&67633408|x[(C(i,896)+a|0)+1075803|0]!=(j&255)|x[a+1074322|0]&4)){break mc}if(x[a+480210|0]&32){e=j&255;if((e|0)==85){w[q+16>>2]=2147483647;break mc}j=e>>>0>85?j-37|0:j}e=C(i,896)+a|0;f=md(a,j&255,w[e+1075752>>2],w[e+1075688>>2]);w[q+16>>2]=f;if(w[a+480180>>2]&71827712){w[e+1075684>>2]=f;break mc}if(!(x[a+1074322|0]&4)){break mc}u[(C(i,896)+a|0)+1075806|0]=j}yc:{if(!(x[X|0]&33)){break yc}f=w[q+16>>2];if((f|0)==2147483647){break yc}zc:{if(w[a+480180>>2]==2){j=3424;g=452;break zc}e=C(w[k+1075752>>2]>>>4&15,24)+25968|0;j=y[e>>1]<<1;e=y[e+22>>1]>>>1|0;g=e>>>0<=452?452:e;if(j>>>0<g>>>0){break yc}}e=g;Ac:{if((f|0)>=(e|0)){e=j;if((f|0)<=(e|0)){break Ac}}w[q+16>>2]=e}e=w[B>>2];if((e|0)>=(g|0)){g=j;if((e|0)<=(g|0)){break yc}}w[B>>2]=g}rn(a,n);g=w[p>>2]}if(!(!(x[a+1074316|0]&32)|(!(g&256)|x[I|0]&64))){w[k+1075668>>2]=128}r=F&65535;tn(a,r);Bc:{if(!h){break Bc}e=qn(a,n,q+16|0);if((e|0)<0|!(x[p+1|0]&2)){break Bc}f=w[a+1304392>>2];if(!f){break Bc}lh(f,r,e>>>2&255,1)}Cc:{if(x[k+1075796|0]!=8){break Cc}Dc:{Ec:{e=x[k+1075797|0];switch(e-5|0){case 1:break Cc;case 0:case 2:break Dc;default:break Ec}}if((e|0)!=26){break Cc}}e=w[a+480180>>2];if((e|0)==4){if(x[I|0]&16){break Cc}e=k+1075823|0;u[e|0]=x[e|0]+x[k+1075827|0];break Cc}if(!(e&16777248)){break Cc}e=x[k+1075798|0];f=e&15;if(f){u[n+844|0]=f<<2}e=e&240;if(e){u[n+843|0]=e>>>4}w[n+88>>2]=w[n+88>>2]|131072;pn(a,r,q+16|0,q+24|0)}pn(a,r,q+16|0,q+24|0);if(h){w[q+12>>2]=0;l=w[n+104>>2];Fc:{if(!l){break Fc}s=x[l+40|0];if(!s){break Fc}e=w[n+656>>2];if(e){i=w[e+44>>2]!=0}else{i=0}Y=w[a+1074312>>2];Gc:{if(!(x[a+480208|0]&16)){e=w[a+480180>>2];g=31280;h=30192;j=30256;f=30128;break Gc}g=31280;h=30192;j=30256;e=w[a+480180>>2];f=30128;if(!(Y&128)|(e|0)==4){break Gc}g=30256;h=30128;j=31280;f=30192}if(!(i|!(Y&2097152)|(e|0)==1048576)){e=x[l+41|0];if(!e){break Fc}i=x[l+39|0];H=e;e=x[n+838|0];u[n+838|0]=H+e;i=i+w[n+780>>2]|0;s=s<<8;i=(i|0)<(s|0)?i:s;w[n+780>>2]=i;s=(i|0)/256|0;Hc:{Ic:{switch(x[l+38|0]-1|0){case 3:e=w[a+1074328>>2];w[a+1074328>>2]=C(e,214013)+2531011;i=(e>>>16&127)+-64|0;break Hc;case 2:i=64-(e+1>>>1|0)|0;break Hc;case 1:i=(e+1>>>1|0)+-64|0;break Hc;case 0:i=(e^-1)>>>1&64;break Hc;default:break Ic}}i=u[e+26560|0]}e=w[q+16>>2];e=((e|0)>=8388607?8388607:e)<<8;w[q+16>>2]=e;Y=C(i,s);l=(Y|0)/64|0;i=l>>31;l=(i^l)-i|0;i=l&3;s=l>>>2|0;l=e>>31;Jc:{Kc:{if((Y|0)<=-64){g=w[(s<<2)+j>>2];h=CV(BV(g,g>>31,e,l),nb,65536,0);j=h;g=nb;h=(g|0)>=0&h>>>0>=2147483647|(g|0)>0;j=h?2147483647:j;g=h?0:g;g=((g|0)<0&j>>>0<=2147483648|(g|0)<-1?-2147483648:j)-e|0;if(i){break Kc}break Jc}f=w[(s<<2)+g>>2];g=CV(BV(f,f>>31,e,l),nb,65536,0);j=g;f=nb;g=(f|0)>=0&g>>>0>=2147483647|(f|0)>0;j=g?2147483647:j;f=g?0:f;g=((f|0)<0&j>>>0<=2147483648|(f|0)<-1?-2147483648:j)-e|0;f=h;if(!i){break Jc}}f=w[(i<<2)+f>>2];h=CV(BV(f,f>>31,e,l),nb,65536,0);j=h;f=nb;h=(f|0)>=0&h>>>0>=2147483647|(f|0)>0;j=h?2147483647:j;f=h?0:f;g=(g-e|0)+((f|0)<0&j>>>0<=2147483648|(f|0)<-1?-2147483648:j)|0}w[q+16>>2]=(e+g|0)/256;w[q+12>>2]=g&255;break Fc}e=e&16777248;Lc:{Mc:{Nc:{Oc:{Pc:{f=x[l+39|0];Qc:{if(!f){if(e){break Qc}f=s<<8;break Mc}if(!e){break Pc}}e=w[n+780>>2]+(f<<1)|0;break Oc}if(x[n+89|0]&8){e=w[n+780>>2];break Nc}e=w[n+780>>2]+((s<<8>>>0)/(f>>>0)|0)|0}w[n+780>>2]=e}f=s<<8;if((f|0)>=(e|0)){break Lc}}w[n+780>>2]=f;e=f}f=x[n+838|0]+x[l+41|0]|0;u[n+838|0]=f;h=f<<24>>24;Rc:{Sc:{switch(x[l+38|0]-1|0){case 3:u[n+838|0]=h+1;f=u[(h&63)+26496|0];break Rc;case 2:f=(64-(h>>>1|0)&127)+-64|0;break Rc;case 1:f=((h>>>1|0)- -64&127)+-64|0;break Rc;case 0:f=(h|0)>=0?-64:64;break Rc;default:break Sc}}f=0-u[(h&255)+26560|0]|0;if(w[a+480180>>2]!=1048576){break Rc}f=(64-u[(h+-64&255)+26560|0]|0)/2<<16>>16}h=C(f,e);e=(h|0)/256|0;if(i){A[q+24>>2]=A[q+24>>2]+D(D(D(s>>>0)*D(1220703143189894e-20))*D(f|0));u[n+872|0]=x[n+872|0]|16;break Fc}if(w[a+480180>>2]!=4){Tc:{if((h|0)<=-256){e=0-e|0;f=e>>>8|0;g=(f<<2)+j|0;break Tc}j=g;f=e>>>8|0;g=(f<<2)+g|0}h=w[q+16>>2];j=w[((f<<2)+j|0)+4>>2];f=w[g>>2];e=((C(j-f|0,e>>>2&63)|0)/64|0)+f|0;f=CV(BV(h,h>>31,e,e>>31),nb,256,0);g=f;e=nb;f=(e|0)>=0&f>>>0>=2147483647|(e|0)>0;g=f?2147483647:g;e=f?0:e;e=(e|0)<0&g>>>0<=2147483648|(e|0)<-1?-2147483648:g;w[q+16>>2]=e;w[q+12>>2]=e&255;w[q+16>>2]=w[q+16>>2]/256;break Fc}w[q+16>>2]=w[q+16>>2]+((h|0)/16384|0)}f=w[q+16>>2];e=w[a+480260>>2];if((f|0)<=(e|0)){if(x[V|0]&2){w[k+1075060>>2]=0}w[q+16>>2]=e;f=e}e=w[L>>2];j=0;Uc:{if(!e|!w[e+44>>2]){break Uc}e=k+1075856|0;g=x[e|0];if(!(g&16)){j=1;if(w[a+1074392>>2]|!(g&8)){break Uc}}Go(n,A[q+24>>2],v[q+22>>1],a);g=e;e=x[e|0];u[g|0]=(e&16?-17:-9)&e;j=1}h=w[p>>2];Vc:{if((h&134219264)!=512){break Vc}e=w[a+1304392>>2];if(!e){break Vc}g=w[a+480180>>2];if(!(!(!(h&4096)|x[a+1074324|0]&8)&(g|0)!=2)){if(!(h&2048?(g|0)==2:0)){Wc:{if(j){g=w[B>>2];break Wc}g=Hn(a,f,w[k+1075688>>2],w[q+12>>2]);h=w[p>>2]}B=w[a+1304392>>2];i=w[a+480240>>2];e=BV(g,0,261625,0)+66904|0;l=nb;g=EV(e,e>>>0<66904?l+1|0:l,133808,0);j=g;e=nb;g=!e&(g|0)==-1|(e|0)!=0;e=BV(i,0,g?-1:j,g?0:e)+32768|0;l=nb;l=e>>>0<32768?l+1|0:l;e=(l&65535)<<16|e>>>16;s=l>>>16|0;j=!s&(e|0)==-1|s?-1:e;e=1;Xc:{if(h&2048){break Xc}e=0;if(!(h&4096)){break Xc}e=!w[k+1075680>>2]}s=w[a+1074320>>2]>>>31|0;g=u[(r+B|0)+58|0];Yc:{if((g|0)<0){break Yc}Y=w[B>>2];if(!Y){break Yc}h=(g|0)<0?-1:g;t=h&255;i=7;g=1023;if(j>>>0<=6208431){i=7;Zc:{if(j>>>0>3104215){break Zc}i=6;if(j>>>0>1552107){break Zc}i=5;if(j>>>0>776053){break Zc}i=4;if(j>>>0>388026){break Zc}i=3;if(j>>>0>194013){break Zc}i=2;if(j>>>0>97006){break Zc}i=j>>>0>48503}g=BV(1<<20-i,0,j,0)+24858e3|0;l=nb;g=EV(g,g>>>0<24858e3?l+1|0:l,49716e3,0)}j=t+B|0;l=i<<10;i=(r&3)+g&65535;g=s?i>>>0>=1023?1023:i:g;u[j+4|0]=(l|g)>>>8|(e?0:32);e=h&255;e=h>>>0<9?e:e-9|256;Pd(Y,(e|160)&65535,g&255);Pd(w[B>>2],(e|176)&65535,x[j+4|0]);u[B+530|0]=1}e=w[a+1304392>>2]}g=e;e=BV(C(w[k+1075748>>2],C(w[k+1075744>>2],w[ba>>2])),0,63,0)+33554432|0;s=nb;s=e>>>0<33554432?s+1|0:s;lh(g,r,((s&67108863)<<6|e>>>26)&255,0);e=k+1075668|0;i=e;e=w[e>>2];g=0;h=w[a+1304392>>2];j=u[(h+r|0)+58|0];_c:{if((j|0)<0){break _c}l=w[h>>2];if(!l){break _c}g=(j|0)<0?-1:j;j=g&255;j=((g>>>0<9?j:j-9|256)|192)&65535;g=x[(h+C(g&255,12)|0)+324|0]&-49;g=(e|0)<171?g|16:g;e=(e|0)>84?g|32:g;Pd(l,j,e&255);g=(e>>>5&1)+(e<<27>>31)|0}w[i>>2]=(g<<7)+128}$c:{e=w[L>>2];if(!e|(x[e+60|0]&7)!=1){break $c}g=w[e+48>>2];e=w[e+52>>2];if((g|0)==(e|0)|z[k+1075712>>2]<y[e-4>>1]|x[e-2|0]){break $c}le(w[a+1304392>>2],r,1);e=w[p>>2];w[p>>2]=(w[a+1074324>>2]&8192?e:e&-4609)|4096;w[k+1075680>>2]=0;break Vc}if(w[k+1075680>>2]|(!(x[a+1074324|0]&8)|!(x[p+1|0]&16))){break Vc}le(w[a+1304392>>2],r,1);w[p>>2]=w[p>>2]&-513}e=BV(ck(a,n,f,w[q+12>>2]),nb,w[a+480240>>2],0);r=nb;f=CV(e,r,65536,0);g=nb;e=e+65535|0;r=e>>>0<65535?r+1|0:r;e=!r&e>>>0<131071;w[m>>2]=e?1:f;w[m+4>>2]=e?0:g}if(!(!W|w[a+1074312>>2]<0)){ji(a,n)}f=w[p>>2];e=f&-65537;l=w[G>>2];B=k+1075008|0;W=k+1075004|0;r=l|(w[B>>2]|w[W>>2])?(e|f<<7&65536)^65536:e;w[p>>2]=r;i=k+1075656|0;e=i;w[e>>2]=0;w[e+4>>2]=0;g=k+1075846|0;e=x[g|0];f=e-4|0;h=e>>>0>=f>>>0?f:0;u[g|0]=h;s=k+1075847|0;e=x[s|0];f=e-4|0;j=e>>>0>=f>>>0?f:0;u[s|0]=j;ad:{bd:{cd:{dd:{ed:{fd:{gd:{e=w[k+1075088>>2];if(!e){break gd}f=w[e+20>>2];if(!f|!w[e>>2]|(!w[k+1075060>>2]|!(w[m>>2]|w[m+4>>2]))){break gd}w[k+1075e3>>2]=f;t=0;break fd}w[k+1075e3>>2]=0;e=w[L>>2];if(!e|(x[e+31|0]-1&255)>>>0>16){break ed}t=1;if(r&6144){break ed}}e=w[k+1075668>>2];f=(C(l,256-e|0)|0)/16384|0;f=f>>>0>=127?127:f;if(h<<24>>24<0){u[g|0]=f;h=f}f=f>>>1|0;if((h&255)>>>0<f>>>0){u[g|0]=f}f=(C(e,l)|0)/16384|0;f=f>>>0>=127?127:f;if(j<<24>>24<0){u[s|0]=f;j=f}f=f>>>1|0;if((j&255)>>>0<f>>>0){u[s|0]=f}if(!t){break dd}break cd}if((h&255)>>>0>=129){u[g|0]=0}if((j&255)>>>0<129){break cd}u[s|0]=0;break cd}h=w[a+24624>>2];hd:{if(h>>>0>=2){g=0;id:{if((e|0)>=0){g=256;if(e>>>0<257){break id}}e=g}g=C(l,o)>>>(x[a+1074369|0]?7:8)|0;jd:{kd:{switch(w[a+1074364>>2]){case 0:if(!(x[a+24616|0]&16)){break jd}case 1:if(e>>>0<=127){j=g>>>1|0;f=(C(e,g)|0)/256|0;break hd}f=g>>>1|0;j=(C(g,256-e|0)|0)/256|0;break hd;case 3:break kd;default:break jd}}f=255;ld:{md:{if(e>>>0>255){break md}f=e;if(e){break md}f=0;e=65536;break ld}e=y[(0-f<<1)+32816>>1]}j=C(e,g)>>>16|0;w[i>>2]=j;f=C(g,y[(f<<1)+32304>>1])>>>16|0;break hd}f=(C(e,g)|0)/256|0;j=(C(g,256-e|0)|0)/256|0;break hd}f=C(l,o)>>>8|0;w[i>>2]=f;j=f}e=w[L>>2];nd:{if(e){g=x[e+14|0];if(g>>>0<5){break nd}}g=x[a+480268|0];if(g>>>0<5){break nd}e=x[a+24648|0];g=x[X|0]&128?w[a+24668>>2]?-1:e:e}l=k+1075660|0;s=k+1075800|0;u[s|0]=g;e=w[m>>2];B=w[m+4>>2];if(!(r&131072|((e|0)!=0|(B|0)!=1)|(w[k+1075764>>2]|(g&255)==255))){u[s|0]=0}g=1<<w[a+1074360>>2];w[i>>2]=(j|0)/(g|0);f=(f|0)/(g|0)|0;w[l>>2]=(r&256)>>>8|0?(h|0)==2?0-f|0:f:f;if(r&128){w[m>>2]=0-e;w[m+4>>2]=0-(((e|0)!=0)+B|0)}l=0;w[n+28>>2]=0;w[n+32>>2]=0;g=w[n+672>>2];if((g|0)>=524288){w[n+672>>2]=524287;g=524287}h=w[n+676>>2];if((h|0)>=524288){w[n+676>>2]=524287;h=524287}od:{pd:{qd:{rd:{e=w[n+88>>2];if(!(e&65536)){break rd}f=w[n+20>>2];j=w[n+24>>2];if((f|0)==(g|0)&(j|0)==(h|0)){break rd}e=a+24604|0;f=(f|0)<(g|0)|(h|0)>(j|0);sd:{if(f){h=Lo(e);break sd}h=Ko(e)}if(!(!(x[a+1074312|0]&16)|!(x[a+480180|0]&4))){e=w[a+24620>>2];e=BV(e,e>>31,5,0)+500|0;r=nb;h=CV(e,e>>>0<500?r+1|0:r,1e3,0)}g=w[n+656>>2];if(!g|!f){break qd}f=y[g+12>>1];e=h;if(!f){break pd}l=1;e=(C(f,w[a+24620>>2])>>>0)/1e5|0;break pd}w[n+24>>2]=h;w[n+20>>2]=g;e=e&-65537;break od}e=h}e=e?e:1;f=w[n+676>>2];g=w[n+24>>2];i=f-g<<12;j=w[n+672>>2];m=w[n+20>>2];r=j-m<<12;td:{if(x[n+90|0]&32|(!(f|j)|(!(g|m)|l))){break td}e=w[a+1074380>>2];if((h|0)>2048){break td}if((e|0)>=(h|0)){h=2048;if((e|0)<2049){break td}}e=h}i=(i|0)/(e|0)|0;w[n+32>>2]=i;l=(r|0)/(e|0)|0;w[n+28>>2]=l;h=f+((C(e,i)|0)/-4096|0)|0;w[n+24>>2]=h;g=j+((C(e,l)|0)/-4096|0)|0;w[n+20>>2]=g;if(i|l){w[n+100>>2]=e;e=w[n+88>>2];break od}w[n+24>>2]=f;w[n+20>>2]=j;h=f;g=j;e=w[n+88>>2]&-65537}w[n+88>>2]=e&-2097153;w[n+40>>2]=h<<12;w[n+36>>2]=g<<12;if(x[p+1|0]&2){break ad}break bd}w[W>>2]=0;w[B>>2]=0;w[k+1075060>>2]=0;if(w[k+1075080>>2]){break bd}if(!w[k+1075076>>2]){break ad}}e=y[a+480212>>1];v[a+480212>>1]=e+1;v[((e<<1)+a|0)+1074466>>1]=F}w[k+1075652>>2]=w[p>>2]}F=F+1|0;if((F|0)!=256){continue}break}f=w[a+24608>>2];j=y[a+480212>>1];if(f>>>0>j>>>0){break Cb}w[q+24>>2]=a;if(!f){break Cb}h=a+1074466|0;if((f|0)>=2){g=f-2>>>1|0;while(1){e=g;bk(h,q+24|0,f,h+(e<<1)|0);g=e-1|0;if(e){continue}break}}F=h+(f<<1)|0;if((f|0)!=(j|0)){i=h+(j<<1)|0;g=y[h>>1];j=a+1074984|0;e=F;while(1){l=y[e>>1];if(w[(j+C(l,896)|0)+680>>2]>w[(j+C(g&65535,896)|0)+680>>2]){v[e>>1]=g;v[h>>1]=l;bk(h,q+24|0,f,h);g=y[h>>1]}e=e+2|0;if((i|0)!=(e|0)){continue}break}}if((f|0)<2){break Cb}e=f&2147483647;while(1){f=y[h>>1];F=F-2|0;v[h>>1]=y[F>>1];v[F>>1]=f;f=e-1|0;bk(h,q+24|0,f,h);g=e>>>0>2;e=f;if(g){continue}break}}jb=q+32|0;if(_^1){f=w[a+480208>>2];break i}e=w[a+480208>>2]|512;if(x[a+1304512|0]){break j}l=0;e=w[a+24620>>2];f=CV(BV(e,e>>31,100,0),nb,1e3,0);g=f;e=nb;f=(e|0)>=0&f>>>0>=2147483647|(e|0)>0;g=f?2147483647:g;e=f?0:e;f=(e|0)<0&g>>>0<=2147483648|(e|0)<-1?-2147483648:g;ud:{if(!f){break ud}g=f>>>0>=1048576?1048576:f;w[a+1074380>>2]=g;j=y[a+480212>>1];if(!j){break ud}h=a+1074376|0;while(1){e=h+C(y[(h+(l<<1)|0)+90>>1],896)|0;i=e+1280|0;w[i>>2]=0;w[i+4>>2]=0;w[e+708>>2]=g;i=w[e+632>>2]<<12;w[e+648>>2]=i;n=w[e+628>>2]<<12;w[e+644>>2]=n;w[e+696>>2]=w[e+696>>2]|65536;w[e+636>>2]=(0-n|0)/(g|0);w[e+640>>2]=(0-i|0)/(g|0);l=l+1|0;if((j|0)!=(l|0)){continue}break}}g=w[a+480208>>2];e=g|256;if(f){break j}e=g|512}f=e;w[a+480208>>2]=f}if(f&512){b=a+1074392|0;c=w[a+1074400>>2]+w[a+1074416>>2]|0;a=w[a+1074396>>2];w[b>>2]=C(c,a?a:1);break h}e=w[a+1074380>>2];e=e>>>0>=512?512:e;n=b>>>0<e>>>0?b:e;if(w[a+24632>>2]){h=0;e=jb-16|0;jb=e;f=(n-((n&1073741823)!=0)<<2)+4|0;g=n<<2<=0;while(1){if(!g){Cb(((h<<11)+a|0)+16396|0,0,f)}h=h+1|0;if((h|0)!=4){continue}break}h=0;while(1){w[e+(h<<2)>>2]=((h<<11)+a|0)+16396;h=h+1|0;if((h|0)!=4){continue}break}ob[w[w[d>>2]+8>>2]](d,e,w[a+24632>>2],n);jb=e+16|0}N=0;ta=0;T=jb-16|0;jb=T;if(n){L=a+12|0;W=a+24592|0;X=a+24588|0;vg(L,n,W,X);if(z[a+24624>>2]>=3){vg(a+8204|0,n,a+24600|0,a+24596|0)}F=y[a+480212>>1];if(F){wa=x[a+1074316|0]&2?2:1;xa=a+24648|0;$=a+24596|0;na=a+24600|0;Da=a+8204|0;I=a+397460|0;ba=a+397456|0;Y=a+393352|0;ya=a+1074376|0;while(1){l=ya+(ta<<1)|0;e=C(y[l+90>>1],896);i=e+ya|0;aa=i;vd:{wd:{if(w[i+624>>2]){break wd}f=a+e|0;if(w[f+1075080>>2]){break wd}if(!w[f+1075076>>2]){break vd}}m=a+e|0;e=x[m+1075800|0]+1|0;if((e&255)>>>0<=5){j=w[(e<<24>>24<<2)+24184>>2]}else{j=0}K=m+1075072|0;h=w[K>>2];xd:{if(!(!(h&16777216)&x[a+24612|0]>>>5)){F=L;g=X;e=h;f=W;if(!(e&8388608)){break xd}}e=Y;if(!w[e+4116>>2]){vg(e+8|0,n,e+4104|0,e+4108|0)}w[e+4116>>2]=1;F=e+8|0;e=w[K>>2];g=I;f=ba}i=i+608|0;e=e>>>8&z[a+24624>>2]>2;oa=e?$:g;pa=e?na:f;f=e?Da:F;ca=Ef(a,y[l+90>>1],2,1);fa=(ca-1&255)>>>0>249;yd:{if(fa){break yd}g=w[(C(ca,160)+a|0)+906140>>2];if(!g){break yd}e=w[g+24>>2];if(!e){break yd}oa=g+36|0;pa=g+40|0;if(!(u[g+28|0]&1)){vg(e,n,pa,oa);w[g+28>>2]=w[g+28>>2]|1}f=e}w[T>>2]=0;w[T+4>>2]=0;w[T+8>>2]=0;w[T+12>>2]=0;if(w[i+16>>2]){bs(T,i);F=w[i+8>>2];g=w[i+12>>2];e=g>>31;l=(g^e)-((e>>>0>(e^F)>>>0)+e|0)|0;e=l;w[T+12>>2]=e>>>0>8191?2:16384/(e+1>>>0)|0}ha=m+1075080|0;ia=m+1075076|0;ja=m+1075060|0;G=0;zd:{Ad:{Bd:{Cd:{ea=m+1075084|0;F=w[ea>>2];e=F?n>>>0>F>>>0?F:n:n;if(!e){break Cd}H=m+1074992|0;g=H;o=w[g+4>>2];q=w[g>>2];if(!(o|q)){break Cd}Ea=h>>>12&8|(h>>>5&2|(j|h&1));Fa=N&65535;Ga=m+1075809|0;Ha=m+1075792|0;Ia=m+1075680|0;Ja=m+1075016|0;Ka=m+1075012|0;La=m+1075660|0;Ma=m+1075656|0;O=m+1075008|0;qa=m+1075004|0;ua=m+1075088|0;ma=m+1075068|0;va=m+1075064|0;da=w[va>>2];t=w[K>>2];g=da&t<<30>>31;k=!(t&2);j=n;while(1){B=w[ja>>2];if(!B){break Bd}h=w[T>>2];if(!h){break Bd}w[aa+624>>2]=h;m=w[i>>2];Dd:{Ed:{Fd:{h=w[i+4>>2];l=h;if((h|0)<(g|0)){if((o|0)<0){r=0;h=(g<<1)-((m>>>0>r>>>0)+h|0)|0;m=r-m|0;w[i>>2]=m;w[i+4>>2]=h;if(!((h|0)>=(g|0)&h>>>0<g+B>>>1>>>0)){m=0;w[i>>2]=m;h=g;w[i+4>>2]=g}p=0-q|0;w[H>>2]=p;r=0-(((q|0)!=0)+o|0)|0;w[H+4>>2]=r;Gd:{if(t&4){t=t&-129;w[K>>2]=t;q=p;o=r;break Gd}t=t|128;w[K>>2]=t;w[i>>2]=m;h=B-1|0;w[i+4>>2]=h;w[H>>2]=q;w[H+4>>2]=o}if(!(t&2)){break Bd}if(h>>>0<B>>>0){break Dd}break Bd}if((h|0)>0|(h|0)>=0){break Ed}h=0;break Fd}if(l>>>0<B>>>0){break Ed}if(k&1){break Bd}if(t&4){if(!!q&(o|0)>=0|(o|0)>0){o=0-(((q|0)!=0)+o|0)|0;q=0-q|0;w[H>>2]=q;w[H+4>>2]=o}t=t|128;w[K>>2]=t;k=(B<<1)-((1-((m|0)!=0)|0)+l|0)|0;r=0-m|0;m=r;w[i>>2]=m;l=0;h=k|l;w[i+4>>2]=h;if(k>>>0<B>>>0&k>>>0>da>>>0){break Ed}m=r;h=l;l=B-wa|0;h=h|(l>>>0<=B>>>0?l:0);break Fd}if((o|0)<0){o=0-(((q|0)!=0)+o|0)|0;q=0-q|0;w[H>>2]=q;w[H+4>>2]=o}k=0;m=k+m|0;r=(g-B|0)+h|0;r=k>>>0>m>>>0?r+1|0:r;w[i>>2]=m;h=r;w[i+4>>2]=h;t=t|8192;w[K>>2]=t;break Ed}w[i>>2]=m;w[i+4>>2]=h}p=q;r=o}ka=h;Hd:{if((h|0)<(g|0)){if((h|r)<0){break Bd}if(B>>>0>ka>>>0){break Hd}break Bd}if((h|0)<0|B>>>0<=ka>>>0){break Bd}}l=r>>31;_=l;V=l^p;Na=l^r;k=w[T+12>>2];k=e>>>0>k>>>0?k:e;sa=BV(p,r,k-1|0,0)+m|0;s=h+nb|0;s=m>>>0>sa>>>0?s+1|0:s;sa=da>>>0>ka>>>0;Aa=da+16|0;if(!(!sa&ka>>>0<Aa>>>0)){t=t&-8193;w[K>>2]=t}da=V-_|0;_=Na-((V>>>0<_>>>0)+l|0)|0;l=s;Id:{Jd:{V=w[T+4>>2];Kd:{if(V){s=w[T+8>>2];if(s>>>0<=ka>>>0){l=w[ma>>2];w[aa+624>>2]=V;g=0;e=(r|0)<0;p=(e?g:m)^-1;g=(e?m:g)+p|0;e=((e?s:h)^-1)+(e?h:l)|0;e=CV(g,g>>>0<p>>>0?e+1|0:e,da,_)+1|0;break Id}if(!(!(t&8192)|sa|ka>>>0>=Aa>>>0)){e=y[w[ua>>2]+34>>1];w[aa+624>>2]=V+C(C(w[ma>>2]-g|0,e&64?2:1),e&1?2:1);s=g+16|0;g=0;e=g+(m^-1)|0;r=s+(h^-1)|0;e=CV(e,e>>>0<g>>>0?r+1|0:r,da,_)+1|0;break Id}if(!p&(r|0)<=0|(r|0)<0){break Kd}if(e>>>0<2|l>>>0<s>>>0){break Jd}l=s+(h^-1)|0;r=0;e=r+(m^-1)|0;e=CV(e,e>>>0<r>>>0?l+1|0:l,da,_)+1|0;break Id}if((r|0)>0|(r|0)>=0){break Jd}}if((g|0)<=(l|0)){break Id}l=g;r=-1;g=r+m|0;e=(l^-1)+h|0;e=CV(g,g>>>0<r>>>0?e+1|0:e,da,_)+1|0;break Id}if((l|0)<(B|0)){break Id}s=B+(h^-1)|0;r=0;e=r+(m^-1)|0;e=CV(e,e>>>0<r>>>0?s+1|0:s,da,_)+1|0}Ld:{if(!k){break Ld}Md:{if(!e){k=1;break Md}if(e>>>0<=k>>>0){break Ld}}e=k}if((e|0)<=0){break Bd}Nd:{Od:{if(Fa>>>0<z[a+24608>>2]){t=4;if(F){break Od}t=0;if(w[O>>2]|w[qa>>2]){break Od}}g=m;m=BV(q,o,e,0);g=g+m|0;l=nb+h|0;w[i>>2]=g;w[i+4>>2]=g>>>0<m>>>0?l+1|0:l;w[ha>>2]=0;w[ia>>2]=0;h=(e<<3)+f|0;G=0;break Nd}h=(e<<3)+f|0;g=h-8|0;w[ia>>2]=0-w[g>>2];l=h-4|0;w[ha>>2]=0-w[l>>2];ob[w[((t|Ea)<<2)+75984>>2]](i,xa,f,e);w[ia>>2]=w[ia>>2]+w[g>>2];w[ha>>2]=w[ha>>2]+w[l>>2];F=w[ea>>2];G=1}Pd:{if(!F){break Pd}if(e>>>0>=F>>>0){w[ea>>2]=0;w[qa>>2]=w[Ma>>2];w[O>>2]=w[La>>2];w[Ka>>2]=0;w[Ja>>2]=0;if(w[Ia>>2]|!(x[K+1|0]&16)){break Pd}w[ja>>2]=0;w[aa+624>>2]=0;break Pd}w[ea>>2]=F-e}g=0;F=0;m=w[i>>2];f=w[i+4>>2];F=f>>>0>=z[ma>>2]?(x[K|0]&2)>>>1|0:F;o=f;f=w[ja>>2];g=o>>>0<f>>>0|(!f|x[K|0]&2)?g:!y[Ha>>1];j=j-e|0;e=0;Qd:{Rd:{o=w[a+1074320>>2];if(!(o&2097152)){break Rd}f=x[Ga|0];if(!f|f>>>0>y[a+480190>>1]){break Rd}q=w[ua>>2];f=C(f,104)+a|0;l=f+484380|0;e=(q|0)!=(l|0);if((l|0)==(q|0)|(g|F)!=1){break Rd}w[ua>>2]=l;w[aa+624>>2]=w[f+484400>>2];e=y[f+484414>>1];w[K>>2]=e|w[K>>2]&-768;g=e<<30>>31;e=w[f+484388>>2];w[ja>>2]=g&e;l=w[f+484384>>2];w[va>>2]=l;w[ma>>2]=e;w[i>>2]=m;w[i+4>>2]=l;bs(T,i);if(!w[aa+624>>2]|(j|0)<=0){break zd}break Qd}if(!(w[va>>2]|(!(o&524288)|(!F|e)))){w[i>>2]=m;w[i+4>>2]=0;e=w[w[ua>>2]+8>>2];w[ja>>2]=e;w[ma>>2]=e}if((j|0)<=0){break zd}}F=w[ea>>2];e=F?j>>>0>F>>>0?F:j:j;if(!e){break Ad}da=w[va>>2];t=w[K>>2];g=da&t<<30>>31;k=!(t&2);f=h;q=w[H>>2];o=w[H+4>>2];if(q|o){continue}break}break Ad}j=n}h=f}w[aa+624>>2]=0;w[ja>>2]=0;w[i>>2]=0;w[i+4>>2]=0;w[ea>>2]=0;g=0;e=w[i+96>>2];f=w[i+92>>2];if(e|f){if(j){while(1){l=(g<<3)+h|0;f=f-(((-2147483648-f>>>31|0)-1&255)+f>>8)|0;w[l>>2]=f+w[l>>2];e=e-(((-2147483648-e>>>31|0)-1&255)+e>>8)|0;w[l+4>>2]=e+w[l+4>>2];g=g+1|0;if((j|0)!=(g|0)){continue}break}}w[i+96>>2]=e;w[i+92>>2]=f}w[pa>>2]=w[pa>>2]+w[ia>>2];w[oa>>2]=w[oa>>2]+w[ha>>2];w[ha>>2]=0;w[ia>>2]=0;w[K>>2]=w[K>>2]&-129}w[aa+624>>2]=w[T>>2];Sd:{if(fa|!G){break Sd}e=w[(C(ca,160)+a|0)+906140>>2];if(!e){break Sd}ob[w[w[e>>2]+144>>2]](e)}N=G+N|0;F=y[a+480212>>1]}ta=ta+1|0;if(ta>>>0<(F&65535)>>>0){continue}break}}e=y[a+480214>>1];f=N&65535;v[a+480214>>1]=e>>>0>f>>>0?e:f}jb=T+16|0;r=w[a+1304392>>2];if(r){j=la;e=(C(w[a+480232>>2],w[a+480236>>2])>>>0)/48|0;l=jb-16|0;jb=l;f=n;if(!(!x[r+530|0]|!f)){e=BV(e,0,6169,0);p=(nb&65535)<<16|e>>>16;while(1){i=w[r>>2];F=w[i>>2];e=w[i+4>>2];if((F|0)<=(e|0)){while(1){w[i+8>>2]=w[i+12>>2];F=0;k=0;t=0;e=jb-16|0;jb=e;while(1){h=i+C(t,44)|0;Td:{if(!x[h+56|0]){v[e+12>>1]=0;v[e+14>>1]=0;break Td}m=w[h+32>>2];g=y[m+3840>>1];if(g&3){m=(y[h+36>>1]>>>7&7)>>>(x[m+3844|0]^1)>>>(g&1)<<y[h+38>>1];g=g&4?0-m|0:m}else{g=0}m=w[h+52>>2];Ud:{if(m){s=y[h+48>>1];B=y[m+32>>1];m=fd(w[h+16>>2],w[h+40>>2],g<<16>>16,0,v[h+46>>1]);o=w[h+40>>2];q=w[h+20>>2];if(!B){if(!s){g=g<<16>>16;m=fd(q,o,g,m,0);m=fd(w[h+24>>2],w[h+40>>2],g,m,0);g=fd(w[h+28>>2],w[h+40>>2],g,m,0);break Ud}g=g<<16>>16;o=fd(q,o,g,0,0);o=fd(w[h+24>>2],w[h+40>>2],g,o,0);g=fd(w[h+28>>2],w[h+40>>2],g,o,0)+m|0;break Ud}if(!s){g=g<<16>>16;m=fd(q,o,g,m,0);o=fd(w[h+24>>2],w[h+40>>2],g,0,0);g=fd(w[h+28>>2],w[h+40>>2],g,o,0)+m|0;break Ud}g=g<<16>>16;o=fd(q,o,g,0,0);g=(fd(w[h+24>>2],w[h+40>>2],g,o,0)+m|0)+fd(w[h+28>>2],w[h+40>>2],g,0,0)|0;break Ud}s=y[h+48>>1];g=g<<16>>16;m=fd(w[h+16>>2],w[h+40>>2],g,0,v[h+46>>1]);o=w[h+40>>2];q=w[h+20>>2];if(!s){g=fd(q,o,g,m,0);break Ud}g=fd(q,o,g,0,0)+m|0}v[e+14>>1]=x[h+57|0]?g:0;v[e+12>>1]=x[h+58|0]?g:0}F=v[e+12>>1]+F|0;k=v[e+14>>1]+k|0;t=t+1|0;if((t|0)!=18){continue}break}g=(k|0)>=32767?32767:k;v[i+12>>1]=(g|0)<=-32768?-32768:g;g=(F|0)>=32767?32767:F;v[i+14>>1]=(g|0)<=-32768?-32768:g;v[i+3832>>1]=y[i+3832>>1]+1;g=(y[i+3834>>1]+1>>>0)%13440|0;v[i+3834>>1]=g;g=g>>>0<6720?g:13440-g|0;v[i+3836>>1]=g>>>8;if(!x[i+3843|0]){v[i+3836>>1]=g>>>10}g=y[i+3838>>1]+1|0;v[i+3838>>1]=g;if((g&65535)>>>0>=1024){v[i+3838>>1]=0;v[i+3840>>1]=y[i+3840>>1]+1&7}jb=e+16|0;F=w[i>>2];e=w[i+4>>2]-F|0;w[i+4>>2]=e;if((e|0)>=(F|0)){continue}break}}g=F-e|0;v[l+14>>1]=(C(v[i+12>>1],e)+C(g,v[i+8>>1])|0)/(F|0);v[l+12>>1]=(C(v[i+14>>1],e)+C(g,v[i+10>>1])|0)/(F|0);w[i+4>>2]=e+49716;w[j>>2]=w[j>>2]+C(p,v[l+14>>1]);w[j+4>>2]=w[j+4>>2]+C(p,v[l+12>>1]);j=j+8|0;f=f-1|0;if(f){continue}break}}jb=l+16|0}e=w[J+4116>>2];if(e|w[J+4120>>2]){if(!e){vg(J+8|0,n,J+4104|0,J+4108|0)}e=w[J>>2];f=w[J+4184>>2];g=C(e,f)>>>4|0;g=g>>>0>=32767?32767:g;v[J+4202>>1]=g;v[J+4200>>1]=g;h=w[J+54052>>2];g=C(h,e)>>>4|0;g=g>>>0>=65536?65536:g;j=g+127>>>3|0;v[J+54050>>1]=j;g=g+255>>>4|0;v[J+54048>>1]=g;v[J+54046>>1]=g;v[J+54044>>1]=j;g=J+8|0;f=(f|0)>(h|0)?f:h;e=36-e>>>1|0;e=16-(e>>>0<=8?8:e)|0;e=16-(C((f|0)>=32768?32768:f,e>>>0<=16?e:0)>>15)|0;f=0;if(n){while(1){h=f<<3;j=h+la|0;w[j>>2]=w[j>>2]+C(e,w[g+h>>2]>>4);h=h|4;j=h+la|0;w[j>>2]=w[j>>2]+C(e,w[g+h>>2]>>4);f=f+1|0;if((n|0)!=(f|0)){continue}break}}f=0;e=w[J+4144>>2];j=w[J+4140>>2];if(n){i=v[J+4188>>1];while(1){h=(f<<3)+g|0;l=w[h>>2]>>12;j=(C(i,l-j|0)>>15)+l|0;w[h>>2]=j;o=h;h=w[h+4>>2]>>12;e=(C(i,h-e|0)>>15)+h|0;w[o+4>>2]=e;f=f+1|0;if((n|0)!=(f|0)){continue}break}}o=J+4172|0;w[J+4144>>2]=e;w[J+4140>>2]=j;Vd:{if(!n){F=w[o>>2];break Vd}f=g;l=y[o+22>>1];k=y[o+20>>1];F=w[o+4>>2];e=n;if(e){h=v[o+26>>1];j=v[o+24>>1];r=v[o+18>>1];p=v[o+16>>1];t=w[o>>2]-1|0;i=o+(F<<2)|0;m=y[i+32930>>1];i=y[i+32928>>1];while(1){q=w[f>>2];F=F+1&127;s=o+(F<<2)|0;G=l<<16>>16;l=w[f+4>>2];l=(l|0)>=32767?32767:l;l=(l|0)<=-32768?-32768:l;B=G-l|0;B=(B|0)>=32767?32767:B;B=(C(r,(B|0)<=-32768?-32768:B)|0)/65536<<1;B=(B|0)>=32767?32767:B;l=((B|0)<=-32768?-32768:B)+l|0;l=(l|0)>=32767?32767:l;l=(l|0)<=-32768?-32768:l;B=m<<16>>16;m=l+((C(B,h)|0)/-65536|0)|0;m=(m|0)>=32767?32767:m;m=(m|0)<=-32768?-32768:m;v[s+32930>>1]=m;q=(q|0)>=32767?32767:q;q=(q|0)<=-32768?-32768:q;k=(k<<16>>16)-q|0;k=(k|0)>=32767?32767:k;k=(C(p,(k|0)<=-32768?-32768:k)|0)/65536<<1;k=(k|0)>=32767?32767:k;q=((k|0)<=-32768?-32768:k)+q|0;q=(q|0)>=32767?32767:q;k=(q|0)<=-32768?-32768:q;q=i<<16>>16;i=k+((C(q,j)|0)/-65536|0)|0;i=(i|0)>=32767?32767:i;i=(i|0)<=-32768?-32768:i;v[s+32928>>1]=i;t=t+1&8191;s=o+(t<<2)|0;B=B+((C(h,m)|0)/65536<<16>>16)|0;B=(B|0)>=32767?32767:B;v[s+162>>1]=(B|0)<=-32768?-32768:B;q=q+((C(i,j)|0)/65536<<16>>16)|0;q=(q|0)>=32767?32767:q;v[s+160>>1]=(q|0)<=-32768?-32768:q;f=f+8|0;e=e-1|0;if(e){continue}break}}j=J+53996|0;v[o+22>>1]=l;v[o+20>>1]=k;w[o+4>>2]=F;l=w[J+4180>>2];ba=J+37612|0;f=g;e=n;while(1){h=l&4095;q=ba+(h<<2)|0;F=f;h=4096-h|0;W=l-w[J+53996>>2]&4095;i=4096-W|0;h=h>>>0<i>>>0?h:i;h=e>>>0<h>>>0?e:h;h=h>>>0>=64?64:h;k=h;l=0;r=jb-32|0;i=w[o>>2];while(1){w[r+(l<<2)>>2]=i+(w[(o+(l<<4)|0)+32>>2]^-1);l=l+1|0;if((l|0)!=7){continue}break}if(k){s=v[o+28>>1]/8<<16>>16;while(1){m=0;i=0;l=0;while(1){p=r+(l<<2)|0;B=w[p>>2]+1&8191;w[p>>2]=B;H=i;i=o+(B<<2)|0;B=v[i+160>>1];p=o+(l<<4)|0;G=v[i+162>>1];i=(H+C(B,v[p+44>>1])|0)+C(G,v[p+46>>1])|0;m=(C(B,v[p+40>>1])+m|0)+C(G,v[p+42>>1])|0;l=l+1|0;if((l|0)!=4){continue}break}i=(i|0)/32768|0;B=(i|0)>=32767?32767:i;i=(m|0)/32768|0;G=(i|0)>=32767?32767:i;m=0;l=4;i=0;while(1){p=r+(l<<2)|0;L=w[p>>2]+1&8191;w[p>>2]=L;H=i;i=o+(L<<2)|0;L=v[i+160>>1];p=o+(l<<4)|0;X=v[i+162>>1];i=(H+C(L,v[p+44>>1])|0)+C(X,v[p+46>>1])|0;m=(C(L,v[p+40>>1])+m|0)+C(X,v[p+42>>1])|0;l=l+1|0;if((l|0)!=7){continue}break}l=((m|0)/32768|0)+((G|0)<=-32768?-32768:G)|0;l=(l|0)>=32767?32767:l;l=(l|0)<=-32768?-32768:l;v[q>>1]=l;w[F>>2]=C(l,s);i=((i|0)/32768|0)+((B|0)<=-32768?-32768:B)|0;i=(i|0)>=32767?32767:i;i=(i|0)<=-32768?-32768:i;v[q+2>>1]=i;w[F+4>>2]=C(i,s);F=F+8|0;q=q+4|0;k=k-1|0;if(k){continue}break}}q=ba+(W<<2)|0;l=f;i=w[j+4>>2];k=i&2047;m=h;if(h){t=y[j+36>>1];aa=v[j+52>>1];ha=v[j+44>>1];ia=v[j+28>>1];r=y[j+38>>1];s=y[j+34>>1];G=y[j+32>>1];ja=v[j+54>>1];ka=v[j+50>>1];ea=v[j+48>>1];ma=v[j+46>>1];da=v[j+42>>1];oa=v[j+40>>1];F=v[j+10>>1];p=v[j+8>>1];pa=v[j+22>>1];ua=v[j+16>>1];ta=v[j+30>>1];va=v[j+26>>1];ya=v[j+24>>1];B=j+24640|0;L=j- -64|0;W=j+8256|0;X=j+16448|0;while(1){I=B+((i+502&2047)<<2)|0;Y=v[I+2>>1];H=B+((i+22&2047)<<2)|0;_=v[H>>1];V=v[W+((i+1206&2047)<<2)>>1];K=v[(W+((i+754&2047)<<2)|0)+2>>1];T=v[L+((i+1750&2047)<<2)>>1];N=v[I>>1];ca=v[q>>1];I=k<<2;O=I+L|0;fa=r<<16>>16;r=v[H+2>>1];H=fa-r|0;H=(H|0)>=32767?32767:H;H=(C(ta,(H|0)<=-32768?-32768:H)|0)/65536<<1;H=(H|0)>=32767?32767:H;r=((H|0)<=-32768?-32768:H)+r|0;r=(r|0)>=32767?32767:r;r=(r|0)<=-32768?-32768:r;H=(C(pa,r)|0)/32768|0;H=(v[q+2>>1]/4<<16>>16)+((H|0)>=32767?32767:H)|0;H=(H|0)>=32767?32767:H;sa=(H|0)<=-32768?-32768:H;qa=v[(L+((i+1602&2047)<<2)|0)+2>>1];H=sa+((C(qa,F)|0)/-65536|0)|0;H=(H|0)>=32767?32767:H;H=(H|0)<=-32768?-32768:H;v[O+2>>1]=H;G=(G<<16>>16)-N|0;G=(G|0)>=32767?32767:G;G=(C(ya,(G|0)<=-32768?-32768:G)|0)/65536<<1;G=(G|0)>=32767?32767:G;G=N+((G|0)<=-32768?-32768:G)|0;G=(G|0)>=32767?32767:G;G=(G|0)<=-32768?-32768:G;N=(C(ua,G)|0)/32768|0;N=((ca|0)/4<<16>>16)+((N|0)>=32767?32767:N)|0;N=(N|0)>=32767?32767:N;ca=(N|0)<=-32768?-32768:N;N=ca+((C(p,T)|0)/-65536|0)|0;N=(N|0)>=32767?32767:N;N=(N|0)<=-32768?-32768:N;v[O>>1]=N;O=I+X|0;H=qa+((C(F,H)|0)/65536<<16>>16)|0;H=(H|0)>=32767?32767:H;qa=(H|0)<=-32768?-32768:H;v[O+2>>1]=qa;H=O;T=T+((C(p,N)|0)/65536<<16>>16)|0;T=(T|0)>=32767?32767:T;O=(T|0)<=-32768?-32768:T;v[H>>1]=O;N=X+((i+682&2047)<<2)|0;T=v[N+2>>1];N=v[N>>1];H=I+W|0;i=X+((i+426&2047)<<2)|0;wa=v[i+2>>1];xa=v[i>>1];i=(C(wa,ma)+C(xa,ha)|0)/32768|0;i=(i|0)>=32767?32767:i;i=(i|0)<=-32768?-32768:i;$=i+((C(F,K)|0)/-65536|0)|0;$=($|0)>=32767?32767:$;$=($|0)<=-32768?-32768:$;v[H+2>>1]=$;fa=H;H=(C(T,da)+C(N,oa)|0)/32768|0;H=(H|0)>=32767?32767:H;H=(H|0)<=-32768?-32768:H;na=H+((C(p,V)|0)/-65536|0)|0;na=(na|0)>=32767?32767:na;na=(na|0)<=-32768?-32768:na;v[fa>>1]=na;I=B+I|0;fa=K;K=(C(F,$)|0)/65536<<16>>16;$=fa+K|0;$=($|0)>=32767?32767:$;$=($|0)<=-32768?-32768:$;v[I+2>>1]=$;fa=I;I=(C(p,na)|0)/65536<<16>>16;V=I+V|0;V=(V|0)>=32767?32767:V;V=(V|0)<=-32768?-32768:V;v[fa>>1]=V;ca=O+ca|0;ca=(ca|0)>=32767?32767:ca;ca=(ca|0)<=-32768?-32768:ca;O=ca+xa|0;O=(O|0)>=32767?32767:O;O=((O|0)<=-32768?-32768:O)-H|0;O=(O|0)>=32767?32767:O;I=I+((O|0)<=-32768?-32768:O)|0;I=(I|0)>=32767?32767:I;fa=w[l+4>>2]+C(aa,(I|0)<=-32768?-32768:I)|0;I=qa+sa|0;I=(I|0)>=32767?32767:I;I=(I|0)<=-32768?-32768:I;O=I+wa|0;O=(O|0)>=32767?32767:O;O=((O|0)<=-32768?-32768:O)-i|0;O=(O|0)>=32767?32767:O;K=K+((O|0)<=-32768?-32768:O)|0;K=(K|0)>=32767?32767:K;w[l+4>>2]=fa+C(ja,(K|0)<=-32768?-32768:K);K=N+ca|0;K=(K|0)>=32767?32767:K;K=((K|0)<=-32768?-32768:K)-H|0;K=(K|0)>=32767?32767:K;V=V+((K|0)<=-32768?-32768:K)|0;V=(V|0)>=32767?32767:V;I=I+T|0;I=(I|0)>=32767?32767:I;i=((I|0)<=-32768?-32768:I)-i|0;i=(i|0)>=32767?32767:i;i=$+((i|0)<=-32768?-32768:i)|0;i=(i|0)>=32767?32767:i;w[l>>2]=(w[l>>2]+C(ea,(V|0)<=-32768?-32768:V)|0)+C(ka,(i|0)<=-32768?-32768:i);i=(t<<16>>16)-_|0;i=(i|0)>=32767?32767:i;i=(C(ia,(i|0)<=-32768?-32768:i)|0)/65536<<1;i=(i|0)>=32767?32767:i;i=_+((i|0)<=-32768?-32768:i)|0;i=(i|0)>=32767?32767:i;t=(i|0)<=-32768?-32768:i;i=(s<<16>>16)-Y|0;i=(i|0)>=32767?32767:i;i=(C(va,(i|0)<=-32768?-32768:i)|0)/65536<<1;i=(i|0)>=32767?32767:i;i=Y+((i|0)<=-32768?-32768:i)|0;i=(i|0)>=32767?32767:i;s=(i|0)<=-32768?-32768:i;l=l+8|0;q=q+4|0;i=k+1|0;k=i&2047;m=m-1|0;if(m){continue}break}v[j+38>>1]=r;v[j+36>>1]=t;v[j+34>>1]=s;v[j+32>>1]=G}w[j+4>>2]=k;l=h+w[J+4180>>2]&4095;w[J+4180>>2]=l;F=h+w[J+4172>>2]&8191;w[J+4172>>2]=F;f=(h<<3)+f|0;e=e-h|0;if(e){continue}break}}w[J+4172>>2]=F&8191;f=la;e=0;l=0;k=w[J+4160>>2];m=w[J+4156>>2];h=n;if(h){F=w[J+4164>>2];l=w[J+4168>>2];while(1){e=w[g>>2];j=l;l=w[g+4>>2];j=j-l|0;j=(((j|0)/1024|0)-j|0)+k|0;w[f+4>>2]=j+w[f+4>>2];i=F-e|0;i=(((i|0)/1024|0)-i|0)+m|0;w[f>>2]=i+w[f>>2];k=j+((j|0)/-512|0)|0;m=i+((i|0)/-512|0)|0;f=f+8|0;g=g+8|0;F=e;h=h-1|0;if(h){continue}break}}w[J+4168>>2]=l;w[J+4164>>2]=e;w[J+4160>>2]=k;w[J+4156>>2]=m;e=w[J+4124>>2];Wd:{if(w[J+4116>>2]){break Wd}e=w[J+4120>>2];if(e>>>0>n>>>0){e=e-n|0;break Wd}v[J+4128>>1]=0;w[J+4104>>2]=0;w[J+4108>>2]=0;Cb(J+4132|0,0,40);Cb(J+4332|0,0,49664);Cb(J+54060|0,0,32768);e=0}w[J+4116>>2]=0;w[J+4120>>2]=e}if(w[a+946300>>2]){m=0;r=0;h=n<<2;q=y[a+480214>>1]!=0;Ba=A[a+1074336>>2];Z=A[a+1074332>>2];while(1){j=C(m,160)+a|0;e=w[j+906300>>2];Xd:{if(!e|!w[e+24>>2]|(0-(w[e+60>>2]-w[e+56>>2]>>11)|0)==w[e+48>>2]-w[e+44>>2]>>11){break Xd}if(!(ob[w[w[e>>2]+108>>2]](e)|0)){ob[w[w[e>>2]+104>>2]](e,1);ob[w[w[e>>2]+116>>2]](e)}f=w[e+44>>2];g=f+2048|0;Yd:{if(u[e+28|0]&1){Gk(w[e+24>>2],f,g,n,Z);break Yd}i=e+40|0;if(w[i>>2]|w[e+36>>2]){vg(w[e+24>>2],n,i,e+36|0);Gk(w[e+24>>2],f,g,n,Z);break Yd}Cb(f,0,h);Cb(g,0,h)}f=e;e=w[e+28>>2];w[f+28>>2]=e&-2;if(u[j+906324|0]&1){break Xd}q=!(e&4)|q}m=m+1|0;if((m|0)!=250){continue}break}i=a+12|0;l=a+12300|0;o=a+14348|0;Gk(i,l,o,n,Z);e=a+1074464|0;W=x[e|0];u[e|0]=0;e=l;f=o;while(1){s=C(r,160)+a|0;B=s+906300|0;h=w[B>>2];Zd:{if(!h|!w[h+24>>2]|(0-(w[h+60>>2]-w[h+56>>2]>>11)|0)==w[h+48>>2]-w[h+44>>2]>>11){break Zd}F=h;_d:{k=s+906324|0;if(u[k|0]&1){break _d}g=ob[w[w[h>>2]+140>>2]](h)|0;F=w[B>>2];if(g|x[F+28|0]&2){break _d}m=0;if(!r){break Zd}while(1){g=w[(C(m,160)+a|0)+906328>>2];if(((g>>>0<=127?255:g&255^128)|0)==(r|0)){break _d}m=m+1|0;if((m|0)!=(r|0)){continue}break}break Zd}p=w[h+44>>2];G=(p|0)==(e|0);e=G?l:e;j=e;f=G?o:f;g=f;X=s+906328|0;m=w[X>>2];$d:{if(!m){break $d}j=e;g=f;m=(m>>>0<=127?-1:m^-128)&255;if(m>>>0<=r>>>0|m>>>0>249){break $d}m=w[(C(m,160)+a|0)+906300>>2];if(!m){break $d}if(!(x[F+28|0]&4)){ob[w[w[m>>2]+144>>2]](m)}j=w[m+44>>2];m=(0-(w[m+60>>2]-w[m+56>>2]>>11)|0)==w[m+48>>2]-j>>11;g=m?f:j+2048|0;j=m?e:j}L=p+2048|0;ae:{if(!(u[k|0]&1)){break ae}be:{if(G){break be}m=0;if(!n){break be}while(1){s=m<<2;G=s+p|0;H=G;Z=A[G>>2];G=e+s|0;A[H>>2]=Z+A[G>>2];I=s+L|0;s=f+s|0;A[I>>2]=A[I>>2]+A[s>>2];w[G>>2]=0;w[s>>2]=0;m=m+1|0;if((n|0)!=(m|0)){continue}break}}f=g;e=j;if(!(q&1)){break ae}f=w[B>>2];if(f){ob[w[w[f>>2]+144>>2]](f)}f=g;s=w[X>>2];m=s^-128;s=(s>>>0<=127?-1:m)&255;if(s>>>0>249|s>>>0<=r>>>0){break ae}while(1){f=m&255;e=C(f,160)+a|0;s=w[e+906328>>2];m=s^-128;s=s>>>0<=127?-1:m;e=w[e+906300>>2];if(e){ob[w[w[e>>2]+144>>2]](e)}e=s&255;if(e>>>0<=249&e>>>0>f>>>0){continue}break}f=g;e=j}m=x[k|0];ce:{if(!(!(m&2)&(!(m&16)|!(x[F+28|0]&4)))){m=0;if(!n){break ce}while(1){h=m<<2;k=h+j|0;A[k>>2]=A[k>>2]+A[h+p>>2];k=g+h|0;A[k>>2]=A[k>>2]+A[h+L>>2];m=m+1|0;if((n|0)!=(m|0)){continue}break}break ce}if(W){ob[w[w[h>>2]+124>>2]](h)}ob[w[w[h>>2]+60>>2]](h,j,g,n);w[F+32>>2]=n+w[F+32>>2];if(!(x[k|0]&16)){break ce}if((ob[w[w[h>>2]+152>>2]](h)|0)<=0|z[F+32>>2]<w[a+24620>>2]<<2>>>0){break ce}h=0;de:{if(!n){break de}while(1){ee:{m=h<<2;Z=A[m+j>>2];if(Z>=D(1.1920928955078125e-7)|Z<=D(-1.1920928955078125e-7)){break ee}Z=A[g+m>>2];if(Z>=D(1.1920928955078125e-7)|!(Z>D(-1.1920928955078125e-7))){break ee}h=h+1|0;if((n|0)!=(h|0)){continue}break de}break}w[F+32>>2]=0;break ce}w[F+28>>2]=w[F+28>>2]|4}w[F+28>>2]=w[F+28>>2]&-3}r=r+1|0;if((r|0)!=250){continue}break}g=0;if(n){while(1){Z=D(A[e>>2]*Ba);fe:{if(D(E(Z))<D(2147483648)){h=~~Z;break fe}h=-2147483648}w[i>>2]=h;Z=D(A[f>>2]*Ba);ge:{if(D(E(Z))<D(2147483648)){h=~~Z;break ge}h=-2147483648}w[i+4>>2]=h;i=i+8|0;f=f+4|0;e=e+4|0;g=g+1|0;if((n|0)!=(g|0)){continue}break}}}if(w[a+24624>>2]==1){f=0;if(n){while(1){e=(f<<3)+la|0;w[(f<<2)+la>>2]=(w[e+4>>2]+w[e>>2]|0)/2;f=f+1|0;if((n|0)!=(f|0)){continue}break}}}if(x[a+1074368|0]){he:{ie:{je:{if(!w[a+1074376>>2]){F=a+1074448|0;e=F;w[e>>2]=0;w[e+4>>2]=0;w[a+1074456>>2]=w[a+1074444>>2];break je}g=w[a+1074456>>2];e=w[a+1074444>>2];ke:{if((g|0)==(e|0)){f=w[a+1074448>>2];break ke}w[a+1074456>>2]=e;f=a+24604|0;h=a+1074448|0;le:{if((e|0)>(g|0)){f=Lo(f);break le}f=Ko(f)}w[h>>2]=f;w[a+1074452>>2]=f}F=a+1074448|0;if((f|0)>0){break ie}}l=0;break he}g=(w[a+1074456>>2]<<12)-w[a+1074460>>2]|0;l=(g|0)/(f|0)|0;if(w[a+1074372>>2]!=2){break he}e=l>>31;o=(e^l)-e|0;h=w[a+1074452>>2];e=1e4/(h+1|0)|0;j=(e|0)<=50?50:e;if(o>>>0<=j>>>0){break he}while(1){f=f+h|0;l=(g|0)/(f|0)|0;e=l>>31;if(j>>>0<(e^l)-e>>>0){continue}break}w[F>>2]=f}me:{ne:{switch(w[a+24624>>2]-1|0){case 0:if((n|0)<=0){break me}f=a+12|0;e=w[a+1074444>>2];j=e<<12;i=e>>31;h=0;while(1){oe:{if(w[F>>2]>0){g=w[a+1074460>>2]+l|0;w[a+1074460>>2]=g;m=w[f>>2];m=CV(BV(m,m>>31,g,g>>31),nb,1048576,0);o=m;g=nb;m=(g|0)>=0&m>>>0>=2147483647|(g|0)>0;o=m?2147483647:o;g=m?0:g;w[f>>2]=(g|0)<0&o>>>0<=2147483648|(g|0)<-1?-2147483648:o;w[a+1074448>>2]=w[a+1074448>>2]-1;break oe}g=w[f>>2];m=CV(BV(g,g>>31,e,i),nb,256,0);o=m;g=nb;m=(g|0)>=0&m>>>0>=2147483647|(g|0)>0;o=m?2147483647:o;g=m?0:g;w[f>>2]=(g|0)<0&o>>>0<=2147483648|(g|0)<-1?-2147483648:o;w[a+1074460>>2]=j}f=f+4|0;h=h+1|0;if((n|0)!=(h|0)){continue}break};break me;case 1:if((n|0)<=0){break me}f=a+12|0;e=w[a+1074444>>2];i=e<<12;g=e>>31;h=0;while(1){pe:{if(w[F>>2]>0){j=w[a+1074460>>2]+l|0;w[a+1074460>>2]=j;m=w[f>>2];m=CV(BV(m,m>>31,j,j>>31),nb,1048576,0);o=m;j=nb;m=(j|0)>=0&m>>>0>=2147483647|(j|0)>0;o=m?2147483647:o;j=m?0:j;w[f>>2]=(j|0)<0&o>>>0<=2147483648|(j|0)<-1?-2147483648:o;j=w[a+1074460>>2];o=j;m=j>>31;j=w[f+4>>2];m=CV(BV(o,m,j,j>>31),nb,1048576,0);o=m;j=nb;m=(j|0)>=0&m>>>0>=2147483647|(j|0)>0;o=m?2147483647:o;j=m?0:j;w[f+4>>2]=(j|0)<0&o>>>0<=2147483648|(j|0)<-1?-2147483648:o;w[a+1074448>>2]=w[a+1074448>>2]-1;break pe}j=w[f>>2];m=CV(BV(j,j>>31,e,g),nb,256,0);o=m;j=nb;m=(j|0)>=0&m>>>0>=2147483647|(j|0)>0;o=m?2147483647:o;j=m?0:j;w[f>>2]=(j|0)<0&o>>>0<=2147483648|(j|0)<-1?-2147483648:o;j=w[f+4>>2];m=CV(BV(j,j>>31,e,g),nb,256,0);o=m;j=nb;m=(j|0)>=0&m>>>0>=2147483647|(j|0)>0;o=m?2147483647:o;j=m?0:j;w[f+4>>2]=(j|0)<0&o>>>0<=2147483648|(j|0)<-1?-2147483648:o;w[a+1074460>>2]=i}f=f+8|0;h=h+1|0;if((n|0)!=(h|0)){continue}break};break me;case 3:break ne;default:break me}}if((n|0)<=0){break me}f=a+12|0;h=a+8204|0;e=w[a+1074444>>2];m=e<<12;g=e>>31;j=0;while(1){qe:{if(w[F>>2]>0){i=w[a+1074460>>2]+l|0;w[a+1074460>>2]=i;o=w[f>>2];o=CV(BV(o,o>>31,i,i>>31),nb,1048576,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[f>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[a+1074460>>2];o=i;r=i>>31;i=w[f+4>>2];o=CV(BV(o,r,i,i>>31),nb,1048576,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[f+4>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[a+1074460>>2];o=i;r=i>>31;i=w[h>>2];o=CV(BV(o,r,i,i>>31),nb,1048576,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[h>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[a+1074460>>2];o=i;r=i>>31;i=w[h+4>>2];o=CV(BV(o,r,i,i>>31),nb,1048576,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[h+4>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;w[a+1074448>>2]=w[a+1074448>>2]-1;break qe}i=w[f>>2];o=CV(BV(i,i>>31,e,g),nb,256,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[f>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[f+4>>2];o=CV(BV(i,i>>31,e,g),nb,256,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[f+4>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[h>>2];o=CV(BV(i,i>>31,e,g),nb,256,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[h>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;i=w[h+4>>2];o=CV(BV(i,i>>31,e,g),nb,256,0);r=o;i=nb;o=(i|0)>=0&o>>>0>=2147483647|(i|0)>0;q=o?2147483647:r;i=o?0:i;w[h+4>>2]=(i|0)<0&q>>>0<=2147483648|(i|0)<-1?-2147483648:q;w[a+1074460>>2]=m}h=h+8|0;f=f+8|0;j=j+1|0;if((n|0)!=(j|0)){continue}break}}}if(w[a+24604>>2]!=128){re:{f=w[a+24624>>2];if(f>>>0<2){break re}e=w[a+24604>>2];if((e|0)==128){break re}zw(a+12|0,n,e);if(f>>>0<4){break re}zw(a+8204|0,n,e)}}e=w[a+24624>>2];if((e|0)==4){e=n-1|0;if((e|0)>=0){while(1){f=e;g=(e<<4)+la|0;h=e<<3;j=h|4;w[g+12>>2]=w[j+za>>2];w[g+8>>2]=w[h+za>>2];w[g+4>>2]=w[j+la>>2];w[g>>2]=w[h+la>>2];e=e-1|0;if(f){continue}break}}e=w[a+24624>>2]}ob[w[w[c>>2]+8>>2]](c,la,e,n);e=w[a+1074380>>2]-n|0;w[a+1074380>>2]=e;w[a+1074376>>2]=n+w[a+1074376>>2];Ca=n+Ca|0;f=w[a+480208>>2];if(f&512){break h}b=b-n|0;if(b){continue}break}}jb=ra+16|0;return Ca}function BD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0;d=jb-752|0;jb=d;w[b+8>>2]=0;f=jb-16|0;jb=f;h=w[b+8>>2];g=w[b>>2];i=d+528|0;w[f+8>>2]=i;w[f+12>>2]=i+192;h=ob[w[w[g>>2]+32>>2]](g,h,f+8|0)|0;if((h|0)==192){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],192)|0){g=w[b+8>>2]+192|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{if((h|0)!=192){break b}if(!Up(d+528|0)){break b}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],y[d+560>>1]+(y[d+566>>1]+(y[d+564>>1]+y[d+562>>1]|0)<<2)|0)|0)){break b}if(!c){e=1;break b}tc(a,32);u[d+527|0]=0;w[d+520>>2]=0;w[d+512>>2]=0;w[d+516>>2]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(w[d+528>>2]==778924148){w[114256]=0;T(346,a|0,16777216);e=w[114256];w[114256]=0;if((e|0)==1){break g}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}e=e-4|0;n:{if(e>>>0>z[b+8>>2]){f=w[b>>2];n=w[w[f>>2]+24>>2];w[114256]=0;f=V(n|0,f|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break g}if(e>>>0>f>>>0){break n}}w[b+8>>2]=e}w[114256]=0;e=Q(232,b|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}n=e?w[d+272>>2]:0;break m}o:{p:{q:{r:{s:{t:{if((y[d+568>>1]-2185&65535)>>>0>1910){break t}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}e=e-4|0;u:{if(e>>>0>z[b+8>>2]){f=w[b>>2];n=w[w[f>>2]+24>>2];w[114256]=0;f=V(n|0,f|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break g}if(e>>>0>f>>>0){break u}}w[b+8>>2]=e}w[114256]=0;e=Q(232,b|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}n=w[d+272>>2];e=e?n:0;if(e>>>0<256){n=e;break t}f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break g}if(e>>>0>=f>>>0){break t}if(e>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break g}if(e>>>0>f>>>0){break t}}w[b+8>>2]=e;w[114256]=0;e=S(343,b|0,10260,3)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(!e){break t}w[114256]=0;T(346,a|0,16777216);e=w[114256];w[114256]=0;if((e|0)==1){break g}e=y[d+568>>1];if(e>>>0>=4096){w[114256]=0;c=Q(347,d+272|0,12279)|0;b=w[114256];w[114256]=0;v:{if((b|0)!=1){w[114256]=0;T(348,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break v}if(u[c+11|0]<0){zb(w[c>>2])}e=0;break c}b=P()|0;break d}b=P()|0;if(u[c+11|0]>=0){break d}zb(w[c>>2]);break d}if(e>>>0<2194){break t}w[114256]=0;e=Q(347,d+496|0,11831)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}w[114256]=0;T(348,a|0,e|0);f=w[114256];w[114256]=0;if((f|0)==1){break r}if(u[e+11|0]>=0){break t}zb(w[e>>2])}if(w[a+480180>>2]!=32){break m}e=y[d+568>>1];if((e&61440)!=20480){break o}f=e&4095;e=f<<16;if(w[d+588>>2]!=1414548815){break q}u[d+527|0]=1;break p}b=P()|0;break d}b=P()|0;if(u[e+11|0]>=0){break d}zb(w[e>>2]);break d}if(f>>>0<297){break p}e=y[d+588>>1]|e}w[a+1074308>>2]=e;break m}f=y[d+570>>1];if(!((f|0)!=2184&(e|0)!=2184)){u[d+527|0]=1;w[a+1074308>>2]=18284544;break m}w:{switch(e-532|0){default:if(w[d+588>>2]|((e|0)!=768|(f|0)!=768)|(y[d+560>>1]!=256|x[d+580|0]!=128)){break m}if(x[d+581|0]){break m}w[a+1074308>>2]=18285088;u[d+527|0]=1;break m;case 3:if(w[d+588>>2]|(f|0)!=512){break m}x:{if(uc(d+592|0,255,64)){w[a+1074308>>2]=18219008;w[114256]=0;f=Q(1,d+480|0,10317)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break x}b=P()|0;break d}w[a+1074308>>2]=18284544;w[114256]=0;f=Q(1,d+480|0,12632)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[f+8>>2];e=w[f+4>>2];w[d+512>>2]=w[f>>2];w[d+516>>2]=e;u[d+527|0]=1;break m;case 1:case 2:break m;case 0:break w}}if(w[d+588>>2]|(f|0)!=514){break m}w[a+1074308>>2]=17367040;w[114256]=0;e=Q(1,d+480|0,10227)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f;u[d+527|0]=1}e=y[d+572>>1];f=e>>>2|0;w[a+480208>>2]=e<<3&32768|(f&8|(f&4|(w[a+480208>>2]&-32797|e<<1&16)));w[114256]=0;Y(209,d+272|0,3,d+528|4,26);e=w[114256];w[114256]=0;if((e|0)==1){break k}e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+276>>2];w[e>>2]=w[d+272>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+280>>2];if(!(!(x[d+574|0]&4)|w[a+1074308>>2]-18285314>>>0>4276681982)){w[a+480216>>2]=x[d+558|0];w[a+480220>>2]=x[d+559|0]}e=x[d+576|0];w[a+480200>>2]=e>>>0>128?256:e<<1;e=x[d+578|0];if(e){w[a+480196>>2]=e}e=x[d+579|0];w[a+480204>>2]=C(e>>>0<=31?31:e,1e4);e=x[d+577|0];w[a+480228>>2]=e>>>0>=128?128:e;e=0;while(1){h=(d+528|0)+e|0;i=h- -64|0;y:{if(x[i|0]==255){break y}w[114256]=0;g=(e<<5)+a|0;f=g+480280|0;X(224,f|0);j=w[114256];w[114256]=0;if((j|0)==1){break j}h=x[h+128|0];v[g+480286>>1]=h>>>0>=64?64:h;h=u[i|0];if((h|0)<0){w[f>>2]=w[f>>2]|1024}h=h&127;if(h>>>0<=64){v[g+480284>>1]=h<<2;break y}if((h|0)!=100){break y}w[f>>2]=w[f>>2]|256}e=e+1|0;if((e|0)!=64){continue}break}break h}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}z:{if(z[b+8>>2]<=191){e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(e>>>0<192){break z}}w[b+8>>2]=192}if(!(w[a+480180>>2]==16777216&(y[d+568>>1]-2187&65535)>>>0<=2)){e=x[a+484376|0];f=w[a+484360>>2];w[114256]=0;da(317,f+(e<<5)|0,b|0,y[d+560>>1],255,254)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}break e}e=0;w[114256]=0;f=Q(197,b|0,d+272|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break f}if(y[d+272>>1]?f:0){break c}w[114256]=0;f=Q(232,b|0,d+272|0)|0;g=w[114256];w[114256]=0;A:{if((g|0)==1){break A}f=f?w[d+272>>2]:0;if(f>>>0>y[w[19467]+12>>1]){break c}g=x[a+484376|0];h=w[a+484360>>2];w[114256]=0;f=da(349,h+(g<<5)|0,b|0,f|0,65535,65535)|0;g=w[114256];w[114256]=0;if((g|0)==1){break A}if(!f){break c}break e}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}e=0;w[114256]=0;w[d+472>>2]=0;w[d+464>>2]=0;w[d+468>>2]=0;w[d+456>>2]=0;w[d+448>>2]=0;w[d+452>>2]=0;w[d+440>>2]=0;w[d+432>>2]=0;w[d+436>>2]=0;f=S(350,b|0,d+464|0,y[d+562>>1])|0;g=w[114256];w[114256]=0;B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((g|0)==1){break ga}if(!f){break T}w[114256]=0;f=S(350,b|0,d+448|0,y[d+564>>1])|0;g=w[114256];w[114256]=0;if((g|0)==1){break ga}if(!f){break T}w[114256]=0;f=S(350,b|0,d+432|0,y[d+566>>1])|0;g=w[114256];w[114256]=0;if((g|0)==1){break ga}if(!f){break T}e=-1;f=w[d+464>>2];h=w[d+468>>2];if((f|0)!=(h|0)){while(1){g=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);e=g?e>>>0>g>>>0?g:e:e;f=f+4|0;if((h|0)!=(f|0)){continue}break}}g=w[d+448>>2];h=w[d+452>>2];if((g|0)!=(h|0)){f=g;while(1){i=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);e=i?e>>>0>i>>>0?i:e:e;f=f+4|0;if((h|0)!=(f|0)){continue}break}}f=w[d+432>>2];j=w[d+436>>2];if((f|0)!=(j|0)){while(1){i=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);e=i?e>>>0>i>>>0?i:e:e;f=f+4|0;if((j|0)!=(f|0)){continue}break}}f=w[d+584>>2];m=e>>>0>f>>>0?f:e;f=y[d+574>>1];i=f&1?m:e;ha:{ia:{ja:{ka:{if(y[d+570>>1]!=532){break ka}e=y[d+568>>1];if(x[d+559|0]|(e?(e|0)!=532:0)|(x[d+558|0]|x[d+581|0])){break ka}if(w[d+588>>2]){break ka}j=y[d+572>>1]&192;la:{if(j){break la}ma:{if(!(y[d+562>>1]|!y[d+564>>1]|i>>>0<(w[b+8>>2]+(h-g|0)|0)+2>>>0)){f=0;na:{while(1){w[114256]=0;e=Q(232,b|0,d+272|0)|0;g=w[114256];w[114256]=0;oa:{if((g|0)!=1){if(!e|!w[d+272>>2]){break oa}e=w[b+8>>2];f=(e-((f&65535)<<2)|0)-4|0;w[b+8>>2]=e>>>0>=f>>>0?f:0;break na}b=P()|0;break B}f=f+1|0;if(y[d+564>>1]>(f&65535)>>>0){continue}break}w[114256]=0;e=Q(1,d+416|0,10461)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ea}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f}if(!y[d+568>>1]){break ma}break la}if(e){break la}}w[114256]=0;e=Q(1,d+400|0,11145)|0;f=w[114256];w[114256]=0;if((f|0)==1){break da}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f}e=y[d+574>>1];if(!(e&2)){break ia}h=!j;break ja}h=0;if(!(f&2)){break ha}}w[114256]=0;e=Q(197,b|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ca}f=y[d+272>>1];g=w[b+8>>2];j=w[b>>2];k=w[w[j>>2]+36>>2];w[114256]=0;m=g;f=e?f:0;g=f&65535;e=g<<3;j=S(k|0,j|0,m|0,e|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break ca}m=e;e=w[b+8>>2];if(!(!j|i>>>0<m+e>>>0)){w[114256]=0;T(351,a+1304500|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break ca}e=w[a+1304500>>2];g=w[a+1304504>>2];if((e|0)!=(g|0)){while(1){w[114256]=0;j=Q(352,b|0,d+272|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break ba}if(!j){w[d+272>>2]=0;w[d+276>>2]=0}w[114256]=0;T(353,d+272|0,e|0);j=w[114256];w[114256]=0;if((j|0)==1){break ba}e=e+48|0;if((g|0)!=(e|0)){continue}break}}if(!(!(f&65535)&h)){break ha}if(x[d+574|0]&4){w[114256]=0;e=Q(1,d+384|0,11178)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f;break ha}b=P()|0;break B}w[114256]=0;e=Q(1,d+384|0,10495)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f;break ha}b=P()|0;break B}f=e-2|0;w[b+8>>2]=e>>>0>=f>>>0?f:0;break ha}if(j|e>>>0>1){break ha}w[114256]=0;e=Q(197,b|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break fa}if(!(y[d+272>>1]?e:0)){w[114256]=0;e=Q(1,d+384|0,10461)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f;break ha}b=P()|0;break B}e=w[b+8>>2];f=e-2|0;w[b+8>>2]=e>>>0>=f>>>0?f:0}if(!(x[d+572|0]&128|x[d+574|0]&8)){break aa}w[114256]=0;e=a+901404|0;f=Q(354,b|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break $}if(!f){Cb(e,0,4896);break aa}w[114256]=0;X(355,e|0);e=w[114256];w[114256]=0;if((e|0)!=1){break aa}break $}b=P()|0;break B}b=P()|0;break B}b=P()|0;break B}b=P()|0;break B}b=P()|0;break B}b=P()|0;break B}if(y[d+568>>1]<=531){w[114256]=0;X(356,a+901404|0);e=w[114256];w[114256]=0;if((e|0)==1){break $}}w[114256]=0;e=V(22,16)|0;f=w[114256];w[114256]=0;if((f|0)==1){break _}w[e+4>>2]=0;w[e+8>>2]=0;w[e+12>>2]=75696;w[e>>2]=75656;w[114256]=0;w[d+376>>2]=0;w[d+380>>2]=0;w[d+372>>2]=e;w[d+368>>2]=e+12;e=S(343,b|0,9590,4)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Z}if(e){w[114256]=0;e=Q(232,b|0,d+352|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Y}w[114256]=0;U(188,d+272|0,b|0,(e?w[d+352>>2]:0)|0);e=w[114256];w[114256]=0;if((e|0)==1){break Y}f=w[d+272>>2];g=w[d+276>>2];w[d+272>>2]=0;w[d+276>>2]=0;e=w[d+372>>2];w[d+368>>2]=f;w[d+372>>2]=g;pa:{if(!e){break pa}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break pa}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[d+284>>2];w[d+376>>2]=w[d+280>>2];w[d+380>>2]=e;Bb(d+272|0)}v[a+480188>>1]=1;w[114256]=0;e=S(343,b|0,9595,4)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Z}if(!e){break W}w[114256]=0;e=Q(232,b|0,d+352|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){w[114256]=0;U(188,d+272|0,b|0,(e?w[d+352>>2]:0)|0);e=w[114256];w[114256]=0;if((e|0)!=1){break X}}b=P()|0;break C}b=P()|0;break B}b=P()|0;break B}b=P()|0;break C}b=P()|0;break C}e=w[d+272>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}e=(e>>>0)/20&65535;f=e>>>0>=127?127:e;v[a+480188>>1]=f;if(f){e=0;while(1){w[114256]=0;S(357,d+272|0,((e<<5)+a|0)+480289|0,20)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}e=e+1|0;if((f|0)!=(e|0)){continue}break}}Bb(d+272|0)}e=w[b+8>>2];qa:{if(e>>>0<=i>>>0){e=i-e|0;break qa}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break V}e=e-w[b+8>>2]|0}w[114256]=0;U(188,d+352|0,b|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break V}w[114256]=0;A=Q(358,a|0,d+352|0)|0;e=w[114256];w[114256]=0;ra:{sa:{if((e|0)==1){break sa}if(!(u[d+574|0]&1)){break ra}e=y[d+582>>1];if(!e){break ra}f=w[d+584>>2];if(f>>>0>z[b+8>>2]){e=w[b>>2];g=w[w[e>>2]+24>>2];w[114256]=0;e=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break sa}if(e>>>0<f>>>0){break ra}e=y[d+582>>1]}w[b+8>>2]=f;w[114256]=0;Z(320,a+1304424|0,b|0,e&65535,4)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break ra}}b=P()|0;break E}h=0;v[a+480192>>1]=0;ta:{ua:{va:{if(!(x[d+572|0]&4)){break va}e=y[d+562>>1];e=e>>>0>=255?255:e;v[a+480192>>1]=e;if(!e){break va}e=0;while(1){f=w[d+464>>2]+(e<<2)|0;f=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);wa:{if(!f){break wa}if(f>>>0>z[b+8>>2]){g=w[b>>2];i=w[w[g>>2]+24>>2];w[114256]=0;g=V(i|0,g|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break ta}if(f>>>0>g>>>0){break wa}}w[b+8>>2]=f;g=w[b>>2];i=w[w[g>>2]+36>>2];w[114256]=0;f=S(i|0,g|0,f|0,554)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ta}if(!f){break wa}w[114256]=0;f=S(243,a|0,e+1&65535,0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ua}if(!f){break wa}w[114256]=0;Z(359,a|0,b|0,f|0,y[d+570>>1])|0;g=w[114256];w[114256]=0;if((g|0)==1){break ua}u[f+33|0]=x[d+581|0]}e=e+1|0;if(e>>>0<y[a+480192>>1]){continue}break}}e=y[d+564>>1];if(e){f=(w[d+448>>2]+(e<<2)|0)-4|0;h=(x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24))+80|0}e=e>>>0>=3999?3999:e;v[a+480190>>1]=e;xa:{if(!e){g=0;f=0;break xa}p=c&2;i=d+256|4;j=d+240|4;q=d+292|0;e=0;g=0;while(1){f=w[d+448>>2]+(e<<2)|0;f=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);ya:{if(!f){break ya}za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{if(f>>>0>z[b+8>>2]){k=w[b>>2];m=w[w[k>>2]+24>>2];w[114256]=0;k=V(m|0,k|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break Ia}if(f>>>0>k>>>0){break ya}}w[b+8>>2]=f;w[114256]=0;f=Q(360,b|0,d+272|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break Ia}if(!f){break ya}w[114256]=0;m=e+1|0;r=C(m,104)+a|0;k=r+484380|0;f=Q(361,d+272|0,k|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break Ha}w[114256]=0;Y(209,d+736|0,3,q|0,26);o=w[114256];w[114256]=0;if((o|0)==1){break Ga}w[114256]=0;w[d+724>>2]=32;w[d+720>>2]=((m<<5)+a|0)+946304;Q(200,d+720|0,d+736|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break Fa}if(u[d+747|0]<0){zb(w[d+736>>2])}if(f>>>0>z[b+8>>2]){o=w[b>>2];s=w[w[o>>2]+24>>2];w[114256]=0;o=V(s|0,o|0)|0;s=w[114256];w[114256]=0;if((s|0)==1){break Ha}if(f>>>0>o>>>0){break ya}}w[b+8>>2]=f;f=y[r+484414>>1];if(!(f&512)){break Ea}w[114256]=0;f=Q(362,b|0,d+736|0)|0;l=w[114256];w[114256]=0;if((l|0)!=1){if(!f){break Da}w[114256]=0;w[d+8>>2]=w[d+744>>2];f=w[d+740>>2];w[d>>2]=w[d+736>>2];w[d+4>>2]=f;U(363,k|0,1,d|0);f=w[114256];w[114256]=0;if((f|0)!=1){break Da}}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;if(u[d+747|0]>=0){break E}zb(w[d+736>>2]);break E}if(!(f&16384)){w[114256]=0;U(364,d+736|0,d+272|0,y[d+568>>1]);f=w[114256];w[114256]=0;if((f|0)==1){break F}if(p){f=0;w[114256]=0;S(214,d+736|0,k|0,b|0)|0;l=w[114256];w[114256]=0;if((l|0)!=1){break Aa}break F}f=1;l=x[d+739|0];if(l>>>0>18){break za}l=1<<l;if(!(l&126991)){if(!(l&396800)){break za}break Ba}if(x[d+736|0]){break Ba}break Aa}w[114256]=0;Q(365,b|0,d+176|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ca}f=w[d+176>>2];if(!(!p|!f)){w[114256]=0;w[d+744>>2]=0;w[d+736>>2]=0;w[d+740>>2]=0;S(258,b|0,d+736|0,f|0)|0;f=w[114256];w[114256]=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{if((f|0)!=1){w[114256]=0;f=Q(1,d+240|0,12201)|0;k=w[114256];w[114256]=0;if((k|0)==1){break Pa}l=w[f>>2];w[i>>2]=w[j>>2];k=x[j+3|0]|x[j+4|0]<<8|(x[j+5|0]<<16|x[j+6|0]<<24);u[i+3|0]=k;u[i+4|0]=k>>>8;u[i+5|0]=k>>>16;u[i+6|0]=k>>>24;k=x[d+251|0];w[f+8>>2]=0;w[f>>2]=0;w[f+4>>2]=0;w[114256]=0;u[d+267|0]=k;w[d+256>>2]=l;w[d+160>>2]=m;U(6,d+224|0,0,d+736|0);k=w[114256];w[114256]=0;if((k|0)==1){break Oa}w[114256]=0;Y(366,d+720|0,d+256|0,d+160|0,d+224|0);k=w[114256];w[114256]=0;if((k|0)==1){break Na}w[114256]=0;U(367,a|0,2,d+720|0);k=w[114256];w[114256]=0;if((k|0)==1){break Ma}if(u[d+731|0]<0){zb(w[d+720>>2])}if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[d+267|0]<0){zb(w[d+256>>2])}if(u[d+251|0]<0){zb(w[f>>2])}if(u[d+747|0]>=0){break Da}zb(w[d+736>>2]);break Da}b=P()|0;break Ja}b=P()|0;break Ja}b=P()|0;break Ka}b=P()|0;break La}b=P()|0;if(u[d+731|0]>=0){break La}zb(w[d+720>>2])}if(u[d+235|0]>=0){break Ka}zb(w[d+224>>2])}if(u[d+267|0]<0){zb(w[d+256>>2])}if(u[d+251|0]>=0){break Ja}zb(w[f>>2])}if(u[d+747|0]>=0){break E}zb(w[d+736>>2]);break E}w[114256]=0;Q(242,b|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ca}}f=0;break za}b=P()|0;break E}f=w[k>>2];w[114256]=0;l=Q(368,d+736|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break F}f=0;w[114256]=0;Q(242,b|0,l|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break F}}if(x[d+739|0]!=1){break za}g=w[k>>2]!=0|g}k=w[b+8>>2];h=h>>>0>k>>>0?h:k;l=(f|0)!=0}f=y[a+480190>>1];e=e+1|0;if(f>>>0>e>>>0){continue}break}}v[a+480190>>1]=f>>>0<=1?1:f;Qa:{Ra:{if(!(g&1)|y[d+568>>1]!=516|(y[d+574>>1]|y[d+570>>1]!=512)){break Ra}if(w[d+588>>2]|(y[d+572>>1]&65527)!=21|(x[d+576|0]!=128|x[d+577|0]!=48)){break Ra}if(y[d+582>>1]|(x[d+581|0]|x[d+580|0]!=128)){break Ra}f=d+656|0;g=d+592|0;e=1;while(1){e=(x[g|0]&127)==32&e;g=g+1|0;if((g|0)!=(f|0)){continue}break}g=d+720|0;while(1){e=x[f|0]==64&e;f=f+1|0;if((g|0)!=(f|0)){continue}break}f=20;while(1){e=!x[(d+f|0)+532|0]&e;f=f+1|0;if((f|0)!=26){continue}break}if(!e){break Ra}w[114256]=0;e=Q(1,d+256|0,5800)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Qa}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[e+8>>2];f=w[e+4>>2];w[d+512>>2]=w[e>>2];w[d+516>>2]=f}w[a+480260>>2]=0;w[a+480264>>2]=2147483647;e=y[w[a+8>>2]+10>>1];f=w[d+436>>2]-w[d+432>>2]>>2;g=f&65535;e=e>>>0<g>>>0?e:g;v[d+222>>1]=e;Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{if((e|0)==(f|0)){break $a}w[114256]=0;e=Q(5,d+720|0,11977)|0;f=w[114256];w[114256]=0;if((f|0)==1){break _a}w[d+232>>2]=w[e+8>>2];f=w[e>>2];e=w[e+4>>2];w[114256]=0;w[d+224>>2]=f;w[d+228>>2]=e;w[d+176>>2]=w[d+436>>2]-w[d+432>>2]>>2;Y(369,d+208|0,d+224|0,d+176|0,d+222|0);e=w[114256];w[114256]=0;if((e|0)==1){break Za}w[114256]=0;U(6,d+272|0,0,d+208|0);e=w[114256];w[114256]=0;if((e|0)==1){break Ya}w[d+744>>2]=w[d+280>>2];w[114256]=0;e=w[d+276>>2];w[d+736>>2]=w[d+272>>2];w[d+740>>2]=e;T(348,a|0,d+736|0);e=w[114256];w[114256]=0;if((e|0)==1){break Xa}if(u[d+747|0]<0){zb(w[d+736>>2])}if(u[d+219|0]<0){zb(w[d+208>>2])}if(u[d+235|0]>=0){break $a}zb(w[d+224>>2])}if(c&1){break Ua}v[d+222>>1]=0;break Ta}b=P()|0;break E}b=P()|0;break Va}b=P()|0;break Wa}b=P()|0;if(u[d+747|0]>=0){break Wa}zb(w[d+736>>2])}if(u[d+219|0]>=0){break Va}zb(w[d+208>>2])}if(u[d+235|0]>=0){break E}zb(w[d+224>>2]);break E}if(!y[d+222>>1]){break Ta}g=0;while(1){c=w[d+432>>2]+(g<<2)|0;c=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);ab:{if(!c){break ab}if(c>>>0>z[b+8>>2]){e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Sa}if(c>>>0>e>>>0){break ab}}w[b+8>>2]=c;w[114256]=0;c=Q(197,b|0,d+272|0)|0;e=w[114256];w[114256]=0;bb:{cb:{if((e|0)!=1){w[114256]=0;e=y[d+272>>1];f=Q(197,b|0,d+272|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break cb}f=f?y[d+272>>1]:0;if((f-1025&65535)>>>0<64512){break ab}i=w[b+8>>2];j=w[b>>2];k=w[w[j>>2]+36>>2];w[114256]=0;i=S(k|0,j|0,i|0,4)|0;j=w[114256];w[114256]=0;if((j|0)==1){break cb}if(i){break bb}c=w[b>>2];e=w[w[c>>2]+24>>2];w[114256]=0;c=V(e|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break cb}w[b+8>>2]=c;break ab}b=P()|0;break E}b=P()|0;break E}w[b+8>>2]=w[b+8>>2]+4;w[114256]=0;U(188,d+272|0,b|0,(c?e:0)|0);c=w[114256];w[114256]=0;if((c|0)==1){break G}c=y[a+480188>>1];w[d+744>>2]=0;w[d+736>>2]=0;w[d+740>>2]=0;if(c){w[114256]=0;T(370,d+736|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break I}H=d,I=Cb(w[d+740>>2],0,c)+c|0,w[H+740>>2]=I}i=f&65535;f=0;while(1){c=w[d+272>>2];e=w[w[c>>2]+36>>2];w[114256]=0;c=S(e|0,c|0,w[d+280>>2],1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}if(c){w[114256]=0;c=Q(241,d+272|0,d+224|0)|0;e=w[114256];w[114256]=0;db:{eb:{if((e|0)!=1){if(c){e=u[d+224|0];if(e){break eb}}f=f+1|0;break db}break K}fb:{c=e&127;j=c?c-1|0:0;c=j&65535;if(c>>>0<w[d+740>>2]-w[d+736>>2]>>>0){break fb}w[114256]=0;u[d+224|0]=0;U(371,d+736|0,c+1|0,d+224|0);k=w[114256];w[114256]=0;if((k|0)!=1){break fb}break K}if((e|0)<0){w[114256]=0;e=Q(241,d+272|0,d+224|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break K}u[c+w[d+736>>2]|0]=e?x[d+224|0]:0}k=c+w[d+736>>2]|0;e=x[k|0];if(!(!(e&15)|c>>>0<y[a+480188>>1])){v[a+480188>>1]=j+1;e=x[k|0]}if(e&1){e=w[d+272>>2];j=w[w[e>>2]+36>>2];w[114256]=0;e=S(j|0,e|0,w[d+280>>2],1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}gb:{if(e){e=w[d+280>>2]+1|0;break gb}e=w[d+272>>2];j=w[w[e>>2]+24>>2];w[114256]=0;e=V(j|0,e|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}}w[d+280>>2]=e;e=x[c+w[d+736>>2]|0]}if(e&2){e=w[d+272>>2];j=w[w[e>>2]+36>>2];w[114256]=0;e=S(j|0,e|0,w[d+280>>2],1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}hb:{if(e){e=w[d+280>>2]+1|0;break hb}e=w[d+272>>2];j=w[w[e>>2]+24>>2];w[114256]=0;e=V(j|0,e|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}}w[d+280>>2]=e;e=x[c+w[d+736>>2]|0]}if(e&4){e=w[d+272>>2];j=w[w[e>>2]+36>>2];w[114256]=0;e=S(j|0,e|0,w[d+280>>2],1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}ib:{if(e){e=w[d+280>>2]+1|0;break ib}e=w[d+272>>2];j=w[w[e>>2]+24>>2];w[114256]=0;e=V(j|0,e|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break K}}w[d+280>>2]=e;e=x[c+w[d+736>>2]|0]}if(!(e&8)){break db}c=w[d+272>>2];e=w[w[c>>2]+36>>2];w[114256]=0;c=S(e|0,c|0,w[d+280>>2],2)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}jb:{if(c){e=w[d+280>>2]+2|0;break jb}c=w[d+272>>2];e=w[w[c>>2]+24>>2];w[114256]=0;e=V(e|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break K}}w[d+280>>2]=e}if(f>>>0<i>>>0){continue}}break}e=w[b+8>>2];c=w[d+736>>2];if(c){w[d+740>>2]=c;zb(c)}f=e>>>0<h>>>0;c=w[d+276>>2];kb:{if(!c){break kb}i=w[c+4>>2];w[c+4>>2]=i-1;if(i){break kb}ob[w[w[c>>2]+8>>2]](c);Ib(c)}h=f?h:e}g=g+1|0;if(g>>>0<y[d+222>>1]){continue}break}}if(!h){break U}lb:{if(z[b+8>>2]<h>>>0){c=w[b>>2];e=w[w[c>>2]+24>>2];w[114256]=0;c=V(e|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break M}if(c>>>0<h>>>0){break lb}}w[b+8>>2]=h}if(!l){break U}f=w[b+8>>2];while(1){c=w[b>>2];e=w[w[c>>2]+36>>2];w[114256]=0;c=S(e|0,c|0,f|0,4)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}if(!c){break U}w[114256]=0;c=S(343,b|0,9569,4)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}mb:{if(!c){w[114256]=0;c=S(343,b|0,9574,4)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}if(!c){break mb}}w[114256]=0;c=Q(232,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){e=w[d+272>>2];f=w[b+8>>2];g=f-8|0;w[b+8>>2]=f>>>0>=g>>>0?g:0;c=c?e:0;if(c&-2139062144|!(c&1616928864)){break mb}break U}b=P()|0;break E}w[114256]=0;c=Q(197,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}e=y[d+272>>1];f=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;c=c?e:0;e=S(h|0,g|0,f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break J}nb:{if(e){f=c+w[b+8>>2]|0;break nb}c=w[b>>2];e=w[w[c>>2]+24>>2];w[114256]=0;f=V(e|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break J}}w[b+8>>2]=f;continue}}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break C}w[114256]=0;c=Q(372,a|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break M}c=c|x[d+527|0];u[d+527|0]=c;if(!(!(c&255)|A)){Sp(a+1074312|0);w[a+1074372>>2]=0}w[114256]=0;Y(373,a|0,b|0,0,d+527|0);c=w[114256];w[114256]=0;if((c|0)==1){break M}w[114256]=0;r=a+484344|0;T(215,r|0,y[d+222>>1]);c=w[114256];w[114256]=0;if((c|0)==1){break M}v[d+112>>1]=0;ob:{if(!y[d+222>>1]){break ob}c=d+224|0;s=c|5;B=c|3;j=c|4;k=c|2;D=c|1;F=d+176|2;G=a+480183|0;e=0;while(1){pb:{qb:{c=w[d+432>>2]+((e&65535)<<2)|0;c=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);if(c){if(c>>>0<=z[b+8>>2]){break qb}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break L}if(c>>>0<=e>>>0){break qb}e=y[d+112>>1]}w[114256]=0;c=S(216,r|0,e&65535,64)|0;e=w[114256];w[114256]=0;if((e|0)==1){break L}if(!c){w[114256]=0;c=Q(5,d+736|0,11410)|0;e=w[114256];w[114256]=0;rb:{sb:{tb:{ub:{vb:{if((e|0)!=1){w[d+184>>2]=w[c+8>>2];e=w[c>>2];c=w[c+4>>2];w[114256]=0;w[d+176>>2]=e;w[d+180>>2]=c;U(374,d+192|0,d+176|0,d+112|0);c=w[114256];w[114256]=0;if((c|0)==1){break vb}w[114256]=0;U(6,d+272|0,0,d+192|0);c=w[114256];w[114256]=0;if((c|0)==1){break ub}w[d+232>>2]=w[d+280>>2];w[114256]=0;c=w[d+276>>2];w[d+224>>2]=w[d+272>>2];w[d+228>>2]=c;T(348,a|0,d+224|0);c=w[114256];w[114256]=0;if((c|0)==1){break tb}if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[d+203|0]<0){zb(w[d+192>>2])}if(u[d+187|0]>=0){break ob}zb(w[d+176>>2]);break ob}b=P()|0;break E}b=P()|0;break rb}b=P()|0;break sb}b=P()|0;if(u[d+235|0]>=0){break sb}zb(w[d+224>>2])}if(u[d+203|0]>=0){break rb}zb(w[d+192>>2])}if(u[d+187|0]>=0){break E}zb(w[d+176>>2]);break E}c=w[r>>2];w[114256]=0;e=y[d+112>>1];w[d+296>>2]=0;w[d+300>>2]=0;w[d+288>>2]=0;w[d+292>>2]=0;w[d+280>>2]=0;w[d+284>>2]=0;w[d+272>>2]=0;w[d+276>>2]=0;S(375,d+368|0,d+272|0,32)|0;f=w[114256];w[114256]=0;if((f|0)==1){break L}w[114256]=0;S(227,c+C(e,52)|0,d+272|0,32)|0;c=w[114256];w[114256]=0;if((c|0)==1){break L}break pb}w[b+8>>2]=c;w[114256]=0;c=Q(197,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){w[114256]=0;e=y[d+272>>1];f=Q(197,b|0,d+272|0)|0;g=w[114256];w[114256]=0;wb:{if((g|0)==1){break wb}g=y[d+272>>1];h=w[b+8>>2];i=w[b>>2];l=w[w[i>>2]+36>>2];w[114256]=0;h=S(l|0,i|0,h|0,4)|0;i=w[114256];w[114256]=0;if((i|0)==1){break wb}if(!h){c=w[b>>2];e=w[w[c>>2]+24>>2];w[114256]=0;c=V(e|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break wb}w[b+8>>2]=c;break pb}w[b+8>>2]=w[b+8>>2]+4;w[114256]=0;t=f?g:0;f=S(216,r|0,y[d+112>>1],t|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break wb}if(!f){break pb}w[114256]=0;U(188,d+272|0,b|0,(c?e:0)|0);c=w[114256];w[114256]=0;if((c|0)!=1){c=w[r>>2];w[114256]=0;T(376,c+C(y[d+112>>1],52)|0,d+368|0);c=w[114256];w[114256]=0;xb:{if((c|0)!=1){c=y[a+480188>>1];w[114256]=0;p=Q(377,d+160|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=y[a+480188>>1];w[114256]=0;v[d+740>>1]=0;w[d+736>>2]=0;l=S(378,d+144|0,c|0,d+736|0)|0;c=w[114256];w[114256]=0;yb:{if((c|0)!=1){zb:{if(!t){break zb}o=w[w[r>>2]+C(y[d+112>>1],52)>>2];c=0;while(1){e=w[d+272>>2];f=w[w[e>>2]+36>>2];w[114256]=0;e=S(f|0,e|0,w[d+280>>2],1)|0;f=w[114256];w[114256]=0;Ab:{if((f|0)!=1){Bb:{if(!e){break zb}w[114256]=0;e=Q(241,d+272|0,d+736|0)|0;f=w[114256];w[114256]=0;Cb:{if((f|0)!=1){if(e){e=u[d+736|0];if(e){break Cb}}c=c+1|0;o=C(y[a+480188>>1],6)+o|0;break Ab}break Bb}Db:{f=e&127;m=f?f-1&65535:0;if(m>>>0<w[d+164>>2]-w[p>>2]>>>0){break Db}w[114256]=0;u[d+736|0]=0;f=m+1|0;U(371,p|0,f|0,d+736|0);g=w[114256];w[114256]=0;if((g|0)==1){break Bb}w[114256]=0;v[d+740>>1]=0;w[d+736>>2]=0;U(379,l|0,f|0,d+736|0);f=w[114256];w[114256]=0;if((f|0)!=1){break Db}break Bb}if((e|0)<0){w[114256]=0;e=Q(241,d+272|0,d+736|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Bb}u[m+w[p>>2]|0]=e?x[d+736|0]:0}v[d+228>>1]=0;w[d+224>>2]=0;q=C(m,6);h=q+o|0;i=m>>>0<y[a+480188>>1];g=i?h:d+224|0;f=m+w[p>>2]|0;e=x[f|0];if(e&16){u[g|0]=x[q+w[l>>2]|0];e=x[f|0]}if(e&32){u[(i?h+1|0:D)|0]=x[(q+w[l>>2]|0)+1|0];e=x[f|0]}if(e&64){e=q+w[l>>2]|0;u[(i?h+2|0:k)|0]=x[e+2|0];u[(i?h+4|0:j)|0]=x[e+4|0];e=x[f|0]}if(e<<24>>24<0){e=q+w[l>>2]|0;u[(i?h+3|0:B)|0]=x[e+3|0];u[(i?h+5|0:s)|0]=x[e+5|0];e=x[f|0]}if(e&1){w[114256]=0;e=Q(241,d+272|0,d+736|0)|0;f=w[114256];w[114256]=0;Eb:{Fb:{if((f|0)!=1){e=e?x[d+736|0]:0;e=(((e^-1)&128)>>>7|0)+e|0;if(!(u[G|0]&1)){break Fb}f=e;break Eb}break Bb}f=253;if((e-121&255)>>>0<132){break Eb}f=(e&255)!=253?e:0}u[g|0]=f;u[q+w[l>>2]|0]=f;e=x[m+w[p>>2]|0]}if(e&2){w[114256]=0;e=Q(241,d+272|0,d+736|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Bb}e=e?x[d+736|0]:0;u[(i?h+1|0:D)|0]=e;u[(q+w[l>>2]|0)+1|0]=e;e=x[m+w[p>>2]|0]}if(e&4){w[114256]=0;e=Q(241,d+272|0,d+736|0)|0;f=w[114256];w[114256]=0;Gb:{Hb:{if((f|0)!=1){e=e?x[d+736|0]:0;f=e&255;if(f>>>0>64){break Hb}u[(i?h+2|0:k)|0]=1;u[(i?h+4|0:j)|0]=e;break Gb}break Bb}if(e<<24>>24<=-64){u[(i?h+2|0:k)|0]=2;u[(i?h+4|0:j)|0]=e^128;break Gb}if(f>>>0<=74){u[(i?h+2|0:k)|0]=5;u[(i?h+4|0:j)|0]=e-65;break Gb}if(f>>>0<=84){u[(i?h+2|0:k)|0]=6;u[(i?h+4|0:j)|0]=e-75;break Gb}if(f>>>0<=94){u[(i?h+2|0:k)|0]=3;u[(i?h+4|0:j)|0]=e-85;break Gb}if(f>>>0<=104){u[(i?h+2|0:k)|0]=4;u[(i?h+4|0:j)|0]=e-95;break Gb}if(f>>>0<=114){u[(i?h+2|0:k)|0]=13;u[(i?h+4|0:j)|0]=e-105;break Gb}if(f>>>0<=124){u[(i?h+2|0:k)|0]=12;u[(i?h+4|0:j)|0]=e-115;break Gb}f=e+63|0;if((f&255)>>>0<=9){u[(i?h+2|0:k)|0]=11;u[(i?h+4|0:j)|0]=f;break Gb}f=e+53|0;E=f&255;if(E>>>0<=9){e=i?h+2|0:k;u[e|0]=8;u[(i?h+4|0:j)|0]=f;if(!E|w[a+1074308>>2]-1>>>0>18285139){break Gb}u[e|0]=7;break Gb}e=e+33|0;if((e&255)>>>0>9){break Gb}u[(i?h+2|0:k)|0]=15;u[(i?h+4|0:j)|0]=e}e=q+w[l>>2]|0;u[e+2|0]=x[(i?h+2|0:k)|0];u[e+4|0]=x[(i?h+4|0:j)|0];e=x[m+w[p>>2]|0]}if(!(e&8)){break Ab}e=w[d+272>>2];f=w[w[e>>2]+36>>2];w[114256]=0;e=S(f|0,e|0,w[d+280>>2],2)|0;f=w[114256];w[114256]=0;Ib:{if((f|0)==1){break Ib}Jb:{if(e){w[d+740>>2]=F;w[d+736>>2]=d+176;e=w[d+272>>2];f=w[w[e>>2]+32>>2];w[114256]=0;e=S(f|0,e|0,w[d+280>>2],d+736|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ib}w[d+280>>2]=e+w[d+280>>2];e=x[d+176|0];break Jb}v[d+176>>1]=0;e=0}f=i?h+3|0:B;u[f|0]=e;e=i?h+5|0:s;u[e|0]=x[d+177|0];w[114256]=0;T(380,g|0,1);g=w[114256];w[114256]=0;if((g|0)==1){break Ib}g=q+w[l>>2]|0;u[g+3|0]=x[f|0];u[g+5|0]=x[e|0];break Ab}}}b=P()|0;a=w[l>>2];if(!a){break yb}w[d+148>>2]=a;zb(a);break yb}if(c>>>0<t>>>0){continue}break}}c=w[l>>2];if(c){w[d+148>>2]=c;zb(c)}c=w[p>>2];if(c){w[d+164>>2]=c;zb(c)}Bb(d+272|0);break pb}b=P()|0}a=w[p>>2];if(!a){break xb}w[d+164>>2]=a;zb(a);break xb}b=P()|0;break xb}b=P()|0}Bb(d+272|0);break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}e=y[d+112>>1]+1|0;v[d+112>>1]=e;if(y[d+222>>1]>(e&65535)>>>0){continue}break}}h=a+1074308|0;Kb:{Lb:{if(!w[a+1074308>>2]){e=y[d+568>>1];if((e|0)!=2184){break Lb}w[h>>2]=18284544}c=x[d+523|0];if(!(c<<24>>24<0?w[d+516>>2]:c)){w[114256]=0;e=Q(1,d+224|0,13266)|0;c=w[114256];w[114256]=0;Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{if((c|0)!=1){w[114256]=0;T(120,d+272|0,h|0);c=w[114256];w[114256]=0;if((c|0)==1){break Rb}w[114256]=0;c=x[d+283|0];f=c<<24>>24<0;c=S(2,e|0,(f?w[d+272>>2]:d+272|0)|0,(f?w[d+276>>2]:c)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Qb}g=w[c>>2];w[d+176>>2]=w[c+4>>2];f=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+179|0]=f;u[d+180|0]=f>>>8;u[d+181|0]=f>>>16;u[d+182|0]=f>>>24;w[c>>2]=0;w[c+4>>2]=0;i=x[c+11|0];w[c+8>>2]=0;if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+512>>2]=g;c=d+512|4;f=x[d+179|0]|x[d+180|0]<<8|(x[d+181|0]<<16|x[d+182|0]<<24);u[c+3|0]=f;u[c+4|0]=f>>>8;u[c+5|0]=f>>>16;u[c+6|0]=f>>>24;w[c>>2]=w[d+176>>2];u[d+523|0]=i;if(u[d+283|0]<0){zb(w[d+272>>2])}if(u[e+11|0]<0){zb(w[e>>2])}if((x[d+588|0]|x[d+589|0]<<8|(x[d+590|0]<<16|x[d+591|0]<<24))==1414548815|(y[d+568>>1]&61440)!=20480){break Mb}w[114256]=0;c=Q(1,d+176|0,12644)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ob}f=w[c>>2];g=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=f;f=e<<24>>24<0;S(2,d+512|0,(f?m:c)|0,(f?g:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Nb}if(u[c+11|0]>=0){break Kb}zb(w[c>>2]);break Kb}b=P()|0;break E}b=P()|0;break Pb}b=P()|0;if(u[d+283|0]>=0){break Pb}zb(w[d+272>>2])}if(u[e+11|0]>=0){break E}zb(w[e>>2]);break E}b=P()|0;break E}b=P()|0;if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}Sb:{Tb:{c=w[h>>2];if(c>>>0>=18285141){if(c>>>0>18350591){break Tb}e=1;if((c|0)!=18350080){break Sb}}e=0;break Sb}e=0;if((c|0)==18350592){break Sb}e=(c|0)!=(c&-256)}if(!e){break Kb}w[114256]=0;c=Q(1,d+176|0,12880)|0;e=w[114256];w[114256]=0;Ub:{if((e|0)!=1){f=w[c>>2];g=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=f;f=e<<24>>24<0;S(2,d+512|0,(f?m:c)|0,(f?g:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ub}if(u[c+11|0]>=0){break Kb}zb(w[c>>2]);break Kb}b=P()|0;break E}b=P()|0;if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}e=y[d+568>>1]}Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{ac:{bc:{cc:{dc:{ec:{fc:{switch(e>>>12&15){case 0:if(A){w[114256]=0;c=Q(1,d+224|0,4525)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E}if((e&65535)!=532){break $b}c=y[d+570>>1];if((c|0)!=532){f=0;if((c|0)!=512){break cc}if(y[d+572>>1]!=9){g=x[d+558|0];e=x[d+559|0];break dc}g=x[d+558|0];e=x[d+559|0];if(y[d+562>>1]|(g|(e|y[d+574>>1]))){break dc}g=0;if(y[d+560>>1]!=(y[d+566>>1]+1|0)|x[d+576|0]!=128|(x[d+577|0]!=100|x[d+578|0]!=1)){break ec}if(x[d+581|0]|x[d+580|0]!=128|(y[d+582>>1]|w[d+584>>2])){break ec}e=0;if(w[d+588>>2]){break dc}w[114256]=0;c=Q(1,d+224|0,5781)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E}f=1;if((x[d+588|0]|x[d+589|0]<<8|(x[d+590|0]<<16|x[d+591|0]<<24))!=1229080643){break cc}w[114256]=0;c=Q(1,d+224|0,4577)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;c=a+1074316|0;w[c>>2]=w[c>>2]&-65;break Kb}b=P()|0;break E;case 1:w[114256]=0;U(381,d+272|0,e&65535,w[d+588>>2]);c=w[114256];w[114256]=0;gc:{hc:{if((c|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[d+280>>2];c=w[d+276>>2];w[d+512>>2]=w[d+272>>2];w[d+516>>2]=c;c=y[d+568>>1];if(c>>>0>6091){break hc}w[a+1074312>>2]=w[a+1074312>>2]&-129;break gc}b=P()|0;break E}if(c>>>0>6561){break Kb}}c=a+1074316|0;w[c>>2]=w[c>>2]&-65;break Kb;case 4:w[114256]=0;c=Q(1,d- -64|0,10991)|0;e=w[114256];w[114256]=0;ic:{jc:{kc:{if((e|0)!=1){f=w[c>>2];w[d+180>>2]=w[c+4>>2];e=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+183|0]=e;u[d+184|0]=e>>>8;u[d+185|0]=e>>>16;u[d+186|0]=e>>>24;w[c>>2]=0;w[c+4>>2]=0;e=x[c+11|0];w[c+8>>2]=0;w[114256]=0;u[d+187|0]=e;w[d+176>>2]=f;e=y[d+568>>1];w[d+80>>2]=e>>>8&15;w[d+16>>2]=e&255;u[d+288|0]=44;w[d+280>>2]=-1;w[d+284>>2]=0;w[d+272>>2]=1042;w[d+276>>2]=2;U(101,d+112|0,d+16|0,d+272|0);e=w[114256];w[114256]=0;if((e|0)==1){break kc}w[114256]=0;Y(366,d+224|0,d+176|0,d+80|0,d+112|0);e=w[114256];w[114256]=0;if((e|0)==1){break jc}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[d+232>>2];e=w[d+228>>2];w[d+512>>2]=w[d+224>>2];w[d+516>>2]=e;u[d+224|0]=0;u[d+235|0]=0;if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[d+187|0]<0){zb(w[d+176>>2])}if(u[c+11|0]>=0){break Kb}zb(w[c>>2]);break Kb}b=P()|0;break E}b=P()|0;break ic}b=P()|0;if(u[d+123|0]>=0){break ic}zb(w[d+112>>2])}if(u[d+187|0]<0){zb(w[d+176>>2])}if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E;case 6:w[114256]=0;c=Q(1,d+224|0,4525)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E;case 7:if(!((e&65535)!=32767|y[d+570>>1]!=533)){w[114256]=0;c=Q(1,d+224|0,1549)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E}w[114256]=0;c=Q(1,d+48|0,10541)|0;e=w[114256];w[114256]=0;lc:{if((e|0)!=1){f=w[c>>2];w[d+228>>2]=w[c+4>>2];e=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+231|0]=e;u[d+232|0]=e>>>8;u[d+233|0]=e>>>16;u[d+234|0]=e>>>24;w[c>>2]=0;w[c+4>>2]=0;e=x[c+11|0];w[c+8>>2]=0;w[114256]=0;u[d+235|0]=e;w[d+224>>2]=f;e=y[d+568>>1];w[d+176>>2]=e>>>8&15;w[d+112>>2]=e>>>4&15;w[d+80>>2]=e&15;ga(119,d+272|0,d+224|0,d+176|0,d+112|0,d+80|0);e=w[114256];w[114256]=0;if((e|0)==1){break lc}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[d+280>>2];e=w[d+276>>2];w[d+512>>2]=w[d+272>>2];w[d+516>>2]=e;u[d+272|0]=0;u[d+283|0]=0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[c+11|0]>=0){break Kb}zb(w[c>>2]);break Kb}b=P()|0;break E}b=P()|0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E;case 13:break fc;default:break Kb}}w[114256]=0;c=Q(1,d+224|0,2516)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E}e=0}if(e&255|g&255){break cc}if(!w[d+588>>2]){break bc}}e=532;if(!f|y[d+574>>1]>1|(x[d+581|0]|w[d+588>>2])){break Vb}if((y[d+572>>1]&4294)!=4){break Vb}if(y[a+480190>>1]){break ac}break Vb}w[h>>2]=16777381;w[114256]=0;c=Q(1,d+224|0,10398)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;u[d+527|0]=1;break Kb}b=P()|0;break E}w[114256]=0;c=Q(5,d+224|0,9286)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Zb}w[114256]=0;e=Q(382,a+484527|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Yb}if(u[c+11|0]<0){zb(w[c>>2])}if(e){break _b}e=y[d+568>>1]}if(e&65535){break Vb}e=0;c=x[d+523|0];if(c<<24>>24<0?w[d+516>>2]:c){break Vb}w[114256]=0;c=Q(1,d+176|0,5621)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Wb}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}w[114256]=0;c=Q(1,d+176|0,4603)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Xb}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break Kb}b=P()|0;break E}b=P()|0;if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}b=P()|0;break E}b=P()|0;break E}c=y[d+570>>1];if(c>>>0>767){break Kb}f=x[d+523|0];if(f<<24>>24<0?w[d+516>>2]:f){break Kb}mc:{if(c>>>0>=533){w[114256]=0;c=Q(1,d+176|0,10431)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[c+8>>2];e=w[c+4>>2];w[d+512>>2]=w[c>>2];w[d+516>>2]=e;break mc}b=P()|0;break E}if((e&65535)>>>0>=533){w[114256]=0;c=Q(1,d+128|0,11258)|0;e=w[114256];w[114256]=0;nc:{if((e|0)!=1){f=w[c>>2];w[d+180>>2]=w[c+4>>2];e=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+183|0]=e;u[d+184|0]=e>>>8;u[d+185|0]=e>>>16;u[d+186|0]=e>>>24;w[c>>2]=0;w[c+4>>2]=0;e=x[c+11|0];w[c+8>>2]=0;w[114256]=0;u[d+187|0]=e;w[d+176>>2]=f;w[d+112>>2]=y[d+568>>1]-532;U(121,d+272|0,d+176|0,d+112|0);e=w[114256];w[114256]=0;if((e|0)==1){break nc}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[d+280>>2];e=w[d+276>>2];w[d+512>>2]=w[d+272>>2];w[d+516>>2]=e;u[d+272|0]=0;u[d+283|0]=0;if(u[d+187|0]<0){zb(w[d+176>>2])}if(u[c+11|0]>=0){break mc}zb(w[c>>2]);break mc}b=P()|0;break E}b=P()|0;if(u[d+187|0]<0){zb(w[d+176>>2])}if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}w[114256]=0;c=Q(1,d+96|0,10927)|0;e=w[114256];w[114256]=0;oc:{pc:{qc:{if((e|0)!=1){f=w[c>>2];w[d+116>>2]=w[c+4>>2];e=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+119|0]=e;u[d+120|0]=e>>>8;u[d+121|0]=e>>>16;u[d+122|0]=e>>>24;w[c>>2]=0;w[c+4>>2]=0;e=x[c+11|0];w[c+8>>2]=0;w[114256]=0;u[d+123|0]=e;w[d+112>>2]=f;e=y[d+568>>1];w[d+16>>2]=e>>>8&15;w[d+76>>2]=e&255;u[d+288|0]=44;w[d+280>>2]=-1;w[d+284>>2]=0;w[d+272>>2]=1042;w[d+276>>2]=2;U(101,d+80|0,d+76|0,d+272|0);e=w[114256];w[114256]=0;if((e|0)==1){break qc}w[114256]=0;Y(366,d+176|0,d+112|0,d+16|0,d+80|0);e=w[114256];w[114256]=0;if((e|0)==1){break pc}if(u[d+523|0]<0){zb(w[d+512>>2])}w[d+520>>2]=w[d+184>>2];e=w[d+180>>2];w[d+512>>2]=w[d+176>>2];w[d+516>>2]=e;u[d+176|0]=0;u[d+187|0]=0;if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[c+11|0]>=0){break mc}zb(w[c>>2]);break mc}b=P()|0;break E}b=P()|0;break oc}b=P()|0;if(u[d+91|0]>=0){break oc}zb(w[d+80>>2])}if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}if(w[a+1304500>>2]!=w[a+1304504>>2]){break Kb}c=w[d+588>>2];if(!c){break Kb}w[114256]=0;c=Q(383,y[d+568>>1],c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break N}e=d+272|0;Cb(e,0,44);w[114256]=0;w[d+316>>2]=c;T(384,a+1304500|0,e|0);c=w[114256];w[114256]=0;if((c|0)!=1){break Kb}b=P()|0;break E}rc:{sc:{if(w[a+480180>>2]!=16777216){break sc}e=y[d+568>>1];if(e>>>0>2185){tc:{if(z[b+8>>2]<n>>>0){c=w[b>>2];e=w[w[c>>2]+24>>2];w[114256]=0;c=V(e|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break M}if(c>>>0<n>>>0){break tc}e=y[d+568>>1]}w[b+8>>2]=n;w[114256]=0;U(385,a|0,b|0,e&65535);b=w[114256];w[114256]=0;if((b|0)==1){break M}}if(w[a+480180>>2]!=16777216){break sc}}w[114256]=0;Q(1,d+112|0,9552)|0;c=w[114256];w[114256]=0;b=1;if((c|0)!=1){break rc}b=P()|0;break E}w[114256]=0;c=Q(1,d+32|0,10927)|0;b=w[114256];w[114256]=0;if((b|0)==1){break S}e=w[c>>2];w[d+84>>2]=w[c+4>>2];b=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+87|0]=b;u[d+88|0]=b>>>8;u[d+89|0]=b>>>16;u[d+90|0]=b>>>24;w[c>>2]=0;w[c+4>>2]=0;b=x[c+11|0];w[c+8>>2]=0;w[114256]=0;u[d+91|0]=b;w[d+80>>2]=e;b=y[d+570>>1];w[d+76>>2]=b>>>8;w[d+12>>2]=b&255;u[d+288|0]=44;w[d+280>>2]=-1;w[d+284>>2]=0;w[d+272>>2]=1042;w[d+276>>2]=2;U(101,d+16|0,d+12|0,d+272|0);b=w[114256];w[114256]=0;if((b|0)==1){break R}b=0;w[114256]=0;Y(366,d+112|0,d+80|0,d+76|0,d+16|0);e=w[114256];w[114256]=0;if((e|0)==1){break Q}}c=a+1304436|0;if(u[a+1304447|0]<0){zb(w[c>>2])}e=w[d+116>>2];w[c>>2]=w[d+112>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+120>>2];u[d+123|0]=0;u[d+112|0]=0;uc:{if(b){break uc}if(u[d+27|0]<0){zb(w[d+16>>2])}if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[d+43|0]>=0){break uc}zb(w[d+32>>2])}b=w[a+480180>>2];w[114256]=0;c=Q(1,d+272|0,((b|0)==16777216?6064:2520)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break O}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}e=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=e;w[b+8>>2]=w[c+8>>2];b=a+1304460|0;if(u[a+1304471|0]<0){zb(w[b>>2])}c=w[d+516>>2];w[b>>2]=w[d+512>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+520>>2];u[d+523|0]=0;u[d+512|0]=0;w[a+1304496>>2]=w[a+1074308>>2]?7:4;Bb(d+352|0);Bb(d+368|0);e=1}a=w[d+432>>2];if(a){w[d+436>>2]=a;zb(a)}a=w[d+448>>2];if(a){w[d+452>>2]=a;zb(a)}a=w[d+464>>2];if(!a){break c}w[d+468>>2]=a;zb(a);break c}b=P()|0;break E}b=P()|0;break P}b=P()|0;if(u[d+27|0]>=0){break P}zb(w[d+16>>2])}if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[c+11|0]>=0){break E}zb(w[c>>2]);break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;break E}b=P()|0;a=w[d+736>>2];if(!a){break H}w[d+740>>2]=a;zb(a);break H}b=P()|0;break E}b=P()|0}Bb(d+272|0);break E}b=P()|0;break E}b=P()|0}Bb(d+352|0);break C}b=P()|0;Bb(d+272|0)}Bb(d+368|0)}a=w[d+432>>2];if(a){w[d+436>>2]=a;zb(a)}a=w[d+448>>2];if(a){w[d+452>>2]=a;zb(a)}a=w[d+464>>2];if(!a){break d}w[d+468>>2]=a;zb(a)}if(u[d+523|0]<0){zb(w[d+512>>2])}R(b|0);M()}if(u[d+523|0]>=0){break b}zb(w[d+512>>2])}jb=d+752|0;return e|0}function wC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,B=0,F=0,I=0,J=0,K=D(0),L=0,N=0,O=0;d=jb-1712|0;jb=d;w[b+8>>2]=0;a:{if(!Mc(b,d+1672|0)){break a}if(!Cp(d+1672|0)){break a}if(!c){h=1;break a}e=x[d+1675|0];u[d+1671|0]=e;b:{if(e>>>0<5){m=-1;e=1048576;break b}e=Nc(b,d+288|0);g=w[b>>2];m=e?w[d+288>>2]:0;if(!(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],m)|0)){break a}e=(m>>>0>=134217727?134217727:m)<<5}w[114256]=0;w[d+1664>>2]=0;w[d+1656>>2]=0;w[d+1660>>2]=0;g=w[d+1676>>2];T(461,d+1656|0,(e>>>0>g>>>0?g:e)|0);e=w[114256];w[114256]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){i=w[d+1676>>2];if(!i){break w}w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}f=e?x[d+288|0]:0;e=w[d+1660>>2];k=w[d+1664>>2];A:{if(e>>>0<k>>>0){u[e|0]=f;w[d+1660>>2]=e+1;break A}g=e;e=w[d+1656>>2];g=g-e|0;l=g+1|0;if((l|0)<0){break e}k=k-e|0;j=k<<1;l=k>>>0>=1073741823?2147483647:j>>>0>l>>>0?j:l;B:{if(!l){break B}w[114256]=0;h=V(22,l|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break d}}k=g+h|0;u[k|0]=f;if((g|0)>0){Fb(h,e,g)}w[d+1664>>2]=h+l;w[d+1660>>2]=k+1;w[d+1656>>2]=h;if(!e){break A}zb(e)}C:{D:{E:{F:{i=i-1|0;if(i){l=0;e=0;while(1){G:{H:{g=e<<1;e=g&254;I:{if(!e){w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}if(!e){break z}g=x[d+288|0]<<1|1;e=g&255;if(g>>>0<256){break I}break H}if((g&65535)>>>0>255){break H}}w[114256]=0;g=Q(241,b|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}if(!g){break z}g=w[d+1660>>2];J:{if((g|0)!=w[d+1664>>2]){u[g|0]=x[d+288|0];w[d+1660>>2]=g+1;break J}k=w[d+1656>>2];g=g-k|0;f=g+1|0;if((f|0)<0){break e}j=g<<1;j=g>>>0>=1073741823?2147483647:f>>>0<j>>>0?j:f;K:{if(!j){f=0;break K}w[114256]=0;f=V(22,j|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break D}}n=f+g|0;u[n|0]=x[d+288|0];if((g|0)>0){Fb(f,k,g)}w[d+1664>>2]=f+j;w[d+1660>>2]=n+1;w[d+1656>>2]=f;if(!k){break J}zb(k)}i=i-1|0;break G}f=1;while(1){L:{M:{N:{h=e<<1&254;if(h){e=(e&65535)>>>0>127}else{w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break E}if(!e){break N}e=x[d+288|0]<<1|1;h=e&255;e=e>>>0>255}f=e|f<<1;e=h<<1&254;if(e){break M}w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break E}if(!e){break N}g=x[d+288|0]<<1|1;e=g&255;if(g>>>0>255){continue}break L}e=0;break L}if(h>>>0>127){continue}}break}O:{if((f|0)<=2){j=0;g=f-2|0;break O}w[114256]=0;g=Q(241,b|0,d+288|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break D}if(!g){break z}g=(x[d+288|0]|f<<8)-768|0;j=((g|0)>1279?2:1)+((g|0)>31999)|0;l=g^-1;g=0}h=e<<1&254;if(h){f=e>>>0>127}else{w[114256]=0;e=Q(241,b|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}if(!e){break z}e=x[d+288|0]<<1|1;h=e&255;f=e>>>0>255}e=h<<1&254;if(e){p=h>>>0>127}else{w[114256]=0;e=Q(241,b|0,d+288|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break D}if(!e){break z}k=x[d+288|0]<<1|1;e=k&255;p=k>>>0>255}f=p|(g<<2|(f?2:0));if(!f){f=1;while(1){P:{Q:{R:{h=e<<1&254;if(h){e=(e&65535)>>>0>127}else{w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break F}if(!e){break R}e=x[d+288|0]<<1|1;h=e&255;e=e>>>0>255}f=e|f<<1;e=h<<1&254;if(e){break Q}w[114256]=0;e=Q(241,b|0,d+288|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break F}if(!e){break R}g=x[d+288|0]<<1|1;e=g&255;if(g>>>0>255){continue}break P}e=0;break P}if(h>>>0>127){continue}}break}f=f+2|0}h=0;g=f+j|0;if(g>>>0>i>>>0|(g|0)<=0|(l|0)>=0){break w}f=w[d+1656>>2];k=w[d+1660>>2];if((f-k|0)>(l|0)){break v}w[114256]=0;u[d+288|0]=0;Z(462,d+1656|0,k|0,g|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}h=w[d+1660>>2]-g|0;f=l+h|0;k=g;while(1){u[h|0]=x[f|0];h=h+1|0;f=f+1|0;j=k>>>0>1;k=k-1|0;if(j){continue}break}i=i-g|0}if(i){continue}break}}S:{if(x[d+1671|0]<5){break S}e=m+12|0;if(e>>>0>z[b+8>>2]){g=w[b>>2];f=w[w[g>>2]+24>>2];w[114256]=0;g=V(f|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break d}if(e>>>0>g>>>0){break S}}w[b+8>>2]=e}w[114256]=0;T(236,a|0,0);e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;X(257,a|0);e=w[114256];w[114256]=0;if((e|0)!=1){break C}break d}f=P()|0;break c}f=P()|0;break c}f=P()|0;break c}w[114256]=0;g=w[d+1656>>2];f=w[d+1660>>2];e=V(22,24)|0;l=w[114256];w[114256]=0;T:{U:{V:{W:{if((l|0)!=1){w[e+4>>2]=0;w[e+8>>2]=0;w[e+20>>2]=f-g;w[e+16>>2]=g;w[e+12>>2]=75592;w[e>>2]=75552;w[114256]=0;w[d+1648>>2]=0;w[d+1652>>2]=0;w[d+1644>>2]=e;w[d+1640>>2]=e+12;S(330,d+1640|0,a+1304400|0,-1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break W}w[114256]=0;S(330,d+1640|0,a+1304424|0,-1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break W}w[114256]=0;e=Q(463,d+1640|0,d+1216|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break y}h=0;if(!e){break x}e=u[d+1216|0];if((e|0)<=0|(x[d+1225|0]|x[d+1226|0]<<8)>>>0>255|(x[d+1227|0]|x[d+1228|0]<<8)>>>0>3999){break x}v[a+480188>>1]=e&255;v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=x[d+1219|0]|x[d+1220|0]<<8;v[a+480192>>1]=x[d+1225|0]|x[d+1226|0]<<8;v[a+480190>>1]=x[d+1227|0]|x[d+1228|0]<<8;e=x[d+1229|0];w[a+480196>>2]=e?e:6;e=x[d+1230|0];w[a+480204>>2]=C(e?e:125,1e4);g=x[d+1231|0]|x[d+1232|0]<<8|(x[d+1233|0]<<16|x[d+1234|0]<<24);e=32;X:{if(g&256){break X}e=2;if(g&2){break X}e=1;if(g&128){break X}e=g&8?16:4}w[114256]=0;T(346,a|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break y}e=w[a+480208>>2];f=e|16777216;w[a+480208>>2]=f;g=x[d+1231|0]|x[d+1232|0]<<8|(x[d+1233|0]<<16|x[d+1234|0]<<24);if(g&1){f=e|16777232;w[a+480208>>2]=f}l=w[a+480180>>2];if(!(!(g&16)|(l|0)!=2)){f=f|65536;w[a+480208>>2]=f}e=4;if(!(g&4)|(l|0)!=2){break V}k=0;e=2;break U}f=P()|0;break c}f=P()|0;break f}k=(l|0)==32;if(g&2048|(l|0)!=32){break T}}f=f|e;w[a+480208>>2]=f}e=!(g&1024)&k;i=g&2097152;if(e|i){w[a+480208>>2]=i>>>6|(e?f|8:f)}if(g&524288){w[a+1074312>>2]=w[a+1074312>>2]|32}Y:{Z:{if(k){h=1;e=x[d+1235|0];e=e>>>0>=128?128:e;break Z}h=2;if((l|0)!=2){break Y}e=x[d+1235|0];e=e>>>0>=64?64:e}w[a+480200>>2]=e<<h}e=u[d+1237|0];_:{if((e|0)<0){e=e+52|0;break _}L=Em(+(e|0)*.15500000000000003);$:{if(L<4294967296&L>=0){e=~~L>>>0;break $}e=0}e=e+51|0}w[a+480228>>2]=e;e=y[a+480188>>1];g=e>>>0>=64?64:e;if(g){h=0;f=(l|0)==4;while(1){aa:{ba:{if(k){e=x[(d+h|0)+1238|0];v[((h<<5)+a|0)+480286>>1]=e>>>0>=64?64:e;break ba}if(f){break aa}}ca:{e=x[(d+h|0)+1302|0];if((e|0)!=255){if((e|0)!=127){break ca}w[((h<<5)+a|0)+480280>>2]=256;break aa}v[((h<<5)+a|0)+480284>>1]=256;break aa}v[((h<<5)+a|0)+480284>>1]=e}h=h+1|0;if((g|0)!=(h|0)){continue}break}}f=0;h=0;k=0;while(1){h=x[(d+k|0)+1366|0]!=0|h;k=k+1|0;if((k|0)!=16){continue}break}while(1){h=x[((f<<1)+d|0)+1383|0]!=0|h;f=f+1|0;if((f|0)!=128){continue}break}da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{if(h&1){h=0;while(1){g=(d+h|0)+1366|0;ma:{if(x[g|0]){w[114256]=0;e=Q(5,d+1680|0,1425)|0;f=w[114256];w[114256]=0;na:{oa:{pa:{qa:{ra:{if((f|0)!=1){w[d+208>>2]=w[e+8>>2];f=w[e+4>>2];w[d+200>>2]=w[e>>2];w[d+204>>2]=f;e=x[g|0];w[114256]=0;w[d+1152>>2]=e-1;u[d+304|0]=44;w[d+296>>2]=-1;w[d+300>>2]=0;w[d+288>>2]=1058;w[d+292>>2]=2;U(464,d+1168|0,d+1152|0,d+288|0);e=w[114256];w[114256]=0;if((e|0)==1){break ra}w[114256]=0;U(281,d+248|0,d+200|0,d+1168|0);e=w[114256];w[114256]=0;if((e|0)==1){break qa}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=((h<<5)+a|0)+901692;Q(200,d+288|0,d+248|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break pa}if(u[d+259|0]<0){zb(w[d+248>>2])}if(u[d+1179|0]<0){zb(w[d+1168>>2])}if(u[d+211|0]>=0){break ma}zb(w[d+200>>2]);break ma}f=P()|0;break f}f=P()|0;break na}f=P()|0;break oa}f=P()|0;if(u[d+259|0]>=0){break oa}zb(w[d+248>>2])}if(u[d+1179|0]>=0){break na}zb(w[d+1168>>2])}if(u[d+211|0]>=0){break f}zb(w[d+200>>2]);break f}w[114256]=0;e=Q(5,d+1200|0,17256)|0;g=w[114256];w[114256]=0;if((g|0)==1){break g}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=((h<<5)+a|0)+901692;Q(200,d+288|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break h}if(u[d+1211|0]>=0){break ma}zb(w[e>>2])}h=h+1|0;if((h|0)!=16){continue}break}h=0;while(1){g=(d+1216|0)+(h<<1)|0;sa:{if(x[g+167|0]){w[114256]=0;e=Q(5,d+1696|0,10757)|0;f=w[114256];w[114256]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{if((f|0)!=1){w[d+208>>2]=w[e+8>>2];f=w[e+4>>2];w[d+200>>2]=w[e>>2];w[d+204>>2]=f;e=x[g+167|0];w[114256]=0;w[d+224>>2]=e-1;u[d+304|0]=44;w[d+296>>2]=-1;w[d+300>>2]=0;w[d+288>>2]=1058;w[d+292>>2]=2;U(464,d+1168|0,d+224|0,d+288|0);e=w[114256];w[114256]=0;if((e|0)==1){break za}e=x[g+166|0];w[114256]=0;u[d+152|0]=e;u[d+304|0]=44;w[d+296>>2]=-1;w[d+300>>2]=0;w[d+288>>2]=1058;w[d+292>>2]=2;U(465,d+1152|0,d+152|0,d+288|0);e=w[114256];w[114256]=0;if((e|0)==1){break ya}w[114256]=0;Y(466,d+248|0,d+200|0,d+1168|0,d+1152|0);e=w[114256];w[114256]=0;if((e|0)==1){break xa}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=((h<<5)+a|0)+902204;Q(200,d+288|0,d+248|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break wa}if(u[d+259|0]<0){zb(w[d+248>>2])}if(u[d+1163|0]<0){zb(w[d+1152>>2])}if(u[d+1179|0]<0){zb(w[d+1168>>2])}if(u[d+211|0]>=0){break sa}zb(w[d+200>>2]);break sa}f=P()|0;break f}f=P()|0;break ta}f=P()|0;break ua}f=P()|0;break va}f=P()|0;if(u[d+259|0]>=0){break va}zb(w[d+248>>2])}if(u[d+1163|0]>=0){break ua}zb(w[d+1152>>2])}if(u[d+1179|0]>=0){break ta}zb(w[d+1168>>2])}if(u[d+211|0]>=0){break f}zb(w[d+200>>2]);break f}w[114256]=0;e=Q(5,d+1184|0,17256)|0;g=w[114256];w[114256]=0;if((g|0)==1){break la}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=((h<<5)+a|0)+902204;Q(200,d+288|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ka}if(u[d+1195|0]>=0){break sa}zb(w[e>>2])}h=h+1|0;if((h|0)!=128){continue}break}}e=w[a+484360>>2];g=x[a+484376|0];w[114256]=0;da(317,e+(g<<5)|0,d+1640|0,x[d+1217|0]|x[d+1218|0]<<8,255,254)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ja}w[114256]=0;U(188,d+1168|0,d+1640|0,C(x[d+1216|0],x[d+1221|0]|x[d+1222|0]<<8)<<1);e=w[114256];w[114256]=0;if((e|0)==1){break ia}w[114256]=0;U(188,d+1152|0,d+1640|0,(x[d+1221|0]|x[d+1222|0]<<8)<<1);e=w[114256];w[114256]=0;if((e|0)==1){break ha}w[114256]=0;F=Q(213,d+1136|0,x[d+1223|0]|x[d+1224|0]<<8)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ga}h=w[F>>2];g=w[F+4>>2];if((h|0)!=(g|0)){while(1){w[114256]=0;e=Q(232,d+1640|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break fa}w[114256]=0;U(188,d+288|0,d+1640|0,(e?w[d+288>>2]:0)|0);e=w[114256];w[114256]=0;if((e|0)==1){break ea}he(h,d+288|0);e=w[d+300>>2];w[h+8>>2]=w[d+296>>2];w[h+12>>2]=e;e=w[d+292>>2];Aa:{if(!e){break Aa}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break Aa}ob[w[w[e>>2]+8>>2]](e);Ib(e)}h=h+16|0;if((g|0)!=(h|0)){continue}break}}e=w[a+480180>>2];g=1;I=c&1;if(!I){break da}w[114256]=0;T(215,a+484344|0,x[d+1221|0]|x[d+1222|0]<<8);f=w[114256];w[114256]=0;if((f|0)!=1){break da}f=P()|0;break k}f=P()|0;break f}f=P()|0;if(u[d+1195|0]>=0){break f}zb(w[e>>2]);break f}f=P()|0;break f}f=P()|0;break f}f=P()|0;break i}f=P()|0;break j}f=P()|0;break k}f=P()|0;break k}Ba:{Ca:{if(x[d+1221|0]|x[d+1222|0]<<8){O=(e|0)==16?14:(e|0)==32?1:13;t=a+484344|0;while(1){w[114256]=0;e=Q(197,d+1152|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ba}Da:{if(!I){break Da}f=y[d+288>>1];w[114256]=0;q=e?f:0;e=S(216,t|0,r&65535,q|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ba}if(!(e&x[d+1216|0]!=0)){break Da}p=0;while(1){w[114256]=0;e=Q(197,d+1168|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ca}e=e?y[d+288>>1]:0;f=w[F>>2];Ea:{if(e>>>0>=w[F+4>>2]-f>>4>>>0){break Ea}B=f+(e<<4)|0;w[B+8>>2]=0;e=w[t>>2];w[114256]=0;e=e+C(r,52)|0;V(218,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break l}if(!q){break Ea}h=w[e>>2]+C(p,6)|0;j=0;while(1){w[114256]=0;e=Q(241,B|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break m}if(!e){break Ea}s=x[d+288|0];if(!s){break Ea}k=0;n=0;o=0;i=0;m=0;e=0;l=0;N=s&15;if(N){while(1){w[114256]=0;Q(467,B|0,d+288|0)|0;f=w[114256];w[114256]=0;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{if((f|0)!=1){_a:{f=x[d+288|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break Ia;case 33:break Ma;case 30:case 31:break Na;case 29:break Oa;case 28:break Pa;case 26:break Qa;case 19:case 20:break Ra;case 17:break Sa;case 15:break Ta;case 14:break Ua;case 10:break Va;case 6:break Wa;case 5:break Xa;case 1:break Ya;case 0:break Za;default:break _a}}switch(f-48|0){case 4:break Ja;case 1:case 2:break Ka;case 0:break La;default:break Ia}}f=P()|0;break k}f=x[d+289|0];$a:{if(f>>>0<=119){n=f+O|0;break $a}n=(f|0)==255?-1:(f|0)==254?-2:-3}g=((n-121&255)>>>0<136|(n-49&255)>>>0<36)&g;break Fa}o=x[d+289|0]+1|0;break Fa}ab:{if(i&255){break ab}f=w[a+480180>>2];if((f|0)!=32){i=0;if((f|0)!=4){break ab}f=x[d+289|0];if(f&15){break ab}e=f>>>4|0;i=11;break Fa}f=0;i=x[d+289|0];while(1){if((i|0)==x[f+25776|0]){break Ha}f=f+1|0;if((f|0)!=10){continue}break}i=0}m=4;l=x[d+289|0];break Fa}f=x[d+289|0];if(!(i&255|f>>>0>9|w[a+480180>>2]!=32)){e=f;i=8;break Fa}m=5;l=f;break Fa}if(i&255){m=9;l=x[d+289|0];break Fa}J=w[a+480180>>2];i=(J|0)!=32;f=x[d+289|0];if(!(i|(f|0)!=255)){i=2;e=64;break Fa}bb:{if(!i){if(!(f&3)){break bb}i=0;m=9;l=f;break Fa}i=0;if(f&15|(J|0)!=4){break Ga}}i=2;e=(f&252)>>>2|0;break Fa}f=x[d+289|0];if(!(i&255|w[a+480180>>2]==1|f>>>0>=65)){e=f;i=1;break Fa}m=13;l=f;break Fa}m=14;l=x[d+289|0];if(w[a+480180>>2]==32){break Fa}l=C((l&240)>>>4|0,10)+(l&15)|0;break Fa}l=x[d+289|0];m=l>>>0<32?16:17;break Fa}e=x[d+289|0];if(e>>>0>=16){i=(f|0)==20?3:5;e=e>>>4|0;break Fa}i=(f|0)==20?4:6;break Fa}e=x[d+289|0];f=e>>>0<16;e=f?e:e>>>4|0;i=f?9:10;break Fa}l=x[d+289|0]|16;m=28;break Fa}l=x[d+289|0]|32;m=28;break Fa}i=x[f+23744|0];e=x[d+289|0];break Fa}f=m&255;m=(f|0)==4?6:(f|0)==5?7:11;l=x[d+289|0];break Fa}f=x[d+289|0];e=(f>>>0)%10|0;if(f>>>0<10){i=5;break Fa}if(f>>>0<20){i=6;break Fa}if(f>>>0<30){i=3;break Fa}i=f>>>0<40?4:i;break Fa}i=x[f+23744|0];e=x[d+289|0];break Fa}J=x[d+289|0]+33|0;f=(J&255)>>>0<10;e=f?J:e;i=f?15:i;break Fa}if(f>>>0>55){break Fa}m=x[f+23744|0];l=x[d+289|0];break Fa}i=11;e=f;break Fa}l=f;m=9}k=k+1|0;if((k&255)>>>0<N>>>0){continue}break}}f=((s&240)>>>4|0)+j|0;f=f>>>0>q>>>0?q:f;if(f>>>0>j>>>0){while(1){u[h+5|0]=l;u[h+4|0]=e;u[h+3|0]=m;u[h+2|0]=i;u[h+1|0]=o;u[h|0]=n;h=C(x[d+1216|0],6)+h|0;j=j+1|0;if((f|0)!=(j|0)){continue}break}j=f}if(j>>>0<q>>>0){continue}break}}p=p+1|0;if(p>>>0<x[d+1216|0]){continue}break}}r=r+1|0;if(r>>>0<(x[d+1221|0]|x[d+1222|0]<<8)>>>0){continue}break}}j=0;cb:{db:{eb:{e=w[a+480180>>2];switch(e-1|0){case 3:break cb;case 0:break eb;default:break db}}if((g^1)&1|y[a+480188>>1]!=4){break db}w[a+480208>>2]=w[a+480208>>2]|8454144}j=!(x[d+1232|0]&2)}g=y[a+480192>>1];w[114256]=0;q=Q(468,d+1120|0,((e|0)==4?g:0)|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){fb:{if(y[a+480192>>1]){k=1;e=1;while(1){gb:{hb:{if(!j){w[114256]=0;g=S(243,a|0,e&65535,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break p}if(g){break hb}}while(1){w[114256]=0;g=Q(241,d+1640|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break o}if(x[d+288|0]?g:0){continue}break}ib:{if(x[d+1671|0]<5){break ib}while(1){w[114256]=0;g=Q(241,d+1640|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){f=P()|0;break n}if(!g){break ib}if(x[d+288|0]){continue}break}}g=w[d+1640>>2];f=w[w[g>>2]+36>>2];w[114256]=0;g=S(f|0,g|0,w[d+1648>>2],826)|0;f=w[114256];w[114256]=0;if((f|0)==1){break p}jb:{if(g){h=w[d+1648>>2]+826|0;break jb}g=w[d+1640>>2];f=w[w[g>>2]+24>>2];w[114256]=0;h=V(f|0,g|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break p}}w[d+1648>>2]=h;break gb}w[114256]=0;w[d+256>>2]=0;w[d+248>>2]=0;w[d+252>>2]=0;S(330,d+1640|0,d+248|0,-1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break q}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=g+492;Q(200,d+288|0,d+248|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break q}kb:{if(x[d+1671|0]<5){break kb}w[114256]=0;S(330,d+1640|0,d+248|0,-1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break q}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=g+524;Q(200,d+288|0,d+248|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break kb}break q}w[114256]=0;l=Q(469,d+1640|0,d+288|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break q}lb:{if(!l){break lb}f=w[a+480180>>2];w[114256]=0;U(470,d+288|0,g|0,f|0);g=w[114256];w[114256]=0;if((g|0)==1){break q}if(w[a+480180>>2]!=4){break lb}g=(w[q>>2]+(k<<2)|0)-4|0;f=y[d+1090>>1]|y[d+1092>>1]<<16;u[g|0]=f;u[g+1|0]=f>>>8;u[g+2|0]=f>>>16;u[g+3|0]=f>>>24}if(u[d+259|0]<0){zb(w[d+248>>2])}if(!l){break fb}}e=e+1|0;k=e&65535;if(k>>>0<=y[a+480192>>1]){continue}break}}if(!j){break fb}v[a+480192>>1]=0}e=y[a+480190>>1];g=0;w[114256]=0;r=Q(471,d+272|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){mb:{if(!y[a+480190>>1]){break mb}p=!(u[d+1231|0]&1)|x[d+1671|0]>4;n=c&2;f=1;e=0;j=1;while(1){w[114256]=0;w[d+160>>2]=0;w[d+152>>2]=0;w[d+156>>2]=0;S(330,d+1640|0,d+152|0,-1)|0;c=w[114256];w[114256]=0;nb:{ob:{pb:{qb:{rb:{if((c|0)==1){break rb}w[114256]=0;w[d+292>>2]=32;w[d+288>>2]=((f<<5)+a|0)+946304;Q(200,d+288|0,d+152|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break rb}o=C(f,104);l=o+a|0;if(x[d+1671|0]<5){break qb}w[114256]=0;S(330,d+1640|0,d+152|0,-1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break rb}w[114256]=0;w[d+292>>2]=22;w[d+288>>2]=l+484423;Q(200,d+288|0,d+152|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break qb}}f=P()|0;break pb}w[114256]=0;c=Q(472,d+1640|0,d+288|0)|0;g=w[114256];w[114256]=0;sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{if((g|0)==1){break zb}h=43;if(!c){break ob}g=w[a+480180>>2];w[114256]=0;c=l+484380|0;Y(473,d+288|0,c|0,g|0,p|0);g=w[114256];w[114256]=0;if((g|0)==1){break zb}m=0;if(!((y[d+308>>1]&61440)!=28672|x[d+1671|0]<5)){w[114256]=0;g=Q(474,d+1640|0,d+248|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break yb}m=g?y[d+248>>1]:0}h=45;if(!n){break ob}k=x[d+323|0]|x[d+324|0]<<8|(x[d+325|0]<<16|x[d+326|0]<<24);g=y[d+308>>1];i=g&61440;if(!(k|i)){w[114256]=0;v[d+250>>1]=0;u[d+249|0]=g&1024?3:1;u[d+248|0]=g&1?16:8;S(214,d+248|0,c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){h=0;break ob}f=P()|0;break pb}if((k|0)<0){h=0;g=f+k|0;if((g|0)<=0){break ob}i=C(g,104);g=w[(i+a|0)+484380>>2];if(g>>>0<z[c>>2]){w[c>>2]=g}k=a+484380|0;f=k+o|0;i=i+k|0;v[f+34>>1]=y[f+34>>1]&65470|y[i+34>>1]&65;if(!w[i+20>>2]|!g){break ob}w[114256]=0;g=V(252,c|0)|0;k=w[114256];w[114256]=0;if((k|0)!=1){if(!g){break ob}g=w[c>>2];c=y[f+34>>1];Fb(w[l+484400>>2],w[i+20>>2],C(C(g,c&64?2:1),c&1?2:1));break ob}f=P()|0;break pb}h=0;if(!k){break ob}if(g&1){o=l+484414|0;v[o>>1]=y[o>>1]|1}if(g&1024){o=l+484414|0;v[o>>1]=y[o>>1]|64}w[114256]=0;U(188,d+200|0,b|0,k|0);k=w[114256];w[114256]=0;if((k|0)==1){break xb}t=l+484414|0;o=y[t>>1];Ab:{Bb:{B=(i|0)==16384;if(!B&(i|0)!=8192){break Bb}k=w[d+200>>2];s=w[w[k>>2]+24>>2];w[114256]=0;k=V(s|0,k|0)|0;s=w[114256];w[114256]=0;if((s|0)==1){break Ab}o=o&64;Cb:{if(k>>>0>(o?2147483647:1073741823)>>>0){break Cb}k=C(k,o?2:4);if(k>>>0>=z[c>>2]){break Cb}w[c>>2]=k}k=o?2:1;if(!B){if((i|0)!=8192){break Bb}w[114256]=0;g=V(252,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break tb}if(!g){break vb}g=w[l+484400>>2];c=w[c>>2];if(u[d+308|0]&1){w[114256]=0;Y(475,d+200|0,g|0,c|0,k|0);c=w[114256];w[114256]=0;g=e;if((c|0)!=1){break ub}break tb}w[114256]=0;Y(476,d+200|0,g|0,c|0,k|0);c=w[114256];w[114256]=0;g=e;if((c|0)==1){break tb}break ub}w[114256]=0;g=V(252,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break tb}if(!g){break vb}g=w[l+484400>>2];c=w[c>>2];if(u[d+308|0]&1){w[114256]=0;Y(477,d+200|0,g|0,c|0,k|0);c=w[114256];w[114256]=0;g=e;if((c|0)==1){break tb}break ub}w[114256]=0;Y(478,d+200|0,g|0,c|0,k|0);c=w[114256];w[114256]=0;g=e;if((c|0)==1){break tb}break ub}if((g&45056)==12288){w[d+248>>2]=w[d+200>>2];c=w[d+204>>2];w[d+252>>2]=c;g=x[d+327|0]|x[d+328|0]<<8;if(c){w[c+4>>2]=w[c+4>>2]+1}v[d+266>>1]=m;v[d+264>>1]=g;c=w[d+212>>2];w[d+256>>2]=w[d+208>>2];w[d+260>>2]=c;c=(w[r>>2]+C(f,20)|0)-20|0;g=d+248|0;he(c,g);f=w[d+260>>2];w[c+8>>2]=w[d+256>>2];w[c+12>>2]=f;w[c+16>>2]=w[d+264>>2];Bb(g);break vb}if((i|0)!=32768){g=1;if((i|0)!=4096){break ub}w[d+248>>2]=w[d+200>>2];g=w[d+204>>2];w[d+252>>2]=g;if(g){w[g+4>>2]=w[g+4>>2]+1}w[114256]=0;g=w[d+212>>2];w[d+256>>2]=w[d+208>>2];w[d+260>>2]=g;g=Q(479,d+240|0,d+200|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){Db:{if(!x[d+245|0]){break Db}i=x[d+327|0]|x[d+328|0]<<8;f=y[d+242>>1]<<1;if(i>>>0<(f&65535)>>>0){break Db}f=i-f|0;u[d+327|0]=f;u[d+328|0]=f>>>8;g=y[g>>1];Eb:{if(g>>>0>z[d+208>>2]){f=w[d+200>>2];i=w[w[f>>2]+24>>2];w[114256]=0;f=V(i|0,f|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break wb}if(f>>>0<g>>>0){break Eb}}w[d+208>>2]=g}g=w[d+200>>2];f=w[w[g>>2]+24>>2];w[114256]=0;g=V(f|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break wb}w[114256]=0;U(188,d+224|0,d+200|0,g-w[d+208>>2]|0);g=w[114256];w[114256]=0;if((g|0)==1){break wb}f=w[d+224>>2];i=w[d+228>>2];w[d+224>>2]=0;w[d+228>>2]=0;g=w[d+252>>2];w[d+248>>2]=f;w[d+252>>2]=i;Fb:{if(!g){break Fb}f=w[g+4>>2];w[g+4>>2]=f-1;if(f){break Fb}ob[w[w[g>>2]+8>>2]](g);Ib(g)}g=w[d+236>>2];w[d+256>>2]=w[d+232>>2];w[d+260>>2]=g;Bb(d+224|0)}w[114256]=0;g=j&65535;f=da(480,a|0,g|0,d+248|0,1,1)|0;i=w[114256];w[114256]=0;if((i|0)==1){break wb}Gb:{if(!f){w[114256]=0;f=Z(481,a|0,g|0,d+248|0,1)|0;g=w[114256];w[114256]=0;if((g|0)==1){break wb}g=1;if(!f){break Gb}}g=x[d+327|0]|x[d+328|0]<<8;Hb:{if(!g){i=w[c>>2];break Hb}i=w[c>>2];f=y[t>>1];k=f&64?2:1;f=f&1?2:1;m=C(C(i,k),f);if(m>>>0<=g>>>0){break Hb}l=w[l+484400>>2];hc(l,g+l|0,m-g|0);i=w[c>>2]-((g>>>0)/(C(f,k)>>>0)|0)|0;w[c>>2]=i}g=w[d+296>>2];if(g>>>0<i>>>0){w[c>>2]=g}g=e}Bb(d+248|0);break ub}break wb}w[114256]=0;g=Q(362,d+200|0,d+248|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(!g){break vb}w[114256]=0;w[d+16>>2]=w[d+256>>2];g=w[d+252>>2];w[d+8>>2]=w[d+248>>2];w[d+12>>2]=g;U(363,c|0,1,d+8|0);c=w[114256];w[114256]=0;if((c|0)!=1){break vb}}f=P()|0;break sb}f=P()|0;break sb}f=P()|0;break pb}f=P()|0;break pb}f=P()|0;break pb}f=P()|0;Bb(d+248|0);break sb}g=e}Bb(d+200|0);break nb}f=P()|0}Bb(d+200|0)}if(u[d+163|0]>=0){break r}zb(w[d+152>>2]);break r}g=e}if(u[d+163|0]<0){zb(w[d+152>>2])}Ib:{if(!(!h|(h|0)==45)){h=y[a+480190>>1];break Ib}e=g;j=j+1|0;f=j&65535;h=y[a+480190>>1];if(f>>>0<=h>>>0){continue}}break}if(!n|!(h&65535)){break mb}f=1;c=1;while(1){l=w[r>>2]+C(f-1|0,20)|0;b=w[l>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;Jb:{Kb:{Lb:{if((e|0)!=1){if(!b){break Jb}Mb:{Nb:{Ob:{b=y[l+18>>1];Pb:{if(!b){break Pb}b=b+c&65535;if(!b|b>>>0>y[a+480190>>1]){break Pb}e=y[l+16>>1];if(e){break Ob}}b=w[l>>2];e=w[w[b>>2]+24>>2];w[114256]=0;V(e|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break Nb}break s}b=(w[r>>2]+C(b,20)|0)-20|0;w[b+8>>2]=0;i=w[b>>2];k=w[w[i>>2]+36>>2];w[114256]=0;i=S(k|0,i|0,0,e|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break s}if(!i){break Jb}w[114256]=0;w[d+288>>2]=0;w[d+224>>2]=0;e=S(482,d+248|0,b|0,e|0)|0;i=w[114256];w[114256]=0;Qb:{if((i|0)!=1){e=w[e>>2];w[114256]=0;i=w[d+252>>2];k=w[d+256>>2];k=da(483,(i?i:(k|0)!=w[d+260>>2]?k:0)|0,(e>>>0>=2147483647?2147483647:e)|0,d+288|0,d+224|0,0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Qb}w[114256]=0;Q(242,b|0,w[d+288>>2])|0;b=w[114256];w[114256]=0;if((b|0)==1){break Qb}b=w[d+256>>2];if(b){w[d+260>>2]=b;zb(b)}b=1;break Mb}f=P()|0;break r}f=P()|0;a=w[d+256>>2];if(!a){break r}w[d+260>>2]=a;zb(a);break r}w[l+8>>2]=0;w[d+288>>2]=0;w[d+224>>2]=0;k=0;b=0}w[114256]=0;e=Q(484,d+200|0,l|0)|0;i=w[114256];w[114256]=0;Rb:{Sb:{if((i|0)!=1){i=w[d+204>>2];j=w[d+208>>2];o=i?i:(j|0)!=w[d+212>>2]?j:0;n=w[e>>2];if(!b){w[114256]=0;k=da(483,o|0,(n>>>0>=2147483647?2147483647:n)|0,d+288|0,d+224|0,0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Rb}w[114256]=0;Q(242,l|0,w[d+288>>2])|0;b=w[114256];w[114256]=0;if((b|0)==1){break Rb}b=w[d+288>>2];n=n-b|0;o=b+o|0}if(k){break Sb}g=1;break Kb}f=P()|0;break r}w[114256]=0;b=C(f,104)+a|0;t=b+484380|0;V(252,t|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Lb}B=b+484414|0;s=b+484400|0;m=0;h=w[d+224>>2];while(1){if(!(!w[s>>2]|(z[t>>2]<=m>>>0|(!n|(h|0)!=1?h:0)))){w[114256]=0;w[d+152>>2]=0;w[d+184>>2]=0;b=la(485,k|0,o|0,(n>>>0>=2147483647?2147483647:n)|0,d+152|0,d+136|0,d+184|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Lb}w[d+288>>2]=b;e=w[l+8>>2];f=w[l>>2];i=w[w[f>>2]+36>>2];w[114256]=0;e=S(i|0,f|0,e|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Lb}Tb:{if(e){h=b+w[l+8>>2]|0;break Tb}b=w[l>>2];e=w[w[b>>2]+24>>2];w[114256]=0;h=V(e|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Lb}}w[l+8>>2]=h;f=w[d+184>>2];b=w[t>>2]-m|0;b=b>>>0>=2147483647?2147483647:b;if((f|0)>(b|0)){w[d+184>>2]=b;f=b}I=w[d+288>>2];Ub:{if((f|0)<=0){break Ub}j=w[d+152>>2];if((j|0)!=((x[B|0]&64?2:1)|0)){break Ub}e=0;if((j|0)<=0){break Ub}while(1){h=w[w[d+136>>2]+(e<<2)>>2];f=w[s>>2];b=w[d+184>>2];i=y[B>>1];Vb:{if(i&1){if(!b){break Vb}f=(f+(C(i&64?2:1,m)<<1)|0)+(e<<1)|0;i=0;while(1){K=_b(D(D(H(D(G(A[h>>2],D(1))),D(-1)))*D(32768)));Wb:{if(D(E(K))<D(2147483648)){p=~~K;break Wb}p=-2147483648}p=(p|0)>=32767?32767:p;v[f>>1]=(p|0)<=-32768?-32768:p;h=h+4|0;f=(j<<1)+f|0;i=i+1|0;if((b|0)!=(i|0)){continue}break}break Vb}if(!b){break Vb}f=(f+C(i&64?2:1,m)|0)+e|0;i=0;while(1){K=_b(D(D(H(D(G(A[h>>2],D(1))),D(-1)))*D(128)));Xb:{if(D(E(K))<D(2147483648)){p=~~K;break Xb}p=-2147483648}p=(p|0)>=127?127:p;u[f|0]=(p|0)<=-128?-128:p;f=f+j|0;h=h+4|0;i=i+1|0;if((b|0)!=(i|0)){continue}break}}e=e+1|0;j=w[d+152>>2];if((e|0)<(j|0)){continue}break}f=w[d+184>>2]}w[114256]=0;h=V(486,k|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Lb}n=n-I|0;o=o+I|0;w[d+224>>2]=h;m=f+m|0;continue}break}w[114256]=0;X(487,k|0);b=w[114256];w[114256]=0;if((b|0)!=1){break Kb}break Lb}break Lb}f=P()|0;break r}f=P()|0;a=w[d+208>>2];if(!a){break r}w[d+212>>2]=a;zb(a);break r}b=w[d+208>>2];if(!b){break Jb}w[d+212>>2]=b;zb(b)}c=c+1|0;f=c&65535;if(f>>>0<=y[a+480190>>1]){continue}break}}Yb:{if(w[a+480180>>2]!=4){break Yb}h=0;while(1){if(y[a+480192>>1]<=h>>>0){break Yb}b=w[q>>2]+(h<<2)|0;c=x[b+3|0];e=x[b+2|0];f=x[b+1|0];b=x[b|0];w[114256]=0;h=h+1|0;ia(488,a|0,h&65535,b|0,f|0,e|0,c|0);b=w[114256];w[114256]=0;if((b|0)!=1){continue}break}f=P()|0;break r}Zb:{_b:{$b:{ac:{if(!(x[d+1233|0]&16)){break ac}b=w[d+1640>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+1648>>2],1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break t}if(!b){break ac}h=0;w[114256]=0;b=Q(241,d+1640|0,d+288|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break u}if(!(!y[a+480188>>1]|(b&x[d+288|0])!=1)){while(1){w[114256]=0;b=Q(232,d+1640|0,d+288|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Zb}u[((h<<5)+a|0)+480288|0]=b?x[d+288|0]:0;h=h+1|0;if(h>>>0<y[a+480188>>1]){continue}break}}while(1){b=w[d+1640>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+1648>>2],1)|0;c=w[114256];w[114256]=0;bc:{if((c|0)!=1){if(!b){break ac}w[114256]=0;b=Q(241,d+1640|0,d+288|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break _b}if(!b){break ac}b=x[d+288|0];if(!b){break ac}w[114256]=0;c=Q(232,d+1640|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $b}w[114256]=0;U(188,d+288|0,d+1640|0,(c?w[d+224>>2]:0)|0);c=w[114256];w[114256]=0;if((c|0)==1){break $b}if(b>>>0>250){break bc}w[114256]=0;T(386,d+288|0,(C(b,160)+a|0)+906140|0);b=w[114256];w[114256]=0;if((b|0)!=1){break bc}f=P()|0;Bb(d+288|0);break r}f=P()|0;break r}Bb(d+288|0);continue}}w[d+192>>2]=0;w[d+184>>2]=0;w[d+188>>2]=0;k=a+901404|0;c=a+1074308|0;f=d+152|4;l=d+168|4;i=d+184|4;e=0;n=0;while(1){b=w[d+1640>>2];j=w[w[b>>2]+36>>2];w[114256]=0;b=S(j|0,b|0,w[d+1648>>2],8)|0;j=w[114256];w[114256]=0;cc:{dc:{ec:{fc:{gc:{hc:{ic:{jc:{kc:{if((j|0)!=1){if(b){w[114256]=0;b=Q(232,d+1640|0,d+288|0)|0;j=w[114256];w[114256]=0;lc:{mc:{nc:{oc:{pc:{qc:{rc:{if((j|0)!=1){w[114256]=0;j=w[d+288>>2];h=Q(232,d+1640|0,d+288|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break rc}w[114256]=0;U(188,d+224|0,d+1640|0,(h?w[d+288>>2]:0)|0);h=w[114256];w[114256]=0;if((h|0)==1){break qc}b=b?j:0;if((b|0)<=1397900629){if((b|0)==1229211981){break oc}if((b|0)!=1229476432){break cc}w[114256]=0;b=Q(241,d+224|0,d+288|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break gc}w[a+480216>>2]=b?x[d+288|0]:0;w[114256]=0;b=Q(241,d+224|0,d+288|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break gc}w[a+480220>>2]=b?x[d+288|0]:0;break cc}if((b|0)==1397900630){break pc}if((b|0)!=1414548815){break cc}w[114256]=0;b=S(343,d+224|0,9590,4)|0;j=w[114256];w[114256]=0;if((j|0)==1){break gc}if(!b){break mc}w[114256]=0;b=Q(232,d+224|0,d+288|0)|0;j=w[114256];w[114256]=0;if((j|0)!=1){w[114256]=0;U(188,d+152|0,d+224|0,(b?w[d+288>>2]:0)|0);b=w[114256];w[114256]=0;if((b|0)!=1){break nc}}f=P()|0;break fc}f=P()|0;break dc}f=P()|0;break dc}f=P()|0;break dc}sc:{tc:{uc:{vc:{b=w[a+480180>>2];switch(b-2|0){case 1:break cc;case 2:break tc;case 0:break uc;default:break vc}}if((b|0)==16){break sc}if((b|0)!=32){break cc}w[114256]=0;b=Q(197,d+224|0,d+288|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break gc}w[114256]=0;e=y[d+288>>1];j=Q(197,d+224|0,d+288|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break gc}n=j?y[d+288>>1]:0;e=b?e:0;break cc}w[114256]=0;b=Q(197,d+224|0,d+288|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break gc}e=b?y[d+288>>1]:0;break cc}b=w[d+224>>2];j=w[w[b>>2]+24>>2];w[114256]=0;b=V(j|0,b|0)|0;j=w[114256];w[114256]=0;if((j|0)!=1){w[114256]=0;Z(489,d+224|0,d+184|0,4,(b>>>0>=32?32:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break cc}}f=P()|0;break fc}w[114256]=0;h=Q(241,d+224|0,d+288|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break lc}w[114256]=0;m=x[d+288|0];b=Q(1,d+168|0,10824)|0;j=w[114256];w[114256]=0;wc:{if((j|0)!=1){o=w[b>>2];w[f>>2]=w[l>>2];j=x[l+3|0]|x[l+4|0]<<8|(x[l+5|0]<<16|x[l+6|0]<<24);u[f+3|0]=j;u[f+4|0]=j>>>8;u[f+5|0]=j>>>16;u[f+6|0]=j>>>24;j=x[d+179|0];w[b+8>>2]=0;w[b>>2]=0;w[b+4>>2]=0;w[114256]=0;u[d+163|0]=j;w[d+152>>2]=o;j=h?m:0;w[d+72>>2]=j>>>4;w[d+56>>2]=j&15;Y(292,d+288|0,d+152|0,d+72|0,d+56|0);j=w[114256];w[114256]=0;if((j|0)==1){break wc}if(u[d+195|0]<0){zb(w[d+184>>2])}w[d+192>>2]=w[d+296>>2];j=w[d+292>>2];w[d+184>>2]=w[d+288>>2];w[d+188>>2]=j;u[d+288|0]=0;u[d+299|0]=0;if(u[d+163|0]<0){zb(w[d+152>>2])}if(u[d+179|0]>=0){break cc}zb(w[b>>2]);break cc}f=P()|0;break fc}f=P()|0;if(u[d+163|0]<0){zb(w[d+152>>2])}if(u[d+179|0]>=0){break fc}zb(w[b>>2]);break fc}w[114256]=0;b=Q(354,d+224|0,k|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break gc}if(!b){Cb(k,0,4896)}w[114256]=0;X(355,k|0);b=w[114256];w[114256]=0;if((b|0)!=1){break cc}break gc}b=w[d+152>>2];j=w[w[b>>2]+24>>2];w[114256]=0;b=V(j|0,b|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break hc}j=(w[a+484348>>2]-w[a+484344>>2]|0)/52&65535;b=b>>>5&65535;b=b>>>0>j>>>0?j:b;if(b){h=0;while(1){w[114256]=0;S(375,d+152|0,d+288|0,32)|0;j=w[114256];w[114256]=0;if((j|0)==1){break hc}j=w[a+484344>>2];w[114256]=0;S(227,j+C(h,52)|0,d+288|0,32)|0;j=w[114256];w[114256]=0;if((j|0)==1){break hc}h=h+1|0;if((b|0)!=(h|0)){continue}break}}Bb(d+152|0)}w[114256]=0;b=S(343,d+224|0,9595,4)|0;j=w[114256];w[114256]=0;if((j|0)==1){break gc}if(b){w[114256]=0;b=Q(232,d+224|0,d+152|0)|0;j=w[114256];w[114256]=0;xc:{if((j|0)!=1){w[114256]=0;U(188,d+288|0,d+224|0,(b?w[d+152>>2]:0)|0);b=w[114256];w[114256]=0;if((b|0)!=1){break xc}}f=P()|0;break fc}b=w[d+288>>2];j=w[w[b>>2]+24>>2];w[114256]=0;b=V(j|0,b|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break ic}j=y[a+480188>>1];b=(b>>>0)/20&65535;b=b>>>0>j>>>0?j:b;if(b){h=0;while(1){w[114256]=0;S(357,d+288|0,((h<<5)+a|0)+480289|0,20)|0;j=w[114256];w[114256]=0;if((j|0)==1){break ic}h=h+1|0;if((b|0)!=(h|0)){continue}break}}Bb(d+288|0)}w[114256]=0;Q(372,a|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break gc}w[114256]=0;Y(373,a|0,d+224|0,1,0);b=w[114256];w[114256]=0;if((b|0)==1){break gc}if((e-2186&65535)>>>0<=117){w[a+480180>>2]=16777216;w[114256]=0;U(385,a|0,d+224|0,e&65535);b=w[114256];w[114256]=0;if((b|0)==1){break gc}}if(!w[c>>2]){break cc}w[114256]=0;j=Q(1,d+136|0,13266)|0;b=w[114256];w[114256]=0;yc:{zc:{Ac:{if((b|0)!=1){w[114256]=0;T(120,d+288|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){break Ac}w[114256]=0;b=x[d+299|0];h=b<<24>>24<0;b=S(2,j|0,(h?w[d+288>>2]:d+288|0)|0,(h?w[d+292>>2]:b)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break zc}m=w[b>>2];w[d+152>>2]=w[b+4>>2];h=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+155|0]=h;u[d+156|0]=h>>>8;u[d+157|0]=h>>>16;u[d+158|0]=h>>>24;w[b>>2]=0;w[b+4>>2]=0;h=x[b+11|0];w[b+8>>2]=0;if(u[d+195|0]<0){zb(w[d+184>>2])}w[d+184>>2]=m;b=x[d+155|0]|x[d+156|0]<<8|(x[d+157|0]<<16|x[d+158|0]<<24);u[i+3|0]=b;u[i+4|0]=b>>>8;u[i+5|0]=b>>>16;u[i+6|0]=b>>>24;w[i>>2]=w[d+152>>2];u[d+195|0]=h;if(u[d+299|0]<0){zb(w[d+288>>2])}if(u[d+147|0]>=0){break cc}zb(w[j>>2]);break cc}f=P()|0;break fc}f=P()|0;break yc}f=P()|0;if(u[d+299|0]>=0){break yc}zb(w[d+288>>2])}if(u[d+147|0]>=0){break fc}zb(w[j>>2]);break fc}f=P()|0;break fc}b=w[a+480180>>2];Bc:{Cc:{Dc:{if((b|0)!=32){break Dc}f=e&65535;if(f>>>0<256){break Dc}if(f>>>0<532){break Cc}}b=(b|0)!=2;Ec:{if(b){break Ec}f=e&65535;if(f>>>0<12544){break Ec}if(f>>>0<12820){break Cc}}if(b){break Bc}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Bc}}w[114256]=0;X(356,k|0);b=w[114256];w[114256]=0;if((b|0)==1){break ec}}Fc:{if(!(u[d+1233|0]&1)){break Fc}Gc:{Hc:{Ic:{Jc:{h=w[c>>2];Kc:{if(!h){k=y[a+480192>>1];if(!k){break Kc}h=1;while(1){b=w[(((h&65535)<<2)+a|0)+900380>>2];if(b){e=w[a+480180>>2];w[114256]=0;U(490,b+88|0,4,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break kc}u[b+19|0]=x[b+19|0]+3>>>2;k=y[a+480192>>1]}h=h+1|0;if((h&65535)>>>0<=(k&65535)>>>0){continue}break}h=w[c>>2]}if(h>>>0>18350079){break Jc}}w[a+1074312>>2]=w[a+1074312>>2]&-134217729;b=a+1074316|0;w[b>>2]=w[b>>2]&-33554433;break Ic}if(h>>>0>19070975){break Hc}}b=a+1074320|0;w[b>>2]=w[b>>2]&-513;break Gc}if(h>>>0>19267583){break Fc}}b=a+1074316|0;w[b>>2]=w[b>>2]&-262145}b=x[d+195|0];if(!(b<<24>>24<0?w[d+188>>2]:b)){w[114256]=0;b=Q(1,d+120|0,11250)|0;e=w[114256];w[114256]=0;Lc:{if((e|0)!=1){f=w[b>>2];w[d+228>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+231|0]=e;u[d+232|0]=e>>>8;u[d+233|0]=e>>>16;u[d+234|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+235|0]=e;w[d+224>>2]=f;U(295,d+288|0,d+224|0,d+1671|0);e=w[114256];w[114256]=0;if((e|0)==1){break Lc}if(u[d+195|0]<0){zb(w[d+184>>2])}w[d+192>>2]=w[d+296>>2];e=w[d+292>>2];w[d+184>>2]=w[d+288>>2];w[d+188>>2]=e;u[d+288|0]=0;u[d+299|0]=0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]>=0){break jc}zb(w[b>>2]);break jc}f=P()|0;break dc}f=P()|0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]>=0){break dc}zb(w[b>>2]);break dc}w[114256]=0;b=Q(1,d+104|0,12983)|0;e=w[114256];w[114256]=0;Mc:{if((e|0)!=1){f=w[b>>2];w[d+228>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+231|0]=e;u[d+232|0]=e>>>8;u[d+233|0]=e>>>16;u[d+234|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+235|0]=e;w[d+224>>2]=f;Y(240,d+288|0,d+224|0,d+1671|0,d+184|0);e=w[114256];w[114256]=0;if((e|0)==1){break Mc}if(u[d+195|0]<0){zb(w[d+184>>2])}w[d+192>>2]=w[d+296>>2];e=w[d+292>>2];w[d+184>>2]=w[d+288>>2];w[d+188>>2]=e;u[d+288|0]=0;u[d+299|0]=0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]>=0){break jc}zb(w[b>>2]);break jc}f=P()|0;break dc}f=P()|0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]>=0){break dc}zb(w[b>>2]);break dc}f=P()|0;break dc}f=P()|0;break dc}w[114256]=0;b=Q(1,d+88|0,11242)|0;e=w[114256];w[114256]=0;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{Vc:{if((e|0)!=1){f=w[b>>2];w[d+228>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+231|0]=e;u[d+232|0]=e>>>8;u[d+233|0]=e>>>16;u[d+234|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+235|0]=e;w[d+224>>2]=f;U(295,d+288|0,d+224|0,d+1671|0);e=w[114256];w[114256]=0;if((e|0)==1){break Vc}e=a+1304436|0;if(u[a+1304447|0]<0){zb(w[e>>2])}f=w[d+292>>2];w[e>>2]=w[d+288>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+296>>2];u[d+299|0]=0;u[d+288|0]=0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]<0){zb(w[b>>2])}w[114256]=0;e=Q(1,d+224|0,10491)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Uc}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];b=w[a+480180>>2];if((b|0)<=15){switch(b-1|0){case 1:break Qc;case 3:break Rc;case 0:break Sc;default:break Nc}}if((b|0)==16){break Tc}if((b|0)==32){break Pc}if((b|0)==16777216){break Oc}break Nc}f=P()|0;break dc}f=P()|0;if(u[d+235|0]<0){zb(w[d+224>>2])}if(u[b+11|0]>=0){break dc}zb(w[b>>2]);break dc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+288|0,6069)|0;b=w[114256];w[114256]=0;Wc:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+152|0,4564)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Wc}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+288|0,8092)|0;b=w[114256];w[114256]=0;Xc:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+152|0,9882)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Xc}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+288|0,6042)|0;b=w[114256];w[114256]=0;Yc:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+152|0,11025)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Yc}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+288|0,6414)|0;b=w[114256];w[114256]=0;Zc:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+152|0,10589)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Zc}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+152|0,2520)|0;b=w[114256];w[114256]=0;_c:{$c:{ad:{bd:{cd:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];if(!(n&65535)){break _c}w[114256]=0;b=Q(1,d+40|0,10927)|0;e=w[114256];w[114256]=0;if((e|0)==1){break cd}f=w[b>>2];w[d+60>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+63|0]=e;u[d+64|0]=e>>>8;u[d+65|0]=e>>>16;u[d+66|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+67|0]=e;w[d+56>>2]=f;w[d+36>>2]=(n&65280)>>>8;w[d+20>>2]=n&255;u[d+304|0]=44;w[d+296>>2]=-1;w[d+300>>2]=0;w[d+288>>2]=1042;w[d+292>>2]=2;U(101,d+24|0,d+20|0,d+288|0);e=w[114256];w[114256]=0;if((e|0)==1){break bd}w[114256]=0;Y(366,d+72|0,d+56|0,d+36|0,d+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break ad}e=a+1304472|0;if(u[a+1304483|0]<0){zb(w[e>>2])}f=w[d+76>>2];w[e>>2]=w[d+72>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+80>>2];u[d+83|0]=0;u[d+72|0]=0;if(u[d+35|0]<0){zb(w[d+24>>2])}if(u[d+67|0]<0){zb(w[d+56>>2])}if(u[b+11|0]>=0){break Nc}zb(w[b>>2]);break Nc}f=P()|0;break dc}f=P()|0;break dc}f=P()|0;break $c}f=P()|0;if(u[d+35|0]>=0){break $c}zb(w[d+24>>2])}if(u[d+67|0]<0){zb(w[d+56>>2])}if(u[b+11|0]>=0){break dc}zb(w[b>>2]);break dc}w[114256]=0;e=Q(1,d+288|0,4724)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}w[114256]=0;e=Q(1,d+288|0,6064)|0;b=w[114256];w[114256]=0;dd:{if((b|0)!=1){b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+152|0,9552)|0;b=w[114256];w[114256]=0;if((b|0)==1){break dd}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break Nc}f=P()|0;break dc}f=P()|0;break dc}b=a+1304460|0;if(u[a+1304471|0]<0){zb(w[b>>2])}e=w[d+188>>2];w[b>>2]=w[d+184>>2];w[b+4>>2]=e;w[b+8>>2]=w[d+192>>2];u[d+195|0]=0;u[d+184|0]=0;ed:{if(w[c>>2]){w[a+1304496>>2]=7;break ed}if(w[a+480180>>2]==1){w[a+1304496>>2]=2;break ed}w[a+1304496>>2]=4}fd:{gd:{hd:{if(!(g&1)){break hd}w[114256]=0;b=Q(1,d+72|0,12413)|0;c=w[114256];w[114256]=0;if((c|0)==1){break gd}w[114256]=0;U(367,a|0,2,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break fd}if(u[b+11|0]<0){zb(w[b>>2])}if(u[d+195|0]>=0){break hd}zb(w[d+184>>2])}Bp(r);a=w[q>>2];if(a){w[q+4>>2]=a;zb(a)}gc(F);Bb(d+1152|0);Bb(d+1168|0);h=1;break x}f=P()|0;break dc}f=P()|0;if(u[b+11|0]>=0){break dc}zb(w[b>>2]);break dc}f=P()|0;Bb(d+288|0);break fc}f=P()|0;Bb(d+152|0);break fc}f=P()|0}Bb(d+224|0);break dc}f=P()|0}if(u[d+195|0]>=0){break r}zb(w[d+184>>2]);break r}b=w[d+228>>2];if(!b){continue}j=w[b+4>>2];w[b+4>>2]=j-1;if(j){continue}ob[w[w[b>>2]+8>>2]](b);Ib(b);continue}}f=P()|0;break r}f=P()|0;break r}f=P()|0;break r}f=P()|0;break n}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break c}h=0;break w}f=P()|0;break f}a=w[d+1644>>2];if(!a){break w}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break w}ob[w[w[a>>2]+8>>2]](a);Ib(a)}f=w[d+1656>>2]}if(!f){break a}w[d+1660>>2]=f;zb(f);break a}f=P()|0;break r}f=P()|0;break r}f=P()|0}Bp(r);break n}f=P()|0;if(u[d+259|0]>=0){break n}zb(w[d+248>>2]);break n}f=P()|0;break n}f=P()|0}a=w[q>>2];if(!a){break k}w[q+4>>2]=a;zb(a);break k}f=P()|0;break k}f=P()|0}gc(F)}Bb(d+1152|0)}Bb(d+1168|0);break f}f=P()|0;if(u[d+1211|0]>=0){break f}zb(w[e>>2]);break f}f=P()|0}Bb(d+1640|0);break c}w[114256]=0;X(491,d+1656|0);a=w[114256];w[114256]=0;if((a|0)==1){break d}M()}f=P()|0}a=w[d+1656>>2];if(a){w[d+1660>>2]=a;zb(a)}R(f|0);M()}jb=d+1712|0;return h|0}function IC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,W=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0;e=jb-960|0;jb=e;w[b+8>>2]=0;a:{if(!Gp(b,e+480|0)){break a}if(!Ip(e+480|0)){break a}f=w[b>>2];m=w[b+8>>2];i=Hp(e+480|0);k=m;m=nb;A=m;m=!m&(i|0)==-1|(m|0)!=0;if(!(ob[w[w[f>>2]+36>>2]](f,k,m?-1:i)|0)){break a}if(!c){d=1;break a}tc(a,8);je(a);u[e+479|0]=x[e+483|0]-48;d=w[e+488>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);b:{if(d>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<d>>>0){break b}}w[b+8>>2]=d}oc(e+456|0,b,504);w[114256]=0;d=Q(434,b|0,e+168|0)|0;f=w[114256];w[114256]=0;c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){j:{if(!d){Cb(e+168|0,0,284);break j}d=0;if(x[e+451|0]>63){break c}}d=0;if(x[e+168|0]&128){break c}Cb(e+88|0,0,80);d=w[e+512>>2];k:{if(!d){break k}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){f=w[b>>2];i=w[w[f>>2]+24>>2];w[114256]=0;f=V(i|0,f|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break i}if(d>>>0>f>>>0){break k}}w[b+8>>2]=d;w[114256]=0;d=Q(435,b|0,e+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}if(d){break k}Cb(e+88|0,0,80)}i=x[e+479|0];w[b+8>>2]=0;w[114256]=0;Y(436,b|0,e+904|0,e+824|0,e+536|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=x[e+955|0];d=d>>>0>=254?254:d;A=w[e+936>>2]?(d>>>0>=49?49:d)+1|0:1;h=4;l:{while(1){m:{if(x[e+819|0]<=63){d=y[e+536>>1];f=(d<<8|d>>>8)<<16>>16;if((f|0)>=0){break m}}d=0;break c}n:{if(d){d=f&65535;m=d>>>0<=1?1:d;f=0;while(1){d=w[e+920>>2];d=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))+(f<<2)|0;o:{if(d>>>0>z[b+8>>2]){k=w[b>>2];n=w[w[k>>2]+24>>2];w[114256]=0;k=V(n|0,k|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break n}if(d>>>0>k>>>0){break o}}w[b+8>>2]=d;w[114256]=0;d=Q(268,b|0,e+72|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break n}p:{if(!d){d=0;break p}d=w[e+72>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if(d>>>0<=z[b+8>>2]){break p}k=w[b>>2];n=w[w[k>>2]+24>>2];w[114256]=0;k=V(n|0,k|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break n}if(d>>>0>k>>>0){break o}}w[b+8>>2]=d;q:{if(!i){w[114256]=0;d=Q(241,b|0,e+72|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break n}d=d?x[e+72|0]:0;break q}w[114256]=0;k=Q(261,b|0,e+72|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=0;if(!k){break q}d=y[e+72>>1];d=d<<8|d>>>8}k=h&65535;d=d&65535;h=d>>>0<k>>>0?k:d}f=f+1|0;if((m|0)!=(f|0)){continue}break}}d=w[e+824>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if(d>>>0<=g>>>0){break h}g=d;if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break l}if(d>>>0>f>>>0){break h}f=w[e+824>>2];g=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24)}w[b+8>>2]=d;w[114256]=0;Y(436,b|0,e+904|0,e+824|0,e+536|0);d=w[114256];w[114256]=0;if((d|0)==1){break l}l=l+1|0;if((l&255)>>>0<(A&255)>>>0){continue}break g}break}f=P()|0;break f}f=P()|0;break f}f=P()|0;break f}f=P()|0;break f}f=P()|0;break f}A=l+1|0}d=0;if((h-128&65535)>>>0<65409){break c}v[a+480188>>1]=h;w[e+80>>2]=0;w[e+72>>2]=0;w[e+76>>2]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{f=w[e+504>>2];F:{if(f){d=f<<8&16711680|f<<24|(f>>>8&65280|f>>>24);G:{if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break E}if(d>>>0>f>>>0){break G}}w[b+8>>2]=d}w[114256]=0;S(437,b|0,e+72|0,x[e+451|0])|0;d=w[114256];w[114256]=0;if((d|0)==1){break E}d=x[e+451|0];break F}if(x[e+451|0]){break d}}d=d&255;v[a+480192>>1]=d;v[a+480190>>1]=d;I=x[e+479|0]<2|u[e+432|0]>=0;H:{if(d){p=c&2;B=!I;h=1;g=1;q=1;while(1){w[114256]=0;n=q&65535;d=S(243,a|0,g&65535,n|0)|0;f=w[114256];w[114256]=0;I:{if((f|0)!=1){if(d){break I}break e}f=P()|0;break r}f=h<<2;k=w[(f+a|0)+900380>>2];w[114256]=0;v[e+908>>1]=0;w[e+904>>2]=0;d=V(22,16)|0;i=w[114256];w[114256]=0;J:{K:{if((i|0)!=1){w[d+4>>2]=0;w[d+8>>2]=0;w[d+12>>2]=75696;w[d>>2]=75656;w[e+544>>2]=0;w[e+548>>2]=0;w[e+540>>2]=d;w[e+536>>2]=d+12;d=(f+w[e+72>>2]|0)-4|0;d=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);if(!d){break J}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){f=w[b>>2];i=w[w[f>>2]+24>>2];w[114256]=0;f=V(i|0,f|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break s}if(d>>>0>f>>>0){break J}}w[b+8>>2]=d;w[114256]=0;d=Q(438,b|0,e+904|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}L:{if(d){f=y[e+908>>1];d=w[e+904>>2];break L}f=0;v[e+908>>1]=0;w[e+904>>2]=0;d=0}w[114256]=0;U(188,e+824|0,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))<<(f>>>13&1&(f<<8|(f&65280)>>>8)<<16>>16>0));d=w[114256];w[114256]=0;if((d|0)!=1){break K}break s}f=P()|0;break r}f=w[e+824>>2];i=w[e+828>>2];w[e+824>>2]=0;w[e+828>>2]=0;d=w[e+540>>2];w[e+536>>2]=f;w[e+540>>2]=i;if(!d){d=w[e+836>>2];w[e+544>>2]=w[e+832>>2];w[e+548>>2]=d;break J}f=w[d+4>>2];w[d+4>>2]=f-1;if(!f){ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[e+836>>2];w[e+544>>2]=w[e+832>>2];w[e+548>>2]=d;d=w[e+828>>2];if(!d){break J}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break J}ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=y[e+908>>1];f=d<<8|d>>>8;d=f&15;M:{N:{O:{P:{Q:{h=f<<16>>16;if((h|0)<0){Cb(k+236|0,0,256);O=1;break Q}if(d>>>0>6){break Q}m=x[d+23622|0];i=m;if(!d){break P}v[a+480190>>1]=(y[a+480190>>1]+m|0)-1;i=k+108|0;j=k+236|0;r=m-2|0;l=4;while(1){f=l-4|0;d=r<<3;o=x[f+(d+23632|0)|0]+q|0;f=x[f+(d+23680|0)|0];t=C(l,12);d=0;while(1){s=d+t|0;v[j+(s<<1)>>1]=o;s=i+s|0;u[s|0]=f+x[s|0];d=d+1|0;if((d|0)!=12){continue}break}f=1;l=l+1|0;if((l|0)!=10){continue}break}i=m;break N}m=1;if((d|0)==7){break O}i=1}f=0;if(B|(h|0)<0){break M}f=k+108|0;l=7;while(1){j=C(l,12);o=C(l,-12)+72|0;d=0;while(1){t=f+(d+j|0)|0;u[t|0]=o+x[t|0];d=d+1|0;if((d|0)!=12){continue}break}l=l+1|0;if((l|0)!=10){continue}break}f=0;break M}f=0;w[114256]=0;T(439,k|0,-24);d=w[114256];w[114256]=0;i=1;if((d|0)==1){break s}}r=1}w[114256]=0;d=Q(440,e+456|0,e+824|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break H}R:{if(!d){w[e+824>>2]=0;w[e+828>>2]=0;break R}d=x[e+828|0];if((d-1&255)>>>0>15){break R}u[k+31|0]=d;r=1}d=x[e+829|0];if((d<<24)-16777216>>24>=0){u[k+30|0]=d}if(i){d=0;while(1){w[114256]=0;k=C(d+n|0,104)+a|0;T(266,k+484380|0,8);l=w[114256];w[114256]=0;if((l|0)==1){break s}l=x[e+830|0];v[k+484410>>1]=(l>>>0>=64?64:l)<<2;u[k+484416|0]=x[e+831|0];d=d+1|0;if((i|0)!=(d|0)){continue}break}}S:{if(!p|(h|0)<0){break S}w[e+56>>2]=65800;d=w[e+536>>2];h=w[w[d>>2]+24>>2];w[114256]=0;k=y[e+824>>1];l=y[e+826>>1];d=V(h|0,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break s}h=y[e+908>>1];h=h<<8|h>>>8;if(h&16){u[e+56|0]=16;d=d>>>1|0}if(h&32){u[e+57|0]=3;d=d>>>1|0}if(h&64){u[e+59|0]=2}d=f?(d>>>0)/((-1<<i^-1)>>>0)|0:d;if(!i){break S}h=(k<<8|k>>>8)&65535;l=(l<<8|l>>>8)&65535;j=h+l|0;f=0;while(1){k=C(f+n|0,104)+a|0;o=k+484380|0;w[o>>2]=d;w[114256]=0;S(214,e+56|0,o|0,e+536|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break s}h=h<<1;j=j<<1;if(l>>>0>=2){w[k+484388>>2]=j;w[k+484384>>2]=h;k=k+484414|0;v[k>>1]=y[k>>1]|2}d=d<<1;f=f+1|0;if((i|0)!=(f|0)){continue}break}}d=w[e+540>>2];T:{if(!d){break T}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break T}ob[w[w[d>>2]+8>>2]](d);Ib(d)}q=m+q|0;g=g+1|0;h=g&65535;if(h>>>0<=y[a+480192>>1]){continue}break}}d=w[e+92>>2];U:{if(!d){break U}f=y[e+96>>1];if(!f){break U}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break t}if(d>>>0>f>>>0){break U}f=y[e+96>>1]}w[b+8>>2]=d;d=(f<<8|(f&65280)>>>8)&65535;f=x[e+451|0];n=d>>>0<f>>>0?d:f;if(!n){break U}d=y[e+98>>1];f=(d<<8|d>>>8)&65535;l=e+836|0;g=0;while(1){w[114256]=0;S(441,b|0,e+536|0,f|0)|0;d=w[114256];w[114256]=0;V:{W:{X:{Y:{Z:{_:{if((d|0)!=1){g=g+1|0;d=w[((g<<2)+a|0)+900380>>2];i=x[e+536|0];if(i){u[e+830|0]=64;u[e+826|0]=64;j=0;v[e+824>>1]=0;v[e+828>>1]=i-1;m=x[e+537|0];if(m){j=64/(m>>>0)|0}w[114256]=0;u[e+834|0]=0;v[e+832>>1]=i+j;U(442,d+48|0,e+824|0,l|0);i=w[114256];w[114256]=0;if((i|0)==1){break _}if(x[e+536|0]==1){h=w[d+52>>2];i=w[d+48>>2];m=i+4|0;k=h-m|0;if((h|0)!=(m|0)){hc(i,m,k)}w[d+52>>2]=i+k}i=x[e+537|0];w[d>>2]=i?i<<9:32767;u[d+60|0]=x[d+60|0]|1;r=1}if(f>>>0<19){break Z}w[d+4>>2]=x[e+554|0]+1>>>1;if(f>>>0>=21){v[d+28>>1]=y[e+556>>1]}h=y[d+358>>1];u[(C(h,104)+a|0)+484417|0]=x[e+539|0]<<4;break Y}f=P()|0;break r}f=P()|0;break r}h=y[d+358>>1];u[(C(h,104)+a|0)+484417|0]=x[e+539|0]<<4;if(f>>>0<15){break X}}i=C(h,104)+a|0;d=y[e+546>>1]|y[e+548>>1]<<16;m=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);w[i+484384>>2]=m;d=y[e+550>>1]|y[e+552>>1]<<16;w[i+484388>>2]=m+(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24));break W}if(f>>>0<6){break V}}i=C(h,104)+a|0;d=i+484414|0;m=d;k=y[d>>1]&65529;d=x[e+541|0];v[m>>1]=k|d<<1&2|d>>>1&4;if(!(d&4)){break V}v[i+484412>>1]=0}if((g|0)!=(n|0)){continue}break}}d=w[e+108>>2];$:{if(!d){break $}f=y[e+112>>1];if(!f){break $}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break t}if(d>>>0>f>>>0){break $}f=y[e+112>>1]}w[b+8>>2]=d;d=(f<<8|(f&65280)>>>8)&65535;f=x[e+451|0];h=d>>>0<f>>>0?d:f;if(!h){break $}d=y[e+114>>1];n=(d<<8|d>>>8)&65535;m=e+824|4;i=0;while(1){w[114256]=0;S(443,b|0,e+536|0,n|0)|0;d=w[114256];w[114256]=0;aa:{ba:{ca:{da:{ea:{if((d|0)!=1){w[114256]=0;Y(209,e+824|0,2,e+536|0,40);d=w[114256];w[114256]=0;if((d|0)==1){break ea}i=i+1|0;k=((i<<2)+a|0)+900380|0;d=w[k>>2];w[114256]=0;w[e+908>>2]=32;w[e+904>>2]=d+492;Q(200,e+904|0,e+824|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break da}if(u[e+835|0]<0){zb(w[e+824>>2])}d=w[k>>2];w[114256]=0;T(444,e+824|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break ca}g=w[e+824>>2];if((m|0)!=(g|0)){break ba}break aa}f=P()|0;break r}f=P()|0;break r}f=P()|0;if(u[e+835|0]>=0){break r}zb(w[e+824>>2]);break r}f=P()|0;break r}while(1){d=w[k>>2];j=w[d+520>>2];f=(y[g+14>>1]<<5)+a|0;l=f+946328|0;w[l>>2]=w[d+516>>2];w[l+4>>2]=j;j=w[d+512>>2];l=f+946320|0;w[l>>2]=w[d+508>>2];w[l+4>>2]=j;j=w[d+504>>2];l=f+946312|0;w[l>>2]=w[d+500>>2];w[l+4>>2]=j;l=w[d+496>>2];f=f+946304|0;w[f>>2]=w[d+492>>2];w[f+4>>2]=l;f=w[g+4>>2];fa:{if(f){while(1){d=f;f=w[d>>2];if(f){continue}break fa}}while(1){d=w[g+8>>2];f=w[d>>2]!=(g|0);g=d;if(f){continue}break}}g=d;if((d|0)!=(m|0)){continue}break}}th(e+824|0,w[e+828>>2]);if((h|0)!=(i|0)){continue}break}}w[114256]=0;X(356,a+901404|0);d=w[114256];w[114256]=0;if((d|0)==1){break t}d=a+901692|0;f=x[1447]|x[1448]<<8|(x[1449]<<16|x[1450]<<24);u[d|0]=f;u[d+1|0]=f>>>8;u[d+2|0]=f>>>16;u[d+3|0]=f>>>24;u[a+901696|0]=x[1451];w[b+8>>2]=0;J=A&255;W=c&1;B=a+484344|0;A=a+1304428|0;p=a+1304424|0;K=a+1304400|0;t=a+484360|0;_=e+168|4;s=e+56|4;m=0;ga:{ha:{ia:{while(1){ja:{w[114256]=0;Y(436,b|0,e+480|0,e+88|0,e+168|0);c=w[114256];w[114256]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)==1){break ua}if(F){w[114256]=0;c=V(262,t|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ua}if((c|0)==255){break e}}c=w[t>>2];w[e+56>>2]=s;w[e+60>>2]=0;w[e+64>>2]=0;n=c+(F<<5)|0;w[n+4>>2]=w[n>>2];if(x[e+479|0]>1){break sa}c=y[e+170>>1];c=(c<<8|c>>>8)&65535;if(c>>>0>256|y[a+480188>>1]>16){break ra}d=e+536|0;Fb(d,_,256);w[114256]=0;da(445,n|0,d|0,c|0,65535,65535)|0;c=w[114256];w[114256]=0;if((c|0)==1){break qa}d=w[n>>2];c=w[n+4>>2];if((d|0)!=(c|0)){break ta}break ma}f=P()|0;break r}while(1){v[d>>1]=y[d>>1]+m;d=d+2|0;if((c|0)!=(d|0)){continue}break}break ma}c=y[e+184>>1];if(!c|((c<<8|c>>>8)&65535)>>>0>64){break ra}g=y[a+480188>>1];if(g>>>0>64){break ra}l=w[e+192>>2];f=w[e+188>>2];h=y[e+186>>1];d=w[e+180>>2];i=w[e+176>>2];k=w[e+172>>2];c=y[e+196>>1];if(c){c=(c<<8|(c&65280)>>>8)&65535;c=(((c>>>0>=800?800:c)<<5)+50>>>0)/100|0}else{c=32}va:{wa:{d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);xa:{if(d>>>0>z[b+8>>2]){g=w[b>>2];j=w[w[g>>2]+24>>2];w[114256]=0;g=V(j|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break va}if(d>>>0>g>>>0){break xa}g=y[a+480188>>1]}w[b+8>>2]=d;d=0;if(!(g&65535)){break xa}while(1){w[114256]=0;g=Q(241,b|0,e+536|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break wa}j=x[e+536|0];v[((d<<5)+a|0)+480286>>1]=g?j>>>0>=64?64:j:0;d=d+1|0;if(d>>>0<y[a+480188>>1]){continue}break}}ya:{za:{if(!f){break za}d=f<<8&16711680|f<<24|(f>>>8&65280|f>>>24);if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break va}if(d>>>0>f>>>0){break za}}w[b+8>>2]=d;d=0;if(!y[a+480188>>1]){break ya}while(1){Aa:{w[114256]=0;f=Q(446,b|0,e+536|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Aa}g=u[e+536|0];g=(g|0)>=16?16:g;v[((d<<5)+a|0)+480284>>1]=f?(((g|0)<=-16?-16:g)<<3)+128|0:128;d=d+1|0;if(d>>>0<y[a+480188>>1]){continue}break ya}break}f=P()|0;break u}w[114256]=0;T(238,a|0,1);d=w[114256];w[114256]=0;if((d|0)==1){break va}}w[e+912>>2]=0;w[e+904>>2]=0;w[e+908>>2]=0;Ba:{Ca:{Da:{d=i<<8&16711680|i<<24|(i>>>8&65280|i>>>24);if(d>>>0<=z[b+8>>2]){break Da}f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break pa}if(d>>>0<=f>>>0){break Da}f=1;d=0;break Ca}w[b+8>>2]=d;f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;i=d;d=y[e+170>>1];g=S(g|0,f|0,i|0,((d<<8|d>>>8)&65535)<<1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break pa}f=1;d=0;if(!g){break Ca}w[114256]=0;g=y[e+170>>1];g=S(447,b|0,e+904|0,(g<<8|g>>>8)&65535)|0;i=w[114256];w[114256]=0;if((i|0)==1){break pa}if(!g){break Ca}i=w[e+904>>2];j=w[e+908>>2];if((i|0)==(j|0)){f=0;d=1;break Ba}k=k<<8&16711680|k<<24|(k>>>8&65280|k>>>24);h=h<<8|(h&65280)>>>8;q=n+12|0;while(1){d=x[i|0]|x[i+1|0]<<8;d=(d<<8|d>>>8)&65535;Ea:{if(d>>>0>(h&65535)>>>0){break Ea}Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{d=k+(d<<2)|0;La:{if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Ka}if(d>>>0>f>>>0){break La}}w[b+8>>2]=d}w[114256]=0;d=Q(268,b|0,e+536|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ka}Ma:{if(!d){d=0;break Ma}d=w[e+536>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if(d>>>0<=z[b+8>>2]){break Ma}f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Ka}if(d>>>0>f>>>0){break Ea}}w[b+8>>2]=d;f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,42)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ka}if(!d){break Ea}w[114256]=0;d=Q(448,b|0,e+536|0)|0;f=w[114256];w[114256]=0;Na:{if((f|0)!=1){if(!d){Cb(e+536|0,0,42)}if(w[n>>2]==w[n+4>>2]){break Na}w[114256]=0;T(449,n|0,65534);d=w[114256];w[114256]=0;if((d|0)!=1){break Na}}f=P()|0;break na}d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;o=d;d=y[e+576>>1];d=(d<<8|d>>>8)&65535;f=S(g|0,f|0,o|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Ja}if(!f){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Ja}f=f-w[b+8>>2]|0;d=d>>>0>f>>>0?f:d}f=w[n>>2];g=w[n+4>>2];w[114256]=0;o=g-f>>1;d=d>>>0>=65534?65534:d;T(450,n|0,o+d|0);f=w[114256];w[114256]=0;if((f|0)==1){break Ha}f=0;if(!d){break Ia}while(1){Oa:{w[114256]=0;g=Q(261,b|0,e+824|0)|0;D=w[114256];w[114256]=0;if((D|0)==1){break Oa}Pa:{Qa:{if(!g){g=0;break Qa}g=y[e+824>>1];g=(g<<8|g>>>8)<<16>>16;if((g|0)<0){break Pa}}w[114256]=0;T(449,n|0,g+m&65535);g=w[114256];w[114256]=0;if((g|0)==1){break Oa}}f=f+1|0;if((d|0)!=(f|0)){continue}break Ia}break}f=P()|0;break na}f=P()|0;break na}f=P()|0;break na}Ra:{if(!x[e+536|0]){break Ra}w[114256]=0;w[e+36>>2]=32;w[e+32>>2]=e+536;T(451,e+40|0,e+32|0);d=w[114256];w[114256]=0;Sa:{Ta:{Ua:{if((d|0)!=1){w[114256]=0;U(6,e+824|0,2,e+40|0);d=w[114256];w[114256]=0;if((d|0)==1){break Ua}w[114256]=0;Q(117,q|0,e+824|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Ta}if(u[e+835|0]<0){zb(w[e+824>>2])}if(u[e+51|0]>=0){break Ra}zb(w[e+40>>2]);break Ra}f=P()|0;break na}f=P()|0;break Sa}f=P()|0;if(u[e+835|0]>=0){break Sa}zb(w[e+824>>2])}if(u[e+51|0]>=0){break na}zb(w[e+40>>2]);break na}d=w[e+568>>2];if(!d){break Ea}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0<=z[b+8>>2]){break Fa}f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){break Ga}}f=P()|0;break na}if(d>>>0>f>>>0){break Ea}}w[b+8>>2]=d;while(1){w[114256]=0;d=Q(452,b|0,e+40|0)|0;f=w[114256];w[114256]=0;Va:{Wa:{Xa:{Ya:{if((f|0)!=1){if(!d){break Ea}w[114256]=0;U(188,e+824|0,b|0,x[e+43|0]);d=w[114256];w[114256]=0;if((d|0)==1){break Ya}d=y[e+40>>1];f=o+((d<<8|d>>>8)&65535)|0;g=f>>>0>=65535?65535:f;v[e+30>>1]=g;f=0;if((d|0)==65535){break Va}d=w[n>>2];if(g>>>0>=w[n+4>>2]-d>>1>>>0){break Va}f=1;switch(x[e+42|0]-1|0){case 1:break Wa;case 0:break Xa;default:break Va}}f=P()|0;break na}f=P()|0;break na}v[d+(g<<1)>>1]=65535;break Va}w[114256]=0;d=Q(261,e+824|0,e+32|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break oa}f=0;if(d){d=y[e+32>>1];f=d<<8|d>>>8}w[114256]=0;d=Q(453,e+56|0,e+30|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break oa}v[d>>1]=f;f=1;v[w[n>>2]+(y[e+30>>1]<<1)>>1]=65534}d=w[e+828>>2];Za:{if(!d){break Za}g=w[d+4>>2];w[d+4>>2]=g-1;if(g){break Za}ob[w[w[d>>2]+8>>2]](d);Ib(d)}if(f){continue}break}}i=i+2|0;if((j|0)!=(i|0)){continue}break}f=0;d=1}i=w[e+904>>2]}if(i){w[e+908>>2]=i;zb(i)}if(d){h=c>>>(l>>>25&1)|0;break la}Lf(e+56|0,w[e+60>>2]);if(!f){break e}break ka}f=P()|0;break u}f=P()|0;break u}d=0;Lf(e+56|0,0);break d}f=P()|0;break u}f=P()|0;break na}f=P()|0;Bb(e+824|0)}a=w[e+904>>2];if(!a){break u}w[e+908>>2]=a;zb(a);break u}w[114256]=0;T(238,a|0,1);c=w[114256];w[114256]=0;if((c|0)!=1){h=32;c=y[a+480188>>1];if(!c){break la}d=0;while(1){f=x[(d+e|0)+434|0];v[((d<<5)+a|0)+480286>>1]=f>>>0>=64?64:f;d=d+1|0;if((c|0)!=(d|0)){continue}break}break la}f=P()|0;break u}c=y[e+428>>1];d=(c<<8|c>>>8)&65535;k=x[e+431|0];L=k&64;c=x[e+432|0];G=c&32;D=(c&31)+1|0;ca=a,ea=Ep(d,L>>>6|0,G>>>5|0,D),w[ca+480204>>2]=ea;c=x[e+433|0];w[a+480196>>2]=c?c>>>0>=32?32:c:1;if(G){w[a+480216>>2]=D;w[a+480220>>2]=D<<2}c=x[e+450|0];if(c){w[a+480200>>2]=(c>>>0>=64?64:c)<<2}w[a+480228>>2]=h;w[a+480232>>2]=h;w[a+480208>>2]=w[a+480208>>2]&-3|(k^-1)>>>4&2;_a:{$a:{ab:{bb:{c=w[e+132>>2];if(!c){break bb}c=c<<8&16711680|c<<24|(c>>>8&65280|c>>>24);if(c>>>0>z[b+8>>2]){d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ab}if(c>>>0>d>>>0){break bb}}w[b+8>>2]=c;w[114256]=0;c=w[e+136>>2];S(258,b|0,K|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=w[114256];w[114256]=0;if((c|0)==1){break ab}if(J>>>0<2){break bb}w[114256]=0;U(6,e+536|0,2,K|0);c=w[114256];w[114256]=0;cb:{if((c|0)!=1){w[114256]=0;Q(117,n+12|0,e+536|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break cb}if(u[e+547|0]>=0){break bb}zb(w[e+536>>2]);break bb}f=P()|0;break u}f=P()|0;if(u[e+547|0]>=0){break u}zb(w[e+536>>2]);break u}c=w[e+104>>2];f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);db:{if(f>>>0<2){break db}c=w[e+100>>2];d=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);if(d>>>0>z[b+8>>2]){c=w[b>>2];f=w[w[c>>2]+24>>2];w[114256]=0;c=V(f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ab}if(c>>>0<d>>>0){break db}c=w[e+104>>2];f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}w[b+8>>2]=d;w[114256]=0;Z(320,p|0,b|0,f-1|0,4)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ab}}c=w[e+144>>2];if(!c){break _a}c=c<<8&16711680|c<<24|(c>>>8&65280|c>>>24);if(c>>>0>z[b+8>>2]){d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ab}if(c>>>0>d>>>0){break _a}}w[b+8>>2]=c;d=w[b>>2];f=w[w[d>>2]+36>>2];w[114256]=0;c=S(f|0,d|0,c|0,12)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ab}if(!c){break _a}w[114256]=0;Q(242,b|0,6)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ab}w[114256]=0;c=Q(261,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break $a}}f=P()|0;break u}if(!c|y[e+536>>1]!=256){break _a}w[114256]=0;c=Q(268,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}if(!c){break _a}c=w[e+536>>2];if(!c){break _a}d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;c=c<<8&16711680|c<<24|(c>>>8&65280|c>>>24);d=S(g|0,f|0,d|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break w}if(!d){break _a}w[e+544>>2]=w[p+8>>2];d=w[p+4>>2];w[e+536>>2]=w[p>>2];w[e+540>>2]=d;w[p>>2]=0;w[p+4>>2]=0;w[p+8>>2]=0;w[114256]=0;Z(320,p|0,b|0,c|0,4)|0;c=w[114256];w[114256]=0;if((c|0)==1){break B}d=x[e+547|0];c=d<<24>>24;if((c|0)<0?w[e+540>>2]:d){w[114256]=0;u[e+906|0]=0;v[e+904>>1]=3341;u[e+915|0]=2;U(454,e+824|0,e+536|0,e+904|0);c=w[114256];w[114256]=0;if((c|0)==1){break z}d=w[a+1304424>>2];f=w[a+1304428>>2];c=x[a+1304435|0];w[114256]=0;g=d;d=c<<24>>24<0;c=S(92,e+824|0,(d?g:p)|0,(d?f:c)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break A}f=w[c>>2];w[e+20>>2]=w[c+4>>2];d=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[e+23|0]=d;u[e+24|0]=d>>>8;u[e+25|0]=d>>>16;u[e+26|0]=d>>>24;w[c>>2]=0;w[c+4>>2]=0;g=x[c+11|0];w[c+8>>2]=0;if(u[a+1304435|0]<0){zb(w[p>>2])}w[a+1304424>>2]=f;c=A;d=x[e+23|0]|x[e+24|0]<<8|(x[e+25|0]<<16|x[e+26|0]<<24);u[c+3|0]=d;u[c+4|0]=d>>>8;u[c+5|0]=d>>>16;u[c+6|0]=d>>>24;w[c>>2]=w[e+20>>2];u[a+1304435|0]=g;if(u[e+835|0]<0){zb(w[e+824>>2])}if(u[e+915|0]<0){zb(w[e+904>>2])}c=x[e+547|0]}if(c<<24>>24>=0){break _a}zb(w[e+536>>2])}eb:{if(!w[e+156>>2]|x[e+479|0]<2){break eb}g=0;if(!y[a+480188>>1]){break eb}while(1){c=w[e+156>>2];c=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+(g<<2)|0;fb:{if(c>>>0>z[b+8>>2]){d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break v}if(c>>>0>d>>>0){break fb}}w[b+8>>2]=c;w[114256]=0;c=Q(268,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}gb:{if(!c){f=0;break gb}c=w[e+536>>2];f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);if(f>>>0<=z[b+8>>2]){break gb}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}if(c>>>0<f>>>0){break fb}}w[b+8>>2]=f;j=0;i=0;while(1){hb:{c=w[b>>2];d=w[w[c>>2]+36>>2];w[114256]=0;c=S(d|0,c|0,f|0,8)|0;d=w[114256];w[114256]=0;ib:{jb:{kb:{lb:{if((d|0)!=1){if(!c){break hb}w[114256]=0;c=Q(455,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break lb}if(!c){break hb}c=w[e+536>>2];if(!c){break hb}switch((c<<8&16711680|(c&31)<<24|(c>>>8&65280|c>>>24))-1|0){case 1:break jb;case 0:break kb;default:break ib}}f=P()|0;break u}f=P()|0;break u}c=w[e+540>>2];j=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);break ib}c=w[e+540>>2];i=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}f=w[b+8>>2];continue}break}if(!j|!i){break fb}if(z[b+8>>2]<j>>>0){c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}if(c>>>0<j>>>0){break fb}}w[b+8>>2]=j;w[114256]=0;S(357,b|0,((g<<5)+a|0)+480289|0,i|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break C}}g=g+1|0;if(g>>>0<y[a+480188>>1]){continue}break}}w[114256]=0;c=y[e+168>>1];o=c<<8|c>>>8;i=o+m|0;T(215,B|0,i&65535);d=w[114256];w[114256]=0;if((d|0)==1){break ha}mb:{nb:{ob:{if(c){$=k&16;aa=m&65535;c=o&65535;ba=c>>>0<=1?1:c;q=0;while(1){pb:{if(!W){break pb}c=w[e+496>>2];c=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+(q<<2)|0;if(c>>>0>z[b+8>>2]){d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ob}if(c>>>0>d>>>0){break pb}}w[b+8>>2]=c;w[114256]=0;c=Q(268,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ob}qb:{if(!c){d=0;break qb}c=w[e+536>>2];d=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);if(d>>>0<=z[b+8>>2]){break qb}c=w[b>>2];f=w[w[c>>2]+24>>2];w[114256]=0;c=V(f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ob}if(c>>>0<d>>>0){break pb}}w[b+8>>2]=d;w[e+48>>2]=0;w[114256]=0;w[e+40>>2]=0;w[e+44>>2]=0;c=V(22,16)|0;d=w[114256];w[114256]=0;rb:{sb:{if((d|0)!=1){w[c+4>>2]=0;w[c+8>>2]=0;w[c+12>>2]=75696;w[c>>2]=75656;w[e+832>>2]=0;w[e+836>>2]=0;w[e+828>>2]=c;w[e+824>>2]=c+12;k=x[e+479|0];if(k){break sb}w[114256]=0;c=Q(456,b|0,e+536|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break D}h=c?x[e+536|0]:0;c=c?x[e+537|0]+1|0:1;d=48;break rb}f=P()|0;break u}w[114256]=0;l=u[e+430|0];c=Q(457,b|0,e+32|0)|0;d=w[114256];w[114256]=0;tb:{ub:{if((d|0)!=1){vb:{if(c){f=y[e+34>>1];g=y[e+32>>1];d=w[e+36>>2];break vb}w[e+32>>2]=0;w[e+36>>2]=0;f=0;g=0;d=0}h=g<<8|(g&65280)>>>8;c=((f<<8|(f&65280)>>>8)&65535)+1|0;if(!d){break tb}f=w[b+8>>2];d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);wb:{if(f>>>0<d>>>0){g=w[b>>2];j=w[w[g>>2]+24>>2];w[114256]=0;g=V(j|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break D}if(d>>>0>g>>>0){break wb}}w[b+8>>2]=d}w[114256]=0;d=Q(458,b|0,e+536|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}if(d){d=w[e+540>>2]}else{Cb(e+536|0,0,36);d=0}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){g=w[b>>2];j=w[w[g>>2]+24>>2];w[114256]=0;g=V(j|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break D}if(d>>>0>g>>>0){break ub}}w[b+8>>2]=d;w[114256]=0;d=w[e+544>>2];S(258,b|0,e+40|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=w[114256];w[114256]=0;if((d|0)!=1){break ub}break D}break D}d=w[e+552>>2];xb:{if(!d){break xb}d=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);if(d>>>0>z[b+8>>2]){g=w[b>>2];j=w[w[g>>2]+24>>2];w[114256]=0;g=V(j|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break D}if(d>>>0>g>>>0){break xb}}w[b+8>>2]=d;w[114256]=0;d=Q(268,b|0,e+904|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}yb:{if(!d){d=0;break yb}d=w[e+904>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if(d>>>0<=z[b+8>>2]){break yb}g=w[b>>2];j=w[w[g>>2]+24>>2];w[114256]=0;g=V(j|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break D}if(d>>>0>g>>>0){break xb}}w[b+8>>2]=d;w[114256]=0;U(188,e+904|0,b|0,C(h&65535,c)|0);d=w[114256];w[114256]=0;if((d|0)==1){break D}g=w[e+904>>2];j=w[e+908>>2];w[e+904>>2]=0;w[e+908>>2]=0;d=w[e+828>>2];w[e+824>>2]=g;w[e+828>>2]=j;zb:{if(!d){break zb}g=w[d+4>>2];w[d+4>>2]=g-1;if(g){break zb}ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[e+916>>2];w[e+832>>2]=w[e+912>>2];w[e+836>>2]=d;Bb(e+904|0)}if(f>>>0>z[b+8>>2]){d=w[b>>2];g=w[w[d>>2]+24>>2];w[114256]=0;d=V(g|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}if(d>>>0<f>>>0){break tb}}w[b+8>>2]=f}d=l+(k>>>0<3?48:24)|0}w[114256]=0;f=q+aa|0;g=S(216,B|0,f&65535,c|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break D}k=d;if(g){d=w[B>>2];w[114256]=0;H=d+C(f,52)|0;Q(270,H|0,e+40|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break D}d=h&65535;f=y[a+480188>>1];N=d>>>0<f>>>0?d:f;l=0;while(1){w[114256]=0;d=V(218,H|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}if(N){d=w[H>>2]+C(C(d,l),6)|0;g=0;while(1){Ab:{if(!x[e+479|0]){w[114256]=0;Q(217,b|0,e+536|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){f=x[e+536|0];u[d+1|0]=f>>>3&16|x[e+537|0]>>>4|f>>>1&32;u[d+3|0]=x[e+537|0]&15;h=x[e+538|0];u[d+5|0]=h;f=f&63;f=f?f+k|0:0;break Ab}break D}w[114256]=0;Q(328,b|0,e+536|0)|0;f=w[114256];w[114256]=0;Bb:{Cb:{if((f|0)!=1){w[114256]=0;f=Q(241,e+824|0,e+904|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break D}u[d+4|0]=f?x[e+904|0]:0;h=x[e+536|0];f=h&127;if(!f){break Cb}f=f+k|0;break Bb}break D}f=0;if((h|0)!=128){break Bb}u[d|0]=254}u[d+1|0]=x[e+537|0]&63;u[d+3|0]=x[e+538|0];h=x[e+539|0];u[d+5|0]=h}if(f-1>>>0<=119){u[d|0]=f}Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{ac:{j=x[d+3|0];switch(j-4|0){case 42:break Fb;case 37:break Gb;case 28:break Hb;case 27:break Ib;case 26:break Jb;case 25:break Kb;case 24:break Lb;case 23:break Mb;case 22:break Nb;case 21:break Ob;case 20:break Pb;case 18:break Qb;case 17:break Rb;case 16:break Sb;case 14:break Tb;case 13:break Ub;case 12:break Vb;case 11:break Wb;case 10:break Xb;case 9:break Yb;case 8:break Zb;case 5:break _b;case 4:break $b;case 0:break ac;default:break Eb}}u[d+3|0]=5;j=h>>>3&31;h=h<<1&30;u[d+5|0]=(j>>>0>=15?15:j)<<4|(h>>>0>=15?15:h);break Db}u[d+3|0]=0;break Db}if((h-1&255)>>>0<=19){u[d+3|0]=16;break Db}u[d+3|0]=0;break Db}u[d+3|0]=13;bc:{if(!$){if((h&255)>>>0>152){break bc}u[d+5|0]=C((h&240)>>>4|0,10)+(h&15);break Db}u[d+5|0]=(h&127)+1>>>1;break Db}u[d+3|0]=0;break Db}u[d+3|0]=11;break Db}u[d+3|0]=0;break Db}j=h&255;if(!j){u[d+3|0]=14;break Db}if(j>>>0<=240){u[d+3|0]=17;j=255;h=h&255;if(h>>>0<=2){u[d+5|0]=112;break Db}E=Tb(+(Ep(h,(L|0)!=0,(G|0)!=0,D)>>>0)*1e-4);cc:{if(E>=255){break cc}j=0;if(E<=0){break cc}j=E<4294967296&E>=0?~~E>>>0:j}u[d+5|0]=j;break Db}u[d+3|0]=0;break Db}u[d+3|0]=31;u[d+5|0]=h|128;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|16;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|32;break Db}u[d+3|0]=5;j=h&15;h=h>>>4&15;u[d+5|0]=(j|(h>>>0>=14?14:h)<<4)+16;break Db}u[d+3|0]=19;u[d+5|0]=h&15|80;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|96;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|192;break Db}u[d+3|0]=10;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|160;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|176;break Db}h=(h<<24)-16777216>>24;if((h|0)>=0){u[d+5|0]=h;u[d+3|0]=31;break Db}u[d+3|0]=0;break Db}u[d+3|0]=14;break Db}u[d+3|0]=19;h=h&255;u[d+5|0]=(h>>>0>=15?15:h)|224;break Db}j=h&255;if(j>>>0>=16){u[d+3|0]=19;u[d+5|0]=(h&240)>>>4|208;break Db}if(j){u[d+3|0]=19;u[d+5|0]=h|144;break Db}u[d+3|0]=0;break Db}if(!(x[d+4|0]|h&255)){if((x[d|0]-1&255)>>>0>119){break Db}u[d+5|0]=159;u[d+3|0]=20;break Db}u[d+3|0]=0;break Db}j=x[d+4|0];if(j){u[d+3|0]=41;h=((h<<8&65280)>>>0)/(j>>>0)|0;u[d+5|0]=h>>>0>=255?255:h;break Db}u[d+3|0]=0;break Db}if((h+16&255)>>>0<=32){u[d+3|0]=9;h=((h^128)&255)<<3;h=h>>>0>=1151?1151:h;u[d+5|0]=((h|0)<=896?896:h)^128;break Db}u[d+3|0]=0;break Db}if(j>>>0<=15){w[114256]=0;X(312,d|0);h=w[114256];w[114256]=0;if((h|0)!=1){break Db}break D}u[d+3|0]=0}r=(f|0)>84&I|r;d=d+6|0;g=g+1|0;if(N>>>0>(g&65535)>>>0){continue}break}}l=l+1|0;if((l|0)!=(c|0)){continue}break}}c=w[e+828>>2];dc:{if(!c){break dc}d=w[c+4>>2];w[c+4>>2]=d-1;if(d){break dc}ob[w[w[c>>2]+8>>2]](c);Ib(c)}if(u[e+51|0]>=0){break pb}zb(w[e+40>>2])}q=q+1|0;if((ba|0)!=(q|0)){continue}break}}f=w[e+56>>2];if((s|0)==(f|0)){break mb}while(1){ec:{fc:{gc:{hc:{ic:{jc:{kc:{c=y[f+14>>1];if(!c){d=0;break kc}w[114256]=0;c=Q(305,n|0,c-1&65535)|0;d=w[114256];w[114256]=0;if((d|0)==1){break hc}d=y[f+14>>1];if(!c){break kc}w[114256]=0;d=Q(459,n|0,d-1&65535)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break jc}break hc}if(y[f+16>>1]==((d&65535)+1|0)){break ic}w[114256]=0;d=S(303,B|0,1,0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break hc}if((d|0)==65535){break ic}v[w[n>>2]+(y[f+14>>1]<<1)>>1]=d}g=w[B>>2];c=y[f+16>>1];u[e+546|0]=12;v[e+544>>1]=65535;u[e+547|0]=c>>>0>=255?255:c;u[e+548|0]=x[e+548|0]&248|1;c=g+C(d,52)|0;g=w[c+12>>2];w[114256]=0;w[e+536>>2]=2;w[e+540>>2]=g-1;Q(271,c|0,e+536|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ec}o=(o&65535)>>>0>d>>>0?o:d+1|0}g=w[f+4>>2];if(!g){break gc}while(1){d=g;g=w[d>>2];if(g){continue}break}break fc}f=P()|0;break u}while(1){d=w[f+8>>2];c=w[d>>2]!=(f|0);f=d;if(c){continue}break}}f=d;if((d|0)!=(s|0)){continue}break nb}break}f=P()|0;break u}f=P()|0;break u}i=m+o|0}c=w[e+88>>2];if(!c){break ja}c=c<<8&16711680|c<<24|(c>>>8&65280|c>>>24);if(c>>>0>z[b+8>>2]){d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ha}if(c>>>0>d>>>0){break ja}}w[b+8>>2]=c;Lf(e+56|0,w[e+60>>2]);m=i}F=F+1|0;if((J|0)!=(F|0)){continue}break ia}break}Lf(e+56|0,w[e+60>>2])}w[114256]=0;T(264,t|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break ga}if(!(r&1)){r=y[a+480192>>1];if(r){f=1;while(1){d=(((f&65535)<<2)+a|0)+900380|0;b=w[d>>2];if(b){c=w[b+88>>2];if(c){w[b+92>>2]=c;zb(c)}c=w[b+68>>2];if(c){w[b+72>>2]=c;zb(c)}c=w[b+48>>2];if(c){w[b+52>>2]=c;zb(c)}zb(b);r=y[a+480192>>1]}w[d>>2]=0;f=f+1|0;if((f&65535)>>>0<=(r&65535)>>>0){continue}break}}v[a+480192>>1]=0}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{if(!O){break sc}w[114256]=0;b=Q(1,e+536|0,12154)|0;c=w[114256];w[114256]=0;if((c|0)==1){break rc}w[114256]=0;U(367,a|0,2,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break qc}if(u[b+11|0]>=0){break sc}zb(w[b>>2])}g=17256;switch(x[e+479|0]){case 3:break mc;case 2:break nc;case 1:break oc;case 0:break pc;default:break lc}}f=P()|0;break r}f=P()|0;if(u[b+11|0]>=0){break r}zb(w[b>>2]);break r}g=y[a+480188>>1]>4?13064:13050;break lc}g=12996;break lc}g=12965;break lc}g=12938}w[114256]=0;b=Q(1,e+8|0,13014)|0;c=w[114256];w[114256]=0;tc:{uc:{vc:{if((c|0)!=1){d=w[b>>2];w[e+908>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+911|0]=c;u[e+912|0]=c>>>8;u[e+913|0]=c>>>16;u[e+914|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[e+915|0]=c;w[e+904>>2]=d;U(295,e+824|0,e+904|0,e+479|0);c=w[114256];w[114256]=0;if((c|0)==1){break vc}c=a+1304436|0;if(u[a+1304447|0]<0){zb(w[c>>2])}d=w[e+828>>2];w[c>>2]=w[e+824>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+832>>2];u[e+835|0]=0;u[e+824|0]=0;if(u[e+915|0]<0){zb(w[e+904>>2])}if(u[b+11|0]<0){zb(w[b>>2])}w[114256]=0;c=Q(1,e+824|0,8437)|0;b=w[114256];w[114256]=0;if((b|0)==1){break uc}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}d=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=d;w[b+8>>2]=w[c+8>>2];w[114256]=0;Q(460,a+1304460|0,g|0)|0;b=w[114256];w[114256]=0;d=1;if((b|0)==1){break tc}w[a+1304496>>2]=2;break d}f=P()|0;break r}f=P()|0;if(u[e+915|0]<0){zb(w[e+904>>2])}if(u[b+11|0]>=0){break r}zb(w[b>>2]);break r}f=P()|0;break r}f=P()|0;break r}f=P()|0;break u}f=P()|0;break r}break s}f=P()|0;break r}f=P()|0;Bb(e+824|0);if(u[e+51|0]>=0){break u}zb(w[e+40>>2]);break u}f=P()|0;break u}f=P()|0;break x}f=P()|0;if(u[e+835|0]>=0){break y}zb(w[e+824>>2]);break y}f=P()|0}if(u[e+915|0]>=0){break x}zb(w[e+904>>2])}if(u[e+547|0]>=0){break u}zb(w[e+536>>2]);break u}f=P()|0;break u}f=P()|0}Lf(e+56|0,w[e+60>>2]);break r}f=P()|0;break r}f=P()|0;Bb(e+536|0)}a=w[e+72>>2];if(!a){break f}w[e+76>>2]=a;zb(a)}Bb(e+456|0);R(f|0);M()}d=0}a=w[e+72>>2];if(!a){break c}w[e+76>>2]=a;zb(a)}a=w[e+460>>2];if(!a){break a}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break a}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=e+960|0;return d|0}function pP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-208|0;jb=h;e=x[b+11|0];c=e<<24>>24;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{g=w[b+4>>2];if(!((c|0)<0?g:e)){w[114256]=0;c=da(186,b|0,0,-1,17256,0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(!c){break r}g=w[b+4>>2];e=x[b+11|0];c=e}s:{t:{if(((c<<24>>24<0?g:e)|0)==15){w[114256]=0;c=da(186,b|0,0,-1,5826,15)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(!c){break t}g=w[b+4>>2];e=x[b+11|0];c=e}if(((c<<24>>24<0?g:e)|0)==21){w[114256]=0;c=da(186,b|0,0,-1,4317,21)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(!c){break q}g=w[b+4>>2];e=x[b+11|0];c=e}if(((c<<24>>24<0?g:e)|0)==21){w[114256]=0;c=da(186,b|0,0,-1,4295,21)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(!c){break p}g=w[b+4>>2];e=x[b+11|0];c=e}if(((c<<24>>24<0?g:e)|0)==21){w[114256]=0;c=da(186,b|0,0,-1,6752,21)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(!c){break o}g=w[b+4>>2];e=x[b+11|0];c=e}if(((c<<24>>24<0?g:e)|0)!=22){break s}w[114256]=0;c=da(186,b|0,0,-1,6536,22)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(c){break s}Hb(a,11545);break l}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;lg(h+104|0);w[114256]=0;w[h+160>>2]=0;T(1435,h+184|0,h+160|0);b=w[114256];w[114256]=0;u:{v:{w:{x:{y:{z:{A:{if((b|0)!=1){w[114256]=0;b=x[h+195|0];c=b<<24>>24<0;S(92,a|0,(c?w[h+184>>2]:h+184|0)|0,(c?w[h+188>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break A}if(u[h+195|0]<0){zb(w[h+184>>2])}w[114256]=0;Q(1315,a|0,12600)|0;b=w[114256];w[114256]=0;B:{if((b|0)==1){break B}w[114256]=0;w[h+160>>2]=5;T(1435,h+184|0,h+160|0);b=w[114256];w[114256]=0;if((b|0)==1){break z}w[114256]=0;b=x[h+195|0];c=b<<24>>24<0;S(92,a|0,(c?w[h+184>>2]:h+184|0)|0,(c?w[h+188>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break y}if(u[h+195|0]<0){zb(w[h+184>>2])}w[114256]=0;Q(1315,a|0,12600)|0;b=w[114256];w[114256]=0;if((b|0)==1){break B}w[114256]=0;w[h+160>>2]=20;T(1435,h+184|0,h+160|0);b=w[114256];w[114256]=0;if((b|0)==1){break x}w[114256]=0;b=x[h+195|0];c=b<<24>>24<0;S(92,a|0,(c?w[h+184>>2]:h+184|0)|0,(c?w[h+188>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break w}if(u[h+195|0]<0){zb(w[h+184>>2])}w[114256]=0;b=Q(5,h+88|0,11545)|0;c=w[114256];w[114256]=0;if((c|0)==1){break v}e=x[b+11|0];c=e<<24>>24;c=(c|0)<0;e=c?w[b+4>>2]:e;if(c){zb(w[b>>2])}if(!e){break u}w[114256]=0;Q(1315,a|0,11545)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break u}}e=P()|0;break i}e=P()|0;break i}e=P()|0;if(u[h+195|0]>=0){break i}zb(w[h+184>>2]);break i}e=P()|0;break i}e=P()|0;if(u[h+195|0]>=0){break i}zb(w[h+184>>2]);break i}e=P()|0;break i}e=P()|0;if(u[h+195|0]>=0){break i}zb(w[h+184>>2]);break i}e=P()|0;break i}w[h+80>>2]=0;w[h+72>>2]=0;w[h+76>>2]=0;i=h+80|0;C:{D:{E:{F:{G:{H:{I:{b=w[h+116>>2];J:{if(!b){break J}w[114256]=0;w[h+56>>2]=b;T(1435,h+184|0,h+56|0);b=w[114256];w[114256]=0;if((b|0)==1){break I}w[114256]=0;b=S(1436,h+184|0,0,5049)|0;c=w[114256];w[114256]=0;if((c|0)==1){break H}c=w[b>>2];w[h+160>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[h+163|0]=e;u[h+164|0]=e>>>8;u[h+165|0]=e>>>16;u[h+166|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;d=u[b+11|0];w[b+8>>2]=0;b=w[h+76>>2];e=w[h+80>>2];K:{if(b>>>0<e>>>0){w[b>>2]=c;w[b+4>>2]=w[h+160>>2];c=x[h+163|0]|x[h+164|0]<<8|(x[h+165|0]<<16|x[h+166|0]<<24);u[b+7|0]=c;u[b+8|0]=c>>>8;u[b+9|0]=c>>>16;u[b+10|0]=c>>>24;u[b+11|0]=d;w[h+76>>2]=b+12;break K}f=w[h+72>>2];g=(b-f|0)/12|0;b=g+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,h+72|0);b=w[114256];w[114256]=0;if((b|0)==1){break G}break g}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;f=Z(921,h+136|0,(e>>>0>=178956970?357913941:b>>>0<f>>>0?f:b)|0,g|0,i|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break G}b=w[f+8>>2];w[b>>2]=c;w[b+4>>2]=w[h+160>>2];c=x[h+163|0]|x[h+164|0]<<8|(x[h+165|0]<<16|x[h+166|0]<<24);u[b+7|0]=c;u[b+8|0]=c>>>8;u[b+9|0]=c>>>16;u[b+10|0]=c>>>24;u[b+11|0]=d;u[h+163|0]=0;u[h+164|0]=0;u[h+165|0]=0;u[h+166|0]=0;w[h+160>>2]=0;e=w[f+8>>2]+12|0;w[f+8>>2]=e;g=w[f+4>>2];b=w[h+76>>2];c=w[h+72>>2];L:{if((b|0)==(c|0)){b=c;break L}while(1){b=b-12|0;d=w[b+4>>2];e=g-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=d;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;g=w[f+4>>2]-12|0;w[f+4>>2]=g;if((b|0)!=(c|0)){continue}break}e=w[f+8>>2];c=w[h+76>>2];b=w[h+72>>2]}w[h+72>>2]=g;w[f+4>>2]=b;w[h+76>>2]=e;w[f+8>>2]=c;c=w[h+80>>2];w[h+80>>2]=w[f+12>>2];w[f>>2]=b;w[f+12>>2]=c;sc(f)}if(u[h+195|0]>=0){break J}zb(w[h+184>>2])}if(!x[h+120|0]){break C}w[114256]=0;d=Q(5,h+56|0,8569)|0;b=w[114256];w[114256]=0;if((b|0)==1){break D}b=w[h+76>>2];c=w[h+80>>2];if(b>>>0>=c>>>0){break E}c=w[d+4>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[h+76>>2]=b+12;break m}e=P()|0;break j}e=P()|0;break F}e=P()|0;if((d|0)>=0){break F}zb(c)}if(u[h+195|0]>=0){break j}zb(w[h+184>>2]);break j}e=w[h+72>>2];f=(b-e|0)/12|0;b=f+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,h+72|0);b=w[114256];w[114256]=0;if((b|0)!=1){break g}break k}w[114256]=0;c=(c-e|0)/12|0;e=c<<1;e=Z(921,h+160|0,(c>>>0>=178956970?357913941:b>>>0<e>>>0?e:b)|0,f|0,i|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}c=w[d+4>>2];b=w[e+8>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+8>>2]+12|0;w[e+8>>2]=f;g=w[e+4>>2];b=w[h+76>>2];c=w[h+72>>2];M:{if((b|0)==(c|0)){b=c;break M}while(1){f=g-12|0;b=b-12|0;g=w[b+4>>2];w[f>>2]=w[b>>2];w[f+4>>2]=g;w[f+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;g=w[e+4>>2]-12|0;w[e+4>>2]=g;if((b|0)!=(c|0)){continue}break}f=w[e+8>>2];c=w[h+76>>2];b=w[h+72>>2]}w[h+72>>2]=g;w[e+4>>2]=b;w[h+76>>2]=f;w[e+8>>2]=c;c=w[h+80>>2];w[h+80>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=c;sc(e);if(u[d+11|0]>=0){break m}zb(w[d>>2]);break m}e=P()|0;break j}if(!x[h+121|0]){break m}w[114256]=0;d=Q(5,h+56|0,8315)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=w[h+76>>2];c=w[h+80>>2];if(b>>>0<c>>>0){c=w[d+4>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[h+76>>2]=b+12;break m}e=w[h+72>>2];f=(b-e|0)/12|0;b=f+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,h+72|0);b=w[114256];w[114256]=0;if((b|0)!=1){break g}break n}w[114256]=0;c=(c-e|0)/12|0;e=c<<1;e=Z(921,h+160|0,(c>>>0>=178956970?357913941:b>>>0<e>>>0?e:b)|0,f|0,i|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}c=w[d+4>>2];b=w[e+8>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+8>>2]+12|0;w[e+8>>2]=f;g=w[e+4>>2];b=w[h+76>>2];c=w[h+72>>2];N:{if((b|0)==(c|0)){b=c;break N}while(1){f=g-12|0;b=b-12|0;g=w[b+4>>2];w[f>>2]=w[b>>2];w[f+4>>2]=g;w[f+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;g=w[e+4>>2]-12|0;w[e+4>>2]=g;if((b|0)!=(c|0)){continue}break}f=w[e+8>>2];c=w[h+76>>2];b=w[h+72>>2]}w[h+72>>2]=g;w[e+4>>2]=b;w[h+76>>2]=f;w[e+8>>2]=c;c=w[h+80>>2];w[h+80>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=c;sc(e);if(u[d+11|0]>=0){break m}zb(w[d>>2]);break m}e=P()|0;break j}if(bd(b,7242)){b=Hb(h+104|0,11545);e=w[b+4>>2];c=x[b+11|0];w[114256]=0;Q(5,a|0,((c<<24>>24<0?e:c)?11706:11460)|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]>=0){break l}zb(w[b>>2]);break l}e=P()|0;if(u[b+11|0]>=0){break h}zb(w[b>>2]);break h}if(bd(b,3624)){b=jb-48|0;jb=b;ev(b+16|0);w[114256]=0;c=Q(1,b|0,17240)|0;e=w[114256];w[114256]=0;O:{P:{Q:{R:{if((e|0)!=1){w[114256]=0;U(128,b+32|0,b+16|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break R}w[114256]=0;U(9,a|0,0,b+32|0);a=w[114256];w[114256]=0;if((a|0)==1){break Q}if(u[b+43|0]<0){zb(w[b+32>>2])}if(u[c+11|0]<0){zb(w[c>>2])}if(u[b+27|0]<0){zb(w[b+16>>2])}jb=b+48|0;break l}a=P()|0;break O}a=P()|0;break P}a=P()|0;if(u[b+43|0]>=0){break P}zb(w[b+32>>2])}if(u[c+11|0]>=0){break O}zb(w[c>>2])}if(u[b+27|0]<0){zb(w[b+16>>2])}break c}if(bd(b,5854)){b=jb-16|0;jb=b;l=jb-16|0;jb=l;w[l+8>>2]=53;d=jb-368|0;jb=d;w[d+152>>2]=0;w[d+144>>2]=0;w[d+148>>2]=0;m=d+152|0;S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{c=w[l+8>>2];if(c&1){w[114256]=0;w[d+344>>2]=19469585;T(120,d+96|0,d+344|0);c=w[114256];w[114256]=0;if((c|0)==1){break ba}c=w[d+148>>2];e=w[d+152>>2];ca:{if(c>>>0<e>>>0){e=w[d+100>>2];w[c>>2]=w[d+96>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+104>>2];w[d+148>>2]=c+12;break ca}f=w[d+144>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)==1){break aa}break T}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;i=Z(106,d+160|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break aa}e=w[d+100>>2];c=w[i+8>>2];w[c>>2]=w[d+96>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+104>>2];w[d+104>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;f=w[i+8>>2]+12|0;w[i+8>>2]=f;g=w[i+4>>2];c=w[d+148>>2];e=w[d+144>>2];da:{if((c|0)==(e|0)){c=e;break da}while(1){f=g-12|0;c=c-12|0;g=w[c+4>>2];w[f>>2]=w[c>>2];w[f+4>>2]=g;w[f+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(e|0)){continue}break}f=w[i+8>>2];e=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=f;w[i+8>>2]=e;e=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=e;sc(i);if(u[d+107|0]>=0){break ca}zb(w[d+96>>2])}c=w[l+8>>2]}if(!(c&4)){break W}w[114256]=0;w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;c=ea(111)|0;e=w[114256];w[114256]=0;ea:{if((e|0)==1){break ea}if(!c){break X}w[114256]=0;e=Q(1,d+184|0,5048)|0;c=w[114256];w[114256]=0;if((c|0)==1){break $}w[114256]=0;c=ea(111)|0;f=w[114256];w[114256]=0;if((f|0)==1){break _}w[114256]=0;w[d+296>>2]=c;T(116,d+96|0,d+296|0);c=w[114256];w[114256]=0;if((c|0)==1){break _}w[114256]=0;c=x[d+107|0];f=c<<24>>24<0;c=S(2,e|0,(f?w[d+96>>2]:d+96|0)|0,(f?w[d+100>>2]:c)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Z}g=w[c>>2];w[d+320>>2]=w[c+4>>2];f=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+323|0]=f;u[d+324|0]=f>>>8;u[d+325|0]=f>>>16;u[d+326|0]=f>>>24;w[c>>2]=0;w[c+4>>2]=0;f=x[c+11|0];w[c+8>>2]=0;w[d+344>>2]=g;u[d+355|0]=f;w[d+348>>2]=w[d+320>>2];c=x[d+323|0]|x[d+324|0]<<8|(x[d+325|0]<<16|x[d+326|0]<<24);u[d+351|0]=c;u[d+352|0]=c>>>8;u[d+353|0]=c>>>16;u[d+354|0]=c>>>24;if(u[d+107|0]<0){zb(w[d+96>>2])}if(u[e+11|0]<0){zb(w[e>>2])}w[114256]=0;c=ea(113)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ea}if(c){w[114256]=0;S(2,d+344|0,13151,1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ea}}w[114256]=0;c=ea(112)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ea}if(!c){break X}w[114256]=0;S(2,d+344|0,12630,1)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break X}}g=P()|0;if(u[d+355|0]>=0){break U}zb(w[d+344>>2]);break U}g=P()|0;break U}g=P()|0;if(u[d+107|0]>=0){break U}zb(w[d+96>>2]);break U}g=P()|0;break U}g=P()|0;break Y}g=P()|0;if(u[d+107|0]>=0){break Y}zb(w[d+96>>2])}if(u[e+11|0]>=0){break U}zb(w[e>>2]);break U}c=w[d+148>>2];e=w[d+152>>2];fa:{if(c>>>0<e>>>0){e=w[d+348>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+352>>2];w[d+148>>2]=c+12;break fa}f=w[d+144>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break V}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;i=Z(106,d+200|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break V}e=w[d+348>>2];c=w[i+8>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;f=w[i+8>>2]+12|0;w[i+8>>2]=f;g=w[i+4>>2];c=w[d+148>>2];e=w[d+144>>2];ga:{if((c|0)==(e|0)){c=e;break ga}while(1){f=g-12|0;c=c-12|0;g=w[c+4>>2];w[f>>2]=w[c>>2];w[f+4>>2]=g;w[f+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(e|0)){continue}break}f=w[i+8>>2];e=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=f;w[i+8>>2]=e;e=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=e;sc(i);if(u[d+355|0]>=0){break fa}zb(w[d+344>>2])}c=w[l+8>>2]}ha:{ia:{ja:{ka:{la:{ma:{if(c&8){w[114256]=0;f=Q(1,d+128|0,2508)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ma}e=w[f>>2];w[d+348>>2]=w[f+4>>2];c=x[f+7|0]|x[f+8|0]<<8|(x[f+9|0]<<16|x[f+10|0]<<24);u[d+351|0]=c;u[d+352|0]=c>>>8;u[d+353|0]=c>>>16;u[d+354|0]=c>>>24;w[f>>2]=0;w[f+4>>2]=0;c=x[f+11|0];w[f+8>>2]=0;w[114256]=0;u[d+355|0]=c;w[d+344>>2]=e;U(121,d+96|0,d+344|0,22596);c=w[114256];w[114256]=0;if((c|0)==1){break la}c=w[d+148>>2];e=w[d+152>>2];na:{if(c>>>0<e>>>0){e=w[d+100>>2];w[c>>2]=w[d+96>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+104>>2];w[d+104>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;w[d+148>>2]=c+12;break na}g=w[d+144>>2];i=(c-g|0)/12|0;c=i+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break ia}w[114256]=0;e=(e-g|0)/12|0;g=e<<1;i=Z(106,d+224|0,(e>>>0>=178956970?357913941:c>>>0<g>>>0?g:c)|0,i|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ia}e=w[d+100>>2];c=w[i+8>>2];w[c>>2]=w[d+96>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+104>>2];w[d+104>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;j=w[i+8>>2]+12|0;w[i+8>>2]=j;g=w[i+4>>2];c=w[d+148>>2];e=w[d+144>>2];oa:{if((c|0)==(e|0)){c=e;break oa}while(1){c=c-12|0;j=w[c+4>>2];g=g-12|0;w[g>>2]=w[c>>2];w[g+4>>2]=j;w[g+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(e|0)){continue}break}j=w[i+8>>2];e=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=j;w[i+8>>2]=e;e=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=e;sc(i);if(u[d+107|0]>=0){break na}zb(w[d+96>>2])}if(u[d+355|0]<0){zb(w[d+344>>2])}if(u[f+11|0]<0){zb(w[f>>2])}c=w[l+8>>2]}if(c&16){break ka}break ja}g=P()|0;break U}g=P()|0;break ha}w[114256]=0;j=V(122,d+96|0)|0;c=w[114256];w[114256]=0;pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{if((c|0)!=1){w[114256]=0;T(123,d+344|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break ya}e=x[d+355|0];c=e<<24>>24;c=(c|0)<0;e=c?w[d+348>>2]:e;if(c){zb(w[d+344>>2])}Oa:{if(!e){break Oa}w[114256]=0;e=Q(1,d+80|0,11458)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Na}f=w[e>>2];w[d+324>>2]=w[e+4>>2];c=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+327|0]=c;u[d+328|0]=c>>>8;u[d+329|0]=c>>>16;u[d+330|0]=c>>>24;w[e>>2]=0;w[e+4>>2]=0;c=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+331|0]=c;w[d+320>>2]=f;T(123,d+296|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break Ma}w[114256]=0;U(124,d+344|0,d+320|0,d+296|0);c=w[114256];w[114256]=0;if((c|0)==1){break La}c=w[d+148>>2];f=w[d+152>>2];Pa:{if(c>>>0<f>>>0){f=w[d+348>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;w[d+148>>2]=c+12;break Pa}g=w[d+144>>2];i=(c-g|0)/12|0;c=i+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break sa}w[114256]=0;f=(f-g|0)/12|0;g=f<<1;i=Z(106,d+248|0,(f>>>0>=178956970?357913941:c>>>0<g>>>0?g:c)|0,i|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break sa}f=w[d+348>>2];c=w[i+8>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;k=w[i+8>>2]+12|0;w[i+8>>2]=k;g=w[i+4>>2];c=w[d+148>>2];f=w[d+144>>2];Qa:{if((c|0)==(f|0)){c=f;break Qa}while(1){c=c-12|0;k=w[c+4>>2];g=g-12|0;w[g>>2]=w[c>>2];w[g+4>>2]=k;w[g+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(f|0)){continue}break}k=w[i+8>>2];f=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=k;w[i+8>>2]=f;f=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=f;sc(i);if(u[d+355|0]>=0){break Pa}zb(w[d+344>>2])}if(u[d+307|0]<0){zb(w[d+296>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break Oa}zb(w[e>>2])}n=j+20|0;c=x[j+31|0];if(!(c<<24>>24<0?w[j+24>>2]:c)){break Ia}w[114256]=0;e=Q(1,d- -64|0,13044)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ha}f=w[e>>2];w[d+324>>2]=w[e+4>>2];c=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+327|0]=c;u[d+328|0]=c>>>8;u[d+329|0]=c>>>16;u[d+330|0]=c>>>24;w[e>>2]=0;w[e+4>>2]=0;c=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+331|0]=c;w[d+320>>2]=f;U(124,d+344|0,d+320|0,n|0);c=w[114256];w[114256]=0;if((c|0)==1){break Ga}c=w[d+148>>2];f=w[d+152>>2];if(c>>>0>=f>>>0){break Ka}f=w[d+348>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;w[d+148>>2]=c+12;break Ja}g=P()|0;break U}g=P()|0;break pa}g=P()|0;break qa}g=P()|0;break ra}g=w[d+144>>2];i=(c-g|0)/12|0;c=i+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break ua}w[114256]=0;f=(f-g|0)/12|0;g=f<<1;i=Z(106,d+272|0,(f>>>0>=178956970?357913941:c>>>0<g>>>0?g:c)|0,i|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ua}f=w[d+348>>2];c=w[i+8>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;k=w[i+8>>2]+12|0;w[i+8>>2]=k;g=w[i+4>>2];c=w[d+148>>2];f=w[d+144>>2];Ra:{if((c|0)==(f|0)){c=f;break Ra}while(1){c=c-12|0;k=w[c+4>>2];g=g-12|0;w[g>>2]=w[c>>2];w[g+4>>2]=k;w[g+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(f|0)){continue}break}k=w[i+8>>2];f=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=k;w[i+8>>2]=f;f=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=f;sc(i);if(u[d+355|0]>=0){break Ja}zb(w[d+344>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break Ia}zb(w[e>>2])}w[114256]=0;T(125,d+344|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break Ca}e=x[d+355|0];c=e<<24>>24;c=(c|0)<0;e=c?w[d+348>>2]:e;if(c){zb(w[d+344>>2])}if(!e){break Da}w[114256]=0;e=Q(1,d+48|0,11458)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ba}f=w[e>>2];w[d+324>>2]=w[e+4>>2];c=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+327|0]=c;u[d+328|0]=c>>>8;u[d+329|0]=c>>>16;u[d+330|0]=c>>>24;w[e>>2]=0;w[e+4>>2]=0;c=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+331|0]=c;w[d+320>>2]=f;T(125,d+32|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break Aa}w[114256]=0;U(124,d+344|0,d+320|0,d+32|0);c=w[114256];w[114256]=0;if((c|0)==1){break za}c=w[d+148>>2];f=w[d+152>>2];if(c>>>0>=f>>>0){break Fa}f=w[d+348>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;w[d+148>>2]=c+12;break Ea}g=P()|0;break pa}g=P()|0;break ta}g=w[d+144>>2];i=(c-g|0)/12|0;c=i+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break xa}w[114256]=0;f=(f-g|0)/12|0;g=f<<1;i=Z(106,d+296|0,(f>>>0>=178956970?357913941:c>>>0<g>>>0?g:c)|0,i|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break xa}f=w[d+348>>2];c=w[i+8>>2];w[c>>2]=w[d+344>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+352>>2];w[d+352>>2]=0;w[d+344>>2]=0;w[d+348>>2]=0;k=w[i+8>>2]+12|0;w[i+8>>2]=k;g=w[i+4>>2];c=w[d+148>>2];f=w[d+144>>2];Sa:{if((c|0)==(f|0)){c=f;break Sa}while(1){c=c-12|0;k=w[c+4>>2];g=g-12|0;w[g>>2]=w[c>>2];w[g+4>>2]=k;w[g+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(f|0)){continue}break}k=w[i+8>>2];f=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=k;w[i+8>>2]=f;f=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=f;sc(i);if(u[d+355|0]>=0){break Ea}zb(w[d+344>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break Da}zb(w[e>>2])}if(u[j+31|0]<0){zb(w[n>>2])}if(u[j+11|0]<0){zb(w[j>>2])}c=w[l+8>>2];break ja}g=P()|0;break pa}g=P()|0;break pa}g=P()|0;break va}g=P()|0;break wa}g=P()|0;break pa}g=P()|0;if(u[d+355|0]>=0){break wa}zb(w[d+344>>2])}if(u[d+43|0]>=0){break va}zb(w[d+32>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break pa}zb(w[e>>2]);break pa}g=P()|0;if(u[d+355|0]>=0){break ta}zb(w[d+344>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break pa}zb(w[e>>2]);break pa}g=P()|0;if(u[d+355|0]>=0){break ra}zb(w[d+344>>2])}if(u[d+307|0]>=0){break qa}zb(w[d+296>>2])}if(u[d+331|0]<0){zb(w[d+320>>2])}if(u[e+11|0]>=0){break pa}zb(w[e>>2])}Xd(j);break U}Ta:{if(c&32){c=w[d+148>>2];e=w[d+152>>2];Ua:{if(c>>>0<e>>>0){w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;w[d+148>>2]=c+12;break Ua}f=w[d+144>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break Ta}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;i=Z(106,d+320|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ta}c=w[i+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;f=w[i+8>>2]+12|0;w[i+8>>2]=f;g=w[i+4>>2];c=w[d+148>>2];e=w[d+144>>2];Va:{if((c|0)==(e|0)){c=e;break Va}while(1){f=g-12|0;c=c-12|0;g=w[c+4>>2];w[f>>2]=w[c>>2];w[f+4>>2]=g;w[f+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[i+4>>2]-12|0;w[i+4>>2]=g;if((c|0)!=(e|0)){continue}break}f=w[i+8>>2];e=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[i+4>>2]=c;w[d+148>>2]=f;w[i+8>>2]=e;e=w[d+152>>2];w[d+152>>2]=w[i+12>>2];w[i>>2]=c;w[i+12>>2]=e;sc(i)}c=w[l+8>>2]}Wa:{Xa:{Ya:{if(!(c&64)){break Ya}w[114256]=0;X(126,d+32|0);c=w[114256];w[114256]=0;if((c|0)==1){break Xa}c=w[d+148>>2];e=w[d+152>>2];if(c>>>0<e>>>0){e=w[d+36>>2];w[c>>2]=w[d+32>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+40>>2];w[d+148>>2]=c+12;break Ya}f=w[d+144>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(105,d+144|0);a=w[114256];w[114256]=0;if((a|0)!=1){break T}break Wa}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;f=Z(106,d+344|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Wa}e=w[d+36>>2];c=w[f+8>>2];w[c>>2]=w[d+32>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+40>>2];w[d+40>>2]=0;w[d+32>>2]=0;w[d+36>>2]=0;i=w[f+8>>2]+12|0;w[f+8>>2]=i;g=w[f+4>>2];c=w[d+148>>2];e=w[d+144>>2];Za:{if((c|0)==(e|0)){c=e;break Za}while(1){c=c-12|0;i=w[c+4>>2];g=g-12|0;w[g>>2]=w[c>>2];w[g+4>>2]=i;w[g+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;g=w[f+4>>2]-12|0;w[f+4>>2]=g;if((c|0)!=(e|0)){continue}break}i=w[f+8>>2];e=w[d+148>>2];c=w[d+144>>2]}w[d+144>>2]=g;w[f+4>>2]=c;w[d+148>>2]=i;w[f+8>>2]=e;e=w[d+152>>2];w[d+152>>2]=w[f+12>>2];w[f>>2]=c;w[f+12>>2]=e;sc(f);if(u[d+43|0]>=0){break Ya}zb(w[d+32>>2])}w[114256]=0;c=Q(1,d+32|0,17256)|0;e=w[114256];w[114256]=0;_a:{$a:{ab:{bb:{cb:{if((e|0)!=1){w[114256]=0;U(127,d+16|0,d+144|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break cb}w[114256]=0;e=Q(1,d|0,17240)|0;f=w[114256];w[114256]=0;if((f|0)==1){break bb}w[114256]=0;U(128,b|0,d+16|0,e|0);f=w[114256];w[114256]=0;if((f|0)==1){break ab}if(u[e+11|0]<0){zb(w[e>>2])}if(u[d+27|0]<0){zb(w[d+16>>2])}if(u[c+11|0]<0){zb(w[c>>2])}bc(d+144|0);jb=d+368|0;break S}g=P()|0;break U}g=P()|0;break _a}g=P()|0;break $a}g=P()|0;if(u[e+11|0]>=0){break $a}zb(w[e>>2])}if(u[d+27|0]>=0){break _a}zb(w[d+16>>2])}if(u[c+11|0]>=0){break U}zb(w[c>>2]);break U}g=P()|0;break U}g=P()|0;if(u[d+43|0]>=0){break U}zb(w[d+32>>2]);break U}g=P()|0;break U}g=P()|0;if(u[d+107|0]>=0){break ha}zb(w[d+96>>2])}if(u[d+355|0]<0){zb(w[d+344>>2])}if(u[f+11|0]>=0){break U}zb(w[f>>2]);break U}g=P()|0;if(u[d+355|0]>=0){break U}zb(w[d+344>>2])}bc(d+144|0);R(g|0);M()}M()}jb=l+16|0;w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,6465)){b=jb-48|0;jb=b;lg(b);w[114256]=0;T(123,b+32|0,b|0);c=w[114256];w[114256]=0;db:{eb:{if((c|0)!=1){w[114256]=0;U(9,a|0,0,b+32|0);a=w[114256];w[114256]=0;if((a|0)==1){break eb}if(u[b+43|0]<0){zb(w[b+32>>2])}if(u[b+31|0]<0){zb(w[b+20>>2])}if(u[b+11|0]<0){zb(w[b>>2])}jb=b+48|0;break l}a=P()|0;break db}a=P()|0;if(u[b+43|0]>=0){break db}zb(w[b+32>>2])}Xd(b);break c}if(bd(b,7205)){b=jb-32|0;jb=b;lg(b);w[114256]=0;U(9,a|0,0,b+20|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+31|0]<0){zb(w[b+20>>2])}if(u[b+11|0]<0){zb(w[b>>2])}jb=b+32|0;break l}a=P()|0;Xd(b);break c}if(bd(b,5867)){b=jb-48|0;jb=b;lg(b+16|0);c=w[b+28>>2];fb:{if(c){w[114256]=0;w[b+12>>2]=c;T(1435,a|0,b+12|0);a=w[114256];w[114256]=0;if((a|0)!=1){break fb}a=P()|0;Xd(b+16|0);break c}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0}if(u[b+47|0]<0){zb(w[b+36>>2])}if(u[b+27|0]<0){zb(w[b+16>>2])}jb=b+48|0;break l}if(bd(b,8559)){lg(h+104|0);w[114256]=0;Q(5,a|0,(x[h+120|0]?11460:11706)|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){Xd(h+104|0);break l}e=P()|0;Xd(h+104|0);break h}if(bd(b,5883)){lg(h+104|0);w[114256]=0;Q(5,a|0,(x[h+121|0]?11460:11706)|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){Xd(h+104|0);break l}e=P()|0;Xd(h+104|0);break h}if(bd(b,8006)){lg(h+104|0);w[114256]=0;Q(5,a|0,(x[h+122|0]?11460:11706)|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){Xd(h+104|0);break l}e=P()|0;Xd(h+104|0);break h}if(bd(b,8289)){b=jb-16|0;jb=b;e=jb-32|0;jb=e;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;c=Ym(e);w[114256]=0;Q(117,b|0,c+20|0)|0;f=w[114256];w[114256]=0;gb:{if((f|0)!=1){if(u[c+31|0]<0){zb(w[c+20>>2])}if(u[c+11|0]<0){zb(w[c>>2])}jb=e+32|0;break gb}a=P()|0;Xd(c);break b}w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,4438)){b=jb-16|0;jb=b;c=jb+-64|0;jb=c;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[114256]=0;e=Q(1,c+16|0,10526)|0;f=w[114256];w[114256]=0;hb:{ib:{jb:{kb:{if((f|0)!=1){d=w[e>>2];w[c+36>>2]=w[e+4>>2];f=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[c+39|0]=f;u[c+40|0]=f>>>8;u[c+41|0]=f>>>16;u[c+42|0]=f>>>24;w[e>>2]=0;w[e+4>>2]=0;f=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[c+43|0]=f;w[c+32>>2]=d;w[c+12>>2]=16;w[c+8>>2]=0;w[c+4>>2]=0;ga(119,c+48|0,c+32|0,c+12|0,c+8|0,c+4|0);f=w[114256];w[114256]=0;if((f|0)==1){break kb}w[114256]=0;f=x[c+59|0];d=f<<24>>24<0;S(2,b|0,(d?w[c+48>>2]:c+48|0)|0,(d?w[c+52>>2]:f)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break jb}if(u[c+59|0]<0){zb(w[c+48>>2])}if(u[c+43|0]<0){zb(w[c+32>>2])}if(u[e+11|0]<0){zb(w[e>>2])}jb=c- -64|0;break hb}a=P()|0;break b}a=P()|0;break ib}a=P()|0;if(u[c+59|0]>=0){break ib}zb(w[c+48>>2])}if(u[c+43|0]<0){zb(w[c+32>>2])}if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,3147)){b=jb-16|0;jb=b;c=jb-16|0;jb=c;e=Hb(c,15244);w[114256]=0;U(6,b|0,0,e|0);f=w[114256];w[114256]=0;lb:{if((f|0)!=1){if(u[e+11|0]<0){zb(w[e>>2])}jb=c+16|0;break lb}break a}w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,2809)){b=jb-48|0;jb=b;e=Hb(b+16|0,13391);w[114256]=0;T(1438,b|0,2);c=w[114256];w[114256]=0;mb:{nb:{ob:{pb:{if((c|0)!=1){w[114256]=0;c=x[b+11|0];f=c<<24>>24<0;c=S(2,e|0,(f?w[b>>2]:b)|0,(f?w[b+4>>2]:c)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break pb}w[b+40>>2]=w[c+8>>2];f=w[c+4>>2];w[b+32>>2]=w[c>>2];w[b+36>>2]=f;w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;w[114256]=0;U(9,a|0,0,b+32|0);a=w[114256];w[114256]=0;if((a|0)==1){break ob}if(u[b+43|0]<0){zb(w[b+32>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(u[e+11|0]<0){zb(w[e>>2])}jb=b+48|0;break l}a=P()|0;break mb}a=P()|0;break nb}a=P()|0;if(u[b+43|0]>=0){break nb}zb(w[b+32>>2])}if(u[b+11|0]>=0){break mb}zb(w[b>>2])}if(u[e+11|0]<0){zb(w[e>>2])}break c}if(bd(b,7228)){b=jb-16|0;jb=b;c=jb-16|0;jb=c;e=Hb(c,13707);w[114256]=0;U(6,b|0,0,e|0);f=w[114256];w[114256]=0;qb:{if((f|0)!=1){if(u[e+11|0]<0){zb(w[e>>2])}jb=c+16|0;break qb}break a}w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,6472)){b=jb-16|0;jb=b;Sj(b,0);w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,6447)){b=jb-16|0;jb=b;Sj(b,2);w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}if(bd(b,6432)){b=jb-16|0;jb=b;Sj(b,3);w[114256]=0;U(9,a|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=b+16|0;break l}break d}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break l}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break l}w[h+104>>2]=0;eh(a,h+104|0);break l}w[h+104>>2]=5;eh(a,h+104|0);break l}w[h+104>>2]=20;eh(a,h+104|0);break l}e=P()|0;if(u[d+11|0]>=0){break j}zb(w[d>>2]);break j}rb:{if(!x[h+122|0]){break rb}w[114256]=0;d=Q(5,h+40|0,6966)|0;b=w[114256];w[114256]=0;sb:{if((b|0)!=1){b=w[h+76>>2];c=w[h+80>>2];if(b>>>0<c>>>0){c=w[d+4>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[h+76>>2]=b+12;break rb}e=w[h+72>>2];f=(b-e|0)/12|0;b=f+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,h+72|0);b=w[114256];w[114256]=0;if((b|0)!=1){break g}break sb}w[114256]=0;c=(c-e|0)/12|0;e=c<<1;e=Z(921,h+184|0,(c>>>0>=178956970?357913941:b>>>0<e>>>0?e:b)|0,f|0,i|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break sb}c=w[d+4>>2];b=w[e+8>>2];w[b>>2]=w[d>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+8>>2]+12|0;w[e+8>>2]=f;g=w[e+4>>2];b=w[h+76>>2];c=w[h+72>>2];tb:{if((b|0)==(c|0)){b=c;break tb}while(1){f=g-12|0;b=b-12|0;g=w[b+4>>2];w[f>>2]=w[b>>2];w[f+4>>2]=g;w[f+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;g=w[e+4>>2]-12|0;w[e+4>>2]=g;if((b|0)!=(c|0)){continue}break}f=w[e+8>>2];c=w[h+76>>2];b=w[h+72>>2]}w[h+72>>2]=g;w[e+4>>2]=b;w[h+76>>2]=f;w[e+8>>2]=c;c=w[h+80>>2];w[h+80>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=c;sc(e);if(u[d+11|0]>=0){break rb}zb(w[d>>2]);break rb}e=P()|0;break j}e=P()|0;if(u[d+11|0]>=0){break j}zb(w[d>>2]);break j}ub:{if(w[h+72>>2]==w[h+76>>2]){break ub}w[114256]=0;Q(1315,a|0,12630)|0;b=w[114256];w[114256]=0;if((b|0)!=1){w[114256]=0;b=Q(5,h+8|0,12600)|0;c=w[114256];w[114256]=0;vb:{wb:{xb:{if((c|0)!=1){w[114256]=0;U(1437,h+24|0,h+72|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break xb}w[114256]=0;c=x[h+35|0];e=c<<24>>24<0;S(92,a|0,(e?w[h+24>>2]:h+24|0)|0,(e?w[h+28>>2]:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break wb}if(u[h+35|0]<0){zb(w[h+24>>2])}if(u[b+11|0]>=0){break ub}zb(w[b>>2]);break ub}e=P()|0;break j}e=P()|0;break vb}e=P()|0;if(u[h+35|0]>=0){break vb}zb(w[h+24>>2])}if(u[b+11|0]>=0){break j}zb(w[b>>2]);break j}e=P()|0;break j}bc(h+72|0);if(u[h+135|0]<0){zb(w[h+124>>2])}if(u[h+115|0]>=0){break l}zb(w[h+104>>2])}jb=h+208|0;break e}e=P()|0;if(u[d+11|0]>=0){break j}zb(w[d>>2])}bc(h+72|0)}Xd(h+104|0);if(u[a+11|0]>=0){break h}zb(w[a>>2])}R(e|0);M()}M()}W(0)|0;Eb();M()}return}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}}R(a|0);M()}if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}function ri(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,W=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ja=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Ba=0,Ca=0;i=jb-176|0;jb=i;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;u[i+146|0]=0;v[i+144>>1]=0;w[i+136>>2]=0;w[i+140>>2]=-1;w[i+128>>2]=-1;w[i+132>>2]=-1;w[i+120>>2]=0;w[i+124>>2]=0;o=x[b+484376|0];l=w[b+484364>>2];K=w[d+16>>2];g=x[d+6|0];h=w[b+484360>>2];n=i+80|0;w[n>>2]=b;m=Fb(Kb(229984),b+1074376|0,602);k=m+608|0;while(1){e=C(r,896);f=e+b|0;e=Fb(e+k|0,f+1074984|0,88);w[e+88>>2]=w[f+1075072>>2];Fb(e+92|0,f+1075076|0,576);w[e+668>>2]=w[f+1075652>>2];Fb(e+672|0,f+1075656|0,52);u[e+724|0]=x[f+1075708|0];t=f+1075712|0;j=w[t+4>>2];w[e+728>>2]=w[t>>2];w[e+732>>2]=j;u[e+736|0]=x[f+1075720|0];t=f+1075724|0;j=w[t+4>>2];w[e+740>>2]=w[t>>2];w[e+744>>2]=j;u[e+748|0]=x[f+1075732|0];t=f+1075736|0;j=w[t+4>>2];w[e+752>>2]=w[t>>2];w[e+756>>2]=j;Fb(e+760|0,f+1075744|0,135);r=r+1|0;if((r|0)!=256){continue}break}w[n+4>>2]=m;w[n+20>>2]=0;w[n+24>>2]=0;e=n+12|0;w[e>>2]=0;w[e+4>>2]=0;w[n+28>>2]=0;w[n+8>>2]=e;w[114256]=0;X(791,n|0);e=w[114256];w[114256]=0;if((e|0)==1){b=P()|0;a=w[n+20>>2];if(a){w[n+24>>2]=a;zb(a)}qg(n+8|0,w[n+12>>2]);a=w[n+4>>2];w[n+4>>2]=0;if(a){zb(a)}R(b|0);M()}j=w[n+4>>2];w[114256]=0;ka=g>>>0<(l-h>>>5&255)>>>0?g:o;o=ka&255;I=S(787,i+48|0,b|0,o|0)|0;e=w[114256];w[114256]=0;a:{if((e|0)!=1){g=w[d>>2];b:{c:{e=y[d+4>>1];E=h+(o<<5)|0;d:{if(e>>>0>=w[E+4>>2]-w[E>>2]>>1>>>0){break d}while(1){w[114256]=0;f=Q(305,E|0,e&65535)|0;r=w[114256];w[114256]=0;if((r|0)==1){break c}if(f){break d}g=0;e=e+1|0;if((e&65535)>>>0<w[E+4>>2]-w[E>>2]>>1>>>0){continue}break}}w[d>>2]=g;v[d+4>>1]=e;w[j+52>>2]=g;w[j+48>>2]=g;w[i+136>>2]=g;v[j+64>>1]=e;v[j+62>>1]=e;v[i+144>>1]=e;w[i+40>>2]=0;w[i+44>>2]=0;e:{f:{g:{h:{i:{j:{k:{ga=c&7;la=(ga|0)!=7;l:{if(la){break l}w[i+40>>2]=268435470;w[i+44>>2]=120;ua=12288;if((K|0)!=2){break l}g=y[d+12>>1];e=w[E>>2];if(g>>>0>=w[E+4>>2]-e>>1>>>0){break l}g=y[e+(g<<1)>>1];f=w[b+484344>>2];if(g>>>0>=((w[b+484348>>2]-f|0)/52&65535)>>>0){break l}e=f+C(g,52)|0;if(w[e>>2]==w[e+4>>2]){break l}g=w[(f+C(g,52)|0)+12>>2];f=w[d+8>>2];if(g>>>0<=f>>>0){break l}w[114256]=0;g=V(218,e|0)|0;r=w[114256];w[114256]=0;if((r|0)==1){break k}r=y[b+480188>>1];if(!r){break l}e=w[e>>2]+C(C(f,g),6)|0;g=w[n+20>>2];f=0;l=y[b+480192>>1];while(1){m:{n:{o:{p:{m=x[e|0];switch(m-253|0){case 1:case 2:break n;case 0:break p;default:break o}}if(l){break n}break m}if((m-1&255)>>>0>119){break m}q:{switch(x[e+3|0]-4|0){case 0:case 2:break m;default:break q}}if(x[e+2|0]==11){break m}}w[(g+C(f,24)|0)+16>>2]=-1}e=e+6|0;f=f+1|0;if((r|0)!=(f|0)){continue}break}}va=b+484360|0;N=j- -64|0;H=j+48|0;na=n+8|0;W=c&1;oa=h+(o<<5)|0;ha=i|4;wa=(K|0)!=3;pa=(K|0)!=2;xa=b+1074317|0;qa=b+1074318|0;ja=b+1074321|0;ya=b+1074319|0;ra=b+1074313|0;za=b+1074314|0;sa=b+1074323|0;r=0;while(1){w[j+48>>2]=w[j+52>>2];e=y[j+64>>1];v[j+62>>1]=e;w[114256]=0;e=Q(305,E|0,e|0)|0;f=w[114256];w[114256]=0;r:{if((f|0)!=1){if(!(!e|z[j+48>>2]<z[(w[b+484344>>2]+C(y[w[E>>2]+(y[j+62>>1]<<1)>>1],52)|0)+12>>2])){w[H>>2]=0;if(w[b+1074316>>2]<0){e=w[j+56>>2];w[j+56>>2]=0;w[j+48>>2]=e}e=y[j+64>>1]+1|0;v[j+62>>1]=e;v[j+64>>1]=e}if(!(B[n+32>>3]>=B[d+8>>3])|wa){break r}break f}f=P()|0;break b}f=y[j+62>>1];e=w[E>>2];s:{t:{if(f>>>0>=w[E+4>>2]-e>>1>>>0){e=65535;v[j+60>>1]=65535;g=w[b+484348>>2];o=w[b+484344>>2];m=(g-o|0)/52|0;break t}e=y[e+(f<<1)>>1];v[j+60>>1]=e;g=w[b+484348>>2];o=w[b+484344>>2];m=(g-o|0)/52|0;h=m&65535;u:{if(h>>>0>e>>>0){l=C(e,52)+o|0;if(w[l>>2]!=w[l+4>>2]){break u}}if((e|0)==65535|pa){break u}if((f|0)==y[d+12>>1]){break f}}if(e>>>0<h>>>0){break s}}while(1){h=y[j+62>>1];v:{w:{if((e&65535)!=65535){q=w[E>>2];e=w[E+4>>2]-q>>1;if(h>>>0<e>>>0){break w}}f=y[oa+28>>1];if((h|0)==(f|0)){break s}q=w[E>>2];e=w[E+4>>2]-q>>1;break v}f=h+1|0}v[j+62>>1]=f;x:{h=f&65535;y:{z:{if(h>>>0>=e>>>0){v[j+64>>1]=f;v[j+60>>1]=65535;break z}e=y[(h<<1)+q>>1];v[j+64>>1]=f;v[j+60>>1]=e;if((m&65535)>>>0<=e>>>0){break z}f=C(e,52)+o|0;if(w[f>>2]!=w[f+4>>2]){break y}}w[114256]=0;e=Z(788,I|0,h|0,0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(e){break x}o=w[b+484344>>2];g=w[b+484348>>2];e=y[j+60>>1]}m=(g-o|0)/52|0;if((e&65535)>>>0>=(m&65535)>>>0){continue}break s}break}if(K>>>0<=1){e=y[j+62>>1];w[i+128>>2]=0;v[i+140>>1]=e;if(!K){break s}}w[114256]=0;e=Z(789,I|0,N|0,H|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}if(!e){break s}B[i+120>>3]=B[n+32>>3];e=w[a+4>>2];A:{if((e|0)!=w[a+8>>2]){f=w[i+124>>2];w[e>>2]=w[i+120>>2];w[e+4>>2]=f;f=w[i+148>>2];w[e+24>>2]=w[i+144>>2];w[e+28>>2]=f;f=w[i+140>>2];w[e+16>>2]=w[i+136>>2];w[e+20>>2]=f;f=w[i+132>>2];w[e+8>>2]=w[i+128>>2];w[e+12>>2]=f;w[a+4>>2]=e+32;break A}w[114256]=0;T(790,a|0,i+120|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}}w[i+136>>2]=w[H>>2];e=y[N>>1];w[114256]=0;v[i+144>>1]=e;X(791,n|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}e=y[j+64>>1];v[j+62>>1]=e;v[j+60>>1]=y[w[E>>2]+(e<<1)>>1];w[j+52>>2]=w[j+48>>2]}if(y[N>>1]==65535){break e}B:{f=y[j+60>>1];e=w[b+484344>>2];if(f>>>0<((w[b+484348>>2]-e|0)/52&65535)>>>0){e=e+C(f,52)|0;if(w[e>>2]!=w[e+4>>2]){break B}}e=y[j+62>>1];if((e|0)==y[oa+28>>1]){if(!K){break e}w[114256]=0;e=Z(789,I|0,N|0,H|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}if(!e){break e}B[i+120>>3]=B[n+32>>3];e=w[a+4>>2];C:{if((e|0)!=w[a+8>>2]){f=w[i+124>>2];w[e>>2]=w[i+120>>2];w[e+4>>2]=f;f=w[i+148>>2];w[e+24>>2]=w[i+144>>2];w[e+28>>2]=f;f=w[i+140>>2];w[e+16>>2]=w[i+136>>2];w[e+20>>2]=f;f=w[i+132>>2];w[e+8>>2]=w[i+128>>2];w[e+12>>2]=f;w[a+4>>2]=e+32;break C}w[114256]=0;T(790,a|0,i+120|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}}w[i+136>>2]=w[H>>2];e=y[N>>1];w[114256]=0;v[i+144>>1]=e;X(791,n|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}w[j+52>>2]=w[j+48>>2];continue}v[N>>1]=e+1;continue}f=w[H>>2];if(f>>>0>=z[e+12>>2]){w[H>>2]=0;f=0}e=y[j+62>>1];if(!((e|0)!=y[d+12>>1]|pa)&w[d+8>>2]==(f|0)){break f}w[114256]=0;e=Z(788,I|0,e|0,f|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}if(e){if(K>>>0<=1){v[i+140>>1]=y[j+62>>1];w[i+128>>2]=w[j+48>>2];if(!K){break e}}w[114256]=0;e=Z(789,I|0,N|0,H|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}if(!e){break e}B[i+120>>3]=B[n+32>>3];e=w[a+4>>2];D:{if((e|0)!=w[a+8>>2]){f=w[i+124>>2];w[e>>2]=w[i+120>>2];w[e+4>>2]=f;f=w[i+148>>2];w[e+24>>2]=w[i+144>>2];w[e+28>>2]=f;f=w[i+140>>2];w[e+16>>2]=w[i+136>>2];w[e+20>>2]=f;f=w[i+132>>2];w[e+8>>2]=w[i+128>>2];w[e+12>>2]=f;w[a+4>>2]=e+32;break D}w[114256]=0;T(790,a|0,i+120|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}}w[i+136>>2]=w[H>>2];e=y[N>>1];w[114256]=0;v[i+144>>1]=e;X(791,n|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}w[j+52>>2]=w[j+48>>2];continue}v[i+142>>1]=y[j+62>>1];q=w[j+48>>2];w[i+132>>2]=q;w[j+52>>2]=q+1;f=w[b+484344>>2]+C(y[j+60>>1],52)|0;E:{F:{if(z[f+12>>2]<=q>>>0){w[H>>2]=0;break F}if(q){break E}}g=y[b+480188>>1];if(!g){q=0;break E}h=w[j>>2];o=w[n+20>>2];G=B[n+32>>3];q=0;e=0;while(1){l=o+C(e,24)|0;w[l+8>>2]=h;B[l>>3]=G;e=e+1|0;if((g|0)!=(e|0)){continue}break}}w[114256]=0;e=V(218,f|0)|0;g=w[114256];w[114256]=0;G:{H:{I:{if((g|0)!=1){if(y[b+480188>>1]){break I}aa=0;h=0;break H}f=P()|0;break b}e=w[f>>2]+C(C(e,q),6)|0;f=0;J=0;aa=0;J:{while(1){K:{L:{if(x[((f<<5)+b|0)+480281|0]&4?x[ja|0]&32:0){break L}if((x[e|0]+5&255)>>>0<=1){M:{if(!W){break M}g=x[e+1|0];if(g-251>>>0<5|!g){break M}h=x[e+5|0];o=x[e+3|0];l=x[e+4|0];m=x[e+2|0];w[114256]=0;u[i+32|0]=g;v[i+34>>1]=l|m<<8;g=i+32|0;w[i+168>>2]=g;ia(792,i|0,na|0,g|0,25632,i+168|0,i+160|0);g=w[114256];w[114256]=0;if((g|0)==1){break K}v[w[i>>2]+18>>1]=h|o<<8}g=C(f,896)+j|0;h=g+1422|0;u[h|0]=0;u[h+1|0]=0;g=g+1418|0;u[g|0]=0;u[g+1|0]=0;u[g+2|0]=0;u[g+3|0]=0;break L}g=C(f,896)+j|0;h=g+1422|0;o=x[e+4|0]|x[e+5|0]<<8;u[h|0]=o;u[h+1|0]=o>>>8;h=g+1418|0;o=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);u[h|0]=o;u[h+1|0]=o>>>8;u[h+2|0]=o>>>16;u[h+3|0]=o>>>24;N:{switch(x[e+3|0]-16|0){case 0:rk(b,j,x[e+5|0]);break L;case 1:if(!(x[b+1074312|0]&32)){break L}g=x[e+5|0];if(!g){break L}rk(b,j,g);break L;case 4:h=g+1423|0;o=x[h|0];O:{if(!(o|!(w[b+480180>>2]&16777250))){u[h|0]=x[g+1461|0];break O}u[g+1461|0]=o}g=x[e+5|0];h=g&240;if((h|0)==96){aa=(g&15)+aa|0;break L}if((h|0)!=224|J){break L}g=g&15;if(x[b+480180|0]&2){J=0;if(!g){break L}}J=g+1|0;break L;case 3:break N;default:break L}}g=x[e+5|0];if((g&240)!=224){break L}J=(g&15)+1|0}e=e+6|0;f=f+1|0;h=y[b+480188>>1];if(f>>>0<h>>>0){continue}break J}break}f=P()|0;break b}if(J){break G}}J=1}e=w[j+40>>2];t=C(aa+e|0,J);P:{if(!h){o=0;ca=0;ea=0;ba=0;_=0;break P}O=t-1|0;e=t-J|0;$=C(e,1e4);f=0;_=0;ba=0;ea=0;ca=0;o=0;Q:{while(1){R:{k=C(f,896)+j|0;q=k+1420|0;A=k+1419|0;g=x[A|0];m=k+1418|0;l=x[m|0];S:{if(!(x[q|0]|(g|l)|x[k+1421|0])|(x[((f<<5)+b|0)+480281|0]&4?x[ja|0]&32:0)){break S}h=x[k+1423|0];fa=k+1421|0;s=x[fa|0];if(g){u[k+1429|0]=0;u[k+1433|0]=g;u[(w[n+20>>2]+C(f,24)|0)+21|0]=255}p=k+608|0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{L=(l-1&255)>>>0>119;aa:{ba:{if(!L){u[k+1429|0]=l;w[114256]=0;X(793,p|0);g=w[114256];w[114256]=0;if((g|0)==1){break R}if((x[m|0]-1&255)>>>0<120){break ba}}if(!x[A|0]){break aa}}g=x[k+1433|0];A=y[b+480192>>1];if(A){if(g>>>0>A>>>0){break aa}g=w[((g<<2)+b|0)+900380>>2];if(!g){break aa}ca:{if(!(u[g+15|0]&1)){break ca}A=w[g+8>>2];w[114256]=0;U(794,p|0,A|0,b|0);A=w[114256];w[114256]=0;if((A|0)!=1){break ca}f=P()|0;break b}if(L){break aa}g=y[(g+(l<<1)|0)+234>>1]}g=g&65535;if(!g|g>>>0>y[b+480190>>1]){break aa}g=C(g,104)+b|0;if(!(x[g+484414|0]&32)){break aa}g=y[g+484408>>1];w[114256]=0;U(794,p|0,g|0,b|0);g=w[114256];w[114256]=0;if((g|0)==1){break $}}da:{ea:{fa:{g=x[q|0];switch(g-1|0){case 2:case 3:break ea;case 0:break fa;case 1:break Z;default:break da}}u[(w[n+20>>2]+C(f,24)|0)+21|0]=x[k+1422|0];break Z}g=x[k+1422|0];if(!g){break Z}u[k+1462|0]=g;break Z}if((g|0)==11){break _}break Z}f=P()|0;break b}if(!x[k+1422|0]){break Z}qk(i,b,m,0);w[k+1384>>2]=w[i>>2];if(!x[i+4|0]){break Z}s=0;break Y}ga:{switch(s-12|0){default:if((s|0)!=28){break Y}s=28;if(x[ya|0]&4|(h&240)!=160){break Y}u[k+1464|0]=h&15;break Y;case 0:g=w[j+48>>2];l=y[j+60>>1];w[114256]=0;g=da(795,b|0,l|0,g|0,f&65535,0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break R}w[j+56>>2]=0;v[j+64>>1]=g;if(!(!(x[b+480180|0]&5)&ea)){w[j+52>>2]=0}ba=1;if(!W){_=1;break S}w[k+1412>>2]=0;u[k+1469|0]=0;_=1;break T;case 2:w[114256]=0;g=Z(796,b|0,j|0,f&65535,h|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break X}if((g|0)==-1){s=14;break Y}w[j+52>>2]=g;if(!_){v[j+64>>1]=y[j+62>>1]+1}ea=1;if(!W){break S}w[k+1412>>2]=0;u[k+1469|0]=0;break T;case 5:s=17;if(x[b+1074312|0]&32){break Y}g=w[j+48>>2];l=y[j+60>>1];w[114256]=0;g=da(795,b|0,l|0,g|0,f&65535,0)|0;l=w[114256];w[114256]=0;ha:{ia:{if((l|0)!=1){m=C(g,1e4);if(!W|!(w[b+480180>>2]&16777250)){break ha}if(m>>>0<1e4){break ia}u[k+1463|0]=(m>>>0)/1e4;break ha}f=P()|0;break b}m=C(x[k+1463|0],1e4)}ja:{if(m>>>0>319999){break ja}m=(m>>>0)/1e4|0;l=C($,m&15);g=w[j+44>>2];if((m&240)==16){m=g+l|0;break ja}l=g-l|0;m=g>>>0>=l>>>0?l:0}w[j+44>>2]=m;l=w[b+8>>2];g=C(w[l+20>>2],1e4);l=u[ra|0]&1?255e4:C(w[l+24>>2],1e4);if(g>>>0>l>>>0){break Y}if(g>>>0<=m>>>0){g=l;if(g>>>0>=m>>>0){break Y}}w[j+44>>2]=g;break Y;case 8:s=20;ka:{switch((h&240)-144>>>4|0){case 0:if(h>>>0>145){break Y}w[k+696>>2]=w[k+696>>2]&-257|((h|0)==145)<<8;break Y;case 1:u[k+1464|0]=h&15;break Y;case 2:g=w[b+480180>>2]==2;l=g?y[b+480188>>1]-1|0:f;m=g?0:f;if(!(h&15)){ba=0;o=1;l=l&65535;if(l>>>0<(m&65535)>>>0){break Y}g=w[j+48>>2];A=w[j>>2];L=w[n+20>>2];G=B[n+32>>3];while(1){F=m&65535;o=L+C(F,24)|0;w[o+12>>2]=g;w[o+8>>2]=A;B[o>>3]=G;w[(C(F,896)+j|0)+1412>>2]=g;o=1;m=m+1|0;if(l>>>0>=(m&65535)>>>0){continue}break}break Y}ca=1;ba=0;if(!((g|x[za|0])&1)){break Y}g=l&65535;if(g>>>0<(m&65535)>>>0){break Y}l=w[H>>2]+1|0;while(1){w[(C(m&65535,896)+j|0)+1412>>2]=l;m=m+1|0;if(g>>>0>=(m&65535)>>>0){continue}break};break Y;case 6:break ka;default:break Y}}u[k+1472|0]=h&15;break Y;case 7:break ga;case 1:case 3:case 4:case 6:break Y}}s=19;g=h&240;if((g|0)!=240){if((g|0)!=96){break Y}if(h&15){w[j+56>>2]=w[(w[n+20>>2]+C(f,24)|0)+12>>2];ca=1;break Y}g=w[n+20>>2]+C(f,24)|0;B[g>>3]=B[n+32>>3];w[g+8>>2]=w[j>>2];o=g;g=w[j+48>>2];w[o+12>>2]=g;w[k+1412>>2]=g;o=1;break Y}u[k+1472|0]=h&15}if(!W){break S}la:{ma:{na:{oa:{pa:{qa:{ra:{switch(s-2|0){case 0:if(!h){break U}if(!(x[sa|0]&4)){u[k+1440|0]=h}u[k+1439|0]=h;break T;case 1:if(!h){break U}if(!(x[sa|0]&4)){u[k+1439|0]=h}u[k+1440|0]=h;break T;case 2:if(!h){break U}w[k+1384>>2]=h;break T;case 8:if(!h){break U}w[k+1272>>2]=h<<8;break T;case 4:case 9:if(!h){break U}u[k+1437|0]=h;break T;case 11:u[(w[n+20>>2]+C(f,24)|0)+21|0]=h;break T;case 21:g=w[b+480180>>2];h=h<<(!(g&59593760)&h<<24>>24>=0);l=h&255;if(l>>>0<=128){w[j+68>>2]=l<<1;break T}if(g&16777250){break T}w[j+68>>2]=256;break T;case 22:sa:{if(x[ra|0]&2){g=k+1445|0;if(h){u[g|0]=h;break sa}h=x[g|0];break sa}if(h){u[j+1445|0]=h;break sa}h=x[j+1445|0]}g=h&15;l=h&255;ta:{if(!((g|0)!=15|l>>>0<16)){h=(h&240)>>>4<<!(w[b+480180>>2]&59593760);g=w[j+68>>2]+(h<<1)|0;break ta}l=l&240;if(!(!g|(l|0)!=240)){h=g<<(w[b+480180>>2]&59593760?1:2);g=w[j+68>>2]-h|0;break ta}if(l){h=(h>>>3&30)<<!(w[b+480180>>2]&59593760);g=w[j+68>>2]+C(e,h)|0;break ta}h=g<<(w[b+480180>>2]&59593760?1:2);g=w[j+68>>2]-C(e,h)|0}w[j+68>>2]=g;s=0;if((g|0)>=0){s=256;if(g>>>0<257){break T}}w[j+68>>2]=s;break T;case 19:if(h>>>0>64){break T}w[k+1368>>2]=h;break T;case 20:g=k+1444|0;ua:{if(h){u[g|0]=h;break ua}h=x[g|0]}L=k+1368|0;g=w[L>>2];s=0;l=h&15;A=h&255;va:{if(!((l|0)!=15|A>>>0<16)){m=g+(A>>>4|0)|0;break va}m=g-l|0;if(!(!l|(A&240)!=240)){break va}m=g-C(e,l)|0;if(l){break va}m=g+C(e,A>>>4|0)|0}wa:{if((m|0)>=0){s=64;if(m>>>0<65){break wa}}m=s}w[L>>2]=m;break T;case 7:Hf(b,p,h,8);break T;case 25:break la;case 6:break ma;case 24:break na;case 3:break oa;case 5:break pa;case 18:break qa;case 17:break ra;default:break T}}if(h>>>0>15){break qa}g=y[b+480188>>1];if(!g){break qa}l=(h&1)<<14;m=0;while(1){s=C(m,896)+j|0;w[s+696>>2]=(l|w[s+696>>2]&-16385)^16384;m=m+1|0;if((g|0)!=(m|0)){continue}break}}if((h&240)!=128){break T}Hf(b,p,h&15,4);break T}if(!h){break W}u[k+1437|0]=h;break W}g=h&15;if(g){u[k+1452|0]=g<<2}if(h>>>0<16){break V}u[k+1451|0]=h>>>4;break V}$n(b,p,h);break T}g=h&15;if(g){u[k+1455|0]=g<<2}if(h>>>0>=16){u[k+1454|0]=h>>>4}w[k+696>>2]=w[k+696>>2]|262144;break T}g=h&15;if(g){u[k+1458|0]=g}if(h>>>0<16){break T}u[k+1457|0]=h>>>4;break T}f=P()|0;break b}h=0}w[k+696>>2]=w[k+696>>2]|131072;break T}h=0}xa:{ya:{switch(x[q|0]-2|0){case 0:Hf(b,p,x[k+1422|0],6);break xa;case 5:g=x[k+1422|0]&15;if(x[qa|0]&32){u[k+1451|0]=g;break xa}if(g){u[k+1451|0]=g}w[k+696>>2]=w[k+696>>2]|131072;break xa;case 6:break ya;default:break xa}}g=x[k+1422|0];l=g&15;if(l){u[k+1452|0]=l<<2}if(g>>>0>=16){u[k+1451|0]=g>>>4}w[k+696>>2]=w[k+696>>2]|131072}za:{Aa:{Ba:{Ca:{Da:{g=x[fa|0];switch(g-5|0){case 1:break za;case 3:break Ba;case 0:case 2:break Ca;default:break Da}}switch(g-26|0){case 1:break Aa;case 0:break Ca;default:break za}}g=k+1447|0;l=g;m=x[g|0];Ea:{if(w[b+480180>>2]&16777248){g=t;if(!(x[b+480208|0]&4)){break Ea}}g=e}g=C(g,x[k+1451|0]);u[l|0]=m+(w[b+1074312>>2]&2097152?g<<2:g);break za}g=k+1448|0;l=g;m=x[g|0];Fa:{if(w[b+480180>>2]&16777248){g=t;if(!(x[b+480208|0]&4)){break Fa}}g=e}g=C(g,x[k+1454|0]);u[l|0]=m+(w[b+1074312>>2]&2097152?g<<2:g);break za}g=k+1449|0;u[g|0]=x[g|0]+C(O,x[k+1457|0]);w[114256]=0;T(797,b|0,p|0);g=w[114256];w[114256]=0;if((g|0)==1){break R}}if(!(x[ja|0]&64)){break S}g=h&255;if(!g){break S}u[k+1468|0]=h;u[k+1440|0]=h;u[k+1439|0]=h;u[k+1437|0]=h;u[k+1436|0]=h;u[k+1455|0]=h<<2&60;v[k+1408>>1]=g;u[k+1461|0]=h;u[k+1454|0]=g>>>4}f=f+1|0;if(f>>>0<y[b+480188>>1]){continue}break Q}break}f=P()|0;break b}e=w[j+40>>2]}if(w[b+480180>>2]==4&(e|0)==65535){break e}w[j+32>>2]=w[b+480216>>2];f=w[b+484344>>2]+C(y[j+60>>1],52)|0;e=w[f+16>>2];if((e|0)!=(0-w[f+20>>2]|0)){w[j+32>>2]=e}w[114256]=0;l=Q(798,b|0,j|0)|0;e=w[114256];w[114256]=0;Ga:{Ha:{Ia:{if((e|0)!=1){e=C(l,t);B[n+32>>3]=+(e>>>0)/+z[b+24620>>2]+B[n+32>>3];w[j>>2]=e+w[j>>2];e=y[b+480188>>1];if(!(!e|la)){m=0;fa=(r|0)!=0&(l|0)!=(r|0);L=J-1|0;while(1){A=C(m,24);F=A+w[n+20>>2]|0;Ja:{if(w[F+16>>2]==-1){break Ja}p=C(m,896)+j|0;q=p+1423|0;s=1;Ka:{La:{O=p+1421|0;switch(x[O|0]-4|0){case 0:case 2:break Ka;default:break La}}s=x[p+1420|0]==11}g=x[q|0];if(x[p+1419|0]){w[p+1268>>2]=0}k=p+608|0;e=g&15;h=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{$=p+1418|0;f=x[$|0];if((f-1&255)>>>0<=119){Ua:{Va:{if(!(!s|!x[F+20|0])){f=w[p+1308>>2];w[114256]=0;f=Ch(799,b,k,f,0);h=nb;F=w[114256];w[114256]=0;if((F|0)==1){break Va}w[p+616>>2]=f;w[p+620>>2]=h}u[p+1432|0]=x[p+1429|0];F=p+1300|0;Ba=w[F>>2];f=x[p+1433|0];if(!f){break Ua}w[114256]=0;ia(800,b|0,k|0,f|0,s|0,1,1);f=w[114256];w[114256]=0;if((f|0)!=1){break Ua}break i}f=P()|0;break b}f=x[$|0];w[114256]=0;ma(801,b|0,k|0,f|0,s|0,1,0,65535);f=w[114256];w[114256]=0;if((f|0)==1){break i}g=g>>>4|0;ta=A+w[n+20>>2]|0;u[ta+20|0]=1;f=x[O|0];Wa:{if(!((x[q|0]&240)!=208|(f-19&255)>>>0>1)){h=e;if(e>>>0<t>>>0){break Wa}}h=(f|0)==33?g>>>0<t>>>0?g:0:0}h=!(w[b+480180>>2]&16777250)|(!h|J>>>0<2)?h:C(L,w[j+40>>2]+aa|0)+h|0;if(!s){w[ta+16>>2]=0}Xa:{Ya:{if((f|0)==9){break Ya}Za:{if((f|0)!=19){if((f|0)!=20|(g|0)!=8){break Za}break Ya}if((g|0)==8){break Ya}}if(x[p+1420|0]!=2){break Xa}}w[F>>2]=Ba}_a:{$a:{ab:{switch(f-39|0){default:if((f|0)!=10){break $a}u[i|0]=0;f=w[j+48>>2];g=y[j+60>>1];w[114256]=0;f=da(795,b|0,g|0,f|0,m&65535,i|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break Sa}if(!x[i|0]){f=f<<8;if(!f){f=w[p+1272>>2]}f=(x[p+1464|0]<<16)+f|0}Gf(b,k,f);break _a;case 2:f=BV(x[q|0],0,w[p+684>>2],0);Gf(b,k,(nb&255)<<24|f>>>8);break _a;case 1:break $a;case 0:break ab}}if(!w[p+712>>2]){break $a}w[114256]=0;Y(802,n|0,m&65535,r|0,-1);f=w[114256];w[114256]=0;if((f|0)==1){break i}_n(k,x[q|0]);h=w[j+40>>2]-1|0;break _a}if(x[p+1420|0]!=15){break _a}g=w[p+712>>2];if(!g){break _a}f=x[p+1422|0];if(f>>>0>9){break _a}bb:{if(!f){f=w[p+1272>>2];break bb}f=w[(g+(f<<2)|0)- -64>>2];w[p+1272>>2]=f}Gf(b,k,f)}f=x[$|0]}cb:{db:{eb:{fb:{switch((f&255)-253|0){case 0:if(y[b+480192>>1]){break eb}break;case 1:case 2:break eb;default:break fb}}f=x[O|0];if((f-19&255)>>>0<=1){if((x[q|0]&240)!=192){g=o;break cb}g=o;if(e>>>0<t>>>0){break eb}break cb}F=f&255;if((F|0)==33&(e|0)!=0&e+h>>>0<t>>>0){break eb}g=o;if((F|0)!=25){break db}}f=x[O|0];g=1}if((f&255)==13){break Ta}}if(x[p+1420|0]==1){w[p+1296>>2]=x[p+1422|0]<<2}if((!w[p+712>>2]|g)&1){break Pa}e=0;if((f&255)>>>0>42){break Qa}break Ra}w[p+1296>>2]=x[q|0]<<2;f=13;if(!((!w[p+712>>2]|g)&1)){break Ra}break Pa}f=P()|0;break b}e=1;if(w[(i+40|0)+(f>>>3&28)>>2]>>>f&1){break Qa}if((f&255)==19){f=19;F=x[q|0]&240;if((F|0)==32|(F|0)==16){break Qa}}e=g}g=x[p+1420|0];if(g>>>0<=15){break Oa}g=e}if(!(g&1)){break Na}break Ma}if((ua>>>g|e)&1){break Ma}}if(fa){w[114256]=0;Y(802,n|0,m&65535,r|0,-1);e=w[114256];w[114256]=0;if((e|0)==1){break j}f=x[O|0]}gb:{hb:{ib:{e=f&255;if(e-6>>>0>=2){jb:{switch(e-19|0){case 1:break hb;case 0:break ib;default:break jb}}if((e|0)!=11){break gb}}if(!t|!x[q|0]&w[b+480180>>2]==1){break gb}e=p+1480|0;f=0;while(1){u[e|0]=!f|x[e|0]&254;rg(b,k,x[q|0]);f=f+1|0;if((t|0)!=(f|0)){continue}break}break gb}f=x[q|0];e=f&15;if(!(e|w[b+480180>>2]&1048580)){break gb}g=p+1480|0;u[g|0]=x[g|0]|1;f=f&240;if((f|0)!=176){if((f|0)!=160){break gb}dh(b,k,e,0);break gb}ch(b,k,e,0);break gb}kb:{lb:{mb:{e=x[q|0];switch(e-158|0){case 1:break lb;case 0:break mb;default:break kb}}w[114256]=0;Y(802,n|0,m&65535,r|0,-1);e=w[114256];w[114256]=0;if((e|0)==1){break j}w[p+696>>2]=w[p+696>>2]&-129;break gb}w[114256]=0;Y(802,n|0,m&65535,r|0,-1);e=w[114256];w[114256]=0;if((e|0)==1){break j}e=w[p+696>>2];w[p+696>>2]=e|128;if(w[k+4>>2]){break gb}f=w[p+684>>2];if(!f|(e&2?(x[$|0]-121&255)>>>0<=135:0)){break gb}w[k>>2]=-1;w[k+4>>2]=f-1;break gb}if((e&240)!=112|e>>>0<115){break gb}w[114256]=0;U(803,k|0,e|0,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break j}}f=p+1480|0;u[f|0]=x[f|0]|1;nb:{ob:{pb:{qb:{e=x[p+1420|0];switch(e-3|0){case 0:case 1:break ob;case 3:break pb;case 2:break qb;default:break nb}}dh(b,k,x[p+1422|0],(w[b+1074316>>2]&512)>>>9|0);break nb}ch(b,k,x[p+1422|0],(w[b+1074316>>2]&512)>>>9|0);break nb}q=x[p+1422|0];rb:{if(q){break rb}q=0;if(!(x[xa|0]&2)){break rb}q=x[p+1462|0];if(!q){break nb}}if(!t){break nb}g=(e|0)==3?q<<4:q;e=0;while(1){u[f|0]=!e|x[f|0]&254;rg(b,k,g&255);e=e+1|0;if((t|0)!=(e|0)){continue}break}}if(s){f=A+w[n+20>>2]|0;e=w[f+16>>2];w[f+16>>2]=e+t;w[114256]=0;Y(802,n|0,m&65535,l|0,(e+h|0)+1|0);e=w[114256];w[114256]=0;if((e|0)!=1){break Ja}f=P()|0;break b}e=A+w[n+20>>2]|0;w[e+16>>2]=w[e+16>>2]+(t-h|0);break Ja}w[114256]=0;X(804,k|0);e=w[114256];w[114256]=0;if((e|0)==1){break j}w[(A+w[n+20>>2]|0)+16>>2]=0}e=y[b+480188>>1];m=m+1|0;if(e>>>0>m>>>0){continue}break}}r=l;if(!ca|(_|ea?x[b+1074320|0]&16:0)|(x[b+1074324|0]>>>7&ba|(_?x[qa|0]&2:0))){continue}w[i>>2]=ha;w[i+4>>2]=0;w[i+8>>2]=0;g=0;if(!(e&65535)){break Ga}while(1){h=C(g,896)+j|0;f=x[h+1423|0];h=x[h+1421|0];if(!(!(!((h|0)!=20|f>>>0<177)&f>>>0<192)&(f>>>0<97|f>>>0>111|(h|0)!=19))){G=B[w[n+20>>2]+C(g,24)>>3];w[114256]=0;B[i+32>>3]=G;e=i+32|0;w[i+160>>2]=e;ia(805,i+168|0,i|0,e|0,25632,i+160|0,i+152|0);e=w[114256];w[114256]=0;if((e|0)==1){break Ia}if(!w[w[i+168>>2]+24>>2]){w[114256]=0;e=i+32|0;w[i+160>>2]=e;ia(805,i+168|0,i|0,e|0,25632,i+160|0,i+152|0);e=w[114256];w[114256]=0;if((e|0)==1){break Ia}w[w[i+168>>2]+24>>2]=1}w[114256]=0;e=i+32|0;w[i+160>>2]=e;ia(805,i+168|0,i|0,e|0,25632,i+160|0,i+152|0);e=w[114256];w[114256]=0;if((e|0)==1){break Ia}h=w[w[i+168>>2]+24>>2];if(h){o=(f&15)+1|0;e=o;f=h>>31;r=(f^h)-f|0;f=r;while(1){h=f;f=e;e=(h>>>0)%(e>>>0)|0;if(e){continue}break}e=C(o,(r|0)/(f|0)|0)}else{e=0}w[114256]=0;f=i+32|0;w[i+160>>2]=f;ia(805,i+168|0,i|0,f|0,25632,i+160|0,i+152|0);f=w[114256];w[114256]=0;if((f|0)==1){break Ia}w[w[i+168>>2]+24>>2]=e;e=y[b+480188>>1]}g=g+1|0;o=e&65535;if(g>>>0<o>>>0){continue}break}break Ha}f=P()|0;break b}f=P()|0;pi(i,w[i+4>>2]);break b}h=w[i>>2];if((ha|0)!=(h|0)){g=w[b+1074312>>2]&65536;G=B[n+32>>3];r=w[n+20>>2];while(1){m=w[h+24>>2]-1|0;G=(G-B[h+16>>3])*+(m|0)+G;B[n+32>>3]=G;sb:{if(!o){break sb}Ca=B[h+16>>3];e=0;while(1){f=r+C(e,24)|0;if(B[f>>3]!=Ca){e=e+1|0;if((o|0)!=(e|0)){continue}break sb}break}e=w[j>>2];e=C(m,e-w[f+8>>2]|0)+e|0;w[j>>2]=e;if(!g&w[b+480180>>2]!=2){break sb}B[f>>3]=G;w[f+8>>2]=e;w[f+12>>2]=w[H>>2]+1}f=w[h+4>>2];tb:{if(f){while(1){e=f;f=w[e>>2];if(f){continue}break tb}}while(1){e=w[h+8>>2];f=w[e>>2]!=(h|0);h=e;if(f){continue}break}}h=e;if((ha|0)!=(e|0)){continue}break}}if(!o|w[b+480180>>2]!=32){break Ga}f=w[n+20>>2];G=B[n+32>>3];e=0;while(1){g=C(e,896)+j|0;if(!(x[g+1421|0]!=20|(x[g+1423|0]+79&255)>>>0>14)){g=f+C(e,24)|0;B[g>>3]=G;w[g+8>>2]=w[j>>2]}e=e+1|0;if((o|0)!=(e|0)){continue}break}}pi(i,w[i+4>>2]);r=l;continue}}f=P()|0;break b}f=P()|0;break b}f=P()|0;break b}f=P()|0;break b}f=P()|0;break b}u[i+146|0]=1}ub:{vb:{wb:{xb:{yb:{if((ga|0)!=7){break yb}f=y[b+480188>>1];if(!f){break yb}e=0;while(1){if(w[(w[n+20>>2]+C(e,24)|0)+16>>2]!=-1){w[114256]=0;Y(802,n|0,e&65535,r|0,-1);d=w[114256];w[114256]=0;if((d|0)==1){break xb}f=y[b+480188>>1]}e=e+1|0;if(e>>>0<(f&65535)>>>0){continue}break}}if(x[i+146|0]){v[i+140>>1]=y[j+62>>1];w[i+128>>2]=w[j+48>>2]}B[i+120>>3]=B[n+32>>3];d=w[a+4>>2];if((d|0)==w[a+8>>2]){break wb}e=w[i+124>>2];w[d>>2]=w[i+120>>2];w[d+4>>2]=e;e=w[i+148>>2];w[d+24>>2]=w[i+144>>2];w[d+28>>2]=e;e=w[i+140>>2];w[d+16>>2]=w[i+136>>2];w[d+20>>2]=e;e=w[i+132>>2];w[d+8>>2]=w[i+128>>2];w[d+12>>2]=e;w[a+4>>2]=d+32;break vb}f=P()|0;break b}w[114256]=0;T(790,a|0,i+120|0);d=w[114256];w[114256]=0;if((d|0)==1){break ub}}zb:{Ab:{if(!W){break Ab}Bb:{Cb:{if(K?x[i+146|0]:1){Fb(b+1074376|0,j,602);r=0;while(1){e=C(r,896);d=e+b|0;e=e+j|0;Fb(d+1074984|0,e+608|0,88);w[d+1075072>>2]=w[e+696>>2];Fb(d+1075076|0,e+700|0,576);w[d+1075652>>2]=w[e+1276>>2];Fb(d+1075656|0,e+1280|0,52);u[d+1075708|0]=x[e+1332|0];g=e+1336|0;h=w[g+4>>2];f=d+1075712|0;w[f>>2]=w[g>>2];w[f+4>>2]=h;u[d+1075720|0]=x[e+1344|0];g=e+1348|0;h=w[g+4>>2];f=d+1075724|0;w[f>>2]=w[g>>2];w[f+4>>2]=h;u[d+1075732|0]=x[e+1356|0];g=e+1360|0;h=w[g+4>>2];f=d+1075736|0;w[f>>2]=w[g>>2];w[f+4>>2]=h;Fb(d+1075744|0,e+1368|0,135);r=r+1|0;if((r|0)!=256){continue}break}d=b+1074448|0;w[d>>2]=0;w[d+4>>2]=0;e=0;w[b+1074400>>2]=0;u[b+1074464|0]=1;d=b+1074392|0;w[d>>2]=-2;w[d+4>>2]=0;d=w[b+1074444>>2];w[b+1074456>>2]=d;w[b+1074428>>2]=w[b+1074424>>2];w[b+1074460>>2]=d<<12;d=w[b+1304392>>2];if(d){w[114256]=0;X(806,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break ub}}h=y[b+480188>>1];if(h){g=(ga|0)==7;while(1){d=C(e,896)+b|0;f=x[d+1075805|0];if(f){u[d+1075808|0]=f}Db:{if(g){break Db}f=w[n+20>>2]+C(e,24)|0;o=x[f+21|0];if((o|0)==255){break Db}u[i|0]=64;w[d+1075672>>2]=x[(o>>>0>64?i:f+21|0)|0]<<2}f=w[d+1075088>>2];Eb:{if(!f|!(x[f+35|0]&2)){break Eb}o=w[b+1304392>>2];if(!o){break Eb}w[114256]=0;h=e&65535;U(807,o|0,h|0,f+68|0);f=w[114256];w[114256]=0;if((f|0)==1){break zb}f=w[b+1304392>>2];w[114256]=0;U(808,f|0,h|0,1);f=w[114256];w[114256]=0;if((f|0)==1){break zb}h=y[b+480188>>1]}w[d+1075e3>>2]=0;e=e+1|0;if(e>>>0<(h&65535)>>>0){continue}break}}w[i+24>>2]=0;w[i+28>>2]=0;w[i+16>>2]=0;w[i+20>>2]=0;w[i+8>>2]=0;w[i+12>>2]=0;w[i>>2]=0;w[i+4>>2]=0;f=w[n+8>>2];g=n+12|0;if((f|0)==(g|0)){break Cb}while(1){Fb:{Gb:{Hb:{e=x[f+14|0]-1&255;d=w[(C(e,160)+b|0)+906300>>2];if(d){Ib:{h=(e>>>3&28)+i|0;o=w[h>>2];r=1<<e;if(o&r){break Ib}Jb:{if(e>>>0>=250){w[114256]=0;X(809,7935);b=w[114256];w[114256]=0;if((b|0)==1){break Jb}M()}w[h>>2]=o|r;e=w[w[d>>2]+168>>2];w[114256]=0;T(e|0,d|0,-1);e=w[114256];w[114256]=0;if((e|0)!=1){break Ib}break Hb}f=P()|0;break b}e=y[f+16>>1];h=y[f+18>>1];o=w[w[d>>2]+44>>2];w[114256]=0;Aa(o|0,d|0,e|0,D(D(D(h>>>0)*D(.0010010009864345193))));d=w[114256];w[114256]=0;if((d|0)==1){break Hb}}e=w[f+4>>2];if(!e){break Gb}while(1){f=e;e=w[e>>2];if(e){continue}break}break Fb}f=P()|0;break b}while(1){d=f;f=w[f+8>>2];if((d|0)!=w[f>>2]){continue}break}}if((f|0)!=(g|0)){continue}break}break Cb}if((c|0)==3){break Bb}w[b+1074416>>2]=w[b+480196>>2];w[b+1074420>>2]=w[b+480204>>2];w[b+1074444>>2]=w[b+480200>>2];break Bb}e=250;f=i;Kb:{while(1){if(w[f>>2]){break Kb}f=f+4|0;e=e-32|0;if(e>>>0>31){continue}break}if(!(w[i+28>>2]&67108863)){break Bb}}f=0;while(1){Lb:{if(!(w[(f>>>3&536870908)+i>>2]>>>f&1)){break Lb}d=w[(C(f,160)+b|0)+906300>>2];e=w[w[d>>2]+172>>2];w[114256]=0;X(e|0,d|0);d=w[114256];w[114256]=0;if((d|0)!=1){break Lb}f=P()|0;break b}f=f+1|0;if((f|0)!=250){continue}break}}d=ka&255;if((d|0)==x[b+484376|0]){break Ab}w[114256]=0;T(264,va|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break ub}}if(c&9){w[114256]=0;T(810,b+1304360|0,I|0);b=w[114256];w[114256]=0;if((b|0)==1){break ub}}a=w[I+12>>2];if(a){w[I+16>>2]=a;zb(a)}ui(I);a=w[n+20>>2];if(a){w[n+24>>2]=a;zb(a)}qg(na,w[n+12>>2]);a=w[n+4>>2];w[n+4>>2]=0;if(a){zb(a)}jb=i+176|0;return}f=P()|0;break b}f=P()|0;break b}f=P()|0}Zn(I);break a}f=P()|0}b=w[n+20>>2];if(b){w[n+24>>2]=b;zb(b)}qg(n+8|0,w[n+12>>2]);b=w[n+4>>2];w[n+4>>2]=0;if(b){zb(b)}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(f|0);M()}function TB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=jb-1776|0;jb=d;w[b+8>>2]=0;f=jb-16|0;jb=f;i=w[b+8>>2];g=w[b>>2];j=d+1632|0;w[f+8>>2]=j;w[f+12>>2]=j+126;i=ob[w[w[g>>2]+32>>2]](g,i,f+8|0)|0;if((i|0)==126){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],126)|0){g=w[b+8>>2]+126|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{if((i|0)!=126){break b}if(!rp(d+1632|0)){break b}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],256)|0)){break b}c:{if(!c){break c}tc(a,1048576);je(a);e=Hb(d+1616|0,10843);g=w[e>>2];w[d+92>>2]=w[e+4>>2];f=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+95|0]=f;u[d+96|0]=f>>>8;u[d+97|0]=f>>>16;u[d+98|0]=f>>>24;w[e>>2]=0;w[e+4>>2]=0;f=x[e+11|0];w[e+8>>2]=0;w[114256]=0;w[d+88>>2]=g;u[d+99|0]=f;f=y[d+1640>>1];w[d+40>>2]=f>>>8;w[d+1344>>2]=f&255;u[d+288|0]=44;w[d+280>>2]=-1;w[d+284>>2]=0;w[d+272>>2]=1042;w[d+276>>2]=2;U(101,d+160|0,d+1344|0,d+272|0);f=w[114256];w[114256]=0;d:{e:{f:{g:{h:{i:{j:{k:{if((f|0)!=1){w[114256]=0;Y(366,d+1360|0,d+88|0,d+40|0,d+160|0);f=w[114256];w[114256]=0;if((f|0)==1){break k}f=a+1304436|0;if(u[a+1304447|0]<0){zb(w[f>>2])}g=w[d+1364>>2];w[f>>2]=w[d+1360>>2];w[f+4>>2]=g;w[f+8>>2]=w[d+1368>>2];u[d+1371|0]=0;u[d+1360|0]=0;if(u[d+171|0]<0){zb(w[d+160>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[e+11|0]<0){zb(w[e>>2])}e=a+1304448|0;f=Hb(d+272|0,10677);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];e=d+1360|0;Vb(e,2,d+1642|0,32);w[114256]=0;U(6,d+272|0,7,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break i}e=a+1304460|0;if(u[a+1304471|0]<0){zb(w[e>>2])}f=w[d+276>>2];w[e>>2]=w[d+272>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+280>>2];u[d+283|0]=0;u[d+272|0]=0;if(u[d+1371|0]<0){zb(w[d+1360>>2])}w[a+1304496>>2]=7;Vb(d+272|0,2,d+1674|0,64);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+276>>2];w[e>>2]=w[d+272>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+280>>2];v[a+480188>>1]=y[d+1744>>1];e=x[d+1748|0];w[a+480204>>2]=125e4;w[a+480208>>2]=32792;w[a+480196>>2]=e?e>>>0>=31?31:e:1;v[a+480192>>1]=y[d+1754>>1];v[a+480190>>1]=y[d+1756>>1];e=x[d+1749|0];w[a+480228>>2]=96;w[a+480232>>2]=48;e=e?e>>>0>=32?32:e:1;w[a+480216>>2]=e;w[a+480220>>2]=e<<2;e=d+1360|0;ll(b,e);f=a+484376|0;Pf(w[a+484360>>2]+(x[f|0]<<5)|0,e,y[d+1738>>1],65535,65535);v[(w[a+484360>>2]+(x[f|0]<<5)|0)+28>>1]=y[d+1740>>1];e=d+272|0;o=cd(b,e)^1|!y[d+272>>1];oc(d+1344|0,b,o?0:274);w[114256]=0;e=Q(232,b|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}w[114256]=0;U(188,d+1328|0,b|0,(e?w[d+272>>2]:0)|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}s=y[a+480188>>1];if(!o){v[a+480188>>1]=s+8}t=c&1;if(!t){break g}w[114256]=0;T(215,a+484344|0,y[d+1742>>1]);e=w[114256];w[114256]=0;if((e|0)!=1){break g}f=P()|0;break f}f=P()|0;break j}f=P()|0;if(u[d+171|0]>=0){break j}zb(w[d+160>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[e+11|0]>=0){break d}zb(w[e>>2]);break d}f=P()|0;if(u[d+1371|0]>=0){break d}zb(w[d+1360>>2]);break d}f=P()|0;break e}l:{m:{n:{o:{p:{q:{r:{if(y[d+1742>>1]){r=a+484344|0;g=0;while(1){w[114256]=0;f=Q(197,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break p}w[114256]=0;e=y[d+272>>1];i=Q(232,b|0,d+88|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break q}w[114256]=0;U(188,d+272|0,b|0,(i?w[d+88>>2]+1&-2:0)|0);i=w[114256];w[114256]=0;if((i|0)==1){break q}s:{t:{if(!t){break t}m=f?e>>>0>=1024?1024:e:0;if(!m){break t}w[114256]=0;e=S(216,r|0,h&65535,m|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}if(!e){break t}k=0;f=0;if(u[d+1750|0]&1){while(1){e=w[d+272>>2];i=w[w[e>>2]+36>>2];w[114256]=0;e=S(i|0,e|0,w[d+280>>2],1)|0;i=w[114256];w[114256]=0;u:{v:{if((i|0)!=1){if(!e){break t}w[114256]=0;e=Q(241,d+272|0,d+160|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break r}n=0;e=e?x[d+160|0]:0;if((e&255)==255){w[114256]=0;e=Q(241,d+272|0,d+160|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break r}w[114256]=0;i=x[d+160|0];j=Q(241,d+272|0,d+160|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break r}n=e?i:0;e=j?x[d+160|0]:0}if(e&127){break v}n=n&255;break u}break r}i=w[r>>2];w[114256]=0;i=i+C(h,52)|0;j=V(218,i|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break r}i=w[i>>2];u[d+91|0]=0;u[d+92|0]=0;u[d+93|0]=0;u[d+94|0]=0;w[d+88>>2]=0;e=e&255;if(e&1){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+88|0]=l?x[d+160|0]:0}if(e&2){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+89|0]=l?x[d+160|0]:0}if(e&4){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+90|0]=l?x[d+160|0]:0}if(e&8){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+91|0]=l?x[d+160|0]:0}if(e&16){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+92|0]=l?x[d+160|0]:0}if(e&32){w[114256]=0;l=Q(241,d+272|0,d+160|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break r}u[d+93|0]=l?x[d+160|0]:0}if(e&64){w[114256]=0;e=Q(241,d+272|0,d+160|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break r}u[d+94|0]=e?x[d+160|0]:0}w[114256]=0;i=i+C(C(f,j)+(k&65535)|0,6)|0;e=Q(498,i|0,d+88|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}g=e|g;j=0;e=i;l=m+(f^-1)|0;n=n&255;p=l>>>0<n>>>0?l:n;if(!p){break u}while(1){e=C(y[a+480188>>1],6)+e|0;l=x[i|0]|x[i+1|0]<<8|(x[i+2|0]<<16|x[i+3|0]<<24);u[e|0]=l;u[e+1|0]=l>>>8;u[e+2|0]=l>>>16;u[e+3|0]=l>>>24;l=x[i+4|0]|x[i+5|0]<<8;u[e+4|0]=l;u[e+5|0]=l>>>8;j=j+1|0;if((p|0)!=(j|0)){continue}break}}f=(f+n|0)+1|0;if(m>>>0<=f>>>0){while(1){k=k+1|0;f=f-m|0;if(m>>>0<=f>>>0){continue}break}}if(s>>>0>(k&65535)>>>0){continue}break t}}while(1){e=w[r>>2];w[114256]=0;e=e+C(h,52)|0;f=V(218,e|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break r}if(s){f=w[e>>2]+C(C(f,k),6)|0;e=0;while(1){w[114256]=0;i=Q(499,d+272|0,d+88|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}if(!i){u[d+91|0]=0;u[d+92|0]=0;u[d+93|0]=0;u[d+94|0]=0;w[d+88>>2]=0}w[114256]=0;i=Q(498,f+C(e,6)|0,d+88|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}g=g|i;e=e+1|0;if((s|0)!=(e|0)){continue}break}}k=k+1|0;if((m|0)!=(k|0)){continue}break}}e=w[d+276>>2];w:{if(!e){break w}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break w}ob[w[w[e>>2]+8>>2]](e);Ib(e)}h=h+1|0;if(h>>>0>=y[d+1742>>1]){break o}continue}break}break r}f=0;e=y[d+1746>>1];if((e-2&65535)>>>0>=4998){break l}break n}f=P()|0;Bb(d+272|0);break f}f=P()|0;break f}f=P()|0;break f}e=y[d+1746>>1];if((e-2&65535)>>>0>=4998){f=g;break l}f=1;if(!(g&1)){break n}g=0;e=((e>>>1|0)+11025e5>>>0)/(e>>>0)|0;break m}g=2;q=Tb(2646e7/+(C(w[a+480216>>2],C(w[a+480196>>2],e&65535))>>>0));if(q>=4294967295){f=0;e=-1;break m}f=0;e=~~q>>>0;if(!(!(q<4294967296&q>=0)|q<=0)){break m}e=0}w[a+480224>>2]=g;w[a+480204>>2]=e}e=y[a+480188>>1];w[114256]=0;u[d+272|0]=0;r=S(500,d+1312|0,e|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){g=a+1304412|0;j=a+484344|0;i=a+1304424|0;f=f&1;n=0;x:{y:{z:{A:{B:{C:{D:{while(1){e=w[d+1328>>2];h=w[w[e>>2]+36>>2];w[114256]=0;e=S(h|0,e|0,w[d+1336>>2],8)|0;h=w[114256];w[114256]=0;E:{if((h|0)!=1){if(e){break E}f=y[a+480188>>1];if(f){h=w[r>>2];g=0;while(1){e=u[g+h|0];F:{if((e|0)<=(g|0)|(e|0)>=(f|0)){break F}i=x[((e<<5)+a|0)+480288|0];if(!i){break F}e=((g<<5)+a|0)+480288|0;k=x[e|0];if(!k){u[e|0]=i;break F}e=k-1|0;while(1){k=(C(e&255,160)+a|0)+906328|0;e=w[k>>2];if(e>>>0>=128){e=e^-128;if((e&255)!=255){continue}}break}e=i-1&255;w[k>>2]=e>>>0<250?e+128|0:0}g=g+1|0;if((f|0)!=(g|0)){continue}break}}w[d+264>>2]=0;w[d+268>>2]=0;w[d+256>>2]=0;w[d+260>>2]=0;w[d+248>>2]=0;w[d+252>>2]=0;w[d+240>>2]=0;w[d+244>>2]=0;G:{H:{I:{J:{if(!o){w[114256]=0;e=Q(501,d+1344|0,d+272|0)|0;f=w[114256];w[114256]=0;K:{if((f|0)!=1){if(!e){Cb(d+272|0,0,274)}f=0;while(1){e=y[a+480192>>1];w[114256]=0;e=Q(502,a|0,e+1&65535)|0;g=w[114256];w[114256]=0;L:{M:{N:{O:{P:{Q:{R:{if((g|0)!=1){g=f<<1;i=g+(d+256|0)|0;v[i>>1]=e;l=g+(d+240|0)|0;g=y[(d+g|0)+274>>1];v[l>>1]=g;if((e|0)==65535){break M}w[114256]=0;g=S(243,a|0,e|0,g+1&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break R}if(!g){break L}w[114256]=0;e=Q(5,d+1760|0,11401)|0;i=w[114256];w[114256]=0;if((i|0)==1){break Q}w[d+168>>2]=w[e+8>>2];i=w[e+4>>2];e=w[e>>2];w[114256]=0;w[d+160>>2]=e;w[d+164>>2]=i;w[d+72>>2]=f+1;U(503,d+88|0,d+160|0,d+72|0);e=w[114256];w[114256]=0;if((e|0)==1){break P}w[114256]=0;w[d+44>>2]=32;w[d+40>>2]=g+492;Q(200,d+40|0,d+88|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break O}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[d+171|0]>=0){break L}zb(w[d+160>>2]);break L}f=P()|0;break x}f=P()|0;break x}f=P()|0;break x}f=P()|0;break N}f=P()|0;if(u[d+99|0]>=0){break N}zb(w[d+88>>2])}if(u[d+171|0]>=0){break x}zb(w[d+160>>2]);break x}v[i>>1]=0}f=f+1|0;if((f|0)!=8){continue}break}break K}f=P()|0;break x}w[114256]=0;k=Q(213,d+224|0,y[d+272>>1])|0;e=w[114256];w[114256]=0;if((e|0)==1){break G}if(y[d+272>>1]){e=0;while(1){w[114256]=0;f=Q(197,b|0,d+88|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break I}w[114256]=0;U(188,d+88|0,b|0,(f?y[d+88>>1]<<5:0)|0);f=w[114256];w[114256]=0;if((f|0)==1){break J}f=w[k>>2]+(e<<4)|0;he(f,d+88|0);g=w[d+100>>2];w[f+8>>2]=w[d+96>>2];w[f+12>>2]=g;f=w[d+92>>2];S:{if(!f){break S}g=w[f+4>>2];w[f+4>>2]=g-1;if(g){break S}ob[w[w[f>>2]+8>>2]](f);Ib(f)}e=e+1|0;if(e>>>0<y[d+272>>1]){continue}break}}w[114256]=0;i=S(504,d+208|0,y[d+1742>>1],23800)|0;e=w[114256];w[114256]=0;T:{if((e|0)!=1){if(!y[d+1738>>1]){break T}h=0;while(1){U:{g=d+h|0;f=x[g+290|0];V:{if(f>>>0>=y[d+272>>1]){break V}m=h<<1;e=y[m+w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]>>1];if(e>>>0>=y[d+1742>>1]){break V}l=w[i>>2]+(e<<1)|0;o=y[l>>1];W:{if((o|0)==65535){v[l>>1]=f;break W}if((f|0)==(o|0)){break W}w[114256]=0;f=S(505,j|0,e|0,0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break U}if((f|0)==65535){break W}v[m+w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]>>1]=f;e=f}f=w[a+484344>>2];if(((w[a+484348>>2]-f|0)/52&65535)>>>0<=e>>>0){break V}m=C(e,52);e=m+f|0;if(w[e>>2]==w[e+4>>2]){break V}l=w[k>>2]+(x[g+290|0]<<4)|0;w[l+8>>2]=0;e=w[l>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break U}f=w[j>>2];if(!w[(m+f|0)+12>>2]){break V}t=e>>>5|0;g=0;while(1){e=y[a+480188>>1];w[114256]=0;f=f+m|0;o=V(218,f|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break U}e=w[f>>2]+C(C(g,o)+(e-8&65535)|0,6)|0;f=0;while(1){u[e|0]=0;u[e+1|0]=0;u[e+2|0]=0;u[e+3|0]=0;u[e+4|0]=0;u[e+5|0]=0;X:{if(g>>>0>=t>>>0){break X}w[114256]=0;Q(506,l|0,d+88|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break U}if(u[d+88|0]>=0){break X}u[e|0]=61;u[e+1|0]=x[(d+256|0)+(f<<1)|0];o=x[d+88|0]&31;if(o){u[e+3|0]=20;u[e+5|0]=(o>>>0>=15?15:o)|208}u[e+2|0]=1;u[e+4|0]=x[d+89|0]+3>>>2}e=e+6|0;f=f+1|0;if((f|0)!=8){continue}break}g=g+1|0;f=w[j>>2];if(g>>>0<z[(m+f|0)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<y[d+1738>>1]){continue}break T}break}f=P()|0;a=w[i>>2];if(!a){break H}w[i+4>>2]=a;zb(a);break H}f=P()|0;break H}e=w[i>>2];if(e){w[i+4>>2]=e;zb(e)}gc(k)}f=y[d+1750>>1]|y[d+1752>>1]<<16;Y:{if(!(f&2)){break Y}e=y[d+1742>>1];if(!e){break Y}g=((f>>>4&1)+((f&8?y[a+480188>>1]:s)&65535)|0)+(y[d+1640>>1]>591?n:0)|0;k=0;while(1){m=0;if(g){Z:{_:{while(1){$:{e=w[b+8>>2];f=w[b>>2];i=w[w[f>>2]+36>>2];w[114256]=0;e=S(i|0,f|0,e|0,4)|0;f=w[114256];w[114256]=0;if((f|0)==1){break $}if(!e){break Z}aa:{ba:{if(y[d+1640>>1]>=515){w[114256]=0;f=Q(232,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $}w[114256]=0;e=w[d+272>>2];Q(232,b|0,d+272|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break $}if(f){break ba}break aa}w[114256]=0;f=Q(197,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $}w[114256]=0;e=y[d+272>>1];Q(197,b|0,d+272|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break $}if(!f){break aa}}if(!e){break aa}while(1){if(e&1){f=w[b+8>>2];i=w[b>>2];h=w[w[i>>2]+36>>2];w[114256]=0;f=S(h|0,i|0,f|0,260)|0;i=w[114256];w[114256]=0;if((i|0)==1){break _}ca:{if(f){f=w[b+8>>2]+260|0;break ca}f=w[b>>2];i=w[w[f>>2]+24>>2];w[114256]=0;f=V(i|0,f|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break _}}w[b+8>>2]=f}f=e>>>0>1;e=e>>>1|0;if(f){continue}break}}m=m+1|0;if((g|0)!=(m|0)){continue}break Z}break}f=P()|0;break x}f=P()|0;break x}e=y[d+1742>>1]}k=k+1|0;if(k>>>0<(e&65535)>>>0){continue}break}}w[114256]=0;e=V(22,4080)|0;f=w[114256];w[114256]=0;da:{if((f|0)==1){break da}w[114256]=0;w[d+192>>2]=e;w[d+196>>2]=e;w[d+200>>2]=e+4080;T(507,d+192|0,255);e=w[114256];w[114256]=0;if((e|0)==1){break da}k=0;ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{while(1){w[114256]=0;Q(508,b|0,d+160|0)|0;e=w[114256];w[114256]=0;pa:{qa:{ra:{sa:{if((e|0)!=1){w[114256]=0;e=Q(232,b|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break sa}w[114256]=0;e=e?w[d+272>>2]:0;e=(e|0)==32?428:e;g=y[d+1640>>1]>513?e?e+4|0:e:e;U(188,d+272|0,b|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break ra}e=w[d+192>>2]+(k<<4)|0;he(e,d+272|0);f=w[d+284>>2];w[e+8>>2]=w[d+280>>2];w[e+12>>2]=f;w[d+40>>2]=w[e>>2];f=w[e+4>>2];w[d+44>>2]=f;if(f){w[f+4>>2]=w[f+4>>2]+1}f=w[e+12>>2];w[d+48>>2]=w[e+8>>2];w[d+52>>2]=f;e=w[d+276>>2];ta:{if(!e){break ta}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break ta}ob[w[w[e>>2]+8>>2]](e);Ib(e)}if(y[d+1754>>1]<=k>>>0){break pa}w[114256]=0;e=k+1&65535;j=S(243,a|0,e|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break qa}f=P()|0;break fa}f=P()|0;break ea}f=P()|0;break ea}f=P()|0;break ea}if(!j){break pa}w[114256]=0;Y(209,d+272|0,2,d+160|0,32);e=w[114256];w[114256]=0;ua:{va:{wa:{if((e|0)!=1){w[114256]=0;w[d+92>>2]=32;w[d+88>>2]=j+492;Q(200,d+88|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break wa}if(u[d+283|0]<0){zb(w[d+272>>2])}if(!g){break pa}w[114256]=0;e=Q(509,d+40|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ja}if(!e){Cb(d+272|0,0,106)}m=3;n=0;if(y[d+1640>>1]>=513){break va}s=0;break ua}f=P()|0;break fa}f=P()|0;if(u[d+283|0]>=0){break fa}zb(w[d+272>>2]);break fa}w[114256]=0;e=Q(197,d+40|0,d+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ga}s=e?y[d+88>>1]:0;if(y[d+1640>>1]<514){break ua}w[114256]=0;e=Q(232,d+40|0,d+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break oa}m=e?w[d+88>>2]:0}w[j>>2]=y[d+374>>1];u[j+16|0]=x[(y[d+376>>1]&3)+23802|0];u[j+17|0]=x[(x[d+377|0]&3)+23802|0];u[j+18|0]=x[(y[d+376>>1]>>>12&3)+23806|0];g=j+48|0;i=j+88|0;h=j+68|0;while(1){xa:{if(!(m&1)){break xa}w[114256]=0;e=Q(510,d+40|0,d+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ha}if(!e){Cb(d+88|0,0,72)}e=g;ya:{za:{switch(x[n+23810|0]-1|0){case 0:e=h;break ya;case 1:break za;default:break ya}}e=i}Aa:{if((n|0)!=3){f=x[d+88|0];l=x[e+12|0]&-17;break Aa}f=x[d+88|0];l=f<<4&16|x[e+12|0]&-17}u[e+12|0]=f>>>1&2|(f<<1&4|(f&1|l&248));w[114256]=0;f=x[d+89|0];T(287,e|0,(f>>>0>=16?16:f)|0);f=w[114256];w[114256]=0;if((f|0)==1){break ia}f=x[d+90|0];u[e+15|0]=f;u[e+16|0]=f;u[e+13|0]=x[d+91|0];u[e+14|0]=x[d+92|0];f=w[e+4>>2];l=w[e>>2];if((f|0)==(l|0)){break xa}e=f-l>>2;o=e>>>0<=1?1:e;e=0;while(1){f=e<<2;t=f+l|0;f=f+(d+88|0)|0;v[t>>1]=x[f+8|0]|x[f+9|0]<<8;f=x[f+10|0]|x[f+11|0]<<8;u[t+2|0]=f>>>0>=64?64:f;e=e+1|0;if((o|0)!=(e|0)){continue}break}}m=m>>>1|0;n=n+1|0;if((n|0)!=4){continue}break}if(!(u[j+60|0]&1|x[j+16|0]==3)){w[j>>2]=32767}u[j+21|0]=255;u[j+22|0]=128;f=s&65535;if(!f){break pa}w[114256]=0;e=Q(511,d+40|0,d+88|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break na}if(!e){w[d+112>>2]=0;w[d+116>>2]=0;w[d+104>>2]=0;w[d+108>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;w[d+88>>2]=0;w[d+92>>2]=0}if(s&2){w[114256]=0;e=Ba(512,a|0,+y[d+90>>1])|0;g=w[114256];w[114256]=0;if((g|0)==1){break na}u[j+21|0]=(e>>>0>=127?127:e)|128;e=x[d+92|0];u[j+22|0]=(e>>>0>=127?127:e)|128}u[j+25|0]=x[d+89|0]==1;if(!(f&4)){break pa}u[j+31|0]=x[d+95|0]+1;e=u[d+96|0];u[j+34|0]=e+1;if((e|0)<0){u[j+30|0]=x[d+103|0]+1}if(x[d+100|0]){h=j+108|0;f=0;while(1){g=1;i=f+1|0;e=i+u[d+100|0]|0;Ba:{if((e|0)>0){g=120;if(e>>>0<121){break Ba}}e=g}u[f+h|0]=e;f=i;if((f|0)!=128){continue}break}}Cb(j+236|0,0,256)}e=w[d+44>>2];Ca:{if(!e){break Ca}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break Ca}ob[w[w[e>>2]+8>>2]](e);Ib(e)}k=k+1|0;if((k|0)!=255){continue}break}w[d+112>>2]=0;w[d+116>>2]=0;w[d+104>>2]=0;w[d+108>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;w[d+88>>2]=0;w[d+92>>2]=0;w[d+184>>2]=0;w[d+188>>2]=0;w[d+176>>2]=0;w[d+180>>2]=0;w[d+168>>2]=0;w[d+172>>2]=0;w[d+160>>2]=0;w[d+164>>2]=0;f=0;Da:{while(1){w[114256]=0;Q(508,b|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Da}w[114256]=0;e=Q(232,b|0,d+40|0)|0;g=w[114256];w[114256]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((g|0)!=1){w[114256]=0;e=e?w[d+40>>2]:0;U(188,d+72|0,b|0,e|0);g=w[114256];w[114256]=0;if((g|0)==1){break Ka}g=!e;e=y[d+1756>>1];if(e>>>0>f>>>0){w[114256]=0;Y(209,d+40|0,2,d+272|0,32);e=w[114256];w[114256]=0;if((e|0)==1){break Ja}w[114256]=0;w[d+12>>2]=32;w[d+8>>2]=((f<<5)+a|0)+946336;Q(200,d+8|0,d+40|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ia}if(u[d+51|0]<0){zb(w[d+40>>2])}e=y[d+1756>>1]}if(e>>>0<=f>>>0|g){break Fa}w[114256]=0;e=C(f+1|0,104)+a|0;i=e+484380|0;T(266,i|0,32);g=w[114256];w[114256]=0;if((g|0)==1){break Ea}w[114256]=0;g=Q(513,d+72|0,d+40|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break ma}if(g){break Ha}g=0;v[d- -64>>1]=0;w[d+56>>2]=0;w[d+60>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0;w[d+40>>2]=0;w[d+44>>2]=0;w[i>>2]=0;w[e+484404>>2]=0;break Ga}f=P()|0;break ea}f=P()|0;break ea}f=P()|0;break la}f=P()|0;if(u[d+51|0]>=0){break la}zb(w[d+40>>2]);break la}h=x[d+48|0];j=w[d+44>>2];g=w[d+40>>2];w[i>>2]=g;w[e+484404>>2]=j;if(h>>>0<2){break Ga}h=e+484414|0;v[h>>1]=y[h>>1]|1;g=g>>>1|0;w[i>>2]=g}if(x[d+49|0]>=2){h=e+484414|0;v[h>>1]=y[h>>1]|64;w[i>>2]=g>>>1}g=2;La:{switch(x[d+51|0]-1|0){case 1:g=6;case 0:i=e+484414|0;v[i>>1]=y[i>>1]|g;break;default:break La}}w[e+484384>>2]=w[d+52>>2];w[e+484388>>2]=w[d+56>>2];v[e+484410>>1]=y[d+60>>1]>>>7;g=x[d+62|0];Ma:{if((g|0)==128){i=e+484414|0;g=y[i>>1]|256;v[i>>1]=g;break Ma}v[e+484408>>1]=(g<<24>>24)+128;g=y[e+484414>>1]}i=e+484414|0;v[i>>1]=g|32;u[e+484416|0]=x[d+63|0];e=x[d+50|0];if(e&2){h=(d+160|0)+(f>>>3&536870908)|0;w[h>>2]=w[h>>2]|1<<f}if(e&5){v[i>>1]=g|16416}if(!(e&8)){break Fa}e=(d+88|0)+(f>>>3&536870908)|0;w[e>>2]=w[e>>2]|1<<f;e=0;while(1){g=e<<1;Na:{if(y[g+(d+240|0)>>1]!=(f|0)){break Na}g=w[((y[g+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!g){break Na}u[g+14|0]=0}e=e+1|0;if((e|0)!=8){continue}break}}e=w[d+76>>2];Oa:{if(!e){break Oa}g=w[e+4>>2];w[e+4>>2]=g-1;if(g){break Oa}ob[w[w[e>>2]+8>>2]](e);Ib(e)}f=f+1|0;if((f|0)==256){break ka}continue}break}f=P()|0;break la}f=P()|0;break ea}f=P()|0;break fa}f=P()|0;break fa}f=P()|0}Bb(d+72|0);break ea}if(y[d+1754>>1]){j=0;while(1){e=j<<4;f=w[e+w[d+192>>2]>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;Pa:{Qa:{Ra:{if((g|0)!=1){if(!f){j=j+1|0;break Pa}e=e+w[d+192>>2]|0;w[e+8>>2]=0;w[114256]=0;e=Q(509,e|0,d+272|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ra}if(e){e=y[d+272>>1]}else{Cb(d+272|0,0,106);e=0}w[114256]=0;w[d+48>>2]=0;w[d+40>>2]=0;w[d+44>>2]=0;S(514,b|0,d+40|0,e&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Qa}j=j+1|0;f=w[((j<<2)+a|0)+900380>>2];if(!(!f|x[f+34|0])){w[f+4>>2]=32;e=0;k=Cb(f+236|0,0,256);n=f+108|0;while(1){g=x[(d+e|0)+274|0];Sa:{if(g>>>0>=y[d+272>>1]){break Sa}m=e+12|0;i=w[d+40>>2]+(g<<3)|0;g=x[i|0];h=g+1|0;v[k+(m<<1)>>1]=h;if(g>>>0>=y[a+480190>>1]){break Sa}g=C(h,104)+a|0;u[g+484418|0]=x[d+370|0]&3;u[g+484419|0]=x[d+371|0];u[g+484420|0]=x[d+372|0];u[g+484421|0]=x[d+373|0];v[g+484412>>1]=x[i+1|0]<<1;u[g+484417|0]=x[i+2|0];g=h-1|0;i=g>>>5<<2;g=1<<g;if(w[i+(d+88|0)>>2]&g){u[f+14|0]=0}if(!(g&w[i+(d+160|0)>>2])){break Sa}u[m+n|0]=61}e=e+1|0;if((e|0)!=96){continue}break}}e=w[d+40>>2];if(!e){break Pa}w[d+44>>2]=e;zb(e);break Pa}f=P()|0;break ea}f=P()|0;break ea}f=P()|0;a=w[d+40>>2];if(!a){break ea}w[d+44>>2]=a;zb(a);break ea}if(y[d+1754>>1]>j>>>0){continue}break}}Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{if(!(!(c&2)|!y[a+480190>>1])){e=d+72|4;i=d+24|4;f=0;while(1){f=f+1|0;c=C(f,104)+a|0;g=c+484416|0;h=u[g|0];j=c+484417|0;k=u[j|0];w[114256]=0;n=c+484380|0;sa(515,n|0,+((+(k|0)*.0078125-+(h-49|0))*.08333333333333333));h=w[114256];w[114256]=0;if((h|0)==1){break Ta}u[j|0]=0;u[g|0]=0;g=y[c+484414>>1];bb:{if(!(g&16384)){w[114256]=0;v[d+274>>1]=3072;u[d+273|0]=g&64?3:1;u[d+272|0]=g&1?16:8;S(214,d+272|0,n|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break bb}f=P()|0;break ea}w[114256]=0;h=Q(232,b|0,d+272|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ab}j=w[d+272>>2];g=w[b+8>>2];k=w[b>>2];n=w[w[k>>2]+36>>2];w[114256]=0;g=S(n|0,k|0,g|0,12)|0;k=w[114256];w[114256]=0;if((k|0)==1){break ab}cb:{if(g){g=w[b+8>>2]+12|0;break cb}g=w[b>>2];k=w[w[g>>2]+24>>2];w[114256]=0;g=V(k|0,g|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break ab}}w[b+8>>2]=g;w[114256]=0;w[d+280>>2]=0;w[d+272>>2]=0;w[d+276>>2]=0;S(258,b|0,d+272|0,(h?j:0)|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break $a}w[114256]=0;w[d+44>>2]=22;w[d+40>>2]=c+484423;Q(200,d+40|0,d+272|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break $a}w[114256]=0;c=Q(1,d+24|0,12201)|0;g=w[114256];w[114256]=0;if((g|0)==1){break _a}h=w[c>>2];w[e>>2]=w[i>>2];g=x[i+3|0]|x[i+4|0]<<8|(x[i+5|0]<<16|x[i+6|0]<<24);u[e+3|0]=g;u[e+4|0]=g>>>8;u[e+5|0]=g>>>16;u[e+6|0]=g>>>24;g=x[d+35|0];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;u[d+83|0]=g;w[d+72>>2]=h;w[d+20>>2]=f;g=w[a+1304496>>2];w[114256]=0;U(6,d+8|0,g|0,d+272|0);g=w[114256];w[114256]=0;if((g|0)==1){break Za}w[114256]=0;Y(366,d+40|0,d+72|0,d+20|0,d+8|0);g=w[114256];w[114256]=0;if((g|0)==1){break Ya}w[114256]=0;U(367,a|0,2,d+40|0);g=w[114256];w[114256]=0;if((g|0)==1){break Xa}if(u[d+51|0]<0){zb(w[d+40>>2])}if(u[d+19|0]<0){zb(w[d+8>>2])}if(u[d+83|0]<0){zb(w[d+72>>2])}if(u[d+35|0]<0){zb(w[c>>2])}if(u[d+283|0]>=0){break bb}zb(w[d+272>>2])}if(y[a+480190>>1]>f>>>0){continue}break}}gc(d+192|0);a=w[r>>2];if(a){w[r+4>>2]=a;zb(a)}a=w[d+1332>>2];db:{if(!a){break db}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break db}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[d+1348>>2];if(!a){break c}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break c}ob[w[w[a>>2]+8>>2]](a);Ib(a);break c}f=P()|0;break ea}f=P()|0;break Ua}f=P()|0;break Ua}f=P()|0;break Va}f=P()|0;break Wa}f=P()|0;if(u[d+51|0]>=0){break Wa}zb(w[d+40>>2])}if(u[d+19|0]>=0){break Va}zb(w[d+8>>2])}if(u[d+83|0]<0){zb(w[d+72>>2])}if(u[d+35|0]>=0){break Ua}zb(w[c>>2])}if(u[d+283|0]>=0){break ea}zb(w[d+272>>2]);break ea}f=P()|0;break ea}f=P()|0;break fa}f=P()|0;break fa}f=P()|0;break fa}f=P()|0}Bb(d+40|0)}gc(d+192|0);break x}f=P()|0;break x}f=P()|0;break H}f=P()|0}gc(k);break x}f=P()|0;break x}f=P()|0;break x}w[114256]=0;e=Q(232,d+1328|0,d+272|0)|0;h=w[114256];w[114256]=0;eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{if((h|0)!=1){w[114256]=0;h=w[d+272>>2];k=Q(232,d+1328|0,d+272|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break rb}w[114256]=0;U(188,d+88|0,d+1328|0,(k?w[d+272>>2]:0)|0);k=w[114256];w[114256]=0;if((k|0)==1){break rb}e=e?h:0;if((e|0)<=844387157){if((e|0)==4674381){break ib}if((e|0)==5068115){break hb}if(f|(e|0)!=726487106){break fb}w[a+480224>>2]=2;w[114256]=0;e=Q(516,d+88|0,d+272|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break eb}q=e?B[d+272>>3]:0;if(q<=1e-8){break fb}q=Tb(2646e7/(q*+(C(w[a+480216>>2],w[a+480196>>2])>>>0)));e=-1;if(q>=4294967295){break pb}e=0;if(q<=0){break pb}if(!(q<4294967296&q>=0)){break qb}e=~~q>>>0;break pb}if((e|0)<=1314144591){if((e|0)==844387158){break gb}if((e|0)!=1280004692){break fb}e=0;if(!y[a+480188>>1]){break fb}while(1){h=w[d+88>>2];k=w[w[h>>2]+36>>2];w[114256]=0;h=S(k|0,h|0,w[d+96>>2],1)|0;k=w[114256];w[114256]=0;if((k|0)==1){break C}if(!h){break fb}w[114256]=0;w[d+280>>2]=0;w[d+272>>2]=0;w[d+276>>2]=0;S(330,d+88|0,d+272|0,-1)|0;h=w[114256];w[114256]=0;if((h|0)==1){break nb}w[114256]=0;h=u[d+283|0];k=(h|0)<0;Y(209,d+160|0,3,(k?w[d+272>>2]:d+272|0)|0,(k?w[d+276>>2]:h&255)|0);h=w[114256];w[114256]=0;if((h|0)==1){break mb}w[114256]=0;w[d+44>>2]=20;w[d+40>>2]=((e<<5)+a|0)+480289;Q(200,d+40|0,d+160|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break lb}if(u[d+171|0]<0){zb(w[d+160>>2])}if(u[d+283|0]<0){zb(w[d+272>>2])}e=e+1|0;if(e>>>0<y[a+480188>>1]){continue}break}break fb}if((e|0)==1397445204){break ob}if((e|0)!=1314144592){break fb}e=0;if(!y[d+1742>>1]){break fb}while(1){h=w[d+88>>2];k=w[w[h>>2]+36>>2];w[114256]=0;h=S(k|0,h|0,w[d+96>>2],1)|0;k=w[114256];w[114256]=0;if((k|0)==1){break B}if(!h|((w[a+484348>>2]-w[a+484344>>2]|0)/52&65535)>>>0<=e>>>0){break fb}w[114256]=0;w[d+280>>2]=0;w[d+272>>2]=0;w[d+276>>2]=0;S(330,d+88|0,d+272|0,-1)|0;h=w[114256];w[114256]=0;if((h|0)==1){break jb}h=w[j>>2];w[114256]=0;Q(270,h+C(e,52)|0,d+272|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break jb}if(u[d+283|0]<0){zb(w[d+272>>2])}e=e+1|0;if(e>>>0<y[d+1742>>1]){continue}break}break fb}f=P()|0;break x}f=P()|0;break x}e=0}w[a+480204>>2]=e;break fb}w[114256]=0;h=Q(197,d+88|0,d+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break z}e=0;h=(h?y[d+272>>1]:0)&65535;h=h>>>0<256?48:h>>>8|0;w[a+480228>>2]=h;w[a+480232>>2]=h>>>1;if(!y[a+480188>>1]){break fb}while(1){w[114256]=0;h=Q(517,d+88|0,d+272|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break D}if(h){v[((e<<5)+a|0)+480286>>1]=y[d+272>>1]>>>10;u[w[r>>2]+e|0]=x[d+275|0]}e=e+1|0;if(e>>>0<y[a+480188>>1]){continue}break}break fb}f=P()|0;break kb}f=P()|0;break kb}f=P()|0;if(u[d+171|0]>=0){break kb}zb(w[d+160>>2])}if(u[d+283|0]>=0){break y}zb(w[d+272>>2]);break y}f=P()|0;if(u[d+283|0]>=0){break y}zb(w[d+272>>2]);break y}e=w[d+88>>2];h=w[w[e>>2]+36>>2];w[114256]=0;e=S(h|0,e|0,w[d+96>>2],1)|0;h=w[114256];w[114256]=0;if((h|0)==1){break z}sb:{if(e){e=w[d+96>>2]+1|0;break sb}e=w[d+88>>2];h=w[w[e>>2]+24>>2];w[114256]=0;e=V(h|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break z}}w[d+96>>2]=e;e=w[d+88>>2];h=w[w[e>>2]+24>>2];w[114256]=0;e=V(h|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break z}w[114256]=0;Z(320,i|0,d+88|0,e-w[d+96>>2]|0,2)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break fb}break z}w[114256]=0;Q(518,d+88|0,d+40|0)|0;e=w[114256];w[114256]=0;tb:{if((e|0)!=1){w[114256]=0;w[d+280>>2]=0;w[d+272>>2]=0;w[d+276>>2]=0;S(330,d+88|0,d+272|0,-1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break tb}e=x[d+283|0];ub:{if(((e<<24>>24<0?w[d+276>>2]:e)|0)==12){w[114256]=0;e=da(186,d+272|0,0,-1,8373,12)|0;h=w[114256];w[114256]=0;if((h|0)==1){break A}if(!e){break ub}}w[114256]=0;U(6,d+160|0,7,d+272|0);e=w[114256];w[114256]=0;if((e|0)==1){break tb}if(u[a+1304423|0]<0){zb(w[g>>2])}e=w[d+164>>2];w[g>>2]=w[d+160>>2];w[g+4>>2]=e;w[g+8>>2]=w[d+168>>2]}if(u[d+283|0]>=0){break fb}zb(w[d+272>>2]);break fb}f=P()|0;break y}f=P()|0;if(u[d+283|0]>=0){break y}zb(w[d+272>>2]);break y}w[114256]=0;e=Q(232,d+88|0,d+272|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break z}n=e?w[d+272>>2]:0}e=w[d+92>>2];if(!e){continue}h=w[e+4>>2];w[e+4>>2]=h-1;if(h){continue}ob[w[w[e>>2]+8>>2]](e);Ib(e);continue}break}f=P()|0;break y}f=P()|0;break y}f=P()|0;break y}f=P()|0;break y}W(0)|0;Eb();M()}f=P()|0}Bb(d+88|0)}a=w[r>>2];if(!a){break f}w[r+4>>2]=a;zb(a);break f}f=P()|0}Bb(d+1328|0)}Bb(d+1344|0)}R(f|0);M()}e=1}jb=d+1776|0;return e|0}function jE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,W=0,Y=0,_=0;d=jb-272|0;jb=d;w[b+8>>2]=0;if(!(!cl(b,d+128|0)|w[d+128>>2]!=1179468868|(x[d+132|0]-1&255)>>>0>9)){a:{if(!c){break a}tc(a,131072);e=Hb(d+112|0,11195);h=w[e>>2];w[d+44>>2]=w[e+4>>2];f=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+47|0]=f;u[d+48|0]=f>>>8;u[d+49|0]=f>>>16;u[d+50|0]=f>>>24;w[e>>2]=0;w[e+4>>2]=0;f=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+51|0]=f;w[d+40>>2]=h;U(295,d+200|0,d+40|0,d+128|4);f=w[114256];w[114256]=0;b:{if((f|0)!=1){f=a+1304436|0;if(u[a+1304447|0]<0){zb(w[f>>2])}h=w[d+204>>2];w[f>>2]=w[d+200>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+208>>2];u[d+211|0]=0;u[d+200|0]=0;if(u[d+51|0]<0){zb(w[d+40>>2])}if(u[e+11|0]<0){zb(w[e>>2])}e=a+1304448|0;f=Hb(d+200|0,6978);if(u[a+1304459|0]<0){zb(w[e>>2])}h=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=h;w[e+8>>2]=w[f+8>>2];w[a+1304496>>2]=4;Vb(d+200|0,3,d+141|0,30);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+204>>2];w[e>>2]=w[d+200>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+208>>2];e=d+40|0;Vb(e,3,d+171|0,20);w[114256]=0;U(6,d+200|0,4,e|0);e=w[114256];w[114256]=0;if((e|0)!=1){e=a+1304412|0;if(u[a+1304423|0]<0){zb(w[e>>2])}f=w[d+204>>2];w[e>>2]=w[d+200>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+208>>2];u[d+211|0]=0;u[d+200|0]=0;if(u[d+51|0]<0){zb(w[d+40>>2])}g=x[d+193|0];f=x[d+192|0];h=x[d+191|0];e=w[a+1304500>>2];w[a+1304504>>2]=e;h=h?h>>>0>=31?31:h:1;f=(f?f>>>0>=12?12:f:1)-1|0;k=a+1304508|0;c:{if((e|0)!=w[k>>2]){w[e>>2]=0;w[e+4>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;w[e+20>>2]=g;w[e+16>>2]=f;w[e+12>>2]=h;w[e+8>>2]=0;w[e+32>>2]=0;w[e+36>>2]=0;w[e+40>>2]=0;w[e+44>>2]=0;w[a+1304504>>2]=e+48;break c}k=bl(d+200|0,1,0,k);e=w[k+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;w[e+20>>2]=g;w[e+16>>2]=f;w[e+12>>2]=h;w[e+8>>2]=0;w[e+32>>2]=0;w[e+36>>2]=0;w[e+40>>2]=0;w[e+44>>2]=0;f=e+48|0;w[k+8>>2]=f;i=w[a+1304504>>2];g=w[a+1304500>>2];e=i-g|0;h=w[k+4>>2]+C((e|0)/-48|0,48)|0;w[k+4>>2]=h;if((e|0)>0){Fb(h,g,e);i=w[a+1304504>>2];g=w[a+1304500>>2];h=w[k+4>>2];f=w[k+8>>2]}w[a+1304500>>2]=h;w[k+4>>2]=g;w[a+1304504>>2]=f;w[k+8>>2]=i;e=w[a+1304508>>2];w[a+1304508>>2]=w[k+12>>2];w[k>>2]=g;w[k+12>>2]=e;al(k)}w[d+104>>2]=0;w[d+96>>2]=0;w[d+100>>2]=0;m=d+104|0;g=w[b+8>>2];d:{e:{f:{g:{while(1){e=w[b>>2];f=w[w[e>>2]+36>>2];w[114256]=0;e=S(f|0,e|0,g|0,8)|0;f=w[114256];w[114256]=0;h:{i:{j:{k:{l:{if((f|0)!=1){if(!e){break f}w[114256]=0;Q(296,b|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}e=w[d+228>>2];m:{f=x[d+132|0];switch(f-3|0){case 1:break k;case 0:break m;default:break j}}i=2;g=w[d+224>>2];if((g|0)!=1431389523){break i}break h}g=P()|0;break d}g=P()|0;break d}i=4;g=w[d+224>>2];if((g|0)!=1431389523){break i}break h}i=0;if(f>>>0>7){break h}g=w[d+224>>2]}e=(g|0)==1146113363?-1:e;i=0}w[114256]=0;U(188,d+40|0,b|0,e|0);e=w[114256];w[114256]=0;if((e|0)!=1){e=w[d+100>>2];f=w[d+104>>2];n:{if(e>>>0<f>>>0){f=w[d+228>>2];w[e>>2]=w[d+224>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+40>>2];w[e+12>>2]=w[d+44>>2];f=w[d+52>>2];w[e+16>>2]=w[d+48>>2];w[e+20>>2]=f;w[d+100>>2]=e+24;break n}h=w[d+96>>2];k=(e-h|0)/24|0;e=k+1|0;if(e>>>0>=178956971){w[114256]=0;X(297,d+96|0);a=w[114256];w[114256]=0;if((a|0)==1){break g}M()}w[114256]=0;f=(f-h|0)/24|0;h=f<<1;k=Z(298,d+200|0,(f>>>0>=89478485?178956970:e>>>0<h>>>0?h:e)|0,k|0,m|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}f=w[d+228>>2];e=w[d+208>>2];w[e>>2]=w[d+224>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+40>>2];w[e+12>>2]=w[d+44>>2];w[d+40>>2]=0;w[d+44>>2]=0;f=w[d+52>>2];w[e+16>>2]=w[d+48>>2];w[e+20>>2]=f;h=w[d+208>>2]+24|0;w[d+208>>2]=h;g=w[d+204>>2];e=w[d+100>>2];f=w[d+96>>2];o:{if((e|0)==(f|0)){e=f;break o}while(1){h=g-24|0;e=e-24|0;g=w[e+4>>2];w[h>>2]=w[e>>2];w[h+4>>2]=g;w[h+8>>2]=w[e+8>>2];w[h+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[h+16>>2]=w[e+16>>2];w[h+20>>2]=g;g=w[d+204>>2]-24|0;w[d+204>>2]=g;if((e|0)!=(f|0)){continue}break}h=w[d+208>>2];f=w[d+100>>2];e=w[d+96>>2]}w[d+204>>2]=e;w[d+96>>2]=g;w[d+100>>2]=h;w[d+208>>2]=f;f=w[d+104>>2];w[d+104>>2]=w[d+212>>2];w[d+212>>2]=f;w[k>>2]=e;pd(k);e=w[d+44>>2];if(!e){break n}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break n}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[b+8>>2];f=w[b>>2];h=w[w[f>>2]+36>>2];w[114256]=0;e=S(h|0,f|0,e|0,i|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}p:{if(e){g=w[b+8>>2]+i|0;break p}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;g=V(f|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}}w[b+8>>2]=g;continue}break}g=P()|0;break d}g=P()|0;Bb(d+40|0);break d}w[114256]=0;b=V(22,16)|0;e=w[114256];w[114256]=0;q:{r:{s:{t:{u:{if((e|0)!=1){w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=75696;w[b>>2]=75656;w[114256]=0;w[d+88>>2]=0;w[d+92>>2]=0;w[d+84>>2]=b;w[d+80>>2]=b+12;U(299,d+40|0,d+96|0,1431389523);b=w[114256];w[114256]=0;if((b|0)==1){break u}e=w[d+40>>2];f=w[d+44>>2];w[d+40>>2]=0;w[d+44>>2]=0;b=w[d+84>>2];w[d+80>>2]=e;w[d+84>>2]=f;v:{if(!b){b=w[d+52>>2];w[d+88>>2]=w[d+48>>2];w[d+92>>2]=b;break v}e=w[b+4>>2];w[b+4>>2]=e-1;if(!e){ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+52>>2];w[d+88>>2]=w[d+48>>2];w[d+92>>2]=b;b=w[d+44>>2];if(!b){break v}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break v}ob[w[w[b>>2]+8>>2]](b);Ib(b)}H=65534;if(x[d+132|0]>=3){break t}break s}g=P()|0;break d}g=P()|0;break q}w[114256]=0;b=Q(197,d+80|0,d+40|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}N=b?y[d+40>>1]:0;if(x[d+132|0]<4){break s}w[114256]=0;b=Q(197,d+80|0,d+40|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}b=b?y[d+40>>1]:0;H=x[d+132|0]==4?b&65535?b:-2:b}b=x[a+484376|0];e=w[a+484360>>2];f=w[d+80>>2];h=w[w[f>>2]+24>>2];w[114256]=0;f=V(h|0,f|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break r}w[114256]=0;da(231,e+(b<<5)|0,d+80|0,f-w[d+88>>2]>>>1|0,65535,65535)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;O=w[b>>2];W=w[b+4>>2];w[114256]=0;U(299,d+40|0,d+96|0,1414807888);b=w[114256];w[114256]=0;w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){e=w[d+40>>2];f=w[d+44>>2];w[d+40>>2]=0;w[d+44>>2]=0;b=w[d+84>>2];w[d+80>>2]=e;w[d+84>>2]=f;N:{if(!b){b=w[d+52>>2];w[d+88>>2]=w[d+48>>2];w[d+92>>2]=b;break N}e=w[b+4>>2];w[b+4>>2]=e-1;if(!e){ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+52>>2];w[d+88>>2]=w[d+48>>2];w[d+92>>2]=b;b=w[d+44>>2];if(!b){break N}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break N}ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+80>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}if(!(c&1)|b^1){break J}w[114256]=0;b=Q(300,d+80|0,d+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break M}if(!b){g=0;u[d+10|0]=0;v[d+8>>1]=0;break L}g=y[d+8>>1];b=x[d+10|0];if(!b){break L}b=(b>>>0>=32?32:b)+1|0;break K}g=P()|0;break q}g=P()|0;break q}b=2}v[a+480188>>1]=b&255;w[114256]=0;A=Q(213,d- -64|0,g&65535)|0;b=w[114256];w[114256]=0;if((b|0)==1){break y}e=w[A>>2];h=w[A+4>>2];if((e|0)!=(h|0)){while(1){b=w[d+80>>2];f=w[w[b>>2]+36>>2];w[114256]=0;k=f;i=b;b=x[d+132|0]<3?9:8;f=b-4|0;k=S(k|0,i|0,w[d+88>>2],f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break x}O:{if(k){f=f+w[d+88>>2]|0;break O}f=w[d+80>>2];k=w[w[f>>2]+24>>2];w[114256]=0;f=V(k|0,f|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break x}}w[114256]=0;w[d+88>>2]=f;f=Q(232,d+80|0,d+40|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break z}w[114256]=0;k=w[d+88>>2];g=k-b|0;w[d+88>>2]=g>>>0<=k>>>0?g:0;U(188,d+40|0,d+80|0,b+(f?w[d+40>>2]:0)|0);b=w[114256];w[114256]=0;if((b|0)==1){break A}he(e,d+40|0);b=w[d+52>>2];w[e+8>>2]=w[d+48>>2];w[e+12>>2]=b;b=w[d+44>>2];P:{if(!b){break P}f=w[b+4>>2];w[b+4>>2]=f-1;if(f){break P}ob[w[w[b>>2]+8>>2]](b);Ib(b)}e=e+16|0;if((h|0)!=(e|0)){continue}break}}b=y[a+480188>>1];w[114256]=0;i=Q(301,d+40|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break E}u[i+16|0]=6;w[i+12>>2]=2015363072;b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;e=w[b>>2];b=w[b+4>>2];w[114256]=0;r=a+484344|0;b=b-e>>1;T(215,r|0,(b>>>0>=65535?65535:b)|0);b=w[114256];w[114256]=0;Q:{if((b|0)!=1){g=w[a+484360>>2];h=x[a+484376|0];b=g+(h<<5)|0;B=w[b>>2];I=w[b+4>>2];if((B|0)!=(I|0)){while(1){f=y[B>>1];e=w[A>>2];if(f>>>0<w[A+4>>2]-e>>4>>>0){b=x[d+132|0];m=e+(f<<4)|0;w[m+8>>2]=0;R:{S:{T:{U:{V:{W:{if(b>>>0<=2){w[114256]=0;b=Q(241,m|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break U}u[d+24|0]=b?x[d+224|0]:0;b=w[m+8>>2];e=w[m>>2];f=w[w[e>>2]+36>>2];w[114256]=0;b=S(f|0,e|0,b|0,2)|0;e=w[114256];w[114256]=0;if((e|0)==1){break U}X:{if(b){e=w[m+8>>2]+2|0;break X}b=w[m>>2];e=w[w[b>>2]+24>>2];w[114256]=0;e=V(e|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break U}}w[m+8>>2]=e;w[114256]=0;b=Q(197,m|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break U}w[114256]=0;v[d+26>>1]=b?y[d+224>>1]:0;b=Q(232,m|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break U}w[d+28>>2]=b?w[d+224>>2]:0;break W}w[114256]=0;e=Q(302,m|0,d+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break U}if(!e){w[d+24>>2]=0;w[d+28>>2]=0}if(b>>>0>5){break V}}u[d+25|0]=0}w[114256]=0;b=y[d+26>>1];E=b?b>>>0>=1024?1024:b:1;F=S(303,r|0,E|0,0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break U}if((F|0)==65535){break R}b=w[r>>2];w[114256]=0;s=C(F,52);e=b+s|0;V(218,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break U}b=y[a+480188>>1];f=b-1&65535;h=x[d+24|0];J=f>>>0<h>>>0?f:h;k=J+1|0;if(b>>>0>k>>>0){f=w[e>>2];e=k;while(1){u[f+C(e,6)|0]=254;e=e+1|0;if((b|0)!=(e|0)){continue}break}}u[i+13|0]=x[d+25|0]>>>4;b=x[i+12|0];w[114256]=0;u[d+224|0]=0;D=S(304,d+248|0,k|0,d+224|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break U}if(!E){break S}q=0;e=(b|0)!=0;Y:{while(1){Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{b=w[D>>2];f=x[b|0];if(!f){w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=(b?x[d+224|0]:0)<<24>>24;if((b|0)<0){w[114256]=0;f=Q(241,m|0,d+224|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break T}u[w[D>>2]]=f?x[d+224|0]:0}b=b&63;if(!b){n=0;h=0;p=0;z=0;if(e&1){break ea}break Z}w[114256]=0;f=Q(241,m|0,d+224|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break T}n=f?x[d+224|0]:0;ga:{ha:{ia:{ja:{ka:{la:{switch(b-1|0){case 1:if(!(n&255)){break fa}u[i+15|0]=n;u[i+12|0]=1;b=x[i+13|0];if(!b){n=0;break ka}u[i+14|0]=C(C(b,n),15);n=0;break ea;case 6:break ga;case 5:break ha;case 3:break ia;case 2:break la;case 0:break aa;default:break fa}}b=n&255;g=b>>>4|0;u[i+13|0]=g;if(b>>>0<16){break ja}n=0;if(x[i+12|0]){break ba}}h=0;break da}n=0;u[i+12|0]=0;h=0;p=0;z=0;if(e&1){break $}break Z}h=0;p=0;z=0;if(e&1){break ea}break Z}f=n&255;if(!f){break fa}e=i+(x[i+12|0]?15:14)|0;b=x[e|0];u[e|0]=b>>>0>=256-f>>>0?-1:b+n|0;n=0;break ea}f=n&255;if(!f){break fa}e=i+(x[i+12|0]?15:14)|0;b=x[e|0];u[e|0]=b>>>0<=f+1>>>0?1:b-n|0;n=0;break ea}u[b|0]=f-1;n=0;h=0;p=0;z=0;if(e&1){break ea}break Z}n=0;h=0;p=0;z=0;if(!(e&1)){break Z}}g=x[i+13|0];b=x[i+12|0];if(!b){break ca}h=0;if(g&255){break ca}}p=0;z=0;break Z}if(!b){break $}}b=C(x[i+15|0],g&255);f=b?b<<1:1;break _}u[i+15|0]=0;u[i+12|0]=0;b=n&255;u[i+14|0]=b>>>0<=1?1:b;n=0}f=C(x[i+14|0],30)+30|0}p=255;ma:{while(1){b=C(f,p);if(b-1536>>>0<=10751){b=((b&65535)>>>0)/48|0;break ma}b=p>>>0>1;p=p-1|0;if(b){continue}break}e=32;if((f|0)>=1536){p=0;e=255;b=(f>>>0)/48|0;if(f>>>0<12288){break ma}}p=0;b=e}h=b;z=1;u[i+16|0]=(p|0)<=1?1:p}b=w[r>>2];w[114256]=0;b=b+s|0;e=V(218,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Y}if(J){G=q-1|0;e=(w[b>>2]+C(C(e,q),6)|0)+6|0;g=1;while(1){na:{oa:{pa:{qa:{ra:{b=w[D>>2]+g|0;f=x[b|0];if(!f){w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=b?x[d+224|0]:0;if(b<<24>>24<0){w[114256]=0;f=Q(241,m|0,d+224|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break T}u[w[D>>2]+g|0]=f?x[d+224|0]:0}K=1;l=b&255;if(l&64){w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=b?x[d+224|0]:0;u[e+1|0]=b;K=!(b&255)}if(!(l&32)){b=x[e|0];break ra}w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=b?x[d+224|0]:0;u[e|0]=b;if((b-1&255)>>>0<=107){b=b&255;b=(b>>>0>=96?96:b)+24|0;u[e|0]=b;u[(w[i>>2]+C(g,6)|0)+1|0]=b;break pa}if((b+127&255)>>>0<=107){b=(b&127)+24|0;u[w[i>>2]+C(g,6)|0]=b>>>0>=120?120:b;u[e|0]=0;break qa}if((b&255)!=255){break ra}u[e|0]=254;break oa}u[b|0]=f-1;break na}if(b&255){break pa}}if(!x[e+1|0]){break oa}b=x[(w[i>>2]+C(g,6)|0)+1|0];u[e+1|0]=0;u[e|0]=b}if((b-1&255)>>>0>119){break oa}u[(w[i>>2]+C(g,6)|0)+5|0]=0}u[d+264|0]=0;u[d+247|0]=0;u[d+246|0]=0;u[d+245|0]=0;u[d+244|0]=0;u[d+243|0]=0;if(l&16){u[e+2|0]=1;w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}u[e+4|0]=b?x[d+224|0]+2>>>2|0:0}sa:{if(!(l&8)){break sa}w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}w[114256]=0;u[d+264|0]=b?x[d+224|0]:0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=b?x[d+224|0]:0;u[d+245|0]=b;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{f=x[d+264|0];switch(f-1|0){case 0:break ua;case 9:break va;case 5:case 6:case 7:case 8:break wa;case 4:break xa;case 3:break ya;case 2:break za;case 1:break Aa;default:break ta}}u[e|0]=255;break ta}b=w[i>>2]+C(g,6)|0;u[e|0]=x[b+1|0];u[b+5|0]=0;break ta}b=(C(x[i+16|0],b&255)>>>0)/255|0;b=b>>>0>=15?15:b;u[d+245|0]=b;Ba:{if(b){u[d+264|0]=20;u[d+245|0]=b|208;break Ba}u[d+264|0]=0}if(x[e|0]){break sa}b=w[i>>2]+C(g,6)|0;u[e|0]=x[b+1|0];u[b+5|0]=0;break sa}f=x[i+16|0];u[d+264|0]=15;b=(C(f,b&255)>>>0)/255|0;b=b>>>0>=15?15:b;u[d+245|0]=b>>>0<=1?1:b;u[(w[i>>2]+C(g,6)|0)+5|0]=0;break sa}Ca:{if(!q){break Ca}b=C(g,6);if((f|0)==x[(b+w[i>>2]|0)+4|0]){break Ca}o=w[r>>2];w[114256]=0;u[d+235|0]=f+122|160;u[d+234|0]=20;v[d+232>>1]=g;w[d+228>>2]=G;w[d+224>>2]=2;u[d+236|0]=x[d+236|0]&248|1;f=Q(271,o+s|0,d+224|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break T}if(!f){break Ca}u[(b+w[i>>2]|0)+4|0]=x[d+264|0]}u[d+264|0]=10;b=w[i>>2];if(!x[e|0]){u[e|0]=x[(b+C(g,6)|0)+1|0]}u[(b+C(g,6)|0)+5|0]=0;break sa}u[d+264|0]=20;b=w[i>>2]+C(g,6)|0;u[d+245|0]=x[b+5|0]?-98:-97;u[b+5|0]=x[b+5|0]^1;break sa}u[e|0]=254}u[d+264|0]=0}o=0;b=0;Da:{if(!(l&4)){break Da}w[114256]=0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}w[114256]=0;u[d+247|0]=b?x[d+224|0]:0;b=Q(241,m|0,d+224|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}b=b?x[d+224|0]:0;u[d+244|0]=b;f=b<<24>>24;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{b=x[d+247|0];switch(b-1|0){case 11:break Ga;case 10:break Ha;case 7:case 8:case 9:break Ia;case 6:break Ja;case 5:break Ka;case 3:case 4:break La;case 2:break Ma;case 1:break Na;case 0:break Oa;default:break Fa}}j=(f|0)>=0;u[d+247|0]=j?2:3;b=f;if(!j){b=0-f|0;u[d+244|0]=b}Pa:{if((b&255)>>>0<16){break Pa}j=x[e|0];if((j-1&255)>>>0>119){break Pa}b=(b&240)>>>4|0;Qa:{if((f|0)>=0){b=b+j|0;b=b>>>0>=120?120:b;break Qa}b=j-b|0;b=(b|0)<=1?1:b}u[e|0]=b;b=x[d+244|0]&15}b=b&255;u[d+244|0]=(b>>>0>=15?15:b)|240;b=0;break Da}b=(C(x[i+16|0],f&255)>>>0)/255|0;b=b>>>0>=15?15:b;u[d+244|0]=b;if(b){u[d+247|0]=20;u[d+244|0]=b|208;b=1;break Da}u[d+247|0]=0;b=1;break Da}b=1;break Ea}j=0;Ra:{if(!f){break Ra}Sa:{if(f>>>0>=16){j=x[i+16|0];if(j>>>0>1){break Sa}}j=f|-16;break Ra}f=((f&255)>>>0)/((j-1&255)>>>0)|0;j=f>>>0<=1?1:f}u[d+244|0]=j;u[d+247|0]=(b|0)==4?2:3;b=1;break Da}b=0;if(!x[e|0]){u[e|0]=x[w[i>>2]+C(g,6)|0];f=x[d+244|0]}j=f&255;Ta:{if(!j){break Ta}b=f|-16;f=x[i+16|0];if(f>>>0<=1){break Ta}b=(j>>>0)/((f-1&255)>>>0)|0;b=b>>>0<=1?1:b}u[d+247|0]=4;u[d+244|0]=b;b=1;break Da}b=f&255;u[e|0]=(b>>>0>=95?95:b)+25;u[d+244|0]=255;u[d+247|0]=4;b=1;break Da}Ua:{if(!q){break Ua}f=C(g,6);if((b|0)==x[(f+w[i>>2]|0)+2|0]){break Ua}j=w[r>>2];w[114256]=0;u[d+235|0]=b-8|48;u[d+234|0]=20;v[d+232>>1]=g;w[d+228>>2]=G;w[d+224>>2]=2;u[d+236|0]=x[d+236|0]&248|1;b=Q(271,j+s|0,d+224|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break T}if(!b){break Ua}u[(f+w[i>>2]|0)+2|0]=x[d+247|0]}u[d+247|0]=5;b=1;f=x[d+244|0];j=f>>>4|0;j=C(x[i+16|0],j>>>0<=1?1:j);t=128/(j>>>0)|0;f=f&15;u[d+244|0]=(j>>>0>128?16:(t>>>0>=15?15:t)<<4)|(f>>>0<=1?1:f);break Da}j=x[i+16|0];u[d+247|0]=18;b=1;t=C(j,(f&240)>>>4|0);L=(t>>>0)/15|0;f=C(j,f&15);j=(f>>>0)/15|0;u[d+244|0]=(t>>>0<15?16:(L>>>0>=15?15:L)<<4)|(f>>>0<15?1:j>>>0>=15?15:j);break Da}b=(C(x[i+16|0],f&255)>>>0)/255|0;b=b>>>0>=15?15:b;u[d+244|0]=b;if(b){u[d+247|0]=20;u[d+244|0]=b|192;b=1;break Da}u[d+247|0]=0;u[e|0]=254;b=1;break Da}b=0}u[d+247|0]=b}Va:{if(!(l&2)){break Va}w[114256]=0;f=Q(241,m|0,d+224|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break T}w[114256]=0;u[d+246|0]=f?x[d+224|0]:0;f=Q(241,m|0,d+224|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break T}f=f?x[d+224|0]:0;u[d+243|0]=f;Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{l=x[d+246|0];switch(l-1|0){case 9:break Xa;case 7:case 8:break Ya;case 6:break Za;case 3:case 4:case 5:break _a;case 2:break $a;case 0:case 1:break ab;default:break Wa}}o=1;j=x[i+16|0];u[d+246|0]=11;Y=d,_=dq(f&255,j,(l|0)==1),u[Y+243|0]=_;break Va}l=x[i+16|0];u[d+246|0]=18;o=1;j=C(l,(f&240)>>>4|0);t=(j>>>0)/15|0;f=C(l,f&15);l=(f>>>0)/15|0;u[d+243|0]=(j>>>0<15?16:(t>>>0>=15?15:t)<<4)|(f>>>0<15?1:l>>>0>=15?15:l);break Va}bb:{if(!q){break bb}f=C(g,6);if((l|0)==x[(f+w[i>>2]|0)+3|0]){break bb}o=w[r>>2];w[114256]=0;u[d+235|0]=l-4|64;u[d+234|0]=20;v[d+232>>1]=g;w[d+228>>2]=G;w[d+224>>2]=2;u[d+236|0]=x[d+236|0]&248|1;o=Q(271,o+s|0,d+224|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break T}if(!o){break bb}u[(f+w[i>>2]|0)+3|0]=x[d+246|0]}u[d+246|0]=8;o=1;f=x[d+243|0];l=f>>>4|0;l=C(x[i+16|0],l>>>0<=1?1:l);j=128/(l>>>0)|0;f=f&15;u[d+243|0]=(l>>>0>128?16:(j>>>0>=15?15:j)<<4)|(f>>>0<=1?1:f);break Va}u[d+246|0]=9;break Va}o=x[i+16|0];u[d+246|0]=29;Y=d,_=dq(f&255,o,(l|0)==8),u[Y+243|0]=_;o=1;break Va}u[d+246|0]=27;o=1;l=f>>>4&15;l=C(x[i+16|0],l>>>0<=1?1:l);j=128/(l>>>0)|0;f=f&15;u[d+243|0]=(l>>>0>128?16:(j>>>0>=15?15:j)<<4)|(f>>>0<=1?1:f);break Va}u[d+246|0]=0}if(b){cq(e,q,y[a+480188>>1],x[d+247|0],d+244|0)}if(o){cq(e,q,y[a+480188>>1],x[d+246|0],d+243|0)}cb:{if(!K|(x[e|0]-1&255)>>>0>119){break cb}b=x[d+247|0];if(!b){u[d+244|0]=255;u[d+247|0]=4;break cb}if(x[d+246|0]|(b|0)==4){break cb}u[d+243|0]=255;u[d+246|0]=4}db:{if(x[e+2|0]!=1){break db}eb:{if(!x[d+247|0]){u[d+247|0]=13;u[d+244|0]=x[e+4|0];break eb}if(x[d+246|0]){break db}u[d+246|0]=13;u[d+243|0]=x[e+4|0]}u[e+2|0]=0}w[114256]=0;ga(272,d+224|0,d+247|0,d+244|0,d+246|0,d+243|0);b=w[114256];w[114256]=0;if((b|0)==1){break T}fb:{if(x[e+2|0]){break fb}b=x[d+247|0];if(!b){break fb}u[e+2|0]=b;u[e+4|0]=x[d+244|0]}gb:{if(x[d+264|0]){w[114256]=0;ga(272,d+224|0,d+246|0,d+243|0,d+264|0,d+245|0);b=w[114256];w[114256]=0;if((b|0)==1){break T}hb:{if(x[e+2|0]){break hb}b=x[d+246|0];if(!b){break hb}u[e+2|0]=b;u[e+4|0]=x[d+243|0]}f=d+245|0;b=x[d+264|0];break gb}f=d+243|0;b=x[d+246|0];if(!b){break na}}u[e+3|0]=b;u[e+5|0]=x[f|0]}e=e+6|0;g=g+1|0;if((k|0)!=(g|0)){continue}break}}ib:{if(!z){break ib}b=w[r>>2];w[114256]=0;u[d+235|0]=h;u[d+234|0]=17;v[d+232>>1]=0;w[d+228>>2]=q;e=x[d+236|0];w[d+224>>2]=1;u[d+236|0]=e&248|1;Q(271,b+s|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break T}b=w[r>>2];w[114256]=0;u[d+235|0]=p;u[d+234|0]=16;v[d+232>>1]=65535;w[d+228>>2]=q;e=x[d+236|0];w[d+224>>2]=1;u[d+236|0]=e&248|1;Q(271,b+s|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break ib}break T}jb:{if((n&255)>>>0<16){break jb}b=w[r>>2];w[114256]=0;u[d+234|0]=20;v[d+232>>1]=65535;w[d+228>>2]=q;w[d+224>>2]=0;u[d+235|0]=(n&240)>>>4|224;u[d+236|0]=x[d+236|0]&248|3;Q(271,b+s|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break jb}break T}kb:{b=n&15;if(b){e=w[r>>2];f=x[i+16|0];w[114256]=0;u[d+234|0]=20;v[d+232>>1]=65535;w[d+228>>2]=q;w[d+224>>2]=0;u[d+236|0]=x[d+236|0]&248|3;b=(C(b,f)>>>0)/15&255;u[d+235|0]=b?(b>>>0>=15?15:b)|96:97;Q(271,e+s|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break kb}}e=0;q=q+1|0;if((E|0)==(q|0)){break S}continue}break}break T}break T}g=P()|0;break I}g=P()|0;a=w[D>>2];if(!a){break I}w[d+252>>2]=a;zb(a);break I}b=w[D>>2];if(!b){break R}w[d+252>>2]=b;zb(b)}v[B>>1]=F}B=B+2|0;if((I|0)!=(B|0)){continue}break}g=w[a+484360>>2];h=x[a+484376|0]}w[114256]=0;e=H&65535;b=W-O>>1;b=b>>>0>=65535?65535:b;b=(b>>>0<=1?1:b)-1&65535;f=b>>>0>e>>>0?e:b;e=Q(305,(h<<5)+g|0,f|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){break Q}}g=P()|0;break I}lb:{if(!e){break lb}e=x[a+484376|0];h=N&65535;b=b>>>0>h>>>0?h:b;mb:{if(b){e=w[w[a+484360>>2]+(e<<5)>>2];break mb}h=w[a+484360>>2]+(e<<5)|0;e=w[h>>2];h=w[h+4>>2]-e>>1;h=h>>>0>=65535?65535:h;if(f>>>0>=((h>>>0<=1?1:h)-1&65535)>>>0){break lb}}e=y[(f<<1)+e>>1];f=w[r>>2];u[d+235|0]=b;u[d+234|0]=12;v[d+232>>1]=65535;u[d+236|0]=x[d+236|0]&248|1;b=f+C(e,52)|0;e=w[b+12>>2];w[114256]=0;w[d+224>>2]=2;w[d+228>>2]=e-1;Q(271,b|0,d+224|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break lb}g=P()|0;break I}b=w[i>>2];if(b){w[i+4>>2]=b;zb(b)}gc(A)}w[114256]=0;U(299,d+224|0,d+96|0,1196641603);b=w[114256];w[114256]=0;if((b|0)==1){break F}e=w[d+224>>2];f=w[d+228>>2];w[d+224>>2]=0;w[d+228>>2]=0;b=w[d+84>>2];w[d+80>>2]=e;w[d+84>>2]=f;if(b){break H}b=w[d+236>>2];w[d+88>>2]=w[d+232>>2];w[d+92>>2]=b;break G}a=w[i>>2];if(!a){break w}w[i+4>>2]=a;zb(a);break w}e=w[b+4>>2];w[b+4>>2]=e-1;if(!e){ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+236>>2];w[d+88>>2]=w[d+232>>2];w[d+92>>2]=b;b=w[d+228>>2];if(!b){break G}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break G}ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+80>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}if(b){b=w[d+80>>2];e=w[w[b>>2]+36>>2];w[114256]=0;b=S(e|0,b|0,w[d+88>>2],1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}nb:{if(b){e=w[d+88>>2]+1|0;break nb}b=w[d+80>>2];e=w[w[b>>2]+24>>2];w[114256]=0;e=V(e|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}}w[d+88>>2]=e;b=w[d+80>>2];e=w[w[b>>2]+24>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}w[114256]=0;da(306,a+1304424|0,d+80|0,b-w[d+88>>2]|0,40,0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}}w[114256]=0;U(299,d+224|0,d+96|0,1146113363);b=w[114256];w[114256]=0;if((b|0)==1){break D}w[114256]=0;U(299,d+24|0,d+96|0,1229999443);b=w[114256];w[114256]=0;if((b|0)!=1){e=w[d+24>>2];f=w[d+28>>2];w[d+24>>2]=0;w[d+28>>2]=0;b=w[d+84>>2];w[d+80>>2]=e;w[d+84>>2]=f;ob:{if(!b){b=w[d+36>>2];w[d+88>>2]=w[d+32>>2];w[d+92>>2]=b;break ob}e=w[b+4>>2];w[b+4>>2]=e-1;if(!e){ob[w[w[b>>2]+8>>2]](b);Ib(b)}b=w[d+36>>2];w[d+88>>2]=w[d+32>>2];w[d+92>>2]=b;b=w[d+28>>2];if(!b){break ob}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break ob}ob[w[w[b>>2]+8>>2]](b);Ib(b)}w[114256]=0;b=Q(241,d+80|0,d+24|0)|0;e=w[114256];w[114256]=0;pb:{qb:{if((e|0)!=1){b=b?x[d+24|0]:0;v[a+480190>>1]=b;if(b){k=!(c&2);e=1;f=1;while(1){h=30;rb:{sb:{if(x[d+132|0]>=2){w[114256]=0;b=Q(241,d+80|0,d+24|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break sb}h=b?x[d+24|0]:0}w[114256]=0;S(307,d+80|0,((e<<5)+a|0)+946304|0,h&255)|0;b=w[114256];w[114256]=0;if((b|0)==1){break sb}w[114256]=0;h=Q(308,d+80|0,d+24|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break C}b=C(e,104)+a|0;c=b+484380|0;if(!h){w[d+32>>2]=0;w[d+36>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0}w[114256]=0;T(309,d+24|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break C}h=x[d+132|0];if(h>>>0>=8){w[114256]=0;S(310,d+80|0,b+484423|0,8)|0;e=w[114256];w[114256]=0;if((e|0)==1){break C}h=x[d+132|0]}e=w[d+80>>2];g=w[w[e>>2]+36>>2];w[114256]=0;i=e;e=(h&255)>>>0>1?6:2;h=S(g|0,i|0,w[d+88>>2],e|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){break rb}break C}g=P()|0;break B}tb:{if(h){h=e+w[d+88>>2]|0;break tb}e=w[d+80>>2];h=w[w[e>>2]+24>>2];w[114256]=0;h=V(h|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break C}}w[114256]=0;w[d+88>>2]=h;e=Q(232,d+224|0,d+264|0)|0;h=w[114256];w[114256]=0;ub:{vb:{if((h|0)==1){break vb}w[114256]=0;U(188,d+8|0,d+224|0,(e?w[d+264>>2]:0)|0);e=w[114256];w[114256]=0;if((e|0)==1){break vb}e=w[d+8>>2];h=w[w[e>>2]+8>>2];w[114256]=0;e=V(h|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break qb}if(k|e^1){break ub}b=y[b+484414>>1];w[114256]=0;u[d+267|0]=(x[d+39|0]&12)==4?7:0;u[d+265|0]=1;u[d+266|0]=0;u[d+264|0]=b&1?16:8;S(214,d+264|0,c|0,d+8|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break ub}break qb}g=P()|0;break B}b=w[d+12>>2];wb:{if(!b){break wb}c=w[b+4>>2];w[b+4>>2]=c-1;if(c){break wb}ob[w[w[b>>2]+8>>2]](b);Ib(b)}f=f+1|0;e=f&65535;if(e>>>0<=y[a+480190>>1]){continue}break}}w[114256]=0;X(257,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break pb}}g=P()|0;break B}g=P()|0;Bb(d+8|0);break B}w[a+480204>>2]=12e5;w[a+480208>>2]=24;w[a+480196>>2]=6;w[a+480200>>2]=256;w[a+480228>>2]=48;w[a+480232>>2]=48;a=w[d+228>>2];xb:{if(!a){break xb}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break xb}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[d+84>>2];yb:{if(!a){break yb}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break yb}ob[w[w[a>>2]+8>>2]](a);Ib(a)}Ac(d+96|0);break a}g=P()|0;break B}g=P()|0;break q}g=P()|0;break w}g=P()|0;break q}g=P()|0}Bb(d+224|0);break q}g=P()|0;break w}g=P()|0;break w}g=P()|0;break q}g=P()|0}gc(A);break q}g=P()|0}Bb(d+80|0);break d}g=P()|0}Ac(d+96|0);break b}g=P()|0;if(u[d+51|0]>=0){break b}zb(w[d+40>>2]);break b}g=P()|0;if(u[d+51|0]<0){zb(w[d+40>>2])}if(u[e+11|0]>=0){break b}zb(w[e>>2])}R(g|0);M()}e=1}jb=d+272|0;return e|0}function EA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,B=0,F=0,I=0,J=D(0),K=0,L=0,N=0,O=0,W=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0;e=jb-608|0;jb=e;w[b+8>>2]=0;a:{if(!wg(b,e+496|0)|(y[e+564>>1]-128&65535)>>>0<65409){break a}if(Jb(e+496|0,13413,17)){break a}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],y[e+560>>1]+(y[e+568>>1]+y[e+566>>1]<<2)|0)|0)){break a}b:{if(!c){break b}tc(a,4);je(a);w[a+1074372>>2]=4;u[e+494|0]=0;v[e+492>>1]=0;c:{d:{e:{k=e+534|0;f:{if(!(Jb(k,13527,20)|w[e+556>>2]!=276)){d=48;if(y[e+554>>1]<260){break f}d=uc(e+513|0,0,20)?1154:34;break f}if(Jb(k,13506,20)){break e}d=1}break d}w[114256]=0;Y(209,e+104|0,3,k|0,20);d=w[114256];w[114256]=0;g:{h:{if((d|0)!=1){w[114256]=0;U(6,e+208|0,4,e+104|0);d=w[114256];w[114256]=0;if((d|0)==1){break h}v[e+492>>1]=y[e+216>>1];m=x[e+219|0];u[e+219|0]=0;n=w[e+208>>2];u[e+208|0]=0;u[e+494|0]=x[e+218|0];s=w[e+212>>2];if(u[e+115|0]<0){zb(w[e+104>>2])}if((x[k|0]|x[k+1|0]<<8|(x[k+2|0]<<16|x[k+3|0]<<24))!=1852141647|(x[k+4|0]|x[k+5|0]<<8|(x[k+6|0]<<16|x[k+7|0]<<24))!=542396493){break g}d=1048;break d}f=P()|0;break c}f=P()|0;if(u[e+115|0]>=0){break c}zb(w[e+104>>2]);break c}if(!Jb(k,13166,12)){d=16;if((y[e+546>>1]|y[e+548>>1]<<16)==538976288&(y[e+550>>1]|y[e+552>>1]<<16)==538976288){break d}w[a+1074372>>2]=5;break d}if(!Jb(k,7460,20)){d=48;break d}if(!Jb(k,23888,15)){d=a+1074316|0;w[d>>2]=w[d>>2]&-4718593;ba=1;d=16;break d}i:{if(Jb(k,23904,14)){if(Jb(k,23919,14)){break i}}d=a+1074316|0;w[d>>2]=w[d>>2]&-34078721;d=16;break d}d=Jb(k,13254,11)?16:256}w[114256]=0;_=e+513|0;Y(209,e+208|0,3,_|0,20);f=w[114256];w[114256]=0;j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){f=a+1304400|0;if(u[a+1304411|0]<0){zb(w[f>>2])}g=w[e+212>>2];w[f>>2]=w[e+208>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+216>>2];w[a+480260>>2]=1;w[a+480264>>2]=31999;l=w[a+484360>>2];g=x[a+484376|0];v[(l+(g<<5)|0)+28>>1]=y[e+562>>1];v[a+480188>>1]=y[e+564>>1];f=y[e+568>>1];v[a+480192>>1]=f>>>0>=255?255:f;f=y[e+572>>1];if(f){w[a+480196>>2]=f}f=y[e+574>>1];if(f){j=w[19470];B=C(w[j+20>>2],1e4);f=C(f,1e4);j=C(w[j+24>>2],1e4);w[a+480204>>2]=f>>>0<B>>>0?B:f>>>0<j>>>0?f:j}f=y[e+570>>1];f=f<<3&-32768|f<<4&16;w[a+480208>>2]=f&32784;w[114256]=0;da(317,l+(g<<5)|0,b|0,y[e+560>>1],65535,65535)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}h=f<<16>>16<0?(d|0)==34?146:d:d;if(!(y[e+560>>1]|h>>>0>1023)){d=w[a+484360>>2];f=x[a+484376|0];w[114256]=0;U(585,d+(f<<5)|0,1,0);d=w[114256];w[114256]=0;if((d|0)==1){break k}}d=w[e+556>>2]+60|0;q:{if(d>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}if(d>>>0>f>>>0){break q}}w[b+8>>2]=d}if(y[e+554>>1]>=260){w[114256]=0;U(586,b|0,e+496|0,a|0);d=w[114256];w[114256]=0;if((d|0)==1){break k}}w[e+488>>2]=0;w[e+480>>2]=0;w[e+484>>2]=0;if(!y[a+480192>>1]){B=-1;l=0;break m}ca=c&2;ea=e+122|0;fa=e+241|0;i=1;K=1;l=0;B=-1;while(1){w[114256]=0;d=Q(232,b|0,e+208|0)|0;f=w[114256];w[114256]=0;r:{s:{t:{u:{v:{w:{if((f|0)!=1){f=w[e+208>>2];g=w[b+8>>2];j=g-4|0;w[b+8>>2]=g>>>0>=j>>>0?j:0;w[114256]=0;d=d?f:0;S(587,b|0,e+208|0,(d?d:263)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}x:{if((h|0)==1){d=w[e+208>>2];if((d|0)!=263){h=16;if((d|0)!=245){break x}w[a+1074308>>2]=16777381;w[114256]=0;d=Q(1,e+192|0,9168)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(m<<24>>24<0){zb(n)}n=w[d>>2];v[e+492>>1]=y[e+200>>1];u[e+494|0]=x[e+202|0];h=17;m=x[e+203|0];s=w[e+196>>2];break x}f=P()|0;break l}w[a+1074308>>2]=16777395;w[114256]=0;d=Q(1,e+176|0,9092)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(m<<24>>24<0){zb(n)}n=w[d>>2];v[e+492>>1]=y[e+184>>1];u[e+494|0]=x[e+186|0];h=17;m=x[e+187|0];s=w[e+180>>2];break x}f=P()|0;break l}if(x[e+235|0]|x[e+236|0]<<8){break x}d=w[e+208>>2];y:{if((d|0)!=29){if(!(!(h&2)|(x[e+237|0]|x[e+238|0]<<8|(x[e+239|0]<<16|x[e+240|0]<<24))|(d|0)!=263)){h=h|16;break x}if(h&256){h=h&-257;break x}if(!(h&160)){break x}if((d|0)!=33){break y}break x}if(!(h&160)){break x}}h=0}w[114256]=0;d=S(243,a|0,K&65535,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(!d){break r}t=((i<<2)+a|0)+900380|0;d=w[t>>2];w[114256]=0;T(588,e+208|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break n}d=x[e+234|0];z:{if((B|0)==-1){B=d;break z}if(!(h&32)|(d|0)==(B|0)){break z}h=h&-161|128}d=x[e+235|0]|x[e+236|0]<<8;if(!d){break r}i=0;w[114256]=0;f=x[e+455|0];g=x[e+451|0]|x[e+452|0]<<8;j=x[e+450|0];o=x[e+449|0];w[e+168>>2]=0;w[e+160>>2]=0;w[e+164>>2]=0;F=d>>>0>=32?32:d;T(450,e+160|0,F|0);d=w[114256];w[114256]=0;if((d|0)==1){break w}h=f|(g|(j|o))?h&-4:h;while(1){A:{q=y[a+480190>>1];f=q+1|0;v[e+56>>1]=f;B:{C:{if((f&65535)>>>0<4e3){g=f;break C}g=1;o=w[e+164>>2];j=w[e+160>>2];D:{while(1){E:{r=g&65535;d=C(r,104)+a|0;if(w[d+484380>>2]?w[d+484400>>2]:0){break E}F:{G:{d=j;if((o|0)==(d|0)){break G}while(1){if((r|0)==y[d>>1]){break G}d=d+2|0;if((o|0)!=(d|0)){continue}break}break F}if((d|0)!=(o|0)){break E}}v[e+56>>1]=g;j=1;f=y[a+480192>>1];if(!f){break D}while(1){d=w[((j<<2)+a|0)+900380>>2];if(d){f=d+492|0;d=d+236|0;while(1){if(y[d>>1]==y[e+56>>1]){v[d>>1]=0}d=d+2|0;if((f|0)!=(d|0)){continue}break}f=y[a+480192>>1]}d=(f&65535)>>>0>j>>>0;j=j+1|0;if(d){continue}break}g=y[e+56>>1];break D}g=g+1|0;if(q>>>0>=(g&65535)>>>0){continue}break}g=f}if((g&65535)>>>0<4e3){break C}w[114256]=0;w[e+112>>2]=0;w[e+104>>2]=0;w[e+108>>2]=0;j=Q(589,a|0,e+104|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break p}H:{if(!j){d=w[e+104>>2];break H}w[114256]=0;Q(590,a|0,e+104|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break p}f=y[a+480192>>1];if(f){g=1;o=w[e+108>>2];while(1){d=w[((g<<2)+a|0)+900380>>2];if(d){q=d+492|0;d=d+236|0;r=w[e+104>>2];while(1){f=y[d>>1];if(!(f>>>0>=o>>>0|w[r+(f>>>3&8188)>>2]>>>f&1)){v[d>>1]=0}d=d+2|0;if((q|0)!=(d|0)){continue}break}f=y[a+480192>>1]}d=(f&65535)>>>0>g>>>0;g=g+1|0;if(d){continue}break}}w[114256]=0;d=w[e+108>>2];w[e+88>>2]=w[e+104>>2];w[e+92>>2]=1;U(591,e+72|0,e+88|0,d-1|0);d=w[114256];w[114256]=0;if((d|0)==1){break p}d=w[e+104>>2];v[e+56>>1]=w[e+76>>2]+(w[e+72>>2]-d<<3)}if(d){zb(d)}if(!j){break A}g=y[e+56>>1];if(g>>>0>3999){break B}}d=w[e+164>>2];I:{if((d|0)!=w[e+168>>2]){v[d>>1]=g;w[e+164>>2]=d+2;break I}w[114256]=0;T(249,e+160|0,e+56|0);d=w[114256];w[114256]=0;if((d|0)==1){break v}}d=y[e+56>>1];if(d>>>0<=y[a+480190>>1]){break B}v[a+480190>>1]=d}i=i+1|0;if(F>>>0>(i&65535)>>>0){continue}}break}f=w[e+160>>2];g=w[e+164>>2]-f>>1;j=w[t>>2]+236|0;d=12;while(1){i=j+(d<<1)|0;o=y[i>>1];if(o>>>0<g>>>0){v[i>>1]=y[f+(o<<1)>>1]}d=d+1|0;if((d|0)!=108){continue}break}if(y[e+554>>1]>259){w[e+484>>2]=w[e+480>>2]}w[114256]=0;L=Q(592,e+144|0,x[e+235|0]|x[e+236|0]<<8)|0;d=w[114256];w[114256]=0;J:{if((d|0)!=1){d=0;if(x[e+235|0]|x[e+236|0]<<8){break J}break s}f=P()|0;break o}K:{L:{M:{N:{while(1){w[114256]=0;f=Q(593,b|0,e+104|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break K}if(!f){Cb(e+104|0,0,40)}w[114256]=0;T(594,e+88|0,e+104|0);f=w[114256];w[114256]=0;O:{if((f|0)==1){break O}f=w[e+484>>2];P:{if(f>>>0<z[e+488>>2]){g=w[e+88>>2];u[f|0]=g;u[f+1|0]=g>>>8;u[f+2|0]=g>>>16;u[f+3|0]=g>>>24;w[e+484>>2]=f+4;break P}w[114256]=0;T(595,e+480|0,e+88|0);f=w[114256];w[114256]=0;if((f|0)==1){break O}}w[w[L>>2]+(d<<2)>>2]=w[e+104>>2];g=x[e+121|0];f=w[e+160>>2];if(w[e+164>>2]-f>>1>>>0>d>>>0){f=y[f+(d<<1)>>1];w[114256]=0;j=(C(f,104)+a|0)+484380|0;T(596,e+104|0,j|0);i=w[114256];w[114256]=0;if((i|0)==1){break N}w[114256]=0;T(597,fa|0,j|0);j=w[114256];w[114256]=0;if((j|0)==1){break N}w[114256]=0;Y(209,e+88|0,3,ea|0,22);j=w[114256];w[114256]=0;if((j|0)==1){break M}w[114256]=0;w[e+76>>2]=32;w[e+72>>2]=((f<<5)+a|0)+946304;Q(200,e+72|0,e+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break L}if(u[e+99|0]<0){zb(w[e+88>>2])}h=(x[e+118|0]&3)==3?(h&2)>>>1|0?h|4:h:h}W=g|W;d=d+1|0;f=x[e+235|0]|x[e+236|0]<<8;if(d>>>0>=f>>>0){break u}continue}break}f=P()|0;break t}f=P()|0;break t}f=P()|0;break t}f=P()|0;if(u[e+99|0]>=0){break t}zb(w[e+88>>2]);break t}f=P()|0;break t}f=P()|0;break l}f=P()|0;break o}f=P()|0;break o}if(y[e+554>>1]<260){break s}t=0;if(!f){break s}Q:{R:{S:{while(1){j=l;d=t<<2;f=w[d+w[L>>2]>>2];g=x[(d+w[e+480>>2]|0)+3|0];w[114256]=0;U(188,e+88|0,b|0,((g|0)==11?(f+1>>>1|0)+16|0:f)|0);f=w[114256];w[114256]=0;T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){if(!ca){break V}f=w[e+160>>2];if(w[e+164>>2]-f>>1>>>0<=t>>>0){break V}f=y[f+(t<<1)>>1];d=d+w[e+480>>2]|0;w[e+576>>2]=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);d=w[e+88>>2];g=w[w[d>>2]+36>>2];w[114256]=0;d=S(g|0,d|0,w[e+96>>2],8)|0;g=w[114256];w[114256]=0;if((g|0)==1){break R}g=C(f,104)+a|0;o=g+484380|0;_:{if(d){d=w[e+88>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+96>>2],4)|0;f=w[114256];w[114256]=0;if((f|0)==1){break R}$:{if(d){d=w[e+96>>2]+4|0;break $}d=w[e+88>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break R}}w[e+96>>2]=d;while(1){d=w[e+88>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+96>>2],1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Z}if(!d){break _}w[114256]=0;d=V(598,e+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Z}if(d){continue}break}}w[114256]=0;w[e+96>>2]=0;S(214,e+576|0,o|0,e+88|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break V}break R}w[114256]=0;w[e+96>>2]=0;f=Q(599,e+88|0,e+104|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break R}l=w[e+104>>2];d=w[e+88>>2];i=w[w[d>>2]+24>>2];w[114256]=0;d=V(i|0,d|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break R}w[114256]=0;U(188,e+104|0,e+88|0,d-w[e+96>>2]|0);d=w[114256];w[114256]=0;if((d|0)==1){break R}N=g+484414|0;i=x[e+577|0]!=1;d=y[N>>1]&-66|x[e+576|0]>15|i<<6;v[N>>1]=d;w[o>>2]=(f?l:0)>>>(d&1)>>>i;w[114256]=0;w[e+72>>2]=0;w[e+56>>2]=0;d=Q(484,e+584|0,e+104|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Y}d=w[d>>2];w[114256]=0;f=w[e+588>>2];l=w[e+592>>2];l=f?f:(l|0)!=w[e+596>>2]?l:0;F=da(483,l|0,(d>>>0>=2147483647?2147483647:d)|0,e+72|0,e+56|0,0)|0;f=w[114256];w[114256]=0;aa:{if((f|0)==1){break aa}f=w[e+104>>2];i=w[w[f>>2]+36>>2];w[114256]=0;p=f;f=w[e+72>>2];i=S(i|0,p|0,w[e+112>>2],f|0)|0;q=w[114256];w[114256]=0;if((q|0)==1){break aa}ba:{if(i){f=f+w[e+112>>2]|0;break ba}f=w[e+104>>2];i=w[w[f>>2]+24>>2];w[114256]=0;f=V(i|0,f|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break aa}}w[e+112>>2]=f;if(!F){break W}f=w[e+72>>2];w[114256]=0;V(252,o|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break aa}q=d-f|0;I=f+l|0;$=g+484400|0;l=0;f=w[e+56>>2];while(1){ca:{if(f){if(!q|(f|0)!=1){break X}if(z[o>>2]>l>>>0){break ca}break X}if(z[o>>2]<=l>>>0){break X}}if(!w[$>>2]){break X}w[114256]=0;w[e+40>>2]=0;w[e+8>>2]=0;d=la(485,F|0,I|0,(q>>>0>=2147483647?2147483647:q)|0,e+40|0,e+580|0,e+8|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}w[e+72>>2]=d;f=w[e+104>>2];g=w[w[f>>2]+36>>2];w[114256]=0;f=S(g|0,f|0,w[e+112>>2],d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break T}da:{if(f){d=d+w[e+112>>2]|0;break da}d=w[e+104>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}}w[e+112>>2]=d;d=w[e+8>>2];f=w[o>>2]-l|0;f=f>>>0>=2147483647?2147483647:f;if((d|0)>(f|0)){w[e+8>>2]=f;d=f}aa=w[e+72>>2];ea:{if((d|0)<=0){break ea}i=w[e+40>>2];if((i|0)<=0){break ea}r=0;if(((x[N|0]&64?2:1)|0)!=(i|0)){break ea}while(1){d=w[w[e+580>>2]+(r<<2)>>2];f=w[$>>2];O=w[e+8>>2];g=y[N>>1];fa:{if(g&1){if(!O){break fa}f=(f+(C(g&64?2:1,l)<<1)|0)+(r<<1)|0;g=0;while(1){J=_b(D(D(H(D(G(A[d>>2],D(1))),D(-1)))*D(32768)));ga:{if(D(E(J))<D(2147483648)){p=~~J;break ga}p=-2147483648}p=(p|0)>=32767?32767:p;v[f>>1]=(p|0)<=-32768?-32768:p;d=d+4|0;f=(i<<1)+f|0;g=g+1|0;if((O|0)!=(g|0)){continue}break}break fa}if(!O){break fa}f=(f+C(g&64?2:1,l)|0)+r|0;g=0;while(1){J=_b(D(D(H(D(G(A[d>>2],D(1))),D(-1)))*D(128)));ha:{if(D(E(J))<D(2147483648)){p=~~J;break ha}p=-2147483648}p=(p|0)>=127?127:p;u[f|0]=(p|0)<=-128?-128:p;f=f+i|0;d=d+4|0;g=g+1|0;if((O|0)!=(g|0)){continue}break}}i=w[e+40>>2];r=r+1|0;if((i|0)>(r|0)){continue}break}d=w[e+8>>2]}w[114256]=0;f=V(486,F|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break T}q=q-aa|0;I=I+aa|0;w[e+56>>2]=f;l=d+l|0;continue}}break T}f=P()|0;break t}f=P()|0;break Q}f=P()|0;break S}w[114256]=0;X(487,F|0);d=w[114256];w[114256]=0;if((d|0)!=1){break W}break T}d=w[e+592>>2];if(d){w[e+596>>2]=d;zb(d)}d=w[e+108>>2];ia:{if(!d){break ia}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break ia}ob[w[w[d>>2]+8>>2]](d);Ib(d)}I=1;l=1;if(!F){break U}}l=j}d=w[e+92>>2];ja:{if(!d){break ja}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break ja}ob[w[w[d>>2]+8>>2]](d);Ib(d)}t=t+1|0;if(t>>>0<(x[e+235|0]|x[e+236|0]<<8)>>>0){continue}break s}break}f=P()|0;a=w[e+592>>2];if(!a){break S}w[e+596>>2]=a;zb(a)}Bb(e+104|0);break Q}f=P()|0}Bb(e+88|0)}a=w[L>>2];if(!a){break o}w[e+148>>2]=a;zb(a);break o}d=w[L>>2];if(d){w[e+148>>2]=d;zb(d)}d=w[e+160>>2];if(!d){break r}w[e+164>>2]=d;zb(d)}K=K+1|0;i=K&65535;if(i>>>0<=y[a+480192>>1]){continue}break}break m}f=P()|0;break j}f=P()|0;a=w[e+104>>2];if(!a){break o}zb(a)}a=w[e+160>>2];if(!a){break l}w[e+164>>2]=a;zb(a);break l}f=P()|0;break l}if(!(!(h&2)|W&255)){h=uc(_,0,20)?h|16:h}ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if(y[e+554>>1]>259){break za}if(c&3){w[114256]=0;U(586,b|0,e+496|0,a|0);d=w[114256];w[114256]=0;if((d|0)==1){break ya}}if(!(c&2)|!y[a+480190>>1]){break za}d=1;while(1){w[114256]=0;c=d&65535;S(214,(w[e+480>>2]+(c<<2)|0)-4|0,(C(c,104)+a|0)+484380|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break xa}d=d+1|0;if(y[a+480190>>1]>=(d&65535)>>>0){continue}break}}Aa:{if(!(l&1)){break Aa}w[114256]=0;c=Q(1,e+104|0,12413)|0;d=w[114256];w[114256]=0;if((d|0)==1){break wa}w[114256]=0;U(367,a|0,2,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break va}if(u[c+11|0]>=0){break Aa}zb(w[c>>2])}w[114256]=0;c=S(343,b|0,2044,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ya}if(c){w[114256]=0;c=Q(232,b|0,e+208|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ya}w[114256]=0;Z(320,a+1304424|0,b|0,(c?w[e+208>>2]:0)|0,0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ya}h=h|16}w[114256]=0;g=S(343,b|0,9809,4)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ka}if(g){w[114256]=0;c=Q(232,b|0,e+208|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ka}w[114256]=0;d=a+901404|0;S(600,b|0,d|0,(c?w[e+208>>2]:0)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ka}w[114256]=0;X(355,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break ka}h=h|16}w[114256]=0;c=S(343,b|0,9590,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ka}if(c){w[114256]=0;c=Q(232,b|0,e+208|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ta}c=(c?w[e+208>>2]>>>5|0:0)&65535;d=(w[a+484348>>2]-w[a+484344>>2]|0)/52&65535;c=c>>>0<d>>>0?c:d;if(c){d=0;while(1){w[114256]=0;S(375,b|0,e+208|0,32)|0;f=w[114256];w[114256]=0;if((f|0)==1){break sa}f=w[a+484344>>2];w[114256]=0;S(227,f+C(d,52)|0,e+208|0,32)|0;f=w[114256];w[114256]=0;if((f|0)==1){break sa}d=d+1|0;if((c|0)!=(d|0)){continue}break}}h=h|16}w[114256]=0;c=S(343,b|0,9595,4)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break ua}break ka}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;if(u[c+11|0]>=0){break l}zb(w[c>>2]);break l}if(c){w[114256]=0;c=Q(232,b|0,e+208|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ra}d=y[a+480188>>1];c=(c?z[e+208>>2]/20|0:0)&65535;c=c>>>0>d>>>0?d:c;if(c){d=0;while(1){w[114256]=0;S(357,b|0,((d<<5)+a|0)+480289|0,20)|0;f=w[114256];w[114256]=0;if((f|0)==1){break qa}d=d+1|0;if((c|0)!=(d|0)){continue}break}}h=h|16}c=w[b+8>>2];d=w[b>>2];f=w[w[d>>2]+36>>2];w[114256]=0;c=S(f|0,d|0,c|0,8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ka}if(c){c=w[b+8>>2];w[114256]=0;Q(358,a|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break pa}h=(c|0)==w[b+8>>2]?h:h|16}Ba:{if(!(h&16)){break Ba}if(h&4){w[a+1074308>>2]=17367040;w[114256]=0;c=Q(1,e+88|0,10206)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(m<<24>>24<0){zb(n)}s=w[c+4>>2];n=w[c>>2];v[e+492>>1]=y[c+8>>1];u[e+494|0]=x[c+10|0];m=x[c+11|0];break Ba}f=P()|0;break l}if(!(h&2)){break Ba}w[a+1074308>>2]=18219008;w[114256]=0;c=Q(1,e+88|0,10345)|0;d=w[114256];w[114256]=0;if((d|0)==1){break oa}if(m<<24>>24<0){zb(n)}s=w[c+4>>2];n=w[c>>2];v[e+492>>1]=y[c+8>>1];u[e+494|0]=x[c+10|0];m=x[c+11|0]}Ca:{if((x[k|0]|x[k+1|0]<<8|(x[k+2|0]<<16|x[k+3|0]<<24))==1852141647&(x[k+4|0]|x[k+5|0]<<8|(x[k+6|0]<<16|x[k+7|0]<<24))==542396493){w[114256]=0;d=V(22,16)|0;c=w[114256];w[114256]=0;Da:{Ea:{Fa:{if((c|0)!=1){w[e+208>>2]=d;w[e+212>>2]=12;w[e+216>>2]=-2147483632;f=y[e+546>>1]|y[e+548>>1]<<16;c=y[e+542>>1]|y[e+544>>1]<<16;g=y[e+550>>1]|y[e+552>>1]<<16;u[d+12|0]=0;u[d+8|0]=g;u[d+9|0]=g>>>8;u[d+10|0]=g>>>16;u[d+11|0]=g>>>24;u[d|0]=c;u[d+1|0]=c>>>8;u[d+2|0]=c>>>16;u[d+3|0]=c>>>24;u[d+4|0]=f;u[d+5|0]=f>>>8;u[d+6|0]=f>>>16;u[d+7|0]=f>>>24;w[114256]=0;U(6,e+160|0,1,e+208|0);c=w[114256];w[114256]=0;if((c|0)==1){break Fa}w[114256]=0;c=V(601,e+160|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Ea}w[a+1074308>>2]=c;if(u[e+171|0]<0){zb(w[e+160>>2]);c=w[a+1074308>>2]}w[a+1074372>>2]=c>>>0<19007257?4:5;if(u[e+219|0]<0){zb(w[e+208>>2])}f=a+1074308|0;h=24;d=1;break Ca}f=P()|0;break l}f=P()|0;break Da}f=P()|0;if(u[e+171|0]>=0){break Da}zb(w[e+160>>2])}if(u[e+219|0]>=0){break l}zb(w[e+208>>2]);break l}if(!(!w[a+1074308>>2]|h&8)){w[a+1074372>>2]=0;Sp(a+1074312|0)}f=a+1074308|0;d=1;if(!(h&32)){break Ca}w[a+1074372>>2]=5;if(!g){w[114256]=0;X(356,a+901404|0);c=w[114256];w[114256]=0;if((c|0)==1){break ka}}d=0;if(y[e+554>>1]<260){break Ca}w[a+1074312>>2]=w[a+1074312>>2]|16}Ga:{if(m<<24>>24<0?s:m&255){break Ga}if(!(!(h&256)|W&255|B+1>>>0>1)){w[114256]=0;c=Q(1,e+160|0,4477)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(m<<24>>24<0){zb(n)}s=w[c+4>>2];n=w[c>>2];v[e+492>>1]=y[c+8>>1];u[e+494|0]=x[c+10|0];m=x[c+11|0];break Ga}f=P()|0;break l}if(!d){w[114256]=0;c=Q(1,e+160|0,7872)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(m<<24>>24<0){zb(n)}s=w[c+4>>2];n=w[c>>2];v[e+492>>1]=y[c+8>>1];u[e+494|0]=x[c+10|0];m=x[c+11|0];break Ga}f=P()|0;break l}w[114256]=0;c=Q(1,e+160|0,5621)|0;d=w[114256];w[114256]=0;if((d|0)==1){break na}if(m<<24>>24<0){zb(n)}s=w[c+4>>2];n=w[c>>2];v[e+492>>1]=y[c+8>>1];u[e+494|0]=x[c+10|0];m=x[c+11|0]}u[e+87|0]=0;if(y[a+480192>>1]){w[114256]=0;c=Q(372,a|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break la}u[e+87|0]=c}w[114256]=0;Y(373,a|0,b|0,1,e+87|0);b=w[114256];w[114256]=0;if((b|0)==1){break la}d=w[f>>2];Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{if(x[e+87|0]){if(d>>>0>18284543){break Va}w[f>>2]=18284544;break Va}if(d>>>0<18284544){break Ua}}w[114256]=0;g=Q(1,e+72|0,13266)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Ta}w[114256]=0;T(120,e+208|0,f|0);b=w[114256];w[114256]=0;if((b|0)==1){break Sa}w[114256]=0;b=x[e+219|0];c=b<<24>>24<0;d=S(2,g|0,(c?w[e+208>>2]:e+208|0)|0,(c?w[e+212>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Ra}s=w[d+4>>2];b=w[d>>2];u[e+58|0]=x[d+10|0];v[e+56>>1]=y[d+8>>1];w[d>>2]=0;w[d+4>>2]=0;c=x[d+11|0];w[d+8>>2]=0;if(m<<24>>24<0){zb(n)}u[e+494|0]=x[e+58|0];v[e+492>>1]=y[e+56>>1];if(u[e+219|0]<0){zb(w[e+208>>2])}if(u[g+11|0]<0){zb(w[g>>2])}d=w[f>>2];m=c;n=b}Wa:{if(d-1>>>0>19005952){break Wa}d=w[a+484344>>2];f=(w[a+484348>>2]-d|0)/52|0;if(!((f&65535)>>>0>=255&w[d+13208>>2]!=w[d+13212>>2])){b=w[a+484360>>2];c=x[a+484376|0];w[114256]=0;T(602,b+(c<<5)|0,254);b=w[114256];w[114256]=0;if((b|0)==1){break la}d=w[a+484344>>2];f=(w[a+484348>>2]-d|0)/52|0}if(w[d+13260>>2]!=w[d+13264>>2]?f&65280:0){break Wa}b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;d=w[b>>2];b=w[b+4>>2];if((d|0)==(b|0)){break Wa}while(1){if(y[d>>1]==255){v[d>>1]=65535}d=d+2|0;if((b|0)!=(d|0)){continue}break}}w[114256]=0;b=Q(1,e+24|0,10766)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Pa}d=w[b>>2];w[e+44>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+47|0]=c;u[e+48|0]=c>>>8;u[e+49|0]=c>>>16;u[e+50|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[e+51|0]=c;w[e+40>>2]=d;c=y[e+554>>1];w[e+580>>2]=c>>>8;w[e+576>>2]=c&255;u[e+224|0]=44;w[e+216>>2]=-1;w[e+220>>2]=0;w[e+208>>2]=1042;w[e+212>>2]=2;U(101,e+8|0,e+576|0,e+208|0);c=w[114256];w[114256]=0;if((c|0)==1){break Oa}w[114256]=0;Y(366,e+56|0,e+40|0,e+580|0,e+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break Na}c=a+1304436|0;if(u[a+1304447|0]<0){zb(w[c>>2])}d=w[e+60>>2];w[c>>2]=w[e+56>>2];w[c+4>>2]=d;w[c+8>>2]=w[e- -64>>2];u[e+67|0]=0;u[e+56|0]=0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[e+51|0]<0){zb(w[e+40>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}w[a+1304460>>2]=n;w[a+1304464>>2]=s;v[a+1304468>>1]=y[e+492>>1];u[a+1304470|0]=x[e+494|0];u[a+1304471|0]=m;w[a+1304496>>2]=ba?7:w[a+1074308>>2]?7:4;n=n&-256;if(!(I&255)){break Ja}b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}d=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=d;w[b+8>>2]=w[c+8>>2];m=0;u[a+1304436|0]=0;u[a+1304447|0]=0;w[114256]=0;b=Q(1,e+208|0,11018)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Ha}if(u[a+1304447|0]<0){zb(w[c>>2])}d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;w[c+8>>2]=w[b+8>>2];w[114256]=0;c=Q(1,e+56|0,6041)|0;b=w[114256];w[114256]=0;if((b|0)==1){break La}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}d=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=d;w[b+8>>2]=w[c+8>>2];w[114256]=0;c=Q(1,e+40|0,6042)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Ka}b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}break Ia}f=P()|0;break l}f=P()|0;break Qa}f=P()|0;if(u[e+219|0]>=0){break Qa}zb(w[e+208>>2])}if(u[g+11|0]>=0){break l}zb(w[g>>2]);break l}f=P()|0;break l}f=P()|0;break Ma}f=P()|0;if(u[e+19|0]>=0){break Ma}zb(w[e+8>>2])}if(u[e+51|0]<0){zb(w[e+40>>2])}if(u[b+11|0]>=0){break l}zb(w[b>>2]);break l}f=P()|0;break l}f=P()|0;break l}m=0;w[114256]=0;c=Q(1,e+208|0,6042)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ma}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}}a=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=a;w[b+8>>2]=w[c+8>>2];a=w[e+480>>2];if(!a){break b}w[e+484>>2]=a;zb(a);break b}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0;break l}f=P()|0}a=w[e+480>>2];if(!a){break j}w[e+484>>2]=a;zb(a);break j}f=P()|0}if(m<<24>>24>=0){break c}zb(n)}R(f|0);M()}d=1}jb=e+608|0;return d|0}function OM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=D(0),l=0,m=D(0),n=0,o=D(0),p=0,q=D(0),r=0,s=0,t=0,B=0,E=0,F=0,G=D(0),H=0,I=0,J=0,K=0,L=0,N=0,O=0,P=0,Q=0,R=D(0),S=0,T=0,U=0,V=0,W=0,X=D(0),Y=D(0),Z=D(0),_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=D(0),ia=0,ja=0,ka=0,la=0,ma=D(0),na=D(0),oa=0,pa=0,qa=D(0),ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=D(0),Da=D(0),Ea=D(0),Fa=D(0),Ga=D(0),Ha=D(0),Ia=D(0),Ja=D(0),Ka=D(0),La=D(0),Ma=D(0),Na=D(0),Oa=D(0),Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=D(0),Va=0,Wa=0;s=jb-2384|0;jb=s;a:{b:{c:{d:{if(w[a+1420>>2]>=0){w[f>>2]=0;e:{n=w[a+1420>>2];if((n|0)<=0){break e}while(1){w[(C(g,20)+a|0)+1436>>2]=0;g=g+1|0;if((n|0)!=(g|0)){continue}break}if((n|0)<=3){break e}j=c;break b}if((c|0)<4){break a}j=c-3|0;g=0;while(1){f:{g:{B=b+g|0;if(!(x[B|0]!=79|(x[B|0]|x[B+1|0]<<8|(x[B+2|0]<<16|x[B+3|0]<<24))!=(x[82856]|x[82857]<<8|(x[82858]<<16|x[82859]<<24)))){L=g+26|0;if((L|0)>=(j|0)){break d}e=g+27|0;d=b+L|0;f=x[d|0];if((e+f|0)>=(j|0)){break d}i=f+27|0;c=0;if(f){break g}break f}g=g+1|0;if((j|0)>(g|0)){continue}break c}while(1){i=x[(c+e|0)+b|0]+i|0;c=c+1|0;if((f|0)!=(c|0)){continue}break}}c=0;h=0;while(1){c=w[((x[(g+h|0)+b|0]^c>>>24)<<2)+455312>>2]^c<<8;l=22;h=h+1|0;if((h|0)!=22){continue}break}while(1){c=w[(c>>>22&1020)+455312>>2]^c<<8;l=l+1|0;if((l|0)!=26){continue}break}w[a+1420>>2]=n+1;e=C(n,20)+a|0;w[e+1432>>2]=c;w[e+1428>>2]=i-26;w[e+1424>>2]=x[B+22|0]|x[B+23|0]<<8|(x[B+24|0]<<16|x[B+25|0]<<24);c=x[(L+x[d|0]|0)+b|0]==255?-1:x[B+6|0]|x[B+7|0]<<8|(x[B+8|0]<<16|x[B+9|0]<<24);w[e+1436>>2]=L;w[e+1440>>2]=c;n=w[a+1420>>2];if((n|0)==4){break c}g=g+1|0;if((j|0)>(g|0)){continue}break}break c}w[a+100>>2]=0;w[a+32>>2]=b;w[a+40>>2]=b+c;if(!vu(a)){w[f>>2]=0;break a}w[a+1504>>2]=0;w[a+1508>>2]=0;h:{i:{j:{k:{if(w[a+96>>2]){break k}l:{if(w[a+1380>>2]!=-1){break l}g=w[a+32>>2];h=w[a+40>>2];if(g>>>0>=h>>>0){w[a+96>>2]=1;break k}c=g+1|0;w[a+32>>2]=c;if(x[g|0]!=79){w[a+100>>2]=30;break h}m:{n:{if(c>>>0>=h>>>0){w[a+96>>2]=1;break n}c=g+2|0;w[a+32>>2]=c;if(x[g+1|0]==103){break m}}w[a+100>>2]=30;break h}o:{p:{if(c>>>0>=h>>>0){w[a+96>>2]=1;break p}c=g+3|0;w[a+32>>2]=c;if(x[g+2|0]==103){break o}}w[a+100>>2]=30;break h}q:{r:{if(c>>>0>=h>>>0){w[a+96>>2]=1;break r}w[a+32>>2]=g+4;if(x[g+3|0]==83){break q}}w[a+100>>2]=30;break h}if(!uu(a)){break k}if(!(u[a+1375|0]&1)){break l}u[a+1376|0]=0;w[a+1384>>2]=0;w[a+100>>2]=32;break j}if(!Km(a)){break k}if(Nb(a,1)){break i}s:{t:{if(!(w[a+84>>2]!=w[a+92>>2]?w[a+80>>2]:0)){j=Nb(a,ig(w[a+408>>2]-1|0));if((j|0)==-1|(j|0)>=w[a+408>>2]){break k}l=a+412|0;ra=l+C(j,6)|0;if(!x[ra|0]){S=w[a+112>>2];c=0;break t}S=w[a+116>>2];c=Nb(a,1);h=Nb(a,1);g=c;c=x[ra|0];_=g|!c?_:S-w[a+112>>2]>>2;if(h|!c){break t}g=w[a+112>>2];h=C(S,3);S=g+h>>2;L=h-g>>2;break s}ha(2707,9008,3152,6666);M()}L=S>>1}ca=w[a+404>>2];ia=x[(l+C(j,6)|0)+1|0];da=ca+C(ia,40)|0;T=w[((c<<2)+a|0)+104>>2];g=w[a+4>>2];if((g|0)>0){while(1){c=x[(w[da+4>>2]+C(p,3)|0)+2|0];g=p<<2;r=g+(s+1344|0)|0;w[r>>2]=0;u:{h=x[(c+da|0)+9|0];if(y[((h<<1)+a|0)+132>>1]){c=w[a+260>>2];v:{if(Nb(a,1)){K=w[(a+g|0)+996>>2];E=c+C(h,1596)|0;H=w[(x[E+1588|0]<<2)+47212>>2];c=ig(H)-1|0;Va=K,Wa=Nb(a,c),v[Va>>1]=Wa;Va=K,Wa=Nb(a,c),v[Va+2>>1]=Wa;if(x[E|0]){J=E+82|0;U=E+65|0;t=E+49|0;B=E+33|0;n=E+1|0;h=2;$=0;while(1){Q=x[n+$|0];l=x[Q+B|0];i=0;I=x[t+Q|0];w:{if(!I){break w}j=w[a+124>>2]+C(x[Q+U|0],2096)|0;c=w[a+1396>>2];x:{if((c|0)>9){break x}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break x}c=Dc(a);if((c|0)==-1){break x}g=w[a+1396>>2];w[a+1396>>2]=g+8;w[a+1392>>2]=w[a+1392>>2]+(c<<g);if((g|0)<17){continue}break}}g=w[a+1392>>2];c=v[(j+((g&1023)<<1)|0)+36>>1];y:{if((c|0)>=0){i=g;g=c&65535;c=x[g+w[j+8>>2]|0];w[a+1392>>2]=i>>>c;c=w[a+1396>>2]-c|0;w[a+1396>>2]=(c|0)>0?c:0;i=(c|0)<0?-1:g;break y}i=hg(a,j)}if(!x[j+23|0]){break w}i=w[w[j+2088>>2]+(i<<2)>>2]}if(l){j=-1<<I^-1;c=h+l|0;while(1){g=0;l=v[(J+(Q<<4)|0)+((i&j)<<1)>>1];z:{if((l|0)<0){break z}N=w[a+124>>2]+C(l&65535,2096)|0;g=w[a+1396>>2];A:{if((g|0)>9){break A}if(!g){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break A}g=Dc(a);if((g|0)==-1){break A}l=w[a+1396>>2];w[a+1396>>2]=l+8;w[a+1392>>2]=w[a+1392>>2]+(g<<l);if((l|0)<17){continue}break}}l=w[a+1392>>2];g=v[(N+((l&1023)<<1)|0)+36>>1];B:{if((g|0)>=0){F=l;l=g&65535;g=x[l+w[N+8>>2]|0];w[a+1392>>2]=F>>>g;g=w[a+1396>>2]-g|0;w[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:l;break B}g=hg(a,N)}if(!x[N+23|0]){break z}g=w[w[N+2088>>2]+(g<<2)>>2]}i=i>>I;v[K+(h<<1)>>1]=g;h=h+1|0;if((c|0)!=(h|0)){continue}break}h=c}$=$+1|0;if($>>>0<x[E|0]){continue}break}}if(w[a+1396>>2]!=-1){break v}}w[r>>2]=1;break u}v[s+64>>1]=257;i=w[E+1592>>2];if((i|0)>=3){r=E+338|0;B=E+1088|0;c=2;while(1){J=c<<1;h=J+B|0;n=x[h+1|0];j=n<<1;l=x[h|0];h=l<<1;g=v[h+K>>1];U=v[j+K>>1]-g|0;t=U>>31;h=y[h+r>>1];h=(C((t^U)-t|0,y[r+J>>1]-h|0)|0)/(y[j+r>>1]-h|0)|0;g=g+((U|0)<0?0-h|0:h)|0;h=K+J|0;t=v[h>>1];C:{D:{if(t){j=s- -64|0;u[j+n|0]=1;u[j+l|0]=1;u[c+j|0]=1;l=H-g|0;if((t|0)>=((g|0)>(l|0)?l:g)<<1){if((g|0)<(l|0)){break C}g=(l+(g-t|0)|0)-1|0;break D}if(t&1){g=g-(t+1>>>1|0)|0;break D}g=(t>>1)+g|0;break D}u[(s- -64|0)+c|0]=0}v[h>>1]=g;i=w[E+1592>>2]}c=c+1|0;if((i|0)>(c|0)){continue}break}}g=0;if((i|0)<=0){break u}while(1){if(!x[(s- -64|0)+g|0]){v[K+(g<<1)>>1]=65535;i=w[E+1592>>2]}g=g+1|0;if((i|0)>(g|0)){continue}break}break u}w[a+100>>2]=21;break h}g=w[a+4>>2];p=p+1|0;if((g|0)>(p|0)){continue}break}}E:{F:{c=w[a+80>>2];if(!(w[a+84>>2]!=w[a+92>>2]?c:0)){Fb(s+320|0,s+1344|0,g<<2);j=y[da>>1];if(j){l=w[(ca+C(ia,40)|0)+4>>2];g=0;while(1){h=l+C(g,3)|0;i=x[h+1|0];p=s+1344|0;h=p+(x[h|0]<<2)|0;if(!(w[(i<<2)+p>>2]?w[h>>2]:0)){w[(s+1344|0)+(i<<2)>>2]=0;w[h>>2]=0}g=g+1|0;if((j|0)!=(g|0)){continue}break}}P=T>>1;N=ca+C(ia,40)|0;if(x[N+8|0]){H=P<<2;$=0;while(1){p=0;i=w[a+4>>2];if((i|0)>0){h=w[N+4>>2];g=0;while(1){if(x[(h+C(g,3)|0)+2|0]==($|0)){c=g<<2;G:{if(w[c+(s+1344|0)>>2]){l=1;c=0;break G}l=0;c=w[(a+c|0)+800>>2]}u[(s- -64|0)+p|0]=l;w[(p<<2)+s>>2]=c;p=p+1|0}g=g+1|0;if((i|0)!=(g|0)){continue}break}}h=x[(N+$|0)+24|0];F=w[a+396>>2]+C(h,24)|0;c=w[F+4>>2];J=y[((h<<1)+a|0)+268>>1];j=(J|0)==2;h=P<<j;g=c>>>0<h>>>0?c:h;c=w[F>>2];V=(g-(c>>>0<h>>>0?c:h)>>>0)/z[F+8>>2]|0;h=V<<2;c=C(h+4|0,i);ea=w[w[a+124>>2]+C(x[F+13|0],2096)>>2];U=w[a+92>>2];H:{if(w[a+80>>2]){l=tu(a,c);i=w[a+4>>2];break H}l=fc(c)}if((i|0)>0){g=(i<<2)+l|0;c=0;while(1){w[(c<<2)+l>>2]=g;g=g+h|0;c=c+1|0;if((i|0)!=(c|0)){continue}break}}g=0;I:{J:{I=(p|0)<=0;K:{if(!I){while(1){if(!x[(s- -64|0)+g|0]){Cb(w[(g<<2)+s>>2],0,H)}g=g+1|0;if((p|0)!=(g|0)){continue}break}if((p|0)==1){break K}g=0;if(!j){break K}while(1){if(!x[(s- -64|0)+g|0]){break J}g=g+1|0;if((p|0)!=(g|0)){continue}break}break I}if(j){break J}}E=0;while(1){if((V|0)>0){aa=0;t=I|(E|0)!=0;n=0;while(1){i=0;if(!t){while(1){if(!x[(s- -64|0)+i|0]){j=w[a+124>>2]+C(x[F+13|0],2096)|0;c=w[a+1396>>2];L:{if((c|0)>9){break L}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break L}c=Dc(a);if((c|0)==-1){break L}h=w[a+1396>>2];w[a+1396>>2]=h+8;w[a+1392>>2]=w[a+1392>>2]+(c<<h);if((h|0)<17){continue}break}}h=w[a+1392>>2];c=v[(j+((h&1023)<<1)|0)+36>>1];M:{if((c|0)>=0){g=h;h=c&65535;c=x[h+w[j+8>>2]|0];w[a+1392>>2]=g>>>c;c=w[a+1396>>2]-c|0;w[a+1396>>2]=(c|0)>0?c:0;g=(c|0)<0?-1:h;break M}g=hg(a,j)}g=x[j+23|0]?w[w[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break I}w[w[(i<<2)+l>>2]+(aa<<2)>>2]=w[w[F+16>>2]+(g<<2)>>2]}i=i+1|0;if((p|0)!=(i|0)){continue}break}}N:{if((ea|0)<=0){break N}Q=0;if((n|0)>=(V|0)){break N}while(1){K=0;if(!I){while(1){O:{if(x[(s- -64|0)+K|0]){break O}h=K<<2;c=v[(w[F+20>>2]+(x[w[w[h+l>>2]+(aa<<2)>>2]+Q|0]<<4)|0)+(E<<1)>>1];if((c|0)<0){break O}W=w[a+124>>2]+C(c&65535,2096)|0;fa=w[F+8>>2];ja=w[F>>2]+C(fa,n)|0;i=w[h+s>>2];if(J){if((fa|0)<=0){break O}O=0;while(1){h=su(a,W);if((h|0)<0){break I}j=i+(ja<<2)|0;g=w[W>>2];c=fa-O|0;B=(c|0)>(g|0)?g:c;h=C(g,h);P:{if(x[W+22|0]){g=0;m=D(0);if((B|0)<=0){break P}while(1){c=j+(g<<2)|0;k=D(A[w[W+28>>2]+(g+h<<2)>>2]+m);A[c>>2]=A[c>>2]+k;m=D(A[W+12>>2]+k);g=g+1|0;if((B|0)!=(g|0)){continue}break}break P}g=0;if((B|0)<=0){break P}while(1){c=j+(g<<2)|0;A[c>>2]=A[c>>2]+A[w[W+28>>2]+(g+h<<2)>>2];g=g+1|0;if((B|0)!=(g|0)){continue}break}}c=w[W>>2];ja=c+ja|0;O=c+O|0;if((fa|0)>(O|0)){continue}break}break O}r=(fa|0)/w[W>>2]|0;if((r|0)<=0){break O}B=i+(ja<<2)|0;O=0;while(1){h=su(a,W);if((h|0)<0){break I}g=w[W>>2];c=fa-(O+ja|0)|0;i=(c|0)>(g|0)?g:c;if((i|0)>0){j=B+(O<<2)|0;h=C(g,h);g=0;m=D(0);while(1){c=j+(C(g,r)<<2)|0;k=D(A[w[W+28>>2]+(g+h<<2)>>2]+m);A[c>>2]=A[c>>2]+k;m=x[W+22|0]?k:m;g=g+1|0;if((i|0)!=(g|0)){continue}break}}O=O+1|0;if((r|0)!=(O|0)){continue}break}}K=K+1|0;if((K|0)!=(p|0)){continue}break}}n=n+1|0;Q=Q+1|0;if((ea|0)<=(Q|0)){break N}if((n|0)<(V|0)){continue}break}}aa=aa+1|0;if((n|0)<(V|0)){continue}break}}E=E+1|0;if((E|0)!=8){continue}break}break I}if((g|0)==(p|0)){break I}t=(V|0)<=0;B=t|(p|0)<3;i=0;while(1){Q:{if((p|0)==2){if(t){break Q}g=0;n=0;while(1){c=w[F>>2]+C(w[F+8>>2],g)|0;w[s+2380>>2]=c&1;w[s+2376>>2]=c>>1;if(!i){j=w[a+124>>2]+C(x[F+13|0],2096)|0;c=w[a+1396>>2];R:{if((c|0)>9){break R}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break R}c=Dc(a);if((c|0)==-1){break R}h=w[a+1396>>2];w[a+1396>>2]=h+8;w[a+1392>>2]=w[a+1392>>2]+(c<<h);if((h|0)<17){continue}break}}h=w[a+1392>>2];c=v[(j+((h&1023)<<1)|0)+36>>1];S:{if((c|0)>=0){J=h;h=c&65535;c=x[h+w[j+8>>2]|0];w[a+1392>>2]=J>>>c;c=w[a+1396>>2]-c|0;w[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:h;break S}c=hg(a,j)}c=x[j+23|0]?w[w[j+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break I}w[w[l>>2]+(n<<2)>>2]=w[w[F+16>>2]+(c<<2)>>2]}T:{if((ea|0)<=0){break T}c=0;if((g|0)>=(V|0)){break T}while(1){j=w[F+8>>2];h=v[(w[F+20>>2]+(x[w[w[l>>2]+(n<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((h|0)>=0){if(!ru(a,w[a+124>>2]+C(h&65535,2096)|0,s,2,s+2380|0,s+2376|0,P,j)){break I}g=g+1|0;break U}g=g+1|0;h=w[F>>2]+C(j,g)|0;w[s+2376>>2]=h>>1;w[s+2380>>2]=h&1}c=c+1|0;if((ea|0)<=(c|0)){break T}if((g|0)<(V|0)){continue}break}}n=n+1|0;if((g|0)<(V|0)){continue}break}break Q}if(B){break Q}g=0;n=0;while(1){c=w[F>>2]+C(w[F+8>>2],g)|0;h=(c|0)/(p|0)|0;w[s+2380>>2]=c-C(h,p);w[s+2376>>2]=h;if(!i){j=w[a+124>>2]+C(x[F+13|0],2096)|0;c=w[a+1396>>2];V:{if((c|0)>9){break V}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break V}c=Dc(a);if((c|0)==-1){break V}h=w[a+1396>>2];w[a+1396>>2]=h+8;w[a+1392>>2]=w[a+1392>>2]+(c<<h);if((h|0)<17){continue}break}}h=w[a+1392>>2];c=v[(j+((h&1023)<<1)|0)+36>>1];W:{if((c|0)>=0){J=h;h=c&65535;c=x[h+w[j+8>>2]|0];w[a+1392>>2]=J>>>c;c=w[a+1396>>2]-c|0;w[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:h;break W}c=hg(a,j)}c=x[j+23|0]?w[w[j+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break I}w[w[l>>2]+(n<<2)>>2]=w[w[F+16>>2]+(c<<2)>>2]}X:{if((ea|0)<=0){break X}c=0;if((g|0)>=(V|0)){break X}while(1){j=w[F+8>>2];h=v[(w[F+20>>2]+(x[w[w[l>>2]+(n<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];Y:{if((h|0)>=0){if(!ru(a,w[a+124>>2]+C(h&65535,2096)|0,s,p,s+2380|0,s+2376|0,P,j)){break I}g=g+1|0;break Y}g=g+1|0;j=w[F>>2]+C(j,g)|0;h=(j|0)/(p|0)|0;w[s+2376>>2]=h;w[s+2380>>2]=j-C(h,p)}c=c+1|0;if((ea|0)<=(c|0)){break X}if((g|0)<(V|0)){continue}break}}n=n+1|0;if((g|0)<(V|0)){continue}break}}i=i+1|0;if((i|0)!=8){continue}break}}if(!w[a+80>>2]){zb(l)}w[a+92>>2]=U;$=$+1|0;if($>>>0<x[N+8|0]){continue}break}c=w[a+80>>2]}if(!(w[a+84>>2]!=w[a+92>>2]?c:0)){n=y[da>>1];if(n){t=(P|0)<=1?1:P;B=ca+C(ia,40)|0;U=a+800|0;while(1){c=n;n=c-1|0;if((T|0)>=2){h=w[B+4>>2]+C(n,3)|0;i=w[U+(x[h+1|0]<<2)>>2];j=w[U+(x[h|0]<<2)>>2];g=0;while(1){h=g<<2;l=h+i|0;o=A[l>>2];h=h+j|0;m=A[h>>2];Z:{if(!(m<=D(0))){if(!(o<=D(0))){k=D(m-o);break Z}k=m;m=D(o+k);break Z}if(!(o<=D(0))){k=D(o+m);break Z}k=m;m=D(k-o)}A[h>>2]=m;A[l>>2]=k;g=g+1|0;if((t|0)!=(g|0)){continue}break}}if((c|0)>1){continue}break}}if(w[a+4>>2]<=0){break E}sa=P<<2;I=ca+C(ia,40)|0;n=0;while(1){c=n<<2;h=c+a|0;K=w[h+800>>2];_:{if(w[c+(s+320|0)>>2]){Cb(K,0,sa);break _}c=x[(I+x[(w[I+4>>2]+C(n,3)|0)+2|0]|0)+9|0];if(!y[((c<<1)+a|0)+132>>1]){w[a+100>>2]=21;break _}E=w[a+260>>2]+C(c,1596)|0;H=w[h+996>>2];c=C(x[E+1588|0],v[H>>1]);g=0;if(w[E+1592>>2]>=2){J=E+338|0;U=E+838|0;p=1;while(1){j=x[p+U|0]<<1;h=v[j+H>>1];if((h|0)>=0){l=C(x[E+1588|0],h&65535);j=y[j+J>>1];if((j|0)!=(g|0)){i=l-c|0;N=j-g|0;Q=(i|0)/(N|0)|0;r=(j|0)<(P|0)?j:P;$:{if((r|0)<=(g|0)){break $}h=K+(g<<2)|0;A[h>>2]=A[h>>2]*A[((c&255)<<2)+47232>>2];g=g+1|0;if((r|0)<=(g|0)){break $}t=i;i=i>>31;h=i;t=(t^h)-h|0;h=Q>>31;t=t-C(N,(h^Q)-h|0)|0;B=i|1;h=0;while(1){i=K+(g<<2)|0;F=i;k=A[i>>2];i=h+t|0;h=(i|0)<(N|0);c=(c+Q|0)+(h?0:B)|0;A[F>>2]=k*A[((c&255)<<2)+47232>>2];h=i-(h?0:N)|0;g=g+1|0;if((r|0)!=(g|0)){continue}break}}g=j}c=l}p=p+1|0;if((p|0)<w[E+1592>>2]){continue}break}}if((g|0)>=(P|0)){break _}k=A[(c<<2)+47232>>2];while(1){c=K+(g<<2)|0;A[c>>2]=A[c>>2]*k;g=g+1|0;if((P|0)!=(g|0)){continue}break}}n=n+1|0;c=w[a+4>>2];if((n|0)<(c|0)){continue}break}break F}ha(2707,9008,3335,2120);M()}ha(2707,9008,3302,2120);M()}if((c|0)<=0){break E}J=P-1|0;ka=T>>3;Pa=J-ka|0;ta=T>>2;Qa=J-ta|0;Ra=J+C(ka,-3)|0;Sa=J-(ka<<1)|0;ya=P-4|0;c=ig(T);za=c-7|0;ua=T>>4;oa=0-ua|0;Aa=0-ka|0;U=c-4>>>1|0;Ta=w[a+92>>2];B=P-2<<2;Ba=(T|0)<16;F=(c|0)>9;la=T>>5;W=0-(la<<4)<<2;V=T-4<<2;$=ta-4<<2;ea=P-8<<2;fa=P-3<<2;while(1){h=x[ra|0];j=w[((va<<2)+a|0)+800>>2];wa=P<<2;aa=j+wa|0;aa:{if(w[a+80>>2]){n=tu(a,sa);break aa}n=fc(sa)}c=n+B|0;i=j;pa=(h<<2)+a|0;H=w[pa+1068>>2];g=H;if(T>>>0>=2){while(1){A[c+4>>2]=D(A[g>>2]*A[i>>2])-D(A[g+4>>2]*A[i+8>>2]);A[c>>2]=D(A[g>>2]*A[i+8>>2])+D(A[g+4>>2]*A[i>>2]);g=g+8|0;c=c-8|0;i=i+16|0;if((aa|0)!=(i|0)){continue}break}}if(c>>>0>=n>>>0){i=j+fa|0;while(1){A[c+4>>2]=D(A[g+4>>2]*A[i>>2])-D(A[g>>2]*A[i+8>>2]);A[c>>2]=D(A[g>>2]*D(-A[i>>2]))-D(A[g+4>>2]*A[i+8>>2]);i=i-16|0;g=g+8|0;c=c-8|0;if(n>>>0<=c>>>0){continue}break}}if(!Ba){g=H+ea|0;h=ta<<2;c=h+n|0;h=h+j|0;l=j;i=n;while(1){q=A[i>>2];o=A[c>>2];m=A[i+4>>2];k=A[c+4>>2];A[h+4>>2]=m+k;A[h>>2]=A[i>>2]+A[c>>2];m=D(k-m);k=D(o-q);A[l+4>>2]=D(A[g+16>>2]*m)-D(A[g+20>>2]*k);A[l>>2]=D(A[g+20>>2]*m)+D(A[g+16>>2]*k);q=A[i+8>>2];o=A[c+8>>2];m=A[i+12>>2];k=A[c+12>>2];A[h+12>>2]=m+k;A[h+8>>2]=A[i+8>>2]+A[c+8>>2];m=D(k-m);k=D(o-q);A[l+12>>2]=D(A[g>>2]*m)-D(A[g+4>>2]*k);A[l+8>>2]=D(A[g+4>>2]*m)+D(A[g>>2]*k);i=i+16|0;c=c+16|0;l=l+16|0;h=h+16|0;g=g-32|0;if(H>>>0<=g>>>0){continue}break}}qu(ua,j,J,Aa,H);qu(ua,j,Qa,Aa,H);di(la,j,J,oa,H,16);di(la,j,Pa,oa,H,16);di(la,j,Sa,oa,H,16);di(la,j,Ra,oa,H,16);h=2;if(F){while(1){c=h;h=c+1|0;p=2<<c;if((p|0)>0){t=8<<c;g=0;i=T>>c+2;l=0-(i>>1)|0;c=T>>c+4;while(1){di(c,j,J-C(g,i)|0,l,H,t);g=g+1|0;if((p|0)!=(g|0)){continue}break}}if((h|0)!=(U|0)){continue}break}h=U}if((h|0)<(za|0)){while(1){c=h;h=c+1|0;O=T>>c+6;if((O|0)>0){t=2<<c;ja=32<<c;xa=8<<c;ia=xa|1;ca=C(xa,3);da=ca|1;E=16<<c;K=E|1;c=T>>c+2;N=0-c|0;Q=0-(c>>1)|0;p=H;l=J;while(1){if((t|0)>0){ma=A[(da<<2)+p>>2];na=A[(ca<<2)+p>>2];ga=A[(K<<2)+p>>2];X=A[(E<<2)+p>>2];Y=A[(ia<<2)+p>>2];Z=A[(xa<<2)+p>>2];R=A[p+4>>2];G=A[p>>2];g=(l<<2)+j|0;c=g+(Q<<2)|0;i=t;while(1){I=c-4|0;m=A[I>>2];o=A[c>>2];k=A[g>>2];A[g>>2]=o+k;r=g-4|0;q=A[r>>2];A[r>>2]=A[I>>2]+q;m=D(q-m);k=D(k-o);A[I>>2]=D(m*G)+D(k*R);A[c>>2]=D(k*G)-D(m*R);ba=c-12|0;m=A[ba>>2];r=g-8|0;q=A[r>>2];I=c-8|0;k=A[I>>2];A[r>>2]=k+q;r=g-12|0;o=A[r>>2];A[r>>2]=A[ba>>2]+o;m=D(o-m);k=D(q-k);A[ba>>2]=D(m*Z)+D(k*Y);A[I>>2]=D(k*Z)-D(m*Y);ba=c-20|0;m=A[ba>>2];r=g-16|0;q=A[r>>2];I=c-16|0;k=A[I>>2];A[r>>2]=k+q;r=g-20|0;o=A[r>>2];A[r>>2]=A[ba>>2]+o;m=D(o-m);k=D(q-k);A[ba>>2]=D(m*X)+D(k*ga);A[I>>2]=D(k*X)-D(m*ga);ba=c-28|0;m=A[ba>>2];r=g-24|0;q=A[r>>2];I=c-24|0;k=A[I>>2];A[r>>2]=k+q;r=g-28|0;o=A[r>>2];A[r>>2]=A[ba>>2]+o;m=D(o-m);k=D(q-k);A[ba>>2]=D(m*na)+D(k*ma);A[I>>2]=D(k*na)-D(m*ma);r=N<<2;c=r+c|0;g=g+r|0;r=i>>>0>1;i=i-1|0;if(r){continue}break}}l=l-8|0;p=(ja<<2)+p|0;c=(O|0)>1;O=O-1|0;if(c){continue}break}}if((h|0)!=(za|0)){continue}break}}if((T|0)>=32){g=(J<<2)+j|0;da=W+g|0;qa=A[H+(ka<<2)>>2];Ua=D(-qa);while(1){E=g-56|0;Ca=A[E>>2];K=g-24|0;Da=A[K>>2];Ea=D(Ca+Da);N=g-40|0;Fa=A[N>>2];h=g-8|0;Ga=A[h>>2];ga=D(Fa+Ga);q=D(Ea+ga);Q=g-48|0;Ha=A[Q>>2];c=g-16|0;Ia=A[c>>2];o=D(Ha+Ia);I=g-32|0;Ja=A[I>>2];Ka=A[g>>2];m=D(Ja+Ka);k=D(o+m);A[g>>2]=q+k;A[h>>2]=k-q;r=g-44|0;La=A[r>>2];p=g-12|0;Ma=A[p>>2];X=D(La+Ma);H=g-60|0;Y=A[H>>2];t=g-28|0;Z=A[t>>2];k=D(Y+Z);R=D(X-k);G=D(m-o);A[c>>2]=R+G;i=g-52|0;Na=A[i>>2];l=g-20|0;q=A[l>>2];o=D(Na+q);h=g-36|0;ma=A[h>>2];c=g-4|0;na=A[c>>2];m=D(ma+na);Oa=D(o+m);k=D(k+X);A[c>>2]=k+Oa;A[K>>2]=G-R;A[p>>2]=Oa-k;m=D(m-o);k=D(ga-Ea);A[l>>2]=m-k;A[t>>2]=k+m;ga=D(Z-Y);X=D(Da-Ca);Y=D(D(ga-X)*qa);R=D(Ma-La);G=D(Ga-Fa);Z=D(D(R+G)*qa);m=D(Y+Z);q=D(q-Na);o=D(Ka-Ja);k=D(q+o);A[I>>2]=m+k;A[N>>2]=k-m;m=D(D(R-G)*qa);k=D(D(ga+X)*Ua);R=D(m-k);G=D(o-q);A[Q>>2]=R+G;q=D(k+m);o=D(Ha-Ia);m=D(na-ma);k=D(o+m);A[h>>2]=q+k;A[E>>2]=G-R;A[r>>2]=k-q;m=D(m-o);k=D(Z-Y);A[i>>2]=m-k;A[H>>2]=k+m;g=g+-64|0;if(da>>>0<g>>>0){continue}break}}if(!Ba){g=n+$|0;c=n+(ya<<2)|0;i=w[pa+1100>>2];while(1){h=(y[i>>1]<<2)+j|0;A[c+12>>2]=A[h>>2];A[c+8>>2]=A[h+4>>2];A[g+12>>2]=A[h+8>>2];A[g+8>>2]=A[h+12>>2];h=(y[i+2>>1]<<2)+j|0;A[c+4>>2]=A[h>>2];A[c>>2]=A[h+4>>2];A[g+4>>2]=A[h+8>>2];A[g>>2]=A[h+12>>2];i=i+4|0;c=c-16|0;g=g-16|0;if(n>>>0<=g>>>0){continue}break}}c=n+wa|0;l=c-16|0;if(n>>>0<l>>>0){i=w[pa+1084>>2];h=c;g=n;while(1){X=A[i+4>>2];H=h-4|0;Y=A[H>>2];o=A[g+4>>2];Z=D(Y+o);m=A[i>>2];R=A[g>>2];t=h-8|0;G=A[t>>2];k=D(R-G);q=D(D(X*Z)-D(m*k));o=D(o-Y);A[g+4>>2]=q+o;m=D(D(m*Z)+D(X*k));k=D(G+R);A[g>>2]=m+k;A[H>>2]=q-o;A[t>>2]=k-m;X=A[i+12>>2];h=h-12|0;Y=A[h>>2];o=A[g+12>>2];Z=D(Y+o);m=A[i+8>>2];R=A[g+8>>2];G=A[l>>2];k=D(R-G);q=D(D(X*Z)-D(m*k));o=D(o-Y);A[g+12>>2]=q+o;m=D(D(m*Z)+D(X*k));k=D(G+R);A[g+8>>2]=m+k;A[l>>2]=k-m;A[h>>2]=q-o;i=i+16|0;g=g+16|0;h=l;l=h-16|0;if(g>>>0<l>>>0){continue}break}}l=c-32|0;if(n>>>0<=l>>>0){g=wa+w[pa+1076>>2]|0;i=(ya<<2)+j|0;h=j+V|0;while(1){G=A[g-4>>2];q=A[c-8>>2];o=A[g-8>>2];m=A[c-4>>2];k=D(D(G*q)-D(o*m));A[j>>2]=k;A[i+12>>2]=-k;k=D(D(o*D(-q))-D(m*G));A[aa>>2]=k;A[h+12>>2]=k;G=A[g-12>>2];q=A[c-16>>2];o=A[g-16>>2];m=A[c-12>>2];k=D(D(G*q)-D(o*m));A[j+4>>2]=k;A[i+8>>2]=-k;k=D(D(o*D(-q))-D(m*G));A[aa+4>>2]=k;A[h+8>>2]=k;G=A[g-20>>2];q=A[c-24>>2];o=A[g-24>>2];m=A[c-20>>2];k=D(D(G*q)-D(o*m));A[j+8>>2]=k;A[i+4>>2]=-k;k=D(D(o*D(-q))-D(m*G));A[aa+8>>2]=k;A[h+4>>2]=k;G=A[g-28>>2];q=A[l>>2];g=g-32|0;o=A[g>>2];m=A[c-28>>2];k=D(D(G*q)-D(o*m));A[j+12>>2]=k;A[i>>2]=-k;k=D(D(o*D(-q))-D(m*G));A[aa+12>>2]=k;A[h>>2]=k;h=h-16|0;i=i-16|0;aa=aa+16|0;j=j+16|0;c=l;l=c-32|0;if(n>>>0<=l>>>0){continue}break}}if(!w[a+80>>2]){zb(n)}w[a+92>>2]=Ta;va=va+1|0;if((va|0)<w[a+4>>2]){continue}break}}c=0-P|0;while(1){if((Dc(a)|0)!=-1){continue}break}ba:{if(x[a+1377|0]){w[a+1060>>2]=c;u[a+1377|0]=0;w[a+1064>>2]=1;w[a+1412>>2]=T-S;break ba}h=w[a+1412>>2];if(!h){break ba}c=L-_|0;if((c|0)<=(h|0)){w[a+1412>>2]=h-c;_=L;break ba}w[a+1412>>2]=0;_=h+_|0}c=w[a+1064>>2];ca:{da:{ea:{if(w[a+1388>>2]==w[a+1404>>2]){fa:{if(!c|!(x[a+1375|0]&4)){break fa}h=w[a+1408>>2];g=w[a+1060>>2];if(h>>>0>=g+(S-_|0)>>>0){break fa}c=h-g|0;c=(c>>>0<=h>>>0?c:0)+_|0;S=(c|0)<(S|0)?c:S;w[a+1060>>2]=g+S;break ca}w[a+1064>>2]=1;c=w[a+1408>>2]+(_-P|0)|0;break ea}if(!c){break da}c=w[a+1060>>2]}w[a+1060>>2]=c+(L-_|0)}if(!w[a+80>>2]|w[a+84>>2]==w[a+92>>2]){break ca}ha(2707,9008,3451,2120);M()}ga:{ha:{n=w[a+992>>2];ia:{ja:{if(!n){g=w[a+4>>2];h=0;break ja}c=n<<1;if((c|0)==w[a+112>>2]){c=a+1092|0}else{h=0;if((c|0)!=w[a+116>>2]){break ga}c=a+1096|0}i=w[c>>2];if(!i){break ha}p=0;g=w[a+4>>2];if((g|0)<=0){w[a+992>>2]=S-L;break ia}l=(n|0)<=0;while(1){if(!l){j=(p<<2)+a|0;g=0;while(1){h=w[j+800>>2]+(g+_<<2)|0;c=g<<2;A[h>>2]=D(A[i+(n+(g^-1)<<2)>>2]*A[c+w[j+928>>2]>>2])+D(A[c+i>>2]*A[h>>2]);g=g+1|0;if((n|0)!=(g|0)){continue}break}g=w[a+4>>2]}p=p+1|0;if((p|0)<(g|0)){continue}break}h=w[a+992>>2]}l=S-L|0;w[a+992>>2]=l;if((g|0)>0){i=0;while(1){if((L|0)<(S|0)){j=(i<<2)+a|0;g=0;c=L;while(1){A[w[j+928>>2]+(g<<2)>>2]=A[w[j+800>>2]+(c<<2)>>2];g=g+1|0;c=L+g|0;if((g|0)!=(l|0)){continue}break}g=w[a+4>>2]}i=i+1|0;if((i|0)<(g|0)){continue}break}}if(!h){break ha}}h=((L|0)>(S|0)?S:L)-_|0;w[a+1416>>2]=h+w[a+1416>>2];break ga}h=0}l=w[a+4>>2];if((l|0)>0){g=0;while(1){c=(g<<2)+a|0;w[c+864>>2]=w[c+800>>2]+(_<<2);g=g+1|0;if((l|0)!=(g|0)){continue}break}}if(d){w[d>>2]=l}w[f>>2]=h;w[e>>2]=a+864;j=w[a+32>>2]-b|0;break a}switch(w[a+100>>2]-32|0){case 3:break i;case 0:break j;default:break h}}if(w[a+992>>2]){break h}w[a+100>>2]=0;while(1){ka:{c=Dc(a);w[a+1396>>2]=0;if((c|0)==-1){break ka}if(!w[a+96>>2]){continue}}break}w[f>>2]=0;j=w[a+32>>2]-b|0;break a}w[a+100>>2]=0;while(1){la:{c=Dc(a);w[a+1396>>2]=0;if((c|0)==-1){break la}if(!w[a+96>>2]){continue}}break}w[f>>2]=0;j=w[a+32>>2]-b|0;break a}w[a+1420>>2]=0;w[a+992>>2]=0;w[a+1504>>2]=0;w[a+1508>>2]=0;w[a+1412>>2]=0;w[a+1416>>2]=0;u[a+1377|0]=0;w[a+1064>>2]=0;w[f>>2]=0;j=1;break a}j=g}if((n|0)<=0){break a}}while(1){L=C(O,20)+a|0;e=L+1432|0;g=w[e>>2];c=0;d=L+1428|0;i=w[d>>2];h=w[L+1436>>2];f=j-h|0;l=(f|0)>(i|0)?i:f;if((l|0)>0){while(1){g=w[((x[(c+h|0)+b|0]^g>>>24)<<2)+455312>>2]^g<<8;c=c+1|0;if((l|0)!=(c|0)){continue}break}}w[d>>2]=i-l;w[e>>2]=g;ma:{if((f|0)>=(i|0)){f=L+1424|0;if(w[f>>2]==(g|0)){w[a+1380>>2]=-1;w[a+992>>2]=0;w[a+1420>>2]=-1;b=w[(C(O,20)+a|0)+1440>>2];w[a+1060>>2]=b;w[a+1064>>2]=(b|0)!=-1;j=h+l|0;break a}c=n-1|0;w[a+1420>>2]=c;e=C(c,20)+a|0;w[f+16>>2]=w[e+1440>>2];d=e+1432|0;c=w[d+4>>2];w[f+8>>2]=w[d>>2];w[f+12>>2]=c;d=e+1424|0;c=w[d+4>>2];w[f>>2]=w[d>>2];w[f+4>>2]=c;n=w[a+1420>>2];break ma}O=O+1|0}if((n|0)>(O|0)){continue}break}}jb=s+2384|0;return j|0}function DE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=jb-432|0;jb=d;w[b+8>>2]=0;a:{if(!Mc(b,d+376|0)|w[d+376>>2]!=810369604|x[d+380|0]>3){break a}if(!c){n=1;break a}w[d+360>>2]=w[b>>2];e=w[b+4>>2];w[d+364>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=w[b+12>>2];b=w[b+8>>2];w[114256]=0;w[d+368>>2]=b;w[d+372>>2]=e;U(254,d+344|0,d+360|0,1);b=w[114256];w[114256]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{if((b|0)!=1){w[114256]=0;U(255,d+176|0,d+344|0,1229866575);b=w[114256];w[114256]=0;if((b|0)==1){break oa}w[114256]=0;n=Q(256,d+176|0,d+328|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break qa}if(!n){v[d+336>>1]=0;w[d+328>>2]=0;w[d+332>>2]=0}b=w[d+180>>2];ra:{if(!b){break ra}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break ra}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(!n){break y}w[114256]=0;T(236,a|0,524288);b=w[114256];w[114256]=0;if((b|0)!=1){w[114256]=0;X(257,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break pa}}e=P()|0;break c}e=P()|0;break b}e=P()|0;Bb(d+176|0);break c}w[a+480208>>2]=12;b=y[d+336>>1];e=(b<<8|b>>>8)&65535;v[a+480188>>1]=b?e>>>0>=127?127:e:1;b=y[d+328>>1];b=(b<<8|b>>>8)&65535;v[a+480192>>1]=b>>>0>=255?255:b;b=y[d+330>>1];w[a+1074312>>2]=w[a+1074312>>2]&-2105409|64;b=(b<<8|b>>>8)&65535;v[a+480190>>1]=b>>>0>=3999?3999:b;w[114256]=0;e=Q(1,d+312|0,5212)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}b=a+1304436|0;if(u[a+1304447|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+296|0,6257)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;b=Q(1,d+280|0,10949)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}f=w[b>>2];w[d+252>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+255|0]=e;u[d+256|0]=e>>>8;u[d+257|0]=e>>>16;u[d+258|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+259|0]=e;w[d+248>>2]=f;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=274;w[d+180>>2]=0;U(239,d+232|0,d+376|4,d+176|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}w[114256]=0;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=274;w[d+180>>2]=0;U(239,d+128|0,d+376|5,d+176|0);e=w[114256];w[114256]=0;if((e|0)==1){break j}w[114256]=0;Y(107,d+264|0,d+248|0,d+232|0,d+128|0);e=w[114256];w[114256]=0;if((e|0)==1){break k}e=a+1304460|0;if(u[a+1304471|0]<0){zb(w[e>>2])}f=w[d+268>>2];w[e>>2]=w[d+264>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+272>>2];u[d+275|0]=0;u[d+264|0]=0;if(u[d+139|0]<0){zb(w[d+128>>2])}if(u[d+243|0]<0){zb(w[d+232>>2])}if(u[d+259|0]<0){zb(w[d+248>>2])}if(u[b+11|0]<0){zb(w[b>>2])}w[a+1304496>>2]=2;w[114256]=0;U(255,d+264|0,d+344|0,1312902469);b=w[114256];w[114256]=0;if((b|0)==1){break l}b=w[d+264>>2];e=w[w[b>>2]+24>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break n}w[114256]=0;k=a+1304400|0;S(258,d+264|0,k|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}w[114256]=0;U(255,d+248|0,d+344|0,1397706311);b=w[114256];w[114256]=0;if((b|0)==1){break o}b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;w[b+4>>2]=w[b>>2];i=a+484360|0;sa:{b=y[d+332>>1];ta:{if(!b){break ta}m=(b<<8|b>>>8)&65535;while(1){b=w[d+248>>2];e=w[w[b>>2]+36>>2];w[114256]=0;b=S(e|0,b|0,w[d+256>>2],46)|0;e=w[114256];w[114256]=0;ua:{if((e|0)!=1){if(!b){break ta}w[114256]=0;S(259,d+248|0,d+176|0,44)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=x[a+1304411|0];if(b<<24>>24<0?w[a+1304404>>2]:b){break ua}w[114256]=0;Q(260,k|0,d+176|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break ua}}e=P()|0;break p}e=P()|0;break p}w[114256]=0;b=Q(261,d+248|0,d+232|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break sa}h=0;if(b){b=y[d+232>>1];h=b<<8|b>>>8}e=w[a+484360>>2];f=x[a+484376|0];b=e+(f<<5)|0;if(w[b>>2]!=w[b+4>>2]){w[114256]=0;b=V(262,i|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break sa}if((b|0)==255){break ta}f=x[a+484376|0];e=w[a+484360>>2]}w[114256]=0;b=Q(5,d+384|0,d+176|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break r}w[114256]=0;U(6,d+232|0,2,b|0);l=w[114256];w[114256]=0;if((l|0)==1){break q}if(u[d+395|0]<0){zb(w[b>>2])}w[114256]=0;Q(117,((f<<5)+e|0)+12|0,d+232|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break s}if(u[d+243|0]<0){zb(w[d+232>>2])}b=w[a+484360>>2];e=x[a+484376|0];w[114256]=0;da(263,b+(e<<5)|0,d+248|0,h&65535,65535,65535)|0;b=w[114256];w[114256]=0;if((b|0)==1){break sa}g=g+1|0;if(m>>>0>(g&65535)>>>0){continue}break}}w[114256]=0;T(264,i|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break t}w[114256]=0;U(255,d+232|0,d+344|0,1229869908);b=w[114256];w[114256]=0;if((b|0)==1){break u}b=w[d+232>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ha}va:{if(!b){break va}if(y[a+480192>>1]){e=1;while(1){w[114256]=0;b=Q(265,d+232|0,d+176|0)|0;f=w[114256];w[114256]=0;wa:{xa:{ya:{if((f|0)!=1){if(b){b=y[d+206>>1]}else{Cb(d+176|0,0,50);b=0}w[114256]=0;b=S(243,a|0,e&65535,(b<<8|(b&65280)>>>8)&65535)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ya}if(!b){break wa}f=y[d+206>>1];if(((f<<8|f>>>8)&65535)>>>0<=3999){break xa}break wa}e=P()|0;break ga}e=P()|0;break ga}w[114256]=0;Y(209,d+128|0,2,d+176|0,30);f=w[114256];w[114256]=0;za:{Aa:{Ba:{Ca:{if((f|0)!=1){w[114256]=0;w[d+116>>2]=32;w[d+112>>2]=b+492;Q(200,d+112|0,d+128|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ca}if(u[d+139|0]<0){zb(w[d+128>>2])}w[114256]=0;Y(209,d+128|0,2,d+176|0,30);f=w[114256];w[114256]=0;if((f|0)==1){break Ba}w[114256]=0;f=y[d+206>>1];w[d+116>>2]=32;w[d+112>>2]=((((f<<8|f>>>8)&65535)<<5)+a|0)+946304;Q(200,d+112|0,d+128|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Aa}if(u[d+139|0]<0){zb(w[d+128>>2])}w[b>>2]=0;f=y[d+222>>1];u[b+15|0]=x[b+15|0]|1;g=b;b=(f<<8|f>>>8)+128&65535;w[g+8>>2]=b>>>0>=256?256:b;w[114256]=0;b=y[d+206>>1];f=C((b<<8|b>>>8)&65535,104)+a|0;T(266,f+484380|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break za}b=y[d+208>>1];b=(b<<8|b>>>8)&65535;v[f+484410>>1]=(b>>>0>=64?64:b)<<2;b=y[d+210>>1]|y[d+212>>1]<<16;b=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);g=BV(b,b>>31,8303,0)+4181|0;b=nb;r=f+484404|0,s=CV(g,g>>>0<4181?b+1|0:b,8363,0),w[r>>2]=s;b=y[d+218>>1]|y[d+220>>1]<<16;if(!b){break wa}g=y[d+224>>1];h=g<<8|g>>>8;if(!(h&3)){break wa}g=y[d+214>>1]|y[d+216>>1]<<16;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);w[f+484384>>2]=g;w[f+484388>>2]=g+(b<<8&16711680|b<<24|(b>>>8&65280|b>>>24));b=f+484414|0;f=y[b>>1];v[b>>1]=f|2;if(!(h&2)){break wa}v[b>>1]=f|6;break wa}e=P()|0;break ga}e=P()|0;if(u[d+139|0]>=0){break ga}zb(w[d+128>>2]);break ga}e=P()|0;break ga}e=P()|0;if(u[d+139|0]>=0){break ga}zb(w[d+128>>2]);break ga}e=P()|0;break ga}e=e+1|0;if(y[a+480192>>1]>=(e&65535)>>>0){continue}break}}w[114256]=0;U(255,d+160|0,d+344|0,1447382614);b=w[114256];w[114256]=0;if((b|0)==1){break ha}w[114256]=0;b=w[d+172>>2];w[d+24>>2]=w[d+168>>2];w[d+28>>2]=b;b=w[d+164>>2];w[d+16>>2]=w[d+160>>2];w[d+20>>2]=b;Y(267,d+16|0,0,a|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break ha}w[114256]=0;U(255,d+144|0,d+344|0,1346719318);b=w[114256];w[114256]=0;if((b|0)==1){break ha}w[114256]=0;b=w[d+156>>2];w[d+8>>2]=w[d+152>>2];w[d+12>>2]=b;b=w[d+148>>2];w[d>>2]=w[d+144>>2];w[d+4>>2]=b;Y(267,d|0,1,a|0,x[d+380|0]>2|0);b=w[114256];w[114256]=0;if((b|0)==1){break ha}b=y[a+480192>>1];if(!b){break va}f=b+1&65535;b=1;while(1){e=w[((b<<2)+a|0)+900380>>2];if(!(!e|u[e+60|0]&1)){w[e>>2]=32767}b=b+1|0;if((f|0)!=(b|0)){continue}break}}b=w[d+236>>2];Da:{if(!b){break Da}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break Da}ob[w[w[b>>2]+8>>2]](b);Ib(b)}w[114256]=0;U(255,d+232|0,d+344|0,1346458708);b=w[114256];w[114256]=0;if((b|0)==1){break ia}b=w[d+232>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ja}if(!(c&1)|b^1){break na}w[114256]=0;U(255,d+176|0,d+344|0,1347305805);b=w[114256];w[114256]=0;if((b|0)==1){break ka}b=w[d+176>>2];e=w[w[b>>2]+36>>2];w[114256]=0;b=S(e|0,b|0,w[d+184>>2],1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ma}Ea:{if(b){e=w[d+184>>2]+1|0;break Ea}b=w[d+176>>2];e=w[w[b>>2]+24>>2];w[114256]=0;e=V(e|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ma}}w[114256]=0;w[d+184>>2]=e;i=a+484344|0;b=y[d+334>>1];T(215,i|0,(b<<8|b>>>8)&65535);b=w[114256];w[114256]=0;if((b|0)==1){break ma}w[d+424>>2]=0;w[d+416>>2]=0;w[d+420>>2]=0;m=0;if(!y[d+334>>1]){break ea}while(1){w[114256]=0;b=Q(261,d+232|0,d+128|0)|0;e=w[114256];w[114256]=0;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((e|0)!=1){e=0;if(b){b=y[d+128>>1];e=b<<8|b>>>8}w[114256]=0;b=Q(268,d+232|0,d+128|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ma}f=0;if(b){b=w[d+128>>2];f=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}w[114256]=0;U(188,d+128|0,d+232|0,f|0);b=w[114256];w[114256]=0;if((b|0)==1){break La}w[114256]=0;p=e&65535;b=S(216,i|0,o&65535,p|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ka}if(!b){break Fa}w[114256]=0;w[d+408>>2]=0;w[d+400>>2]=0;w[d+404>>2]=0;S(269,d+176|0,d+400|0,-1)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=w[i>>2];w[114256]=0;l=C(o,52);Q(270,l+b|0,d+400|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break Ja}}break Ia}e=P()|0;break Ga}e=P()|0;break Ga}e=P()|0;break Ga}e=P()|0;break Ha}b=w[i>>2];w[114256]=0;b=b+l|0;V(218,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){Na:{g=w[b>>2];w[d+420>>2]=w[d+416>>2];k=0;while(1){b=w[d+128>>2];e=w[w[b>>2]+36>>2];w[114256]=0;b=S(e|0,b|0,w[d+136>>2],1)|0;e=w[114256];w[114256]=0;Oa:{Pa:{if((e|0)!=1){if(b){w[114256]=0;b=Q(241,d+128|0,d+112|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ia}if(b){e=x[d+112|0];if(e){break Oa}}b=w[d+416>>2];e=w[d+420>>2];if((b|0)!=(e|0)){while(1){f=w[i>>2];g=x[b|0]|x[b+1|0]<<8;w[114256]=0;v[d+120>>1]=65535;w[d+112>>2]=0;w[d+116>>2]=k;v[d+122>>1]=g;u[d+124|0]=x[d+124|0]&248|1;Q(271,f+l|0,d+112|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ia}b=b+2|0;if((e|0)!=(b|0)){continue}break}b=w[d+416>>2]}w[d+420>>2]=b;k=k+1|0;if(p>>>0>k>>>0){break Pa}}if(u[d+411|0]>=0){break Fa}zb(w[d+400>>2]);break Fa}break Ia}b=w[i>>2];w[114256]=0;b=b+l|0;e=V(218,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Na}g=w[b>>2]+C(C(e,k),6)|0;continue}f=y[a+480188>>1];w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;b=w[114256];w[114256]=0;Qa:{Ra:{if((b|0)!=1){b=C(e-1|0,6)+g|0;e=e>>>0>f>>>0;f=h?x[d+112|0]:0;Sa:{if(!(f&1)){break Sa}w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Ia}j=e?d+96|0:b;h=h?x[d+112|0]:0;if((h&255)!=31){if((h-1&255)>>>0>252){break Sa}h=(C((h&240)>>>4|0,12)+(h&15)|0)+13|0}else{h=255}u[j|0]=h}if(!(f&2)){break Qa}w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;j=w[114256];w[114256]=0;if((j|0)!=1){break Ra}}break Ia}u[(e?d+80|0:b+1|0)|0]=h?x[d+112|0]:0}if(!(f&60)){continue}u[d+111|0]=0;u[d+110|0]=0;u[d+109|0]=0;u[d+108|0]=0;if(f&4){w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Na}u[d+110|0]=h?x[d+112|0]:0}if(f&8){w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Na}u[d+108|0]=h?x[d+112|0]:0}if(f&16){w[114256]=0;h=Q(241,d+128|0,d+112|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Na}u[d+111|0]=h?x[d+112|0]:0}if(f&32){w[114256]=0;f=Q(241,d+128|0,d+112|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break Na}u[d+109|0]=f?x[d+112|0]:0}kq(d+111|0,d+109|0);kq(d+110|0,d+108|0);f=x[d+110|0];Ta:{Ua:{if((f|0)==13){h=x[d+111|0];break Ua}if(f){break Ta}h=x[d+111|0];if((h|0)==13){break Ta}}u[d+110|0]=h;u[d+111|0]=f;f=x[d+109|0];u[d+109|0]=x[d+108|0];u[d+108|0]=f}w[114256]=0;ga(272,d+112|0,d+111|0,d+109|0,d+110|0,d+108|0);f=w[114256];w[114256]=0;if((f|0)==1){break Na}w[114256]=0;f=Q(273,x[d+112|0],x[d+113|0])|0;h=w[114256];w[114256]=0;if((h|0)==1){break Na}Va:{if(!f){break Va}w[114256]=0;S(274,d+416|0,w[d+416>>2],d+112|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break Va}break Ia}u[(e?d- -64|0:b+2|0)|0]=x[d+111|0];u[(e?d+32|0:b+4|0)|0]=x[d+109|0];f=x[d+110|0];u[(e?d+48|0:b+3|0)|0]=f;u[(e?d+76|0:b+5|0)|0]=x[d+108|0];if((f|0)==40){q=1;continue}if((f|0)!=31){continue}m=1;continue}}}}e=P()|0;if(u[d+411|0]>=0){break Ha}zb(w[d+400>>2])}Bb(d+128|0)}a=w[d+416>>2];if(!a){break la}w[d+420>>2]=a;zb(a);break la}b=w[d+132>>2];Wa:{if(!b){break Wa}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break Wa}ob[w[w[b>>2]+8>>2]](b);Ib(b)}o=o+1|0;b=y[d+334>>1];if(o>>>0<((b<<8|b>>>8)&65535)>>>0){continue}break}break fa}e=P()|0;break p}e=P()|0;break c}m=0;f=0;if(c&4){break da}break z}e=P()|0}Bb(d+176|0);break v}e=P()|0;break v}e=P()|0;break v}e=P()|0;break p}e=P()|0}Bb(d+232|0);break p}b=w[d+416>>2];if(!b){break ea}w[d+420>>2]=b;zb(b)}b=w[d+180>>2];Xa:{if(!b){break Xa}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break Xa}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(!(c&4)){break ca}f=0;if(!q){break da}e=y[a+480188>>1];if(!e){f=1;break da}b=0;while(1){f=1;g=(b<<5)+a|0;u[g+480288|0]=1;g=g+480280|0;w[g>>2]=w[g>>2]|67108864;b=b+1|0;if((e|0)!=(b|0)){continue}break}}w[114256]=0;w[d+128>>2]=-1778364416;w[d+132>>2]=-16756736;U(255,d+176|0,d+344|0,1146310725);b=w[114256];w[114256]=0;Ya:{Za:{_a:{if((b|0)!=1){b=w[d+176>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(!b){break Ya}w[114256]=0;b=Q(261,d+176|0,d+112|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ba}if(!b){break _a}b=y[d+112>>1];if(!b){break _a}h=(b<<8|b>>>8)&65535;b=0;e=f;while(1){w[114256]=0;g=Q(241,d+176|0,d+112|0)|0;i=w[114256];w[114256]=0;$a:{ab:{if((i|0)!=1){if(y[a+480188>>1]<=b>>>0){break $a}g=!x[d+112|0]|g^1;if(!f){break ab}i=((b<<5)+a|0)+480280|0;w[i>>2]=w[i>>2]&-67108865|(g?0:67108864);break $a}break ba}if(!g){break $a}e=1;u[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((h|0)!=(b|0)){continue}break}break Za}break ba}e=P()|0;break v}e=f}w[114256]=0;Q(275,d+176|0,d+128|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ba}f=e&1}b=w[d+180>>2];bb:{if(!b){break bb}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break bb}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(!f){break ca}w[114256]=0;X(276,a+906300|0);b=w[114256];w[114256]=0;if((b|0)==1){break aa}b=a+906327|0;u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[a+906326|0]=10;v[a+906324>>1]=16;b=a+906316|0;w[b>>2]=810369604;w[b+4>>2]=1869112133;b=a+906335|0;u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;b=a+906340|0;u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;w[114256]=0;b=Q(5,d+96|0,5442)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $}w[114256]=0;Q(277,a+906348|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break _}if(u[b+11|0]<0){zb(w[b>>2])}w[114256]=0;b=Q(5,d+80|0,5426)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Z}w[114256]=0;Q(278,a+906380|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Y}if(u[b+11|0]<0){zb(w[b>>2])}w[114256]=0;b=a+906304|0;T(279,b|0,8);e=w[114256];w[114256]=0;if((e|0)==1){break aa}e=w[b>>2];h=x[d+129|0]|x[d+131|0]<<8|x[d+133|0]<<16;b=x[d+135|0]<<24;f=1869112133;u[e|0]=f;u[e+1|0]=f>>>8;u[e+2|0]=f>>>16;u[e+3|0]=f>>>24;b=b|h;u[e+4|0]=b;u[e+5|0]=b>>>8;u[e+6|0]=b>>>16;u[e+7|0]=b>>>24}if(!m){break z}b=0;while(1){w[114256]=0;w[d+76>>2]=C(b,127)>>>5;e=Q(5,d+400|0,11343)|0;f=w[114256];w[114256]=0;if((f|0)==1){break X}w[d+56>>2]=w[e+8>>2];f=w[e+4>>2];e=w[e>>2];w[114256]=0;w[d+48>>2]=e;w[d+52>>2]=f;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=1058;w[d+180>>2]=2;U(280,d+32|0,d+76|0,d+176|0);e=w[114256];w[114256]=0;if((e|0)==1){break W}w[114256]=0;U(281,d- -64|0,d+48|0,d+32|0);e=w[114256];w[114256]=0;if((e|0)==1){break V}w[114256]=0;w[d+180>>2]=32;e=(b<<5)+a|0;w[d+176>>2]=e+902204;Q(200,d+176|0,d- -64|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break U}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[d+59|0]<0){zb(w[d+48>>2])}w[114256]=0;f=Q(5,d+416|0,11325)|0;g=w[114256];w[114256]=0;if((g|0)==1){break R}w[d+56>>2]=w[f+8>>2];g=w[f+4>>2];f=w[f>>2];w[114256]=0;w[d+48>>2]=f;w[d+52>>2]=g;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=1058;w[d+180>>2]=2;U(280,d+32|0,d+76|0,d+176|0);f=w[114256];w[114256]=0;if((f|0)==1){break Q}w[114256]=0;U(281,d- -64|0,d+48|0,d+32|0);f=w[114256];w[114256]=0;if((f|0)==1){break P}w[114256]=0;w[d+180>>2]=32;w[d+176>>2]=e+903228;Q(200,d+176|0,d- -64|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break O}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[d+59|0]<0){zb(w[d+48>>2])}w[114256]=0;f=Q(5,d+112|0,11307)|0;g=w[114256];w[114256]=0;if((g|0)==1){break L}w[d+56>>2]=w[f+8>>2];g=w[f+4>>2];f=w[f>>2];w[114256]=0;w[d+48>>2]=f;w[d+52>>2]=g;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=1058;w[d+180>>2]=2;U(280,d+32|0,d+76|0,d+176|0);f=w[114256];w[114256]=0;if((f|0)==1){break K}w[114256]=0;U(281,d- -64|0,d+48|0,d+32|0);f=w[114256];w[114256]=0;if((f|0)==1){break J}w[114256]=0;w[d+180>>2]=32;w[d+176>>2]=e+904252;Q(200,d+176|0,d- -64|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break I}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[d+59|0]<0){zb(w[d+48>>2])}w[114256]=0;f=Q(5,d+128|0,11298)|0;g=w[114256];w[114256]=0;if((g|0)==1){break F}w[d+56>>2]=w[f+8>>2];g=w[f+4>>2];f=w[f>>2];w[114256]=0;w[d+48>>2]=f;w[d+52>>2]=g;u[d+192|0]=44;w[d+184>>2]=-1;w[d+188>>2]=0;w[d+176>>2]=1058;w[d+180>>2]=2;U(280,d+32|0,d+76|0,d+176|0);f=w[114256];w[114256]=0;if((f|0)==1){break E}w[114256]=0;U(281,d- -64|0,d+48|0,d+32|0);f=w[114256];w[114256]=0;if((f|0)==1){break D}w[114256]=0;w[d+180>>2]=32;w[d+176>>2]=e+905276;Q(200,d+176|0,d- -64|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break C}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[d+59|0]<0){zb(w[d+48>>2])}b=b+1|0;if((b|0)!=32){continue}break}break z}e=P()|0;Bb(d+176|0);break v}e=P()|0;break v}e=P()|0;break v}e=P()|0;if(u[b+11|0]>=0){break v}zb(w[b>>2]);break v}e=P()|0;break v}e=P()|0;if(u[b+11|0]>=0){break v}zb(w[b>>2]);break v}e=P()|0;break v}e=P()|0;break S}e=P()|0;break T}e=P()|0;if(u[d+75|0]>=0){break T}zb(w[d+64>>2])}if(u[d+43|0]>=0){break S}zb(w[d+32>>2])}if(u[d+59|0]>=0){break v}zb(w[d+48>>2]);break v}e=P()|0;break v}e=P()|0;break M}e=P()|0;break N}e=P()|0;if(u[d+75|0]>=0){break N}zb(w[d+64>>2])}if(u[d+43|0]>=0){break M}zb(w[d+32>>2])}if(u[d+59|0]>=0){break v}zb(w[d+48>>2]);break v}e=P()|0;break v}e=P()|0;break G}e=P()|0;break H}e=P()|0;if(u[d+75|0]>=0){break H}zb(w[d+64>>2])}if(u[d+43|0]>=0){break G}zb(w[d+32>>2])}if(u[d+59|0]>=0){break v}zb(w[d+48>>2]);break v}e=P()|0;break v}e=P()|0;break A}e=P()|0;break B}e=P()|0;if(u[d+75|0]>=0){break B}zb(w[d+64>>2])}if(u[d+43|0]>=0){break A}zb(w[d+32>>2])}if(u[d+59|0]>=0){break v}zb(w[d+48>>2]);break v}w[114256]=0;U(255,d+176|0,d+344|0,1397575756);b=w[114256];w[114256]=0;if((b|0)==1){break w}b=w[d+176>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break x}if(!(!y[a+480190>>1]|(b&c>>>1)!=1)){g=1;f=1;while(1){w[114256]=0;c=Q(268,d+176|0,d- -64|0)|0;b=w[114256];w[114256]=0;cb:{if((b|0)!=1){b=0;if(c){b=w[d+64>>2];b=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}w[114256]=0;c=Q(268,d+176|0,d- -64|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break x}e=0;if(c){c=w[d+64>>2];e=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}if(!(b&7)){break cb}c=(C(g,104)+a|0)+484380|0;w[c>>2]=e;w[114256]=0;u[d+67|0]=0;u[d+65|0]=1;u[d+66|0]=1;u[d+64|0]=b&4?32:b&2?16:8;S(214,d- -64|0,c|0,d+176|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break cb}break x}break x}f=f+1|0;g=f&65535;if(g>>>0<=y[a+480190>>1]){continue}break}}a=w[d+180>>2];db:{if(!a){break db}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break db}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[d+236>>2];eb:{if(!a){break eb}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break eb}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[d+252>>2];fb:{if(!a){break fb}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break fb}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[d+268>>2];if(!a){break y}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break y}ob[w[w[a>>2]+8>>2]](a);Ib(a)}Ac(d+344|0);a=w[d+364>>2];if(!a){break a}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break a}ob[w[w[a>>2]+8>>2]](a);Ib(a);break a}e=P()|0;Bb(d+176|0);break v}e=P()|0}Bb(d+232|0);break p}e=P()|0;break p}e=P()|0;break p}e=P()|0;if(u[d+243|0]>=0){break p}zb(w[d+232>>2]);break p}e=P()|0;break p}e=P()|0;if(u[d+395|0]>=0){break p}zb(w[b>>2])}Bb(d+248|0);break m}e=P()|0;break m}e=P()|0}Bb(d+264|0);break c}e=P()|0;break c}e=P()|0;if(u[d+139|0]>=0){break i}zb(w[d+128>>2]);break i}e=P()|0}if(u[d+243|0]>=0){break g}zb(w[d+232>>2]);break g}e=P()|0}if(u[d+259|0]<0){zb(w[d+248>>2])}if(u[b+11|0]>=0){break c}zb(w[b>>2]);break c}e=P()|0;break c}e=P()|0;break c}e=P()|0}Ac(d+344|0)}Bb(d+360|0);R(e|0);M()}jb=d+432|0;return n|0}function NM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=D(0),B=0,F=0,G=D(0),H=0,J=0,K=0,L=0,N=0,O=0,P=0,Q=D(0);f=jb-2528|0;jb=f;Cb(f+8|0,0,1512);if(e){h=w[e+4>>2];w[f+88>>2]=w[e>>2];w[f+92>>2]=h;e=h&-8;w[f+92>>2]=e;w[f+100>>2]=e}w[f+1428>>2]=-1;w[f+132>>2]=0;w[f+104>>2]=0;w[f+108>>2]=0;u[f+56|0]=1;w[f+40>>2]=a;w[f+48>>2]=a+b;u[f+1385|0]=1;a:{b:{c:{if(!Pj(f+8|0)){break c}b=x[f+1383|0];if(!(b&2)){w[f+108>>2]=34;break c}if(b&4){w[f+108>>2]=34;break c}if(b&1){w[f+108>>2]=34;break c}if(w[f+1124>>2]!=1){w[f+108>>2]=34;break c}d:{b=x[f+1128|0];if((b|0)!=30){if((b|0)!=64){break d}a=w[f+40>>2];b=a+6|0;e=w[f+48>>2];e:{if(b>>>0>e>>>0){w[f+104>>2]=1;break e}h=f+2524|0;v[h>>1]=x[a+4|0]|x[a+5|0]<<8;a=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);w[f+2520>>2]=a;w[f+40>>2]=b;c=(a&255)==102;g=x[f+2523|0]==104;j=x[f+2522|0]==115;i=x[f+2521|0]==105;k=x[f+2525|0]==97;l=x[h|0]==101;a=b}if(!(c&1)|b>>>0>e>>>0|(!(i&1)|!(j&1))|(!(k&1)|(!(g&1)|!(l&1)))){break d}if(a>>>0>=e>>>0){w[f+104>>2]=1;break d}b=a+1|0;w[f+40>>2]=b;if(x[a|0]!=100){break d}f:{if(b>>>0>=e>>>0){w[f+104>>2]=1;break f}w[f+40>>2]=a+2;if(x[a+1|0]){break d}}w[f+108>>2]=38;break c}g:{b=w[f+40>>2];e=w[f+48>>2];h:{if(b>>>0>=e>>>0){w[f+104>>2]=1;break h}w[f+40>>2]=b+1;if(x[b|0]==1){break g}}w[f+108>>2]=34;break c}g=e;e=b+7|0;if(g>>>0<e>>>0){w[f+104>>2]=1;w[f+108>>2]=10;break c}v[f+2524>>1]=x[b+5|0]|x[b+6|0]<<8;w[f+2520>>2]=x[b+1|0]|x[b+2|0]<<8|(x[b+3|0]<<16|x[b+4|0]<<24);w[f+40>>2]=e;if(Jb(f+2520|0,82860,6)){w[f+108>>2]=34;break c}if(we(f+8|0)){w[f+108>>2]=34;break c}i:{b=w[f+40>>2];j:{if(b>>>0>=z[f+48>>2]){w[f+12>>2]=0;w[f+104>>2]=1;break j}w[f+40>>2]=b+1;b=x[b|0];w[f+12>>2]=b;if(b){break i}}w[f+108>>2]=34;break c}if(b>>>0>=17){w[f+108>>2]=5;break c}b=we(f+8|0);w[f+8>>2]=b;if(!b){w[f+108>>2]=34;break c}we(f+8|0);we(f+8|0);we(f+8|0);b=w[f+40>>2];h=w[f+48>>2];k:{if(b>>>0>=h>>>0){w[f+104>>2]=1;e=0;break k}g=b+1|0;w[f+40>>2]=g;e=x[b|0];b=g}g=e&15;w[f+120>>2]=1<<g;i=e>>>4&15;w[f+124>>2]=1<<i;if(g-14>>>0<=4294967287){w[f+108>>2]=20;break c}if((e<<24)+536870912>>24>=0){w[f+108>>2]=20;break c}if(g>>>0>i>>>0){w[f+108>>2]=20;break c}l:{m:{if(b>>>0>=h>>>0){w[f+104>>2]=1;break m}w[f+40>>2]=b+1;if(u[b|0]&1){break l}}w[f+108>>2]=34;break c}if(!Pj(f+8|0)){break c}if(!Km(f+8|0)){break c}if(!Im(f+8|0)){break c}e=0;b=Dc(f+8|0);w[f+1404>>2]=0;n:{if((b|0)==3){while(1){O=(f+2520|0)+e|0,P=Dc(f+8|0),u[O|0]=P;w[f+1404>>2]=0;e=e+1|0;if((e|0)!=6){continue}break}if(Jb(f+2520|0,82860,6)){w[f+108>>2]=20;break c}b=f+8|0;g=Hm(b);b=yc(b,g+1|0);w[f+28>>2]=b;if(b){e=0;if((g|0)>0){while(1){b=Dc(f+8|0);w[f+1404>>2]=0;u[w[f+28>>2]+e|0]=b;e=e+1|0;if((g|0)!=(e|0)){continue}break}b=w[f+28>>2]}u[b+g|0]=0;b=Hm(f+8|0);w[f+36>>2]=0;w[f+32>>2]=b;o:{p:{if((b|0)<=0){break p}b=yc(f+8|0,b<<2);w[f+36>>2]=b;if(!b){w[f+108>>2]=3;break c}if(w[f+32>>2]<=0){break p}g=0;while(1){b=f+8|0;h=Hm(b);b=yc(b,h+1|0);i=g<<2;w[i+w[f+36>>2]>>2]=b;b=w[i+w[f+36>>2]>>2];if(!b){break o}e=0;if((h|0)>0){while(1){b=Dc(f+8|0);w[f+1404>>2]=0;u[w[i+w[f+36>>2]>>2]+e|0]=b;e=e+1|0;if((h|0)!=(e|0)){continue}break}b=w[i+w[f+36>>2]>>2]}u[b+h|0]=0;g=g+1|0;if((g|0)<w[f+32>>2]){continue}break}}b=Dc(f+8|0);w[f+1404>>2]=0;if(!(b&1)){w[f+108>>2]=20;break c}b=w[f+40>>2]+x[f+1384|0]|0;w[f+40>>2]=b;if(b>>>0>=z[f+48>>2]){w[f+104>>2]=1}u[f+1384|0]=0;while(1){b=Im(f+8|0);e=b+w[f+40>>2]|0;w[f+40>>2]=e;if(e>>>0>=z[f+48>>2]){w[f+104>>2]=1}u[f+1384|0]=0;if(b){continue}break}if(!Km(f+8|0)){break c}q:{r:{if(vu(f+8|0)){i=0;while(1){e=i<<24;b=0;while(1){e=e>>31&79764919^e<<1;b=b+1|0;if((b|0)!=8){continue}break}w[(i<<2)+455312>>2]=e;i=i+1|0;if((i|0)!=256){continue}break}e=0;b=Dc(f+8|0);w[f+1404>>2]=0;if((b|0)!=5){break q}while(1){O=(f+2520|0)+e|0,P=Dc(f+8|0),u[O|0]=P;w[f+1404>>2]=0;e=e+1|0;if((e|0)!=6){continue}break}if(!Jb(f+2520|0,82860,6)){break r}w[f+108>>2]=20;break c}if(w[f+108>>2]!=21){break c}w[f+108>>2]=20;break c}b=f+8|0;e=Nb(b,8)+1|0;w[f+128>>2]=e;b=yc(b,C(e,2096));w[f+132>>2]=b;if(!b){w[f+108>>2]=3;break c}Cb(b,0,C(w[f+128>>2],2096));s:{if(w[f+128>>2]>0){while(1){n=w[f+132>>2];if((Nb(f+8|0,8)&255)!=66){w[f+108>>2]=20;break c}if((Nb(f+8|0,8)&255)!=67){w[f+108>>2]=20;break c}if((Nb(f+8|0,8)&255)!=86){w[f+108>>2]=20;break c}g=n+C(B,2096)|0;b=f+8|0;O=g,P=Nb(b,8)&255|Nb(b,8)<<8,w[O>>2]=P;O=g,P=Nb(f+8|0,8)&255|(Nb(f+8|0,8)<<8&65280|Nb(f+8|0,8)<<16),w[O+4>>2]=P;e=0;h=Nb(b,1);if(!h){e=Nb(f+8|0,1)}u[g+23|0]=e;m=g+4|0;b=w[m>>2];t:{if(w[g>>2]){i=b;break t}i=0;if(!b){break t}w[f+108>>2]=20;break c}u:{v:{w:{if(e&255){b=i+7&-8;e=w[f+88>>2];if(e){b=w[f+100>>2]-b|0;if((b|0)<w[f+96>>2]){break v}w[f+100>>2]=b;j=b+e|0;break w}j=fc(b);break w}j=yc(f+8|0,i);w[g+8>>2]=j}if(j){break u}}w[f+108>>2]=3;break c}x:{if(!h){e=0;l=0;b=w[m>>2];if((b|0)<=0){break x}while(1){y:{z:{if(x[g+23|0]){if(!Nb(f+8|0,1)){break z}}b=Nb(f+8|0,5)+1|0;u[e+j|0]=b;if((b&255)!=32){l=l+1|0;break y}w[f+108>>2]=20;break c}u[e+j|0]=255}b=w[m>>2];e=e+1|0;if((b|0)>(e|0)){continue}break}break x}i=Nb(f+8|0,5);l=0;e=0;b=w[m>>2];if((b|0)<=0){break x}while(1){b=Nb(f+8|0,ig(b-e|0));i=i+1|0;if((i|0)>=32){w[f+108>>2]=20;break c}h=b+e|0;if((h|0)>w[m>>2]){w[f+108>>2]=20;break c}Cb(e+j|0,i,b);b=w[m>>2];e=h;if((b|0)>(e|0)){continue}break}}A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if(x[g+23|0]){if(b>>2>(l|0)){break L}e=f+8|0;if(w[f+24>>2]<(b|0)){w[f+24>>2]=b;b=w[m>>2]}b=yc(e,b);w[g+8>>2]=b;if(!b){w[f+108>>2]=3;break c}Fb(b,j,w[m>>2]);M:{if(w[f+88>>2]){w[f+100>>2]=w[f+100>>2]+(w[m>>2]+7&-8);break M}zb(j)}j=w[g+8>>2];u[g+23|0]=0;b=w[m>>2]}n=0;e=0;i=0;if((b|0)>0){while(1){i=((x[e+j|0]-11&255)>>>0<244)+i|0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}w[g+2092>>2]=i;b=yc(f+8|0,b<<2);w[g+32>>2]=b;if(b){p=g+2092|0;break K}w[f+108>>2]=3;break c}w[g+2092>>2]=l;p=g+2092|0;N:{if(!l){n=0;e=0;break N}b=yc(f+8|0,l);w[g+8>>2]=b;if(!b){w[f+108>>2]=3;break c}b=(w[p>>2]<<2)+7&-8;O:{e=w[f+88>>2];P:{Q:{if(e){b=w[f+100>>2]-b|0;if((b|0)<w[f+96>>2]){w[(n+C(B,2096)|0)+32>>2]=0;break P}w[f+100>>2]=b;b=b+e|0;break Q}b=fc(b)}w[g+32>>2]=b;if(b){break O}}w[f+108>>2]=3;break c}b=(w[p>>2]<<2)+7&-8;e=w[f+88>>2];R:{if(e){b=w[f+100>>2]-b|0;if((b|0)<w[f+96>>2]){break J}w[f+100>>2]=b;n=b+e|0;break R}n=fc(b)}if(!n){break J}b=w[m>>2];e=w[p>>2]}b=(e<<3)+b|0;if(b>>>0<=z[f+24>>2]){break K}w[f+24>>2]=b}i=w[m>>2];b=0;Cb(f+1520|0,0,128);S:{T:{U:{V:{if((i|0)<=0){break V}while(1){if(x[b+j|0]!=255){break V}b=b+1|0;if((i|0)!=(b|0)){continue}break}break U}if((b|0)!=(i|0)){break T}}if(!w[g+2092>>2]){break S}ha(11633,9008,1103,3800);M()}h=b+j|0;k=x[h|0];if(k>>>0>=32){break I}e=w[g+32>>2];W:{if(!x[g+23|0]){w[e+(b<<2)>>2]=0;break W}w[e>>2]=0;u[w[g+8>>2]]=k;w[n>>2]=b}h=x[h|0];if(h){e=1;while(1){w[(f+1520|0)+(e<<2)>>2]=1<<32-e;k=(e|0)==(h|0);e=e+1|0;if(!k){continue}break}}k=b+1|0;if((i|0)<=(k|0)){break S}h=1;while(1){F=j+k|0;b=x[F|0];X:{if((b|0)==255){break X}if(b>>>0>31){break H}Y:{e=b;if(b){while(1){o=(f+1520|0)+(e<<2)|0;l=w[o>>2];if(l){break Y}l=(e|0)>1;e=e-1|0;if(l){continue}break}}if(!(w[f+88>>2]|!x[g+23|0])){zb(n)}w[f+108>>2]=20;break c}w[o>>2]=0;o=l<<8&16711680|l<<24|(l>>>8&65280|l>>>24);o=o>>>4&252645135|(o&252645135)<<4;o=o>>>2&858993459|(o&858993459)<<2;o=o>>>1&1431655765|(o&1431655765)<<1;q=w[g+32>>2];Z:{if(!x[g+23|0]){w[q+(k<<2)>>2]=o;break Z}H=q;q=h<<2;w[H+q>>2]=o;u[w[g+8>>2]+h|0]=b;w[n+q>>2]=k}h=h+1|0;b=x[F|0];if(e>>>0>=b>>>0){break X}while(1){o=(f+1520|0)+(b<<2)|0;if(w[o>>2]){break G}w[o>>2]=l+(1<<32-b);b=b-1|0;if((e|0)<(b|0)){continue}break}}k=k+1|0;if((i|0)!=(k|0)){continue}break}}b=w[p>>2];if(!b){break E}b=yc(f+8|0,(b<<2)+4|0);w[g+2084>>2]=b;if(!b){w[f+108>>2]=3;break c}b=yc(f+8|0,(w[p>>2]<<2)+4|0);w[g+2088>>2]=b;if(!b){w[f+108>>2]=3;break c}i=g+2084|0;k=g+2088|0;w[k>>2]=b+4;w[b>>2]=-1;if(x[g+23|0]){e=w[g+2092>>2];if((e|0)<=0){break F}h=g+2092|0;b=0;while(1){l=b<<2;e=w[l+w[g+32>>2]>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=e>>>4&252645135|(e&252645135)<<4;e=e>>>2&858993459|(e&858993459)<<2;w[l+w[i>>2]>>2]=e>>>1&1431655765|(e&1431655765)<<1;b=b+1|0;e=w[h>>2];if((b|0)<(e|0)){continue}break}break F}_:{if(w[m>>2]<=0){e=0;break _}b=0;e=0;while(1){if(pu(g,x[b+j|0])){h=w[w[g+32>>2]+(b<<2)>>2];h=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=h>>>4&252645135|(h&252645135)<<4;h=h>>>2&858993459|(h&858993459)<<2;w[w[i>>2]+(e<<2)>>2]=h>>>1&1431655765|(h&1431655765)<<1;e=e+1|0}b=b+1|0;if((b|0)<w[m>>2]){continue}break}}if(w[g+2092>>2]==(e|0)){break F}ha(3741,9008,1200,5927);M()}w[f+108>>2]=3;break c}ha(10716,9008,1104,3800);M()}ha(10709,9008,1118,3800);M()}ha(11677,9008,1133,3800);M()}_t(w[i>>2],e,1552);w[w[i>>2]+(w[g+2092>>2]<<2)>>2]=-1;H=g+2092|0;e=x[g+23|0];J=w[(e?H:m)>>2];if((J|0)<=0){break D}h=0;while(1){K=x[(x[g+23|0]?w[(h<<2)+n>>2]:h)+j|0];$:{if(!pu(g,K)){break $}L=h<<2;b=w[L+w[g+32>>2]>>2];b=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);b=b>>>4&252645135|(b&252645135)<<4;b=b>>>2&858993459|(b&858993459)<<2;l=b>>>1&1431655765|(b&1431655765)<<1;o=w[i>>2];e=0;b=w[H>>2];if((b|0)>=2){while(1){q=b>>>1|0;N=q+e|0;F=l>>>0<z[o+(N<<2)>>2];e=F?e:N;b=F?q:b-q|0;if((b|0)>1){continue}break}}b=e<<2;if((l|0)!=w[b+o>>2]){break C}if(x[g+23|0]){w[b+w[k>>2]>>2]=w[n+L>>2];u[w[g+8>>2]+e|0]=K;break $}w[b+w[k>>2]>>2]=h}h=h+1|0;if((J|0)!=(h|0)){continue}break}}e=x[g+23|0]}if(!(e&255)){Cb(g+36|0,255,2048);break B}aa:{ba:{ca:{da:{ea:{if(w[f+88>>2]){b=w[f+100>>2]+((w[p>>2]<<2)+7&-8)|0;w[f+100>>2]=b;e=g+32|0;break ea}zb(n);e=g+32|0;if(!w[f+88>>2]){break da}b=w[f+100>>2]}b=((w[p>>2]<<2)+7&-8)+b|0;w[f+100>>2]=b;break ca}zb(w[g+32>>2]);if(!w[f+88>>2]){break ba}b=w[f+100>>2]}w[f+100>>2]=(w[m>>2]+7&-8)+b;break aa}zb(j)}w[e>>2]=0;b=x[g+23|0];Cb(g+36|0,255,2048);if(!b){break B}b=g+2092|0;break A}ha(8024,9008,1230,5927);M()}b=m}b=w[b>>2];if((b|0)>0){h=(b|0)>=32767?32767:b;n=g+2084|0;i=w[g+8>>2];b=0;while(1){fa:{if(x[b+i|0]>10){break fa}ga:{if(x[g+23|0]){e=w[w[n>>2]+(b<<2)>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=e>>>4&252645135|(e&252645135)<<4;e=e>>>2&858993459|(e&858993459)<<2;e=e>>>1&1431655765|(e&1431655765)<<1;break ga}e=w[w[g+32>>2]+(b<<2)>>2]}if(e>>>0>1023){break fa}while(1){v[(g+(e<<1)|0)+36>>1]=b;i=w[g+8>>2];e=(1<<x[i+b|0])+e|0;if(e>>>0<1024){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=Nb(f+8|0,4);u[g+21|0]=b;b=b&255;if(b>>>0>=3){w[f+108>>2]=20;break c}ha:{if(!b){break ha}b=f+8|0;e=Nb(b,32);r=+((e&2097151)>>>0);O=g,Q=D(cu(+D((e|0)<0?-r:r),(e>>>21&1023)-788|0)),A[O+12>>2]=Q;e=Nb(b,32);r=+((e&2097151)>>>0);O=g,Q=D(cu(+D((e|0)<0?-r:r),(e>>>21&1023)-788|0)),A[O+16>>2]=Q;O=g,P=Nb(b,4)+1|0,u[O+20|0]=P;O=g,P=Nb(b,1),u[O+22|0]=P;h=w[g>>2];i=w[m>>2];ia:{if(x[g+21|0]==1){r=I(Em(+D(D($h(+D(i|0)))/D(h|0))));ja:{if(E(r)<2147483648){b=~~r;break ja}b=-2147483648}r=I(ym(+D(D(b|0)+D(1)),h));ka:{if(E(r)<2147483648){e=~~r;break ka}e=-2147483648}e=((e|0)<=(i|0))+b|0;t=D(e|0);la:{if(ym(+D(t+D(1)),h)<=+(i|0)){break la}r=I(ym(+t,h));ma:{if(E(r)<2147483648){b=~~r;break ma}b=-2147483648}if((b|0)>(i|0)){break la}if((e|0)>=0){break ia}}w[f+108>>2]=20;break c}e=C(h,i)}w[g+24>>2]=e;if(!e){w[f+108>>2]=20;break c}b=(e<<1)+7&-8;e=w[f+88>>2];na:{if(e){b=w[f+100>>2]-b|0;if((b|0)<w[f+96>>2]){break s}w[f+100>>2]=b;b=b+e|0;break na}b=fc(b)}if(!b){break s}e=0;j=w[g+24>>2];if((j|0)>0){while(1){h=Nb(f+8|0,x[g+20|0]);if((h|0)==-1){oa:{if(w[f+88>>2]){w[f+100>>2]=w[f+100>>2]+((w[g+24>>2]<<1)+7&-8);break oa}zb(b)}w[f+108>>2]=20;break c}v[b+(e<<1)>>1]=h;e=e+1|0;j=w[g+24>>2];if((e|0)<(j|0)){continue}break}}pa:{qa:{ra:{if(x[g+21|0]==1){i=x[g+23|0];sa:{if(i){e=w[p>>2];if(e){break sa}break ra}e=w[m>>2]}e=yc(f+8|0,C(w[g>>2],e)<<2);w[g+28>>2]=e;if(!e){ta:{if(w[f+88>>2]){w[f+100>>2]=w[f+100>>2]+((w[g+24>>2]<<1)+7&-8);break ta}zb(b)}w[f+108>>2]=3;break c}n=w[(i?p:m)>>2];if((n|0)>0){p=g+2088|0;t=D(0);h=0;while(1){m=i?w[w[p>>2]+(h<<2)>>2]:h;ua:{k=w[g>>2];if((k|0)<=0){break ua}l=w[g+24>>2];e=1;j=0;while(1){G=D(D(A[g+12>>2]+t)+D(A[g+16>>2]*D(y[b+(((m>>>0)/(e>>>0)>>>0)%(l>>>0)<<1)>>1])));A[w[g+28>>2]+(C(h,k)+j<<2)>>2]=G;t=x[g+22|0]?G:t;k=w[g>>2];j=j+1|0;if((k|0)<=(j|0)){break ua}l=w[g+24>>2];BV(l,0,e,0);if(nb){va:{if(w[f+88>>2]){w[f+100>>2]=w[f+100>>2]+((l<<1)+7&-8);break va}zb(b)}w[f+108>>2]=20;break c}else{e=C(e,l);continue}}}h=h+1|0;if((n|0)!=(h|0)){continue}break}}u[g+21|0]=2;break ra}e=yc(f+8|0,j<<2);w[g+28>>2]=e;if(!e){break qa}e=0;if(w[g+24>>2]<=0){break ra}t=D(0);while(1){G=D(D(A[g+12>>2]+t)+D(A[g+16>>2]*D(y[b+(e<<1)>>1])));A[w[g+28>>2]+(e<<2)>>2]=G;t=x[g+22|0]?G:t;e=e+1|0;if((e|0)<w[g+24>>2]){continue}break}}if(!w[f+88>>2]){break pa}w[f+100>>2]=w[f+100>>2]+((w[g+24>>2]<<1)+7&-8);break ha}wa:{if(w[f+88>>2]){w[f+100>>2]=w[f+100>>2]+((w[g+24>>2]<<1)+7&-8);break wa}zb(b)}w[f+108>>2]=3;break c}zb(b)}B=B+1|0;if((B|0)<w[f+128>>2]){continue}break}}xa:{b=Nb(f+8|0,6)+1&255;if(!b){break xa}while(1){if(!Nb(f+8|0,16)){s=s+1|0;if((b|0)!=(s|0)){continue}break xa}break}w[f+108>>2]=20;break c}b=f+8|0;e=Nb(b,6)+1|0;w[f+136>>2]=e;b=yc(b,C(e,1596));w[f+268>>2]=b;ya:{if(b){m=0;if(w[f+136>>2]>0){break ya}n=0;break n}w[f+108>>2]=3;break c}n=0;za:while(1){b=Nb(f+8|0,16);v[((m<<1)+f|0)+140>>1]=b;b=b&65535;if(b>>>0>=2){w[f+108>>2]=20;break c}if(!b){b=w[f+268>>2]+C(m,1596)|0;a=f+8|0;O=b,P=Nb(a,8),u[O|0]=P;O=b,P=Nb(a,16),v[O+2>>1]=P;O=b,P=Nb(a,16),v[O+4>>1]=P;O=b,P=Nb(a,6),u[O+6|0]=P;O=b,P=Nb(a,8),u[O+7|0]=P;a=(Nb(a,4)&255)+1|0;u[b+8|0]=a;if((a|0)==(a&255)){c=b+9|0;a=0;while(1){O=a+c|0,P=Nb(f+8|0,8),u[O|0]=P;a=a+1|0;if(a>>>0<x[b+8|0]){continue}break}}w[f+108>>2]=4;break c}e=w[f+268>>2]+C(m,1596)|0;b=Nb(f+8|0,5);u[e|0]=b;Aa:{if(b&255){g=e+1|0;b=-1;i=0;while(1){h=Nb(f+8|0,4);u[g+i|0]=h;h=h&255;b=(b|0)<(h|0)?h:b;i=i+1|0;if(i>>>0<x[e|0]){continue}break}j=e+82|0;k=e+65|0;l=e+49|0;p=e+33|0;g=0;while(1){i=f+8|0;O=g+p|0,P=Nb(i,3)+1|0,u[O|0]=P;h=g+l|0;i=Nb(i,2);u[h|0]=i;Ba:{if(i&255){i=Nb(f+8|0,8);u[g+k|0]=i;if(w[f+128>>2]<=(i&255)){break Aa}if(x[h|0]==31){break Ba}}i=0;while(1){s=Nb(f+8|0,8)-1|0;v[(j+(g<<4)|0)+(i<<1)>>1]=s;if(w[f+128>>2]<=s<<16>>16){break Aa}i=i+1|0;if((i|0)<1<<x[h|0]){continue}break}}h=(b|0)!=(g|0);g=g+1|0;if(h){continue}break}}b=f+8|0;O=e,P=Nb(b,2)+1|0,u[O+1588|0]=P;b=Nb(b,4);w[e+1592>>2]=2;v[e+338>>1]=0;u[e+1589|0]=b;v[e+340>>1]=1<<b;p=e+338|0;k=x[e|0];Ca:{if(k){g=e+33|0;h=e+1|0;l=0;i=2;while(1){b=0;j=g+x[h+l|0]|0;if(x[j|0]){while(1){i=Nb(f+8|0,x[e+1589|0]);v[p+(w[e+1592>>2]<<1)>>1]=i;i=w[e+1592>>2]+1|0;w[e+1592>>2]=i;b=b+1|0;if(b>>>0<x[j|0]){continue}break}k=x[e|0]}l=l+1|0;if(l>>>0<(k&255)>>>0){continue}break}if((i|0)<=0){break Ca}}b=0;while(1){g=y[p+(b<<1)>>1];h=(f+1520|0)+(b<<2)|0;v[h+2>>1]=b;v[h>>1]=g;b=b+1|0;i=w[e+1592>>2];if((b|0)<(i|0)){continue}break}}_t(f+1520|0,i,1553);i=w[e+1592>>2];g=((i|0)<=1?1:i)-1|0;b=0;while(1){if((b|0)==(g|0)){Da:{if((i|0)<=0){break Da}g=e+838|0;b=0;while(1){u[b+g|0]=x[((f+1520|0)+(b<<2)|0)+2|0];b=b+1|0;i=w[e+1592>>2];if((b|0)<(i|0)){continue}break}if((i|0)<3){break Da}B=e+1088|0;k=2;while(1){o=k<<1;s=o+p|0;g=-1;l=65536;j=0;h=0;b=0;while(1){i=y[p+(b<<1)>>1];if((i|0)>(g|0)){q=i>>>0<y[s>>1];g=q?i:g;j=q?b:j}if((i|0)<(l|0)){q=i;i=i>>>0>y[s>>1];l=i?q:l;h=i?b:h}b=b+1|0;if((k|0)!=(b|0)){continue}break}b=o+B|0;u[b+1|0]=h;u[b|0]=j;i=w[e+1592>>2];k=k+1|0;if((i|0)>(k|0)){continue}break}}n=(i|0)>(n|0)?i:n;m=m+1|0;if((m|0)<w[f+136>>2]){continue za}break n}h=f+1520|0;q=y[h+(b<<2)>>1];b=b+1|0;if((q|0)!=y[h+(b<<2)>>1]){continue}break}}break}w[f+108>>2]=20;break c}w[f+108>>2]=3;break c}w[f+108>>2]=20;break c}w[f+108>>2]=3;break c}w[f+108>>2]=3;break c}w[f+108>>2]=20;break c}b=f+8|0;e=Nb(b,6)+1|0;w[f+272>>2]=e;b=yc(b,C(e,24));w[f+404>>2]=b;if(!b){w[f+108>>2]=3;break c}s=0;Cb(b,0,C(w[f+272>>2],24));Ea:{Fa:{if(w[f+272>>2]>0){m=20;while(1){b=w[f+404>>2];e=Nb(f+8|0,16);v[((s<<1)+f|0)+276>>1]=e;if((e&65535)>>>0>2){break Ea}j=b+C(s,24)|0;O=j,P=Nb(f+8|0,24),w[O>>2]=P;b=Nb(f+8|0,24);w[j+4>>2]=b;if(b>>>0<z[j>>2]){break Ea}b=f+8|0;O=j,P=Nb(b,24)+1|0,w[O+8>>2]=P;O=j,P=Nb(b,6)+1|0,u[O+12|0]=P;b=Nb(b,8);u[j+13|0]=b;if(w[f+128>>2]<=(b&255)){break Ea}e=0;Ga:{if(!x[j+12|0]){b=0;break Ga}while(1){g=(f+1520|0)+e|0;b=f+8|0;h=Nb(b,3);if(Nb(b,1)){b=Nb(f+8|0,5)}else{b=0}u[g|0]=h+(b<<3);b=x[j+12|0];e=e+1|0;if(b>>>0>e>>>0){continue}break}}b=yc(f+8|0,b<<4);w[j+20>>2]=b;if(!b){break Fa}if(x[j+12|0]){k=0;while(1){b=x[(f+1520|0)+k|0];e=0;while(1){Ha:{if(b>>>e&1){g=Nb(f+8|0,8);i=e<<1;h=k<<4;v[i+(h+w[j+20>>2]|0)>>1]=g;if(w[f+128>>2]<=v[i+(h+w[j+20>>2]|0)>>1]){break Ea}break Ha}v[(w[j+20>>2]+(k<<4)|0)+(e<<1)>>1]=65535}e=e+1|0;if((e|0)!=8){continue}break}k=k+1|0;if(k>>>0<x[j+12|0]){continue}break}}b=yc(f+8|0,w[(w[f+132>>2]+C(x[j+13|0],2096)|0)+4>>2]<<2);w[j+16>>2]=b;if(!b){break Fa}h=0;Cb(b,0,w[(w[f+132>>2]+C(x[j+13|0],2096)|0)+4>>2]<<2);e=w[f+132>>2];b=x[j+13|0];if(w[(e+C(b,2096)|0)+4>>2]>0){while(1){e=w[C(b,2096)+e>>2];b=yc(f+8|0,e);k=h<<2;w[k+w[j+16>>2]>>2]=b;if(!w[k+w[j+16>>2]>>2]){break Fa}if((e|0)>0){i=x[j+12|0];b=h;while(1){g=e-1|0;u[g+w[k+w[j+16>>2]>>2]|0]=(b|0)%(i&255);i=x[j+12|0];b=(b|0)/(i|0)|0;l=e>>>0>1;e=g;if(l){continue}break}}h=h+1|0;e=w[f+132>>2];b=x[j+13|0];if((h|0)<w[(e+C(b,2096)|0)+4>>2]){continue}break}}s=s+1|0;if((s|0)<w[f+272>>2]){continue}break}}b=f+8|0;e=Nb(b,6)+1|0;w[f+408>>2]=e;b=yc(b,C(e,40));w[f+412>>2]=b;if(!b){w[f+108>>2]=3;break c}k=0;Cb(b,0,C(w[f+408>>2],40));if(w[f+408>>2]>0){while(1){b=w[f+412>>2];if(Nb(f+8|0,16)){w[f+108>>2]=20;break c}g=b+C(k,40)|0;b=yc(f+8|0,C(w[f+12>>2],3));w[g+4>>2]=b;if(!b){w[f+108>>2]=3;break c}if(Nb(f+8|0,1)){b=Nb(f+8|0,4)+1|0}else{b=1}u[g+8|0]=b;Ia:{if(Nb(f+8|0,1)){e=Nb(f+8|0,8)+1|0;v[g>>1]=e;Ja:{b=w[f+12>>2];e=e&65535;if((b|0)>=(e|0)){j=0;if(e){break Ja}break Ia}w[f+108>>2]=20;break c}while(1){h=f+8|0;b=Nb(h,ig(b-1|0));e=C(j,3);u[e+w[g+4>>2]|0]=b;b=Nb(h,ig(w[f+12>>2]-1|0));u[(e+w[g+4>>2]|0)+1|0]=b;b=w[f+12>>2];e=e+w[g+4>>2]|0;h=x[e|0];if((b|0)<=(h|0)){w[f+108>>2]=20;break c}e=x[e+1|0];if((e|0)>=(b|0)){w[f+108>>2]=20;break c}if((e|0)!=(h|0)){j=j+1|0;if(j>>>0>=y[g>>1]){break Ia}continue}break}w[f+108>>2]=20;break c}v[g>>1]=0}if(Nb(f+8|0,2)){w[f+108>>2]=20;break c}h=w[f+12>>2];Ka:{La:{e=x[g+8|0];if(e>>>0<=1){b=0;if((h|0)>0){while(1){u[(w[g+4>>2]+C(b,3)|0)+2|0]=0;b=b+1|0;if((b|0)<w[f+12>>2]){continue}break}e=x[g+8|0]}if(!(e&255)){break Ka}break La}b=0;if((h|0)<=0){break La}while(1){Ma:{e=Nb(f+8|0,4);h=C(b,3);u[(h+w[g+4>>2]|0)+2|0]=e;if(x[(h+w[g+4>>2]|0)+2|0]>=x[g+8|0]){break Ma}b=b+1|0;if((b|0)<w[f+12>>2]){continue}break La}break}w[f+108>>2]=20;break c}e=0;while(1){Nb(f+8|0,8);b=e+g|0;O=b+9|0,P=Nb(f+8|0,8),u[O|0]=P;h=Nb(f+8|0,8);u[b+24|0]=h;if(w[f+136>>2]<=x[b+9|0]){w[f+108>>2]=20;break c}if(w[f+272>>2]>(h&255)){e=e+1|0;if(e>>>0>=x[g+8|0]){break Ka}continue}break}w[f+108>>2]=20;break c}k=k+1|0;if((k|0)<w[f+408>>2]){continue}break}}b=Nb(f+8|0,6);w[f+416>>2]=b+1;Na:{if(b>>>0>=2147483647){break Na}h=f+420|0;b=0;while(1){e=h+C(b,6)|0;m=f+8|0;g=m;O=e,P=Nb(g,1),u[O|0]=P;O=e,P=Nb(g,16),v[O+2>>1]=P;O=e,P=Nb(g,16),v[O+4>>1]=P;g=Nb(g,8);u[e+1|0]=g;if(y[e+2>>1]){w[f+108>>2]=20;break c}if(y[e+4>>1]){w[f+108>>2]=20;break c}if(w[f+408>>2]>(g&255)){b=b+1|0;if((b|0)>=w[f+416>>2]){break Na}continue}break}w[f+108>>2]=20;break c}while(1){if((Dc(f+8|0)|0)!=-1){continue}break}w[f+1e3>>2]=0;if(w[f+12>>2]>0){h=n<<1;b=0;while(1){g=f+8|0;e=g+(b<<2)|0;O=e+800|0,P=yc(g,w[f+124>>2]<<2),w[O>>2]=P;O=e,P=yc(g,w[f+124>>2]<<1&2147483646),w[O+928>>2]=P;g=yc(g,h);w[e+996>>2]=g;i=w[e+800>>2];if(g?!i|!w[e+928>>2]:1){w[f+108>>2]=3;break c}Cb(i,0,w[f+124>>2]<<2);b=b+1|0;if((b|0)<w[f+12>>2]){continue}break}}if(!ou(f+8|0,0,w[f+120>>2])){break c}if(!ou(f+8|0,1,w[f+124>>2])){break c}b=w[f+124>>2];w[f+116>>2]=b;w[f+112>>2]=w[f+120>>2];h=b<<1&2147483646;m=w[f+272>>2];if((m|0)<=0){b=4}else{e=(b|0)/2|0;b=0;n=w[f+404>>2];i=0;while(1){g=n+C(i,24)|0;j=w[g+4>>2];q=e>>>0>j>>>0?j:e;j=w[g>>2];g=(q-(e>>>0>j>>>0?j:e)>>>0)/z[g+8>>2]|0;b=(b|0)<(g|0)?g:b;i=i+1|0;if((m|0)!=(i|0)){continue}break}b=(b<<2)+4|0}b=C(b,w[f+12>>2]);e=b>>>0<h>>>0?h:b;w[f+20>>2]=e;Oa:{Pa:{b=w[f+88>>2];if(!b){break Pa}g=w[f+100>>2];if((g|0)!=w[f+92>>2]){break Oa}if(g>>>0>=(e+w[f+96>>2]|0)+1512>>>0){break Pa}w[f+108>>2]=3;break c}w[f+60>>2]=w[f+1388>>2]==-1?x[f+56|0]?0:w[f+40>>2]-w[f+44>>2]|0:0;w[f+16>>2]=w[f+16>>2]+1512;Qa:{Ra:{if(b){e=w[f+96>>2];g=e+1512|0;if((g|0)>w[f+100>>2]){break Qa}w[f+96>>2]=g;e=b+e|0;break Ra}e=fc(1512)}if(!e){break Qa}O=c,P=w[Fb(e,f+8|0,1512)+32>>2]-a|0,w[O>>2]=P;w[d>>2]=0;break a}break b}ha(3568,9008,4196,4914);M()}m=3}w[f+108>>2]=m;break c}w[f+108>>2]=34}w[d>>2]=w[f+104>>2]?1:w[f+108>>2]}wu(f+8|0);e=0}jb=f+2528|0;return e|0}function XC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,B=0;d=jb-400|0;jb=d;w[b+8>>2]=0;a:{if(!gl(b,d+392|0)|w[d+392>>2]!=1279544644|x[d+396|0]>31){break a}if(!c){t=1;break a}w[d+376>>2]=w[b>>2];e=w[b+4>>2];w[d+380>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=w[b+8>>2];b=w[b+12>>2];w[114256]=0;w[d+384>>2]=e;w[d+388>>2]=b;U(415,d+360|0,d+376|0,0);b=w[114256];w[114256]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((b|0)!=1){w[114256]=0;U(416,d+344|0,d+360|0,20041);b=w[114256];w[114256]=0;if((b|0)==1){break C}e=w[d+344>>2];b=w[w[e>>2]+8>>2];w[114256]=0;e=V(b|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}if(!e){break q}w[114256]=0;e=Q(417,d+344|0,d+248|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}if(!e){break q}w[114256]=0;T(236,a|0,16384);b=w[114256];w[114256]=0;if((b|0)==1){break u}w[a+480208>>2]=8;w[a+1074312>>2]=w[a+1074312>>2]&-1075839489|512;w[114256]=0;e=Q(1,d+232|0,4465)|0;b=w[114256];w[114256]=0;if((b|0)==1){break z}f=a+1304436|0;if(u[a+1304447|0]<0){zb(w[f>>2])}b=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=b;w[f+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+216|0,6662)|0;b=w[114256];w[114256]=0;if((b|0)==1){break y}f=a+1304448|0;if(u[a+1304459|0]<0){zb(w[f>>2])}b=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=b;w[f+8>>2]=w[e+8>>2];w[114256]=0;g=Q(1,d+200|0,13153)|0;b=w[114256];w[114256]=0;if((b|0)==1){break x}f=10603;b=x[d+396|0];switch(b-16|0){case 1:break v;case 0:break B;default:break A}}b=P()|0;break b}b=P()|0;break c}f=10522;break v}if(!b){break w}f=17256;break v}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}f=9081}w[114256]=0;h=Q(1,d+184|0,f|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}b=w[h>>2];e=w[h+4>>2];f=x[h+11|0];w[114256]=0;i=b;b=f<<24>>24<0;f=S(2,g|0,(b?i:h)|0,(b?e:f)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break g}e=w[f>>2];w[d+48>>2]=w[f+4>>2];b=x[f+7|0]|x[f+8|0]<<8|(x[f+9|0]<<16|x[f+10|0]<<24);u[d+51|0]=b;u[d+52|0]=b>>>8;u[d+53|0]=b>>>16;u[d+54|0]=b>>>24;w[f>>2]=0;w[f+4>>2]=0;b=x[f+11|0];w[f+8>>2]=0;if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}w[a+1304460>>2]=e;w[a+1304464>>2]=w[d+48>>2];f=a+1304467|0;e=x[d+51|0]|x[d+52|0]<<8|(x[d+53|0]<<16|x[d+54|0]<<24);u[f|0]=e;u[f+1|0]=e>>>8;u[f+2|0]=e>>>16;u[f+3|0]=e>>>24;u[a+1304471|0]=b;if(u[h+11|0]<0){zb(w[h>>2])}if(u[g+11|0]<0){zb(w[g>>2])}w[a+1304496>>2]=4;w[114256]=0;Y(209,d+48|0,3,d+248|0,32);b=w[114256];w[114256]=0;if((b|0)==1){break h}e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}b=w[d+52>>2];w[e>>2]=w[d+48>>2];w[e+4>>2]=b;w[e+8>>2]=w[d+56>>2];w[114256]=0;Y(209,d+168|0,3,d+280|0,20);b=w[114256];w[114256]=0;if((b|0)==1){break i}w[114256]=0;U(6,d+48|0,4,d+168|0);b=w[114256];w[114256]=0;if((b|0)==1){break j}e=a+1304412|0;if(u[a+1304423|0]<0){zb(w[e>>2])}b=w[d+52>>2];w[e>>2]=w[d+48>>2];w[e+4>>2]=b;w[e+8>>2]=w[d+56>>2];u[d+59|0]=0;u[d+48|0]=0;if(u[d+179|0]<0){zb(w[d+168>>2])}w[a+480200>>2]=x[d+304|0]+1;b=x[d+305|0];w[a+480196>>2]=b?b:1;b=x[d+306|0];w[a+480204>>2]=C(b>>>0<=4?4:b,1e4);e=x[a+484376|0];b=w[a+484360>>2];w[114256]=0;da(317,b+(e<<5)|0,d+344|0,y[d+300>>1],65535,65535)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=y[d+302>>1];v[a+480188>>1]=0;b=0;while(1){w[114256]=0;h=(b<<5)+a|0;g=h+480280|0;X(224,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break k}f=u[(b+d|0)+307|0];e=f<<1&254;v[h+480284>>1]=(e|0)==254?256:e;D:{if((f|0)<0){w[g>>2]=w[g>>2]|1024;break D}v[a+480188>>1]=b+1}w[114256]=0;S(418,d+344|0,h+480289|0,8)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}b=b+1|0;if((b|0)!=32){continue}break}w[114256]=0;U(416,d+48|0,d+360|0,17741);b=w[114256];w[114256]=0;if((b|0)==1){break l}e=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;f=w[d+348>>2];w[d+344>>2]=e;w[d+348>>2]=b;E:{if(!f){break E}b=w[f+4>>2];w[f+4>>2]=b-1;if(b){break E}ob[w[w[f>>2]+8>>2]](f);Ib(f)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;e=w[d+52>>2];F:{if(!e){break F}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break F}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[d+344>>2];b=w[w[e>>2]+24>>2];w[114256]=0;e=V(b|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}w[114256]=0;Z(320,a+1304424|0,d+344|0,e|0,0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}w[114256]=0;U(416,d+48|0,d+360|0,21321);b=w[114256];w[114256]=0;if((b|0)==1){break m}e=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;f=w[d+348>>2];w[d+344>>2]=e;w[d+348>>2]=b;G:{if(!f){b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;break G}b=w[f+4>>2];w[f+4>>2]=b-1;if(!b){ob[w[w[f>>2]+8>>2]](f);Ib(f)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;e=w[d+52>>2];if(!e){break G}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break G}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[d+344>>2];b=w[w[e>>2]+8>>2];w[114256]=0;e=V(b|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}H:{if(e){w[114256]=0;U(416,d+48|0,d+360|0,16723);b=w[114256];w[114256]=0;if((b|0)==1){break n}w[114256]=0;e=Q(241,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}h=x[d+168|0];I:{if(!(e&(h|0)!=0)){break I}g=c&2;while(1){w[114256]=0;e=Q(241,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}f=(e?x[d+168|0]:0)&255;if(!f){break I}e=w[d+344>>2];b=w[w[e>>2]+36>>2];w[114256]=0;e=S(b|0,e|0,w[d+352>>2],56)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}if(!e){break I}if(f>>>0>y[a+480190>>1]){v[a+480190>>1]=f}w[114256]=0;k=C(f,104)+a|0;n=k+484380|0;T(266,n|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break o}w[114256]=0;S(307,d+344|0,((f<<5)+a|0)+946304|0,32)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}w[114256]=0;S(310,d+344|0,k+484423|0,8)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}f=k+484404|0;J:{if(x[d+396|0]<=15){w[114256]=0;e=Q(197,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}b=e?y[d+168>>1]:0;break J}w[114256]=0;e=Q(232,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}b=e?w[d+168>>2]:0}w[f>>2]=b<<1;w[114256]=0;e=Q(232,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}w[n>>2]=e?w[d+168>>2]:0;w[114256]=0;e=Q(232,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}r=k+484384|0;w[r>>2]=e?w[d+168>>2]:0;w[114256]=0;e=Q(232,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}i=k+484388|0;e=e?w[d+168>>2]:0;w[i>>2]=e;if(e){b=k+484414|0;v[b>>1]=y[b>>1]|2;w[i>>2]=e+w[r>>2]}w[114256]=0;e=Q(241,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break H}if(x[d+396|0]<=15){v[k+484410>>1]=e?x[d+168|0]:0}w[114256]=0;e=Q(241,d+344|0,d+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}f=k+484414|0;b=y[f>>1];p=8;e=e?x[d+168|0]:0;if(e&1){b=b|1;v[f>>1]=b;w[n>>2]=w[n>>2]>>>1;w[r>>2]=w[r>>2]>>>1;w[i>>2]=w[i>>2]>>>1;p=16}v[f>>1]=b&65531|e<<1&4;u[d+171|0]=((e&12)!=0)<<3;u[d+169|0]=1;u[d+170|0]=0;u[d+168|0]=p;K:{if(!g){break K}w[114256]=0;S(214,d+168|0,n|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break K}break o}j=j+1|0;if(h>>>0>(j&255)>>>0){continue}break}}Bb(d+48|0)}w[114256]=0;U(416,d+48|0,d+360|0,18761);b=w[114256];w[114256]=0;if((b|0)==1){break t}e=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;f=w[d+348>>2];w[d+344>>2]=e;w[d+348>>2]=b;L:{if(!f){b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;break L}b=w[f+4>>2];w[f+4>>2]=b-1;if(!b){ob[w[w[f>>2]+8>>2]](f);Ib(f)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;e=w[d+52>>2];if(!e){break L}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break L}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[d+344>>2];b=w[w[e>>2]+8>>2];w[114256]=0;e=V(b|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}if(!e){break r}w[114256]=0;w[d+176>>2]=0;w[d+168>>2]=0;w[d+172>>2]=0;w[d+160>>2]=0;w[d+152>>2]=0;w[d+156>>2]=0;w[d+144>>2]=0;w[d+136>>2]=0;w[d+140>>2]=0;U(416,d+120|0,d+360|0,17750);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;b=w[d+132>>2];w[d+40>>2]=w[d+128>>2];w[d+44>>2]=b;b=w[d+124>>2];w[d+32>>2]=w[d+120>>2];w[d+36>>2]=b;T(419,d+32|0,d+168|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(416,d+104|0,d+360|0,17744);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;b=w[d+116>>2];w[d+24>>2]=w[d+112>>2];w[d+28>>2]=b;b=w[d+108>>2];w[d+16>>2]=w[d+104>>2];w[d+20>>2]=b;T(419,d+16|0,d+152|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(416,d+88|0,d+360|0,17734);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;b=w[d+100>>2];w[d+8>>2]=w[d+96>>2];w[d+12>>2]=b;b=w[d+92>>2];w[d>>2]=w[d+88>>2];w[d+4>>2]=b;T(419,d|0,d+136|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;e=Q(241,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}t=x[d+48|0];if(!(e&(t|0)!=0)){break s}k=d+80|2;p=0;while(1){e=w[d+344>>2];b=w[w[e>>2]+36>>2];w[114256]=0;e=S(b|0,e|0,w[d+352>>2],2)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}M:{N:{O:{if(e){w[d+52>>2]=k;w[d+48>>2]=d+80;e=w[d+344>>2];b=w[w[e>>2]+32>>2];w[114256]=0;e=S(b|0,e|0,w[d+352>>2],d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}f=e+w[d+352>>2]|0;w[d+352>>2]=f;if(!x[d+80|0]){break O}e=w[d+344>>2];b=w[w[e>>2]+36>>2];w[114256]=0;e=S(b|0,e|0,f|0,C(x[d+81|0],14)+32|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break M}if(!e){break O}w[114256]=0;l=S(243,a|0,x[d+80|0],0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break M}if(!l){break O}w[114256]=0;S(307,d+344|0,l+492|0,32)|0;b=w[114256];w[114256]=0;if((b|0)==1){break M}if(!x[d+81|0]){break N}n=l+88|0;r=l+68|0;i=l+48|0;h=l+236|0;j=0;b=0;while(1){w[114256]=0;f=Q(420,d+344|0,d+48|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break p}P:{if(!f){break P}e=x[d+48|0];if(!e|e>>>0>y[a+480190>>1]){break P}f=x[d+49|0];if(f>>>0>=129){u[d+49|0]=128;f=128}if((b&255)>>>0<=f>>>0){while(1){v[h+((b&255)<<1)>>1]=x[d+48|0];f=x[d+49|0];b=b+1|0;if(f>>>0>=(b&255)>>>0){continue}break}}w[114256]=0;U(421,i|0,x[d+51|0],d+168|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(421,r|0,x[d+53|0],d+152|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(421,n|0,x[d+61|0],d+136|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}w[l>>2]=y[d+54>>1]+1>>>1;e=x[d+48|0];Q:{if(x[d+51|0]&64){v[(C(e,104)+a|0)+484410>>1]=x[d+50|0];break Q}b=(C(e,104)+a|0)+484414|0;v[b>>1]=y[b>>1]|32768}m=C(e,104)+a|0;b=x[d+52|0]<<1;v[m+484408>>1]=b>>>0>=254?254:b;u[m+484418|0]=x[(x[d+59|0]&3)+23587|0];e=m+484419|0;q=x[d+58|0];u[e|0]=q;g=x[d+57|0]+3>>>2|0;u[m+484420|0]=g;u[m+484421|0]=x[d+56|0];b=f+1|0;if(q){f=((g<<8|q>>>1)>>>0)/(q>>>0)|0;f=f>>>0>=255?255:f}else{f=255}u[e|0]=f;if(!(x[d+53|0]&64)){break P}e=m+484414|0;v[e>>1]=y[e>>1]|32}j=j+1|0;if(x[d+81|0]>(j&255)>>>0){continue}break}break N}v[d+80>>1]=0}e=w[d+344>>2];b=w[w[e>>2]+36>>2];w[114256]=0;f=C(x[d+81|0],14)+32|0;e=S(b|0,e|0,w[d+352>>2],f|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break M}R:{if(e){b=f+w[d+352>>2]|0;break R}e=w[d+344>>2];b=w[w[e>>2]+24>>2];w[114256]=0;b=V(b|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break M}}w[d+352>>2]=b}p=p+1|0;if(t>>>0>(p&255)>>>0){continue}break s}break}break p}break o}b=P()|0;break d}b=P()|0;break d}b=w[d+136>>2];if(b){w[d+140>>2]=b;zb(b)}b=w[d+152>>2];if(b){w[d+156>>2]=b;zb(b)}b=w[d+168>>2];if(!b){break r}w[d+172>>2]=b;zb(b)}w[d+176>>2]=0;w[d+168>>2]=0;w[d+172>>2]=0;t=1;S:{if(!(c&1)){break S}w[114256]=0;U(416,d+48|0,d+360|0,21076);b=w[114256];w[114256]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((b|0)!=1){c=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;e=w[d+348>>2];w[d+344>>2]=c;w[d+348>>2]=b;ba:{if(!e){break ba}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break ba}ob[w[w[e>>2]+8>>2]](e);Ib(e)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;c=w[d+344>>2];b=w[w[c>>2]+8>>2];w[114256]=0;c=V(b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break U}Bb(d+48|0);ca:{if(!c){break ca}w[114256]=0;c=Q(197,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break V}w[114256]=0;g=c?y[d+48>>1]:0;T(422,d+168|0,g+1|0);b=w[114256];w[114256]=0;if((b|0)==1){break V}if(!g){break ca}f=1;while(1){w[114256]=0;c=Q(197,d+344|0,d+152|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break W}w[114256]=0;U(188,d+48|0,d+344|0,(c?y[d+152>>1]:0)|0);b=w[114256];w[114256]=0;if((b|0)==1){break W}b=f;e=w[d+168>>2]+(b<<4)|0;he(e,d+48|0);c=w[d+60>>2];w[e+8>>2]=w[d+56>>2];w[e+12>>2]=c;e=w[d+52>>2];da:{if(!e){break da}c=w[e+4>>2];w[e+4>>2]=c-1;if(c){break da}ob[w[w[e>>2]+8>>2]](e);Ib(e)}f=b+1|0;if((b|0)!=(g|0)){continue}break}}w[114256]=0;U(416,d+48|0,d+360|0,16720);b=w[114256];w[114256]=0;if((b|0)==1){break X}c=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;e=w[d+348>>2];w[d+344>>2]=c;w[d+348>>2]=b;ea:{if(!e){break ea}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break ea}ob[w[w[e>>2]+8>>2]](e);Ib(e)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;c=w[d+344>>2];b=w[w[c>>2]+8>>2];w[114256]=0;c=V(b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Y}Bb(d+48|0);fa:{if(!c){break fa}c=0;w[114256]=0;e=Q(241,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Z}z=e?x[d+48|0]:0;if(z){while(1){f=32;ga:{if(x[d+396|0]>=16){w[114256]=0;e=Q(423,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break aa}f=(e?x[d+48|0]:0)&255;if(!(f>>>0>32|y[a+480188>>1]>=f>>>0)){v[a+480188>>1]=f}if(!f){break ga}}b=0;while(1){w[114256]=0;g=Q(197,d+344|0,d+48|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $}if(!(!g|(!y[d+48>>1]|b>>>0>31)|y[a+480188>>1]>b>>>0)){v[a+480188>>1]=b+1}b=b+1|0;if((f|0)!=(b|0)){continue}break}}c=c+1|0;if(z>>>0>(c&65535)>>>0){continue}break}}ha:{if(!w[d+352>>2]){c=w[d+344>>2];b=w[w[c>>2]+24>>2];w[114256]=0;c=V(b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Z}if(!c){break ha}}w[d+352>>2]=1}w[114256]=0;s=a+484344|0;T(215,s|0,z|0);b=w[114256];w[114256]=0;if((b|0)==1){break Z}if(!z){break fa}r=d+48|2;while(1){w[d+160>>2]=0;w[d+152>>2]=0;w[d+156>>2]=0;ia:{if(x[d+396|0]<16){l=32;e=64;break ia}w[114256]=0;c=Q(423,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}ja:{if(c){j=x[d+48|0];b=x[d+49|0];break ja}v[d- -64>>1]=0;w[d+56>>2]=0;w[d+60>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0;j=0;b=0}w[114256]=0;Y(209,d+136|0,3,r|0,16);c=w[114256];w[114256]=0;if((c|0)==1){break _}if(u[d+163|0]<0){zb(w[d+152>>2])}l=j&255;w[d+160>>2]=w[d+144>>2];c=w[d+140>>2];w[d+152>>2]=w[d+136>>2];w[d+156>>2]=c;e=(b&255)+1|0}w[114256]=0;c=S(216,s|0,B&65535,e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}ka:{if(!c){c=w[d+344>>2];b=w[w[c>>2]+36>>2];w[114256]=0;e=l<<1;c=S(b|0,c|0,w[d+352>>2],e|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}la:{if(c){b=e+w[d+352>>2]|0;break la}c=w[d+344>>2];b=w[w[c>>2]+24>>2];w[114256]=0;b=V(b|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break _}}w[d+352>>2]=b;break ka}b=w[s>>2];w[114256]=0;q=C(B,52);Q(270,q+b|0,d+152|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}if(!l){break ka}j=0;while(1){w[114256]=0;c=Q(197,d+344|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}ma:{if(!c){break ma}f=y[d+48>>1];if(!f){break ma}b=w[d+168>>2];if(y[a+480188>>1]<=j>>>0|f>>>0>=w[d+172>>2]-b>>4>>>0){break ma}c=0;o=b+(f<<4)|0;w[o+8>>2]=0;while(1){g=w[o+8>>2];f=w[o>>2];b=w[w[f>>2]+36>>2];w[114256]=0;f=S(b|0,f|0,g|0,1)|0;b=w[114256];w[114256]=0;na:{oa:{pa:{qa:{ra:{sa:{if((b|0)!=1){if(!f){break ma}b=w[s>>2];w[114256]=0;f=b+q|0;g=V(218,f|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}A=w[f>>2];w[114256]=0;f=Q(241,o|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}m=C(C(c,g)+j|0,6);b=m+A|0;k=f?x[d+48|0]:0;f=(k&252)>>>2|0;switch((k&3)-1|0){case 2:break pa;case 1:break qa;case 0:break ra;default:break sa}}break _}c=(c+f|0)+1|0;break na}if(!c){c=0;break na}g=w[s>>2];w[114256]=0;i=g+q|0;h=V(218,i|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){h=w[i>>2]+C(C(h,c-1|0)+j|0,6)|0;while(1){g=x[h|0]|x[h+1|0]<<8|(x[h+2|0]<<16|x[h+3|0]<<24);u[b|0]=g;u[b+1|0]=g>>>8;u[b+2|0]=g>>>16;u[b+3|0]=g>>>24;g=x[h+4|0]|x[h+5|0]<<8;u[b+4|0]=g;u[b+5|0]=g>>>8;c=c+1|0;if(e>>>0<=c>>>0){break na}b=C(y[a+480188>>1],6)+b|0;g=f&255;f=f-1|0;if(g){continue}break}break na}break _}if(c>>>0<=f>>>0){break oa}g=w[s>>2];w[114256]=0;i=g+q|0;h=V(218,i|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break _}g=w[i>>2]+C(C(f,h)+j|0,6)|0;f=x[g|0]|x[g+1|0]<<8|(x[g+2|0]<<16|x[g+3|0]<<24);u[b|0]=f;u[b+1|0]=f>>>8;u[b+2|0]=f>>>16;u[b+3|0]=f>>>24;f=x[g+4|0]|x[g+5|0]<<8;u[b+4|0]=f;u[b+5|0]=f>>>8;break oa}if(f&1){w[114256]=0;h=Q(241,o|0,d+48|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break _}i=b;b=h?x[d+48|0]:0;u[i|0]=(b&255)>>>0>120?-1:b}if(f&2){w[114256]=0;g=Q(241,o|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}u[(m+A|0)+1|0]=g?x[d+48|0]:0}n=0;p=0;if(f&4){w[114256]=0;g=Q(241,o|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}p=g?x[d+48|0]:0}b=0;if(f&8){w[114256]=0;g=Q(241,o|0,d+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}b=g?x[d+48|0]:0;n=b&15;b=(b&240)>>>4|0}i=0;h=0;if(f&16){w[114256]=0;g=Q(241,o|0,d+48|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break _}h=g?x[d+48|0]:0}if(k<<24>>24<0){w[114256]=0;g=Q(241,o|0,d+48|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break _}i=g?x[d+48|0]:0}u[d+136|0]=n;u[d+399|0]=h;u[d+398|0]=i;u[d+80|0]=b;if(b-1>>>0<=5){u[d+80|0]=b+15}Lp(d+136|0,d+399|0);Lp(d+80|0,d+398|0);ta:{if(x[d+136|0]==10){u[d+399|0]=x[d+399|0]&15?-1:x[d+398|0];if(x[d+80|0]!=10){break ta}u[d+80|0]=0;break ta}if(x[d+80|0]!=10){break ta}u[d+398|0]=x[d+398|0]&15?-1:0}f=p&255;if(f){b=m+A|0;u[b+2|0]=1;u[b+4|0]=f+2>>>2}w[114256]=0;Z(424,d+136|0,d+399|0,d+80|0,d+398|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}g=x[d+136|0];ua:{if(!g){break ua}b=x[d+80|0];if(!b){u[d+80|0]=g;u[d+398|0]=x[d+399|0];break ua}if((b|0)==(g|0)&(g|0)!=20){break ua}if(!f){w[114256]=0;ga(272,d+48|0,d+136|0,d+399|0,d+80|0,d+398|0);b=w[114256];w[114256]=0;if((b|0)==1){break _}b=m+A|0;u[b+2|0]=x[d+136|0];u[b+4|0]=x[d+399|0];break ua}w[114256]=0;g=V(425,g|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}w[114256]=0;f=V(425,x[d+80|0])|0;b=w[114256];w[114256]=0;if((b|0)==1){break _}if(f>>>0>=g>>>0){break ua}u[d+80|0]=x[d+136|0];u[d+398|0]=x[d+399|0]}b=m+A|0;u[b+3|0]=x[d+80|0];u[b+5|0]=x[d+398|0]}c=c+1|0}if(c>>>0<e>>>0){continue}break}}j=j+1|0;if((l|0)!=(j|0)){continue}break}}if(u[d+163|0]<0){zb(w[d+152>>2])}B=B+1|0;if((z|0)!=(B|0)){continue}break}}w[114256]=0;U(416,d+48|0,d+360|0,20048);b=w[114256];w[114256]=0;va:{wa:{xa:{if((b|0)!=1){c=w[d+48>>2];b=w[d+52>>2];w[d+48>>2]=0;w[d+52>>2]=0;e=w[d+348>>2];w[d+344>>2]=c;w[d+348>>2]=b;ya:{if(!e){break ya}b=w[e+4>>2];w[e+4>>2]=b-1;if(b){break ya}ob[w[w[e>>2]+8>>2]](e);Ib(e)}b=w[d+60>>2];w[d+352>>2]=w[d+56>>2];w[d+356>>2]=b;c=w[d+344>>2];b=w[w[c>>2]+8>>2];w[114256]=0;c=V(b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break xa}Bb(d+48|0);if(!c|!((w[a+484348>>2]-w[a+484344>>2]|0)/52&65535)){break S}while(1){c=w[d+344>>2];b=w[w[c>>2]+36>>2];w[114256]=0;c=S(b|0,c|0,w[d+352>>2],16)|0;b=w[114256];w[114256]=0;if((b|0)==1){break wa}if(!c){break S}w[114256]=0;S(426,d+344|0,d+48|0,16)|0;b=w[114256];w[114256]=0;if((b|0)==1){break va}b=w[a+484344>>2];w[114256]=0;S(227,b|0,d+48|0,17)|0;b=w[114256];w[114256]=0;if((b|0)==1){break va}if((w[a+484348>>2]-w[a+484344>>2]|0)/52&65535){continue}break}break S}b=P()|0;break T}b=P()|0;Bb(d+48|0);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;if(u[d+163|0]>=0){break T}zb(w[d+152>>2]);break T}b=P()|0;break T}b=P()|0;Bb(d+48|0);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;Bb(d+48|0)}gc(d+168|0);break d}gc(d+168|0)}b=w[d+348>>2];za:{if(!b){break za}a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break za}ob[w[w[b>>2]+8>>2]](b);Ib(b)}Ac(d+360|0);b=w[d+380>>2];if(!b){break a}a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break a}ob[w[w[b>>2]+8>>2]](b);Ib(b);break a}b=P()|0;a=w[d+136>>2];if(a){w[d+140>>2]=a;zb(a)}a=w[d+152>>2];if(a){w[d+156>>2]=a;zb(a)}a=w[d+168>>2];if(!a){break d}w[d+172>>2]=a;zb(a);break d}b=P()|0;Bb(d+48|0);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;if(u[d+179|0]>=0){break d}zb(w[d+168>>2]);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;if(u[h+11|0]>=0){break e}zb(w[h>>2]);break e}b=P()|0}if(u[g+11|0]>=0){break d}zb(w[g>>2])}Bb(d+344|0)}Ac(d+360|0)}Bb(d+376|0);R(b|0);M()}jb=d+400|0;return t|0}function TA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=jb-432|0;jb=f;w[b+8>>2]=0;e=jb-16|0;jb=e;g=w[b+8>>2];d=w[b>>2];i=f- -64|0;w[e+8>>2]=i;w[e+12>>2]=i+204;g=ob[w[w[d>>2]+32>>2]](d,g,e+8|0)|0;if((g|0)==204){d=w[b>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],204)|0){d=w[b+8>>2]+204|0;break a}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d}jb=e+16|0;b:{if((g|0)!=204){break b}if(!Wo(f- -64|0)){break b}if(!c){m=1;break b}tc(a,134217728);d=Hb(f+48|0,11218);g=w[d>>2];w[f+308>>2]=w[d+4>>2];e=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[f+311|0]=e;u[f+312|0]=e>>>8;u[f+313|0]=e>>>16;u[f+314|0]=e>>>24;w[d>>2]=0;w[d+4>>2]=0;e=x[d+11|0];w[d+8>>2]=0;w[114256]=0;u[f+315|0]=e;w[f+304>>2]=g;U(570,f+328|0,f+304|0,f- -64|4);e=w[114256];w[114256]=0;c:{d:{if((e|0)!=1){e=a+1304436|0;if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[f+332>>2];w[e>>2]=w[f+328>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+336>>2];u[f+339|0]=0;u[f+328|0]=0;if(u[f+315|0]<0){zb(w[f+304>>2])}if(u[d+11|0]<0){zb(w[d>>2])}e=a+1304448|0;d=Hb(f+328|0,5059);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+8>>2];w[a+480188>>2]=4;w[a+1304496>>2]=2;e=y[f+200>>1];w[a+480196>>2]=(e<<8|e>>>8)&65535;d=y[f+204>>1];q=Tb(44325e5/+(((d<<8|d>>>8)&65535)>>>0));e=-1;e:{if(q>=4294967295){break e}e=0;if(q<=0){break e}e=~~q>>>0;if(q<4294967296&q>=0){break e}e=0}w[a+480260>>2]=56;w[a+480264>>2]=13696;w[a+480204>>2]=e;Ze(w[a+484360>>2]+(x[a+484376|0]<<5)|0,f+72|0,x[f+70|0],65535,65535);w[f+40>>2]=0;w[f+32>>2]=0;w[f+36>>2]=0;w[f+24>>2]=0;w[f+16>>2]=0;w[f+20>>2]=0;f:{if(y[f+264>>1]){while(1){w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){if(!e){break c}e=y[f+328>>1];d=e<<8|e>>>8;if((d-4e3&65535)>>>0<61537){break c}n:{if(y[f+68>>1]!=512){e=y[f+266>>1];e=(e<<8|e>>>8)&65535;break n}w[114256]=0;e=Q(268,b|0,f+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break m}if(e){e=w[f+328>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)}else{e=0}e=e-2|0}w[114256]=0;U(188,f|0,b|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break l}g=y[a+480190>>1];e=d&65535;E=e>>>0<g>>>0?g:e;v[a+480190>>1]=E;w[114256]=0;i=C(e,104)+a|0;g=i+484380|0;T(266,g|0,1);d=w[114256];w[114256]=0;o:{p:{q:{r:{s:{t:{u:{if((d|0)==1){break u}d=y[f+68>>1];if(((d<<8|d>>>8)&65535)>>>0>1){break t}w[114256]=0;S(571,f|0,i+484423|0,31)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}d=w[f>>2];j=w[w[d>>2]+36>>2];w[114256]=0;d=S(j|0,d|0,w[f+8>>2],1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break u}v:{if(d){h=w[f+8>>2]+1|0;break v}d=w[f>>2];j=w[w[d>>2]+24>>2];w[114256]=0;h=V(j|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}}w[114256]=0;w[f+8>>2]=h;S(572,f|0,((e<<5)+a|0)+946304|0,30)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break s}}e=P()|0;break j}w[114256]=0;w[f+336>>2]=0;w[f+328>>2]=0;w[f+332>>2]=0;S(330,f|0,f+328|0,257)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}w[114256]=0;w[f+276>>2]=22;w[f+272>>2]=i+484423;Q(200,f+272|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}d=w[f>>2];j=w[w[d>>2]+36>>2];w[114256]=0;d=S(j|0,d|0,w[f+8>>2],1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}w:{if(d){h=w[f+8>>2]+1|0;break w}d=w[f>>2];j=w[w[d>>2]+24>>2];w[114256]=0;h=V(j|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}}w[114256]=0;w[f+8>>2]=h;S(330,f|0,f+328|0,31)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}w[114256]=0;w[f+276>>2]=32;w[f+272>>2]=((e<<5)+a|0)+946304;Q(200,f+272|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}d=w[f+8>>2];if(d&1){j=w[f>>2];h=w[w[j>>2]+36>>2];w[114256]=0;d=S(h|0,j|0,d|0,1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}x:{if(d){d=w[f+8>>2]+1|0;break x}d=w[f>>2];j=w[w[d>>2]+24>>2];w[114256]=0;d=V(j|0,d|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}}w[f+8>>2]=d}if(u[f+339|0]>=0){break s}zb(w[f+328>>2])}w[114256]=0;d=Q(573,f|0,f+328|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break o}if(!d){w[f+344>>2]=0;w[f+336>>2]=0;w[f+340>>2]=0;w[f+328>>2]=0;w[f+332>>2]=0}w[114256]=0;T(574,f+328|0,g|0);d=w[114256];w[114256]=0;if((d|0)==1){break o}d=1;g=y[f+68>>1];switch((g<<8|g>>>8)&65535){case 0:break g;case 2:break q;default:break p}}e=P()|0;if(u[f+339|0]>=0){break j}zb(w[f+328>>2]);break j}u[i+484417|0]=x[f+346|0]<<3}w[114256]=0;T(204,f+16|0,E|0);d=w[114256];w[114256]=0;if((d|0)==1){break o}w[114256]=0;T(575,f+32|0,E|0);d=w[114256];w[114256]=0;if((d|0)==1){break o}g=w[f+32>>2]+C(e-1|0,12)|0;w[g+4>>2]=w[g>>2];w[114256]=0;d=Q(261,b|0,f+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}e=0;if(d){e=y[f+272>>1];e=e<<8|e>>>8}d=w[b+8>>2];j=w[b>>2];h=w[w[j>>2]+36>>2];w[114256]=0;l=e&65535;e=S(h|0,j|0,d|0,l<<3)|0;d=w[114256];w[114256]=0;if((d|0)==1){break k}d=0;if(!e){break g}w[114256]=0;T(576,g|0,l|0);e=w[114256];w[114256]=0;if((e|0)==1){break k}if(!l){if(!(x[i+484414|0]&2)){break h}d=w[i+484384>>2];i=w[i+484388>>2]-d|0;e=w[g+4>>2];if((e|0)!=w[g+8>>2]){w[e+8>>2]=0;w[e+4>>2]=i;w[e>>2]=d;w[g+4>>2]=e+12;break h}y:{e=(e-w[g>>2]|0)/12|0;j=e+1|0;if(j>>>0>=357913942){w[114256]=0;X(577,g|0);a=w[114256];w[114256]=0;if((a|0)==1){break y}break i}w[114256]=0;h=e<<1;j=Z(578,f+280|0,(e>>>0>=178956970?357913941:h>>>0>j>>>0?h:j)|0,e|0,g+8|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){e=w[f+288>>2];w[e+8>>2]=0;w[e+4>>2]=i;w[e>>2]=d;h=w[f+288>>2]+12|0;w[f+288>>2]=h;k=w[g+4>>2];d=w[g>>2];i=k-d|0;e=w[f+284>>2]+C((i|0)/-12|0,12)|0;w[f+284>>2]=e;if((i|0)>0){Fb(e,d,i);k=w[g+4>>2];d=w[g>>2];h=w[f+288>>2];e=w[f+284>>2]}w[g>>2]=e;w[f+284>>2]=d;w[g+4>>2]=h;w[f+288>>2]=k;e=w[g+8>>2];w[g+8>>2]=w[f+292>>2];w[f+292>>2]=e;w[j>>2]=d;Kk(j);break h}e=P()|0;break j}e=P()|0;break j}i=g+8|0;k=0;while(1){z:{w[114256]=0;d=Q(268,b|0,f+272|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break z}e=0;if(d){e=w[f+272>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)}w[114256]=0;d=Q(268,b|0,f+272|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break z}h=0;if(d){d=w[f+272>>2];h=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}d=w[g+4>>2];A:{if((d|0)!=w[i>>2]){w[d+8>>2]=0;w[d+4>>2]=h;w[d>>2]=e;w[g+4>>2]=d+12;break A}d=(d-w[g>>2]|0)/12|0;j=d+1|0;if(j>>>0>=357913942){w[114256]=0;X(577,g|0);a=w[114256];w[114256]=0;if((a|0)!=1){break i}e=P()|0;break j}w[114256]=0;n=d<<1;n=Z(578,f+304|0,(d>>>0>=178956970?357913941:j>>>0<n>>>0?n:j)|0,d|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break z}d=w[f+312>>2];w[d+8>>2]=0;w[d+4>>2]=h;w[d>>2]=e;h=w[f+312>>2]+12|0;w[f+312>>2]=h;j=w[g+4>>2];d=w[g>>2];o=j-d|0;e=w[f+308>>2]+C((o|0)/-12|0,12)|0;w[f+308>>2]=e;if((o|0)>0){Fb(e,d,o);d=w[g>>2];h=w[f+312>>2];j=w[g+4>>2];e=w[f+308>>2]}w[g>>2]=e;w[f+308>>2]=d;w[g+4>>2]=h;w[f+312>>2]=j;e=w[i>>2];w[i>>2]=w[f+316>>2];w[f+316>>2]=e;w[n>>2]=d;Kk(n)}d=1;k=k+1|0;if(l>>>0>(k&65535)>>>0){continue}break g}break}e=P()|0;break j}e=P()|0;break j}e=P()|0;break f}e=P()|0;break f}e=P()|0;break f}e=P()|0}Bb(f);break f}M()}d=1}e=w[f+4>>2];B:{if(!e){break B}g=w[e+4>>2];w[e+4>>2]=g-1;if(g){break B}ob[w[w[e>>2]+8>>2]](e);Ib(e)}if(!d){break c}p=p+1|0;e=y[f+264>>1];if((p&65535)>>>0<((e<<8|e>>>8)&65535)>>>0){continue}break}}C:{D:{E:{F:{G:{if(y[f+68>>1]){o=w[b+8>>2];r=128;t=x[f+71|0];break G}w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(e){e=y[f+328>>1];r=e<<8|e>>>8}t=x[f+71|0];if(!y[f+68>>1]){s=4;break E}o=w[b+8>>2];if(r&65535){break G}r=0;s=4;break F}e=P()|0;break f}s=4;h=0;while(1){w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}H:{if(!(!e|y[f+328>>1]!=65535)){d=w[b+8>>2];break H}w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}t=0;if(e){e=y[f+328>>1];t=e<<8|e>>>8}w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}I:{if(!e){s=0;break I}e=y[f+328>>1];s=e<<8|e>>>8;if((s&65535)>>>0>127){break c}}d=y[a+480188>>1];e=s&65535;v[a+480188>>1]=d>>>0>e>>>0?d:e;d=w[b+8>>2];g=w[b>>2];p=w[w[g>>2]+36>>2];w[114256]=0;e=C(e,t&65535)<<2;d=S(p|0,g|0,d|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break C}J:{if(d){d=e+w[b+8>>2]|0;break J}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;d=V(d|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break C}}w[b+8>>2]=d;h=h+1|0;if((h&65535)>>>0<(r&65535)>>>0){continue}}break}if(d>>>0>=o>>>0){break F}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;e=V(d|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break D}if(e>>>0<o>>>0){break E}}w[b+8>>2]=o}K:{L:{e=y[a+480188>>1];M:{if(!e){o=0;break M}w[114256]=0;d=C(e,9);o=V(22,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break L}Cb(o,0,d-((d-9>>>0)%9|0)|0)}H=r&65535;if(H){I=a+484344|0;L=c&1;A=x[f+203|0];p=0;j=0;while(1){N:{e=j;O:{if(!y[f+68>>1]){break O}w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break K}if(e){e=y[f+328>>1];if((e|0)==65535){break N}e=e<<8|e>>>8}else{e=0}w[114256]=0;d=Q(261,b|0,f+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break K}t=0;if(d){d=y[f+328>>1];t=d<<8|d>>>8}w[114256]=0;d=Q(261,b|0,f+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break K}s=0;if(!d){break O}d=y[f+328>>1];s=d<<8|d>>>8}d=w[b+8>>2];g=w[b>>2];i=w[w[g>>2]+36>>2];w[114256]=0;h=d;F=s&65535;B=t&65535;d=C(F,B)<<2;g=S(i|0,g|0,h|0,d|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break K}if(!g){break N}P:{Q:{if(!L){break Q}w[114256]=0;J=e&65535;e=S(216,I|0,J|0,B|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break K}if(!e){break Q}if(!B){break P}r=0;R:{while(1){e=w[I>>2];w[114256]=0;d=e+C(J,52)|0;g=V(218,d|0)|0;e=w[114256];w[114256]=0;S:{T:{U:{V:{if((e|0)!=1){e=0;z=0;switch((A&3)-1|0){case 2:break T;case 1:break U;case 0:break V;default:break S}}break K}z=!(r&3);break S}z=!(r&1);break S}z=(r&3)!=3}W:{if(F){l=w[d>>2]+C(C(g,r),6)|0;D=0;while(1){w[114256]=0;Q(328,b|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break W}n=C(e,9)+o|0;m=C(e,6)+l|0;u[m+1|0]=x[f|0];d=x[f+1|0];u[m|0]=d;h=x[f+3|0];u[m+5|0]=h;g=m+5|0;if(d){u[m|0]=d+25;u[n+8|0]=0;u[n|0]=0;u[n+1|0]=0;u[n+2|0]=0;u[n+3|0]=0;u[n+4|0]=0;u[n+5|0]=0;u[n+6|0]=0;u[n+7|0]=0;h=x[g|0]}i=h&255;k=x[f+2|0];X:{Y:{if(k>>>0>=240){i=i|(k&15)<<8;if(i){q=Tb(44325e5/+(i>>>0));d=-1;Z:{if(q>=4294967295){break Z}d=0;if(q<=0){break Z}d=~~q>>>0;if(q<4294967296&q>=0){break Z}d=0}q=Tb(+(d>>>0)*1e-4);d=255;_:{if(q>=255){break _}d=0;if(q<=0){break _}d=~~q>>>0;if(q<4294967296&q>=0){break _}d=0}u[g|0]=d;u[m+3|0]=17;k=0;break X}u[m+3|0]=0;break Y}G=i>>>4|0;K=i<<4;d=G|K;$:{switch(k|0){case 0:d=C(e,6)+l|0;if(h&255){u[d+3|0]=1;k=0;break X}u[d+3|0]=0;break Y;case 1:u[(C(e,6)+l|0)+3|0]=2;k=0;break X;case 2:u[(C(e,6)+l|0)+3|0]=3;k=0;break X;case 3:u[f+328|0]=15;u[n|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|16;d=C(e,9)+o|0;u[d+7|0]=0;u[d+1|0]=0;u[d+2|0]=0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 4:u[f+328|0]=15;u[n|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|32;d=C(e,9)+o|0;u[d+7|0]=0;u[d+1|0]=0;u[d+2|0]=0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 5:u[n|0]=0;d=C(e,9)+o|0;u[d+7|0]=0;u[d+2|0]=0;u[d+1|0]=h;u[(C(e,6)+l|0)+3|0]=0;break Y;case 6:u[n|0]=0;d=C(e,9)+o|0;u[d+7|0]=0;u[d+2|0]=h;u[d+1|0]=0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 7:u[(C(e,6)+l|0)+3|0]=23;k=0;p=0;break X;case 8:u[(C(e,6)+l|0)+3|0]=0;k=1;p=d;break X;case 9:u[(C(e,6)+l|0)+3|0]=19;u[f+328|0]=15;u[g|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|16;k=0;break X;case 10:u[(C(e,6)+l|0)+3|0]=19;u[f+328|0]=15;u[g|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|32;k=0;break X;case 11:u[(C(e,9)+o|0)+3|0]=d;u[(C(e,6)+l|0)+3|0]=0;break Y;case 12:d=C(e,6)+l|0;u[d+4|0]=h;k=1;u[d+2|0]=1;u[(C(e,9)+o|0)+3|0]=0;u[d+3|0]=0;break X;case 13:aa:{ba:{if((h&255)>>>0>=16){u[(C(e,6)+l|0)+2|0]=4;h=(h&240)>>>4|0;break ba}if(!(i&15)){break aa}u[(C(e,6)+l|0)+2|0]=3}u[(C(e,6)+l|0)+4|0]=h}u[(C(e,9)+o|0)+3|0]=0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 14:u[(C(e,6)+l|0)+3|0]=19;u[g|0]=!(h&255);k=0;break X;case 15:u[(C(e,6)+l|0)+3|0]=16;u[g|0]=(h&240)>>>4;A=h&15;k=0;break X;case 16:d=C(e,9)+o|0;u[d+5|0]=0;u[d+4|0]=h;u[(C(e,6)+l|0)+3|0]=0;break Y;case 17:u[(C(e,9)+o|0)+6|0]=i&15?h:0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 18:u[(C(e,6)+l|0)+3|0]=14;k=0;break X;case 19:u[n|0]=0;d=C(e,9)+o|0;u[d+8|0]=0;u[d+7|0]=h;u[d+1|0]=0;u[d+2|0]=0;u[(C(e,6)+l|0)+3|0]=0;break Y;case 20:u[(C(e,6)+l|0)+3|0]=12;k=0;break X;case 22:d=x[m+1|0];ca:{if(!d){break ca}i=w[f+32>>2];if(d>>>0>(w[f+36>>2]-i|0)/12>>>0){break ca}h=h-1|0;u[g|0]=h;v[f+362>>1]=0;u[f+385|0]=0;u[f+386|0]=0;u[f+387|0]=0;u[f+388|0]=0;u[f+389|0]=0;u[f+390|0]=0;u[f+391|0]=0;u[f+392|0]=0;u[f+379|0]=0;u[f+380|0]=0;u[f+381|0]=0;u[f+382|0]=0;u[f+383|0]=0;u[f+384|0]=0;u[f+385|0]=0;u[f+386|0]=0;u[f+371|0]=0;u[f+372|0]=0;u[f+373|0]=0;u[f+374|0]=0;u[f+375|0]=0;u[f+376|0]=0;u[f+377|0]=0;u[f+378|0]=0;w[114256]=0;w[f+348>>2]=0;T(266,f+328|0,0);k=w[114256];w[114256]=0;if((k|0)==1){break K}d=(i+C(d,12)|0)-12|0;d=(w[d+4>>2]-w[d>>2]|0)/12|0;if((h&255)>>>0>=(d>>>0>=9?9:d)>>>0){break ca}d=C(e,6)+l|0;u[d+2|0]=15;u[d+4|0]=x[g|0]}u[(C(e,6)+l|0)+3|0]=0;break Y;case 23:d=x[m+1|0];da:{if(!d){break da}i=w[f+32>>2];if(d>>>0>(w[f+36>>2]-i|0)/12>>>0){break da}h=h-1|0;u[g|0]=h;i=(i+C(d,12)|0)-12|0;d=w[i>>2];k=(w[i+4>>2]-d|0)/12|0;i=h&255;if(k>>>0<=i>>>0){break da}d=d+C(i,12)|0;h=y[d+8>>1];ea:{if(h){break ea}h=0;i=y[a+480190>>1];if(i>>>0>3998){break ea}h=i+1|0;v[a+480190>>1]=h;v[d+8>>1]=h}u[m+1|0]=h}u[(C(e,6)+l|0)+3|0]=0;break Y;case 24:d=x[m+1|0];fa:{if(!d){break fa}i=w[f+32>>2];if(d>>>0>(w[f+36>>2]-i|0)/12>>>0){break fa}h=h-1|0;u[g|0]=h;v[f+362>>1]=0;u[f+385|0]=0;u[f+386|0]=0;u[f+387|0]=0;u[f+388|0]=0;u[f+389|0]=0;u[f+390|0]=0;u[f+391|0]=0;u[f+392|0]=0;u[f+379|0]=0;u[f+380|0]=0;u[f+381|0]=0;u[f+382|0]=0;u[f+383|0]=0;u[f+384|0]=0;u[f+385|0]=0;u[f+386|0]=0;u[f+371|0]=0;u[f+372|0]=0;u[f+373|0]=0;u[f+374|0]=0;u[f+375|0]=0;u[f+376|0]=0;u[f+377|0]=0;u[f+378|0]=0;w[114256]=0;w[f+348>>2]=0;T(266,f+328|0,0);k=w[114256];w[114256]=0;if((k|0)==1){break R}d=(i+C(d,12)|0)-12|0;d=(w[d+4>>2]-w[d>>2]|0)/12|0;if((h&255)>>>0<(d>>>0>=9?9:d)>>>0){d=C(e,6)+l|0;u[d+2|0]=15;u[d+4|0]=x[g|0]}d=(w[f+16>>2]+(x[m+1|0]<<1)|0)-2|0;h=y[d>>1];ga:{if(h){break ga}h=0;i=y[a+480190>>1];if(i>>>0>3998){break ga}h=i+1|0;v[a+480190>>1]=h;v[d>>1]=h}u[m+1|0]=h}u[(C(e,6)+l|0)+3|0]=0;break Y;case 25:d=x[m+1|0];ha:{if(!d){break ha}i=w[f+32>>2];if(d>>>0>(w[f+36>>2]-i|0)/12>>>0){break ha}h=h-1|0;u[g|0]=h;i=(i+C(d,12)|0)-12|0;d=w[i>>2];k=(w[i+4>>2]-d|0)/12|0;i=h&255;if(k>>>0<=i>>>0){break ha}d=d+C(i,12)|0;h=y[d+10>>1];ia:{if(h){break ia}h=0;i=y[a+480190>>1];if(i>>>0>3998){break ia}h=i+1|0;v[a+480190>>1]=h;v[d+10>>1]=h}u[m+1|0]=h}u[(C(e,6)+l|0)+3|0]=0;break Y;case 29:u[(C(e,6)+l|0)+3|0]=11;u[g|0]=d;if(i&15){u[g|0]=K|15;k=0;break X}k=0;if((h&255)>>>0<16){break X}u[g|0]=G|240;break X;case 32:if((h&255)>>>0>=16){u[(C(e,9)+o|0)+3|0]=G;u[(C(e,6)+l|0)+3|0]=0;break Y}u[(C(e,6)+l|0)+3|0]=19;u[g|0]=h|192;k=0;break X;case 33:u[(C(e,6)+l|0)+3|0]=19;u[f+328|0]=15;u[g|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|208;k=0;break X;case 34:u[(C(e,6)+l|0)+3|0]=19;u[f+328|0]=15;u[g|0]=x[((h&255)>>>0>15?f+328|0:g)|0]|144;k=0;break X;case 73:u[(C(e,6)+l|0)+3|0]=10;k=0;break X;case 78:if((h&112|128)==224){u[(C(e,6)+l|0)+3|0]=19;k=0;break X}u[(C(e,6)+l|0)+3|0]=0;break Y;case 79:d=C(e,6)+l|0;if((h&255)>>>0<=31){u[d+3|0]=16;k=0;A=0;break X}u[d+3|0]=17;k=0;break X;default:break $}}u[(C(e,6)+l|0)+3|0]=0}k=1}i=0;h=x[n+3|0];if(!(x[m+2|0]|!h)){ja:{if(h>>>0>=16){u[m+2|0]=5;h=h>>>4|0;break ja}u[m+2|0]=6}u[m+4|0]=h;i=1}ka:{if(!k){break ka}d=x[n+1|0];la:{if(d){u[m+3|0]=2;break la}d=x[n+2|0];if(d){u[m+3|0]=3;break la}d=x[n|0];if(d){u[m+3|0]=19;break la}d=x[n+7|0];if(d){u[m+3|0]=4;u[n+8|0]=d;break la}d=x[n+4|0];if(d){u[m+3|0]=5;u[n+5|0]=d;break la}d=x[n+3|0];if(!(!d|i)){u[m+3|0]=11;u[g|0]=d;if(d&15){d=d|-16;break la}if(d>>>0<16){break ka}d=d|15;break la}d=x[n+6|0];if(d){u[m+3|0]=8;break la}if(z){u[m+3|0]=20;z=0;d=97;break la}z=0;if(D){break ka}d=p&255;if(!d){break ka}u[m+3|0]=24;u[g|0]=p;if(p&15){d=p|-16}else{D=1;if(d>>>0<16){break ka}d=p|15}D=1}u[g|0]=d}e=e+1|0;if((F|0)!=(e|0)){continue}break}}r=r+1|0;if((B|0)!=(r|0)){continue}break P}break}break K}break K}e=w[b+8>>2];g=w[b>>2];i=w[w[g>>2]+36>>2];w[114256]=0;e=S(i|0,g|0,e|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break K}ma:{if(e){d=d+w[b+8>>2]|0;break ma}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;d=V(d|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}}w[b+8>>2]=d}j=j+1|0;if(H>>>0>(j&65535)>>>0){continue}}break}e=y[a+480188>>1]}w[a+480228>>2]=256/((e&65535)>>>0);w[114256]=0;T(238,a|0,1);e=w[114256];w[114256]=0;if((e|0)==1){break K}if(y[f+68>>1]){e=w[b+8>>2];na:{while(1){d=w[b>>2];g=w[w[d>>2]+36>>2];w[114256]=0;e=S(g|0,d|0,e|0,2)|0;d=w[114256];w[114256]=0;oa:{if((d|0)!=1){if(!e){break na}w[114256]=0;e=Q(261,b|0,f+328|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break K}if(y[f+328>>1]==65535?e:0){break na}e=w[b+8>>2];d=w[b>>2];g=w[w[d>>2]+36>>2];w[114256]=0;e=S(g|0,d|0,e|0,2)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break oa}break K}break K}pa:{if(e){d=w[b+8>>2]+2|0;break pa}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;d=V(d|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}}w[b+8>>2]=d;w[114256]=0;d=Q(268,b|0,f+328|0)|0;e=w[114256];w[114256]=0;qa:{if((e|0)==1){break qa}e=0;if(d){e=w[f+328>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)}d=w[b+8>>2];g=w[b>>2];p=w[w[g>>2]+36>>2];w[114256]=0;d=S(p|0,g|0,d|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break qa}ra:{if(d){e=w[b+8>>2]+e|0;break ra}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;e=V(d|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break qa}}w[b+8>>2]=e;continue}break}break K}e=w[b+8>>2];d=w[b>>2];g=w[w[d>>2]+36>>2];w[114256]=0;e=S(g|0,d|0,e|0,34)|0;d=w[114256];w[114256]=0;if((d|0)==1){break K}sa:{if(e){d=w[b+8>>2]+34|0;break sa}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;d=V(d|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}}w[b+8>>2]=d}if(!(!(c&2)|!E)){m=f+396|0;n=f+364|0;d=1;r=1;while(1){p=C(d,104)+a|0;g=p+484380|0;ta:{if(!w[g>>2]){break ta}w[114256]=0;w[f+328>>2]=264;S(214,f+328|0,g|0,b|0)|0;c=w[114256];w[114256]=0;ua:{va:{if((c|0)!=1){c=w[f+32>>2];if((w[f+36>>2]-c|0)/12>>>0<d>>>0){break ta}s=d-1|0;j=C(s,12);t=p+484400|0;if(!w[t>>2]){break ua}e=w[g>>2];if(!e){break ua}h=c+j|0;l=w[h>>2];c=(w[h+4>>2]-l|0)/12|0;if(c>>>0<2){break ua}Fb(f+328|0,g,34);z=p+484414|0;v[f+362>>1]=y[z>>1];A=p+484416|0;B=Fb(n,A,68);i=0;w[f+348>>2]=0;d=0;wa:{while(1){k=l+C(i,12)|0;D=w[k>>2];if(D>>>0>=e>>>0){break wa}k=w[k+4>>2];if(k>>>0>e-D>>>0|268435456-k>>>0<d>>>0){break wa}d=d+k|0;i=i+1|0;if((c|0)!=(i|0)){continue}break}i=c}w[114256]=0;w[f+328>>2]=d;c=V(252,f+328|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break K}if(!c){break ua}d=0;e=0;if(!i){break va}while(1){c=w[h>>2]+C(d,12)|0;Fb(w[f+348>>2]+e|0,w[t>>2]+w[c>>2]|0,w[c+4>>2]);w[c>>2]=e;if(d-10>>>0>=4294967287){w[(m+(d<<2)|0)-4>>2]=e}e=w[c+4>>2]+e|0;d=d+1|0;if((d|0)!=(i|0)){continue}break}break va}break K}w[114256]=0;X(579,g|0);c=w[114256];w[114256]=0;if((c|0)==1){break K}c=Fb(g,f+328|0,34);e=y[f+362>>1];Fb(A,B,68);w[p+484384>>2]=0;w[p+484388>>2]=w[c>>2];v[z>>1]=e|2}xa:{c=y[w[f+16>>2]+(s<<1)>>1];if(!c){break xa}e=w[g>>2];w[114256]=0;ga(580,g|0,(C(c,104)+a|0)+484380|0,0,e|0,0);c=w[114256];w[114256]=0;if((c|0)!=1){break xa}break K}c=j+w[f+32>>2]|0;d=w[c>>2];c=w[c+4>>2];if((d|0)==(c|0)){break ta}while(1){e=y[d+8>>1];if(e){p=w[d+4>>2];i=w[d>>2];w[114256]=0;ga(580,g|0,(C(e,104)+a|0)+484380|0,i|0,p|0,1);e=w[114256];w[114256]=0;if((e|0)==1){break K}}e=y[d+10>>1];if(e){p=w[d+4>>2];i=w[d>>2];w[114256]=0;ga(580,g|0,(C(e,104)+a|0)+484380|0,i|0,p|0,0);e=w[114256];w[114256]=0;if((e|0)==1){break K}}d=d+12|0;if((c|0)!=(d|0)){continue}break}}r=r+1|0;d=r&65535;if(E>>>0>=d>>>0){continue}break}}m=1;if(!o){break c}zb(o);break c}e=P()|0;break f}e=P()|0;if(!o){break f}zb(o);break f}e=P()|0;break f}e=P()|0}a=w[f+16>>2];if(a){w[f+20>>2]=a;zb(a)}Vo(f+32|0);break d}e=P()|0;if(u[f+315|0]<0){zb(w[f+304>>2])}if(u[d+11|0]>=0){break d}zb(w[d>>2])}R(e|0);M()}a=w[f+16>>2];if(a){w[f+20>>2]=a;zb(a)}Vo(f+32|0)}jb=f+432|0;return m|0}function uB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0;d=jb-336|0;jb=d;w[b+8>>2]=0;a:{if(!Ii(b,d+296|0)){break a}if(!kp(d+296|0)){break a}w[d+280>>2]=w[b>>2];e=w[b+4>>2];w[d+284>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=w[b+12>>2];w[d+288>>2]=w[b+8>>2];w[d+292>>2]=e;w[d+272>>2]=0;w[d+264>>2]=0;w[d+268>>2]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){w[114256]=0;Y(536,d+24|0,d+280|0,1,1413891155);b=w[114256];w[114256]=0;if((b|0)==1){break z}break B}w[114256]=0;U(537,d+24|0,d+280|0,1);b=w[114256];w[114256]=0;if((b|0)==1){break A}}b=d+264|0;jp(b);w[d+264>>2]=w[d+24>>2];e=w[d+28>>2];f=w[d+32>>2];w[d+32>>2]=0;w[d+268>>2]=e;w[d+272>>2]=f;w[d+24>>2]=0;w[d+28>>2]=0;e=d+24|0;Ac(e);w[114256]=0;U(538,e|0,b|0,1413891155);b=w[114256];w[114256]=0;C:{D:{if((b|0)!=1){w[114256]=0;j=S(343,d+24|0,9824,8)|0;b=w[114256];w[114256]=0;if((b|0)==1){break D}b=w[d+28>>2];E:{if(!b){break E}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break E}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(!c){break b}if(!(j^1)){break C}break b}b=P()|0;break c}b=P()|0;Bb(d+24|0);break c}w[114256]=0;T(236,a|0,4194304);b=w[114256];w[114256]=0;if((b|0)==1){break d}w[a+480208>>2]=12;w[114256]=0;U(538,d+248|0,d+264|0,1280592212);b=w[114256];w[114256]=0;if((b|0)==1){break e}b=w[d+248>>2];e=w[w[b>>2]+24>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;S(395,d+248|0,a+1304400|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break g}b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;w[b+4>>2]=w[b>>2];w[114256]=0;w[d+240>>2]=0;w[d+232>>2]=0;w[d+236>>2]=0;u[d+231|0]=0;U(539,d+216|0,d+264|0,1196314451);b=w[114256];w[114256]=0;if((b|0)==1){break i}n=a+484360|0;l=w[d+216>>2];o=w[d+220>>2];F:{if((l|0)==(o|0)){break F}p=d+120|2;q=d+204|0;j=0;while(1){w[d+24>>2]=w[l>>2];b=w[l+4>>2];w[d+28>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[l+12>>2];e=w[l+8>>2];w[114256]=0;w[d+32>>2]=e;w[d+36>>2]=b;b=Q(540,d+24|0,d+8|0)|0;e=w[114256];w[114256]=0;G:{H:{I:{if((e|0)!=1){f=1;if(!(b&x[d+17|0]==1)){break G}e=y[a+480188>>1];b=x[d+18|0];v[a+480188>>1]=b>>>0<e>>>0?e:b>>>0>=127?127:b;w[114256]=0;k=V(541,d+160|0)|0;b=w[114256];w[114256]=0;J:{K:{L:{M:{N:{if((b|0)!=1){w[114256]=0;Y(209,d+128|0,1,d+8|0,9);b=w[114256];w[114256]=0;if((b|0)==1){break N}w[114256]=0;w[d+148>>2]=10;w[d+144>>2]=q;Q(200,d+144|0,d+128|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break M}if(u[d+139|0]<0){zb(w[d+128>>2])}f=w[a+484360>>2];b=x[a+484376|0];e=f+(b<<5)|0;if(w[e>>2]==w[e+4>>2]){break J}w[114256]=0;b=V(262,n|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break L}if((b|0)!=255){break K}f=2;break H}b=P()|0;break k}b=P()|0;break l}b=P()|0;if(u[d+139|0]>=0){break l}zb(w[d+128>>2]);break l}b=P()|0;break l}b=x[a+484376|0];f=w[a+484360>>2]}w[114256]=0;e=Q(5,d+312|0,q|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break n}w[114256]=0;U(6,d+128|0,4,e|0);i=w[114256];w[114256]=0;if((i|0)==1){break m}if(u[d+323|0]<0){zb(w[e>>2])}w[114256]=0;Q(117,((b<<5)+f|0)+12|0,d+128|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}if(u[d+139|0]<0){zb(w[d+128>>2])}w[114256]=0;U(537,d+144|0,d+24|0,1);b=w[114256];w[114256]=0;if((b|0)==1){break p}O:{e=w[d+144>>2];s=w[d+148>>2];if((e|0)!=(s|0)){while(1){f=w[e+8>>2];w[d+128>>2]=f;b=w[e+12>>2];w[d+132>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[e+20>>2];h=w[e+16>>2];w[d+136>>2]=h;w[d+140>>2]=b;i=1;b=x[e+4|0]|x[e+5|0]<<8|(x[e+6|0]<<16|x[e+7|0]<<24);P:{g=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);if((g|0)!=1212960847){if((g|0)!=1312903248){break P}b=0;if(!y[a+480188>>1]){break P}Q:{while(1){f=w[d+128>>2];h=w[w[f>>2]+36>>2];w[114256]=0;f=S(h|0,f|0,w[d+136>>2],2)|0;h=w[114256];w[114256]=0;if((h|0)==1){break Q}if(!f){break P}f=w[d+128>>2];h=w[w[f>>2]+36>>2];w[114256]=0;f=S(h|0,f|0,w[d+136>>2],2)|0;h=w[114256];w[114256]=0;R:{S:{T:{if((h|0)==1){break r}U:{if(f){w[d+332>>2]=p;w[d+328>>2]=d+120;f=w[d+128>>2];h=w[w[f>>2]+32>>2];w[114256]=0;f=S(h|0,f|0,w[d+136>>2],d+328|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break r}w[d+136>>2]=f+w[d+136>>2];V:{switch(x[d+120|0]){case 4:break S;case 2:break T;case 0:break V;default:break R}}f=x[d+121|0];break U}u[d+120|0]=0;f=0}u[w[k>>2]+b|0]=f^128;f=w[d+184>>2]+(b>>>3&536870908)|0;h=w[f>>2];t=f,z=FV(-2,b)&h,w[t>>2]=z;break R}u[w[k>>2]+b|0]=128;f=w[d+184>>2]+(b>>>3&536870908)|0;w[f>>2]=w[f>>2]|1<<b;break R}u[w[k>>2]+b|0]=128;f=w[d+184>>2]+(b>>>3&536870908)|0;h=w[f>>2];t=f,z=FV(-2,b)&h,w[t>>2]=z}b=b+1|0;if(b>>>0<y[a+480188>>1]){continue}break}break P}break r}if(b>>>0<9){break P}b=w[w[f>>2]+36>>2];w[114256]=0;b=S(b|0,f|0,h|0,2)|0;f=w[114256];w[114256]=0;if((f|0)==1){break r}W:{if(b){b=w[d+136>>2]+2|0;break W}b=w[d+128>>2];f=w[w[b>>2]+24>>2];w[114256]=0;b=V(f|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break r}}w[d+136>>2]=b;f=0;h=65535;while(1){g=w[d+128>>2];m=w[w[g>>2]+36>>2];w[114256]=0;b=S(m|0,g|0,b|0,1)|0;g=w[114256];w[114256]=0;X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{if((g|0)!=1){if(!b){break P}w[114256]=0;b=Q(241,d+128|0,d+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}switch((b?x[d+328|0]:0)&255){case 0:break P;case 14:break Y;case 13:break Z;case 12:break $;case 8:break aa;case 7:break ba;case 4:break ca;case 1:break da;default:break _}}break r}b=x[a+484376|0];ea:{if(y[d+196>>1]!=65535){b=w[n>>2]+(b<<5)|0;b=w[b+4>>2]-w[b>>2]>>1;b=b>>>0>=65535?65535:b;break ea}b=w[n>>2]+(b<<5)|0;b=w[b+4>>2]-w[b>>2]>>1;b=b>>>0>=65535?65535:b;v[d+196>>1]=b}w[114256]=0;v[d+198>>1]=b;b=Q(542,d+128|0,d+231|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}fa:{ga:{switch(b-254|0){case 1:b=65535;break fa;case 0:break ga;default:break fa}}b=65534}g=w[a+484360>>2];m=x[a+484376|0];w[114256]=0;T(449,g+(m<<5)|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break r}h=(h&65535)==65535?f:h;break X}w[114256]=0;b=Q(197,d+128|0,d+328|0)|0;g=w[114256];w[114256]=0;ha:{ia:{if((g|0)!=1){b=b?y[d+328>>1]:0;if((b&65535)>>>0>=(h&65535)>>>0){break ia}b=y[d+200>>1];break ha}break r}b=b-h|0;v[d+200>>1]=b}v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=b;break X}w[114256]=0;b=Q(241,d+128|0,d+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}u[d+203|0]=b?x[d+328|0]:0;break X}w[114256]=0;b=Q(241,d+128|0,d+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}u[d+202|0]=b?x[d+328|0]:0;break X}w[114256]=0;b=Q(518,d+128|0,d+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}if(x[d+328|0]|!b|(x[d+330|0]|x[d+329|0]!=255)){break _}if(x[d+331|0]|x[d+332|0]!=1){break _}if(!x[d+333|0]){break X}}i=0;break P}w[114256]=0;Q(217,d+128|0,d+328|0)|0;b=w[114256];w[114256]=0;ja:{ka:{la:{ma:{if((b|0)!=1){b=x[d+328|0];g=w[k>>2];if(b>>>0>=w[d+164>>2]-g>>>0){break X}switch(x[d+330|0]){case 4:break ka;case 2:break la;case 0:break ma;default:break ja}}break r}u[b+g|0]=x[d+329|0]^128;b=x[d+328|0];g=w[d+184>>2]+(b>>>3&28)|0;m=w[g>>2];t=g,z=FV(-2,b)&m,w[t>>2]=z;break ja}u[b+g|0]=128;b=x[d+328|0];g=w[d+184>>2]+(b>>>3&28)|0;w[g>>2]=w[g>>2]|1<<b;break ja}u[b+g|0]=128;b=x[d+328|0];g=w[d+184>>2]+(b>>>3&28)|0;m=w[g>>2];t=g,z=FV(-2,b)&m,w[t>>2]=z}na:{if(r){break na}g=w[d+236>>2];if((g|0)==w[d+232>>2]){r=0;break X}if(x[w[g-56>>2]+b|0]!=x[w[k>>2]+b|0]){break na}r=0;m=w[g-32>>2];g=b>>>3&28;b=1<<b;if(((w[m+g>>2]&b)!=0|0)==((b&w[g+w[d+184>>2]>>2])!=0|0)){break X}}r=1;break X}b=w[d+128>>2];g=w[w[b>>2]+36>>2];w[114256]=0;b=S(g|0,b|0,w[d+136>>2],2)|0;g=w[114256];w[114256]=0;if((g|0)==1){break O}oa:{if(b){w[d+332>>2]=p;w[d+328>>2]=d+120;b=w[d+128>>2];g=w[w[b>>2]+32>>2];w[114256]=0;b=S(g|0,b|0,w[d+136>>2],d+328|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break O}w[d+136>>2]=b+w[d+136>>2];b=x[d+120|0];break oa}v[d+120>>1]=0;b=0}g=w[d+172>>2];if(b>>>0>=w[d+176>>2]-g>>>0){break X}u[b+g|0]=(x[d+121|0]>>>2|0)+1}f=f+1|0;b=w[d+136>>2];continue}}b=w[d+132>>2];pa:{if(!b){break pa}f=w[b+4>>2];w[b+4>>2]=f-1;if(f){break pa}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(!i){f=1;break I}e=e+24|0;if((s|0)!=(e|0)){continue}break}}f=0;if(y[d+196>>1]==65535|y[d+198>>1]==65535){break I}b=w[a+484360>>2];e=x[a+484376|0];w[114256]=0;T(449,b+(e<<5)|0,65535);b=w[114256];w[114256]=0;if((b|0)!=1){w[114256]=0;T(543,d+232|0,k|0);b=w[114256];w[114256]=0;if((b|0)!=1){break I}}b=P()|0;break q}break r}b=P()|0;break k}Ac(d+144|0)}b=w[d+184>>2];if(b){zb(b)}b=w[d+172>>2];if(b){w[d+176>>2]=b;zb(b)}b=w[k>>2];if(!b){break G}w[d+164>>2]=b;zb(b)}b=w[d+28>>2];qa:{if(!b){break qa}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break qa}ob[w[w[b>>2]+8>>2]](b);Ib(b)}if(f){if((f|0)==2){break F}break s}l=l+16|0;if((o|0)!=(l|0)){continue}break}}j=0;w[114256]=0;T(264,n|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break y}b=w[d+232>>2];if((b|0)==w[d+236>>2]){break s}ra:{if(c&2){w[114256]=0;U(539,d+128|0,d+264|0,1347244868);b=w[114256];w[114256]=0;if((b|0)==1){break ra}b=w[d+128>>2];k=w[d+132>>2];if((b|0)!=(k|0)){i=d+37|0;j=d+41|0;l=x[d+231|0];while(1){sa:{ta:{ua:{va:{wa:{if(!l){w[114256]=0;e=Q(544,b|0,d+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break wa}if(!e){break sa}e=y[d+76>>1];f=e+1|0;if(e>>>0>3998){break ua}h=y[a+480190>>1];e=f&65535;v[a+480190>>1]=e>>>0<h>>>0?h:e;w[114256]=0;T(545,d+24|0,(C(e,104)+a|0)+484380|0);h=w[114256];w[114256]=0;if((h|0)==1){break wa}w[114256]=0;Y(209,d+144|0,1,i|0,33);h=w[114256];w[114256]=0;xa:{if((h|0)!=1){w[114256]=0;w[d+12>>2]=32;w[d+8>>2]=((e<<5)+a|0)+946304;Q(200,d+8|0,d+144|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break xa}if(u[d+155|0]>=0){break ua}zb(w[d+144>>2]);break ua}b=P()|0;break ta}b=P()|0;if(u[d+155|0]>=0){break ta}zb(w[d+144>>2]);break ta}w[114256]=0;e=Q(546,b|0,d+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break va}if(!e){break sa}e=y[d+80>>1];f=e+1|0;if(e>>>0>3998){break ua}h=y[a+480190>>1];e=f&65535;v[a+480190>>1]=e>>>0<h>>>0?h:e;w[114256]=0;T(547,d+24|0,(C(e,104)+a|0)+484380|0);h=w[114256];w[114256]=0;if((h|0)==1){break va}w[114256]=0;Y(209,d+144|0,1,j|0,33);h=w[114256];w[114256]=0;ya:{if((h|0)!=1){w[114256]=0;w[d+12>>2]=32;w[d+8>>2]=((e<<5)+a|0)+946304;Q(200,d+8|0,d+144|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ya}if(u[d+155|0]>=0){break ua}zb(w[d+144>>2]);break ua}b=P()|0;break ta}b=P()|0;if(u[d+155|0]>=0){break ta}zb(w[d+144>>2]);break ta}b=P()|0;break ta}b=P()|0;break ta}if((f-1&65535)>>>0>3998){break sa}w[114256]=0;w[d+24>>2]=33554696;S(214,d+24|0,(C(f&65535,104)+a|0)+484380|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break sa}b=P()|0}gc(d+128|0);break j}b=b+16|0;if((k|0)!=(b|0)){continue}break}}gc(d+128|0);b=w[d+232>>2]}w[a+480196>>2]=x[b+43|0];w[a+480204>>2]=C(x[b+42|0],1e4);v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=y[b+40>>1];za:{if(y[a+480188>>1]){b=0;while(1){w[114256]=0;e=(b<<5)+a|0;f=e+480280|0;X(224,f|0);k=w[114256];w[114256]=0;if((k|0)==1){break za}k=w[d+232>>2];v[e+480286>>1]=x[w[k+12>>2]+b|0];v[e+480284>>1]=x[w[k>>2]+b|0];w[f>>2]=w[f>>2]&-257|(w[w[k+24>>2]+(b>>>3&536870908)>>2]>>>b&1)<<8;b=b+1|0;if(b>>>0<y[a+480188>>1]){continue}break}}w[114256]=0;e=Q(1,d+128|0,(x[d+231|0]?12894:12767)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break t}b=a+1304436|0;if(u[a+1304447|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[114256]=0;e=Q(1,d+144|0,6077)|0;b=w[114256];w[114256]=0;if((b|0)==1){break u}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];w[a+1304496>>2]=4;j=1;if(!(c&1)|!y[a+480188>>1]){break s}w[114256]=0;U(539,d+8|0,d+264|0,1146045008);b=w[114256];w[114256]=0;if((b|0)==1){break v}w[114256]=0;k=a+484344|0;T(215,k|0,w[d+12>>2]-w[d+8>>2]>>>4&65535);b=w[114256];w[114256]=0;if((b|0)==1){break x}i=w[d+8>>2];g=w[d+12>>2];if((i|0)!=(g|0)){p=d|2;q=d+120|2;while(1){b=w[i>>2];c=w[w[b>>2]+24>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;Aa:{Ba:{Ca:{if((c|0)==1){break Ca}w[114256]=0;c=Q(232,i|0,d+24|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ca}if((b|0)!=((c?w[d+24>>2]:0)|0)){break Aa}b=w[i>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,0,8)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ca}if(b){break Ba}break Aa}b=P()|0;break w}w[114256]=0;h=Q(542,i|0,d+231|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){w[114256]=0;b=Q(197,i|0,d+24|0)|0;c=w[114256];w[114256]=0;Da:{if((c|0)==1){break Da}w[114256]=0;n=b?y[d+24>>1]:0;b=S(216,k|0,h|0,n|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Da}if(!n|b^1){break Aa}l=0;Ea:{Fa:{Ga:{while(1){Ha:{b=w[k>>2];w[114256]=0;b=b+C(h,52)|0;c=V(218,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Ea}b=w[b>>2];w[114256]=0;e=Q(197,i|0,d+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Fa}Ia:{Ja:{e=(e?y[d+24>>1]:0)&65535;if(e>>>0<3){break Ja}w[114256]=0;U(188,d+24|0,i|0,e-2|0);e=w[114256];w[114256]=0;if((e|0)==1){break Ga}e=b+C(C(c,l),6)|0;while(1){b=w[d+24>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+32>>2],3)|0;c=w[114256];w[114256]=0;Ka:{if((c|0)!=1){if(b){b=w[d+24>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+32>>2],2)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ha}La:{if(b){w[d+332>>2]=q;w[d+328>>2]=d+120;b=w[d+24>>2];c=w[w[b>>2]+32>>2];w[114256]=0;b=S(c|0,b|0,w[d+32>>2],d+328|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ha}w[d+32>>2]=b+w[d+32>>2];f=x[d+121|0];b=x[d+120|0];break La}v[d+120>>1]=0;f=0;b=0}c=y[a+480188>>1]-1&65535;f=f&255;f=c>>>0<f>>>0?c:f;c=e+C(f,6)|0;if(b<<24>>24<0){w[114256]=0;b=Q(241,d+24|0,d+328|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Ha}j=x[d+328|0];b=b?j:0;Ma:{if(!x[d+231|0]){o=b&255;if((o|0)==255){j=254;break Ma}if(o>>>0>128){break Ma}j=(C((b&240)>>>4|0,12)+(b&15)|0)+13|0;break Ma}j=(b&255)>>>0<85?b+36|0:b}u[c|0]=j;b=x[d+120|0]}if(b&64){w[114256]=0;b=Q(241,d+24|0,d+328|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Ha}u[c+1|0]=b?x[d+328|0]+1|0:1;b=x[d+120|0]}if(b&32){w[114256]=0;j=Q(241,d+24|0,d+328|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Ha}b=x[d+328|0];u[c+2|0]=1;u[c+4|0]=j?(b>>>0>=127?127:b)+1>>>1|0:0;b=x[d+120|0]}if(!(b&16)){continue}b=w[d+24>>2];j=w[w[b>>2]+36>>2];w[114256]=0;b=S(j|0,b|0,w[d+32>>2],2)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Ha}Na:{if(b){w[d+332>>2]=p;w[d+328>>2]=d;b=w[d+24>>2];j=w[w[b>>2]+32>>2];w[114256]=0;b=S(j|0,b|0,w[d+32>>2],d+328|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Ha}w[d+32>>2]=b+w[d+32>>2];b=x[d+1|0];break Na}v[d>>1]=0;b=0}u[c+5|0]=b;Oa:{switch(x[d|0]-1|0){case 0:u[(e+C(f,6)|0)+3|0]=11;if(x[d+231|0]){u[c+5|0]=b<<4|15;continue}u[c+5|0]=b<<3|15;continue;case 1:u[(e+C(f,6)|0)+3|0]=11;if(x[d+231|0]){u[c+5|0]=b<<4;continue}u[c+5|0]=b<<3&240;continue;case 2:u[(e+C(f,6)|0)+3|0]=11;if(x[d+231|0]){u[c+5|0]=b|240;continue}u[c+5|0]=b>>>1|240;continue;case 3:u[(e+C(f,6)|0)+3|0]=11;if(x[d+231|0]){u[c+5|0]=b&15;continue}if((b&255)>>>0<=1){u[c+5|0]=b|240;continue}u[c+5|0]=b>>>1&15;continue;case 10:u[(e+C(f,6)|0)+3|0]=2;Pa:{if(x[d+231|0]){break Pa}if((b&255)>>>0<=3){b=b|-16;break Pa}b=(b&252)>>>2|0}u[c+5|0]=b|240;continue;case 11:u[(e+C(f,6)|0)+3|0]=2;if(x[d+231|0]){break Ka}if((b&255)>>>0<=3){b=b|-16;break Ka}b=(b&252)>>>2|0;break Ka;case 12:u[(e+C(f,6)|0)+3|0]=3;Qa:{if(x[d+231|0]){break Qa}if((b&255)>>>0<=3){b=b|-16;break Qa}b=(b&252)>>>2|0}u[c+5|0]=b|240;continue;case 13:u[(e+C(f,6)|0)+3|0]=3;if(x[d+231|0]){break Ka}if((b&255)>>>0<=3){b=b|-16;break Ka}b=(b&252)>>>2|0;break Ka;case 14:u[(e+C(f,6)|0)+3|0]=4;if(x[d+231|0]){continue}u[c+5|0]=(b&252)>>>2;continue;case 16:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&1|16;continue;case 15:u[(e+C(f,6)|0)+3|0]=6;u[c+5|0]=b&240;continue;case 17:u[(e+C(f,6)|0)+3|0]=6;u[c+5|0]=(b&240)>>>4;continue;case 18:u[(e+C(f,6)|0)+3|0]=20;continue;case 20:u[(e+C(f,6)|0)+3|0]=5;continue;case 21:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|48;continue;case 22:u[(e+C(f,6)|0)+3|0]=7;u[c+5|0]=b|240;continue;case 23:u[(e+C(f,6)|0)+3|0]=7;continue;case 30:u[(e+C(f,6)|0)+3|0]=8;continue;case 31:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|64;continue;case 40:u[(e+C(f,6)|0)+3|0]=10;w[114256]=0;b=Q(241,d+24|0,d+328|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ia}u[c+5|0]=b?x[d+328|0]:0;b=w[d+24>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+32>>2],1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ia}Ra:{if(b){b=w[d+32>>2]+1|0;break Ra}b=w[d+24>>2];c=w[w[b>>2]+24>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ia}}w[d+32>>2]=b;continue;case 41:u[(e+C(f,6)|0)+3|0]=15;continue;case 42:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|192;continue;case 43:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|208;continue;case 50:u[(e+C(f,6)|0)+3|0]=12;u[c+5|0]=(b&254)>>>1;b=w[d+24>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+32>>2],1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ia}Sa:{if(b){b=w[d+32>>2]+1|0;break Sa}b=w[d+24>>2];c=w[w[b>>2]+24>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Ia}}w[d+32>>2]=b;continue;case 51:u[(e+C(f,6)|0)+3|0]=14;u[c+5|0]=0;continue;case 52:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|176;continue;case 53:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|224;continue;case 60:u[(e+C(f,6)|0)+3|0]=16;continue;case 61:u[(e+C(f,6)|0)+3|0]=17;continue;case 70:u[(e+C(f,6)|0)+3|0]=1;continue;case 71:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|32;continue;case 72:u[(e+C(f,6)|0)+3|0]=20;u[c+5|0]=b&15|128;continue;default:break Oa}}u[(e+C(f,6)|0)+3|0]=0;continue}b=w[d+28>>2];if(!b){break Ja}c=w[b+4>>2];w[b+4>>2]=c-1;if(c){break Ja}ob[w[w[b>>2]+8>>2]](b);Ib(b);break Ja}break Ha}u[c+5|0]=b;continue}}l=l+1|0;if((n|0)==(l|0)){break Aa}continue}}break}b=P()|0;Bb(d+24|0);break w}b=P()|0;break w}b=P()|0;break w}b=P()|0;break w}b=P()|0;break w}b=P()|0;break w}i=i+16|0;if((g|0)!=(i|0)){continue}break}}f=w[d+236>>2];b=w[d+232>>2];if(!((f-b|0)/56>>>0<2|(b|0)==(f|0))){e=0;while(1){Ta:{j=w[a+484360>>2]+((e&255)<<5)|0;c=C(e,56)+b|0;l=y[c+36>>1];h=y[w[j>>2]+(l<<1)>>1];i=w[a+484344>>2];if(h>>>0>=((w[a+484348>>2]-i|0)/52&65535)>>>0){break Ta}i=i+C(h,52)|0;if(w[i>>2]==w[i+4>>2]){break Ta}w[114256]=0;f=Q(459,j|0,l|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(y[a+480188>>1]!=0&r){b=0;while(1){i=w[k>>2]+C(f,52)|0;Ua:{if(w[w[c+24>>2]+(b>>>3&536870908)>>2]>>>b&1){w[114256]=0;v[d+34>>1]=37140;v[d+32>>1]=b;w[d+24>>2]=1;w[d+28>>2]=0;u[d+36|0]=x[d+36|0]&248|1;Q(271,i|0,d+24|0)|0;i=w[114256];w[114256]=0;if((i|0)!=1){break Ua}b=P()|0;break w}j=x[w[c>>2]+b|0];w[114256]=0;u[d+35|0]=j;u[d+34|0]=9;u[d+36|0]=x[d+36|0]&248|1;v[d+32>>1]=b;w[d+24>>2]=1;w[d+28>>2]=0;Q(271,i|0,d+24|0)|0;i=w[114256];w[114256]=0;if((i|0)!=1){break Ua}b=P()|0;break w}b=b+1|0;if(b>>>0<y[a+480188>>1]){continue}break}}b=w[k>>2];i=x[c+43|0];w[114256]=0;u[d+35|0]=i;u[d+34|0]=16;v[d+32>>1]=65535;w[d+24>>2]=1;w[d+28>>2]=0;u[d+36|0]=x[d+36|0]&248|1;g=b;b=C(f,52);Q(271,g+b|0,d+24|0)|0;f=w[114256];w[114256]=0;Va:{if((f|0)!=1){f=w[k>>2];c=x[c+42|0];w[114256]=0;u[d+35|0]=c;u[d+34|0]=17;v[d+32>>1]=65535;w[d+24>>2]=1;w[d+28>>2]=0;u[d+36|0]=x[d+36|0]&248|1;Q(271,b+f|0,d+24|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break Va}b=w[d+232>>2];f=w[d+236>>2];break Ta}b=P()|0;break w}b=P()|0;break w}b=P()|0;break w}e=e+1|0;if(e>>>0<(f-b|0)/56>>>0){continue}break}}gc(d+8|0);j=1;break s}b=P()|0;break j}b=P()|0;break j}b=P()|0;break c}b=P()|0;break c}b=P()|0;break j}b=P()|0}gc(d+8|0);break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;break j}gc(d+216|0);hp(d+232|0);a=w[d+252>>2];if(!a){break b}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break b}ob[w[w[a>>2]+8>>2]](a);Ib(a);break b}b=P()|0;Bb(d+128|0)}Ac(d+144|0);break l}b=P()|0;break l}b=P()|0;if(u[d+139|0]>=0){break l}zb(w[d+128>>2]);break l}b=P()|0;break l}b=P()|0;if(u[d+323|0]>=0){break l}zb(w[e>>2])}a=w[k+24>>2];if(a){zb(a)}a=w[k+12>>2];if(a){w[k+16>>2]=a;zb(a)}a=w[k>>2];if(a){w[k+4>>2]=a;zb(a)}}Bb(d+24|0)}gc(d+216|0);break h}b=P()|0}hp(d+232|0);break f}b=P()|0}Bb(d+248|0);break c}b=P()|0;break c}b=P()|0}Ac(d+264|0);Bb(d+280|0);R(b|0);M()}Ac(d+264|0);a=w[d+284>>2];if(!a){break a}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break a}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+336|0;return j|0}function WD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=jb-256|0;jb=e;w[b+8>>2]=0;f=jb-16|0;jb=f;h=w[b+8>>2];g=w[b>>2];j=e+232|0;w[f+8>>2]=j;w[f+12>>2]=j+22;h=ob[w[w[g>>2]+32>>2]](g,h,f+8|0)|0;if((h|0)==22){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],22)|0){g=w[b+8>>2]+22|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((h|0)!=22){break y}if(!$p(e+232|0)){break y}if(!c){d=1;break y}tc(a,1024);je(a);w[a+480208>>2]=w[a+480208>>2]|12;w[a+1074312>>2]=w[a+1074312>>2]&-2097153;f=y[e+248>>1];if(f){w[a+480204>>2]=C((f<<8|f>>>8)&65535,1e4)}f=y[e+246>>1];if(f){w[a+480196>>2]=(f<<8|f>>>8)&65535}if(!x[e+242|0]){Ce(a,1)}f=w[e+236>>2];Ki(b,a+1304400|0,(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))-14|0);w[e+128>>2]=w[b>>2];f=w[b+4>>2];w[e+132>>2]=f;if(f){w[f+4>>2]=w[f+4>>2]+1}f=w[b+8>>2];b=w[b+12>>2];w[114256]=0;w[e+136>>2]=f;w[e+140>>2]=b;U(315,e+216|0,e+128|0,1);b=w[114256];w[114256]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((b|0)!=1){b=w[e+132>>2];K:{if(!b){break K}f=w[b+4>>2];w[b+4>>2]=f-1;if(f){break K}ob[w[w[b>>2]+8>>2]](b);Ib(b)}w[114256]=0;U(316,e+128|0,e+216|0,1395544366);b=w[114256];w[114256]=0;if((b|0)==1){break D}b=w[e+128>>2];f=w[w[b>>2]+8>>2];w[114256]=0;b=V(f|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break I}if(!b){break E}w[114256]=0;b=Q(261,e+128|0,e- -64|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break I}if(b){b=y[e+64>>1];d=b<<8|b>>>8}f=0;w[114256]=0;b=Q(261,e+128|0,e- -64|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break I}if(b){b=y[e+64>>1];f=b<<8|b>>>8}b=w[e+128>>2];g=w[w[b>>2]+36>>2];w[114256]=0;b=S(g|0,b|0,w[e+136>>2],4)|0;g=w[114256];w[114256]=0;if((g|0)==1){break I}L:{if(b){b=w[e+136>>2]+4|0;break L}b=w[e+128>>2];g=w[w[b>>2]+24>>2];w[114256]=0;b=V(g|0,b|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break I}}w[e+136>>2]=b;b=x[a+484376|0];g=w[a+484360>>2];w[114256]=0;da(317,g+(b<<5)|0,e+128|0,d&65535,65535,65535)|0;b=w[114256];w[114256]=0;if((b|0)==1){break I}v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=f;b=w[e+132>>2];M:{if(!b){break M}d=w[b+4>>2];w[b+4>>2]=d-1;if(d){break M}ob[w[w[b>>2]+8>>2]](b);Ib(b)}w[114256]=0;U(316,e+128|0,e+216|0,1346458708);b=w[114256];w[114256]=0;if((b|0)==1){break H}b=w[e+128>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}if(b){break J}f=0;break F}d=P()|0;Bb(e+128|0);break b}w[114256]=0;b=Q(261,e+128|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}if(!b){f=0;v[a+480188>>1]=0;break F}b=y[e+64>>1];d=b<<8|b>>>8;v[a+480188>>1]=d;f=0;if(b){break G}break F}d=P()|0;Bb(e+128|0);break c}d=P()|0;break c}if((d&65535)>>>0>32){break F}d=0;w[114256]=0;b=Q(261,e+128|0,e- -64|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break d}if(b){b=y[e+64>>1];d=b<<8|b>>>8}w[114256]=0;T(215,a+484344|0,d&65535);b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=Q(268,e+128|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}N:{if(!b){break N}f=0;O:{b=w[e+64>>2];m=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);switch(m-841887796|0){case 1:break F;case 0:case 2:break N;default:break O}}if(m){break F}}f=1}b=w[e+132>>2];P:{if(!b){break P}d=w[b+4>>2];w[b+4>>2]=d-1;if(d){break P}ob[w[w[b>>2]+8>>2]](b);Ib(b)}d=0;if(!f){break z}w[114256]=0;U(316,e+200|0,e+216|0,1398157625);b=w[114256];w[114256]=0;Q:{R:{S:{if((b|0)!=1){b=w[e+200>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(!b){break Q}b=w[e+200>>2];d=w[w[b>>2]+36>>2];w[114256]=0;b=S(d|0,b|0,w[e+208>>2],2)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}T:{if(b){f=w[e+208>>2]+2|0;break T}b=w[e+200>>2];d=w[w[b>>2]+24>>2];w[114256]=0;f=V(d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}}w[114256]=0;w[e+208>>2]=f;b=Q(268,e+200|0,e+128|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(b){b=w[e+128>>2];d=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}else{d=0}n=Tb((+(d>>>0)*2.3283064365386963e-10+ +(z[a+480204>>2]/1e4>>>0))*1e4);b=-1;U:{if(n>=4294967295){break U}b=0;if(n<=0){break U}b=~~n>>>0;if(n<4294967296&n>=0){break U}b=0}w[a+480204>>2]=b;w[114256]=0;Q(318,e+200|0,e+128|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}b=y[a+480188>>1];if(b){b=b-1&65535;d=(b>>>0>=31?31:b)+1|0;b=0;while(1){f=y[(e+128|0)+(b<<1)>>1];f=(f<<8|f>>>8)&65535;v[((b<<5)+a|0)+480284>>1]=((((f>>>0>=180?180:f)<<23)-752025600>>16)/90|0)+128;b=b+1|0;if((d|0)!=(b|0)){continue}break}}b=w[e+200>>2];d=w[w[b>>2]+36>>2];w[114256]=0;b=S(d|0,b|0,w[e+208>>2],16)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(!b){break S}b=w[e+208>>2]+16|0;break R}d=P()|0;break c}b=w[e+200>>2];d=w[w[b>>2]+24>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}}w[e+208>>2]=b;d=w[e+200>>2];f=w[w[d>>2]+36>>2];w[114256]=0;b=S(f|0,d|0,b|0,2)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(b){w[114256]=0;b=Q(261,e+200|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(b){b=y[e+64>>1];b=(b<<8|b>>>8)&65535;b=b>>>0>=256?256:b}else{b=0}w[a+480200>>2]=b}b=w[e+200>>2];d=w[w[b>>2]+36>>2];w[114256]=0;b=S(d|0,b|0,w[e+208>>2],128)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}V:{if(b){d=w[e+208>>2]+128|0;break V}b=w[e+200>>2];d=w[w[b>>2]+24>>2];w[114256]=0;d=V(d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}}w[114256]=0;w[e+208>>2]=d;b=Q(318,e+200|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(!b){break Q}b=y[a+480188>>1];if(b){b=b-1&65535;d=(b>>>0>=31?31:b)+1|0;b=0;while(1){f=y[(e- -64|0)+(b<<1)>>1];f=(f<<8|f>>>8)&65535;v[((b<<5)+a|0)+480286>>1]=(f>>>0>=128?128:f)>>>1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}w[a+480228>>2]=w[a+480228>>2]<<1}Bb(e+200|0);w[114256]=0;U(316,e+128|0,e+216|0,1413830740);b=w[114256];w[114256]=0;W:{if((b|0)!=1){b=w[e+128>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break W}if(!b){break B}w[114256]=0;b=Q(319,e+128|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(!b){w[e+72>>2]=0;w[e+64>>2]=0;w[e+68>>2]=0;break C}if(y[e+74>>1]!=65535){break C}b=w[e+128>>2];d=w[w[b>>2]+36>>2];w[114256]=0;b=S(d|0,b|0,w[e+136>>2],1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}X:{if(b){b=w[e+136>>2]+1|0;break X}b=w[e+128>>2];d=w[w[b>>2]+24>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}}w[e+136>>2]=b;break C}d=P()|0;break c}break f}a=w[e+132>>2];if(!a){break A}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break A}ob[w[w[a>>2]+8>>2]](a);Ib(a);break A}d=P()|0;break c}b=w[e+128>>2];d=w[w[b>>2]+24>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}w[114256]=0;Z(320,a+1304424|0,e+128|0,b-w[e+136>>2]|0,2)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break B}break f}Bb(e+128|0);w[114256]=0;U(316,e- -64|0,e+216|0,1229869908);b=w[114256];w[114256]=0;if((b|0)==1){break g}b=w[e+64>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}Y:{if(!b){break Y}w[114256]=0;b=Q(261,e- -64|0,e+128|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}Z:{_:{$:{if(!b){h=0;d=0;b=0;break $}b=y[e+128>>1];b=b<<8|b>>>8;h=b&32767;if(h>>>0>3999){break _}d=b<<16>>16;b=(d|0)<0}f=w[e+64>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,w[e+72>>2],C((d>>>14&2)+50|0,h)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}if(!d){break _}d=b;v[a+480190>>1]=h;if(h){j=e+146|0;b=1;while(1){f=b;if(d){w[114256]=0;f=Q(261,e- -64|0,e+128|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}if(f){f=y[e+128>>1];f=f<<8|f>>>8}else{f=0}f=f+1|0}w[114256]=0;g=Q(321,e- -64|0,e+128|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break l}if(!g){Cb(e+128|0,0,50)}aa:{if((f-4e3&65535)>>>0<61537){break aa}g=y[a+480190>>1];f=f&65535;v[a+480190>>1]=f>>>0<g>>>0?g:f;w[114256]=0;g=y[e+250>>1]|y[e+252>>1]<<16;Y(322,e+128|0,(C(f,104)+a|0)+484380|0,g<<8&16711680|g<<24|(g>>>8&65280|g>>>24),m|0);g=w[114256];w[114256]=0;if((g|0)==1){break m}w[114256]=0;Y(209,e+200|0,2,j|0,22);g=w[114256];w[114256]=0;if((g|0)==1){break n}w[114256]=0;w[e+52>>2]=32;w[e+48>>2]=((f<<5)+a|0)+946304;Q(200,e+48|0,e+200|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break o}if(u[e+211|0]>=0){break aa}zb(w[e+200>>2])}f=b&65535;b=b+1|0;if(f>>>0<h>>>0){continue}break}}w[114256]=0;b=Q(261,e- -64|0,e+128|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break j}if(!b|y[e+128>>1]!=1024){break Y}b=y[a+480190>>1];v[a+480192>>1]=b>>>0>=255?255:b;w[114256]=0;U(316,e+200|0,e+216|0,1229278806);b=w[114256];w[114256]=0;ba:{if((b|0)!=1){while(1){b=w[e+64>>2];d=w[w[b>>2]+36>>2];w[114256]=0;b=S(d|0,b|0,w[e+72>>2],15)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ba}if(!b){break Z}w[114256]=0;b=Q(323,e- -64|0,e+48|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ba}if(b){b=y[e+48>>1]}else{u[e+55|0]=0;u[e+56|0]=0;u[e+57|0]=0;u[e+58|0]=0;u[e+59|0]=0;u[e+60|0]=0;u[e+61|0]=0;u[e+62|0]=0;w[e+48>>2]=0;w[e+52>>2]=0;b=0}d=b<<8|(b&65280)>>>8;b=d&65535;if(b>>>0>=y[a+480192>>1]){continue}b=C(b,104)+a|0;u[b+484524|0]=x[e+56|0];f=x[e+55|0];u[b+484523|0]=255;u[b+484525|0]=f;w[114256]=0;b=d+1&65535;d=S(243,a|0,b|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ba}if(!d){continue}b=x[e+53|0]|x[e+54|0]<<8;b=(b<<8|b>>>8)&65535;w[d>>2]=b>>>0>=4095?4095:b;b=x[e+51|0];if((b|0)==255){continue}b=C(b,34)+2|0;if(b>>>0>z[e+208>>2]){f=w[e+200>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ba}if(b>>>0>f>>>0){continue}}w[114256]=0;w[e+208>>2]=b;b=Q(324,e+200|0,e+128|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ba}f=d+48|0;if(b){b=y[e+128>>1]}else{Cb(e+128|0,0,34);b=0}u[d+60|0]=x[d+60|0]|1;w[114256]=0;b=(b<<8|(b&65280)>>>8)&65535;T(287,f|0,(b>>>0>=16?16:b)|0);b=w[114256];w[114256]=0;if((b|0)==1){break ba}b=w[d+52>>2];g=w[d+48>>2];f=b-g>>2;h=(b|0)==(g|0);if(!h){j=f>>>0<=1?1:f;b=0;while(1){k=g+(b<<2)|0;i=(e+128|0)+(b<<1)|0;l=x[i+2|0];u[k+2|0]=l>>>0>=64?64:l;v[k>>1]=x[i+3|0];b=b+1|0;if((j|0)!=(b|0)){continue}break}}b=x[e+52|0];if((b|0)!=255){u[d- -64|0]=b;u[d+63|0]=b;u[d+60|0]=x[d+60|0]|4}if(h){continue}b=f-1|0;u[d+62|0]=b;u[d+61|0]=b;u[d+60|0]=x[d+60|0]|2;continue}}d=P()|0;break h}d=P()|0;Bb(e+200|0);break h}Bb(e- -64|0);break A}Bb(e+200|0)}b=e- -64|0;Bb(b);w[114256]=0;U(325,b|0,e+216|0,1145131092);b=w[114256];w[114256]=0;if((b|0)==1){break s}ca:{da:{ea:{g=w[e+64>>2];q=w[e+68>>2];if((g|0)!=(q|0)){k=a+484344|0;s=c&1;r=(m|0)!=841887798;t=(m|0)!=841887796;while(1){b=w[g+8>>2];d=w[g>>2];f=w[w[d>>2]+36>>2];w[114256]=0;b=S(f|0,d|0,b|0,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break q}fa:{if(b){b=w[g+8>>2]+4|0;break fa}b=w[g>>2];d=w[w[b>>2]+24>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break q}}w[g+8>>2]=b;w[114256]=0;b=Q(261,g|0,e+128|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}d=0;if(b){b=y[e+128>>1];d=b<<8|b>>>8}w[114256]=0;b=Q(261,g|0,e+128|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ca}if(b){b=y[e+128>>1];b=b<<8|b>>>8}else{b=0}j=b&65535;j=r?j:(j>>>0)/z[a+480196>>2]|0;ga:{if(!s){break ga}i=d&65535;if(i>>>0>255){break ga}w[114256]=0;b=S(216,k|0,i|0,j|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ca}if(!b){break ga}if(!r){b=w[g+8>>2];d=w[g>>2];f=w[w[d>>2]+36>>2];w[114256]=0;b=S(f|0,d|0,b|0,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ca}ha:{if(b){b=w[g+8>>2]+4|0;break ha}b=w[g>>2];d=w[w[b>>2]+24>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ca}}w[g+8>>2]=b;l=0;if(!y[a+480188>>1]){break ga}while(1){w[114256]=0;f=Q(261,g|0,e+128|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break da}d=0;b=0;if(f){b=y[e+128>>1];b=b<<8|b>>>8}w[114256]=0;U(188,e+128|0,g|0,(b&1)+b&65535);b=w[114256];w[114256]=0;f=0;h=0;if((b|0)==1){break t}ia:{ja:{while(1){b=w[e+128>>2];o=w[w[b>>2]+36>>2];w[114256]=0;b=S(o|0,b|0,w[e+136>>2],6)|0;o=w[114256];w[114256]=0;if((o|0)==1){break ia}if(!(b&d>>>0<j>>>0)){break ja}b=w[k>>2];w[114256]=0;b=b+C(i,52)|0;o=V(218,b|0)|0;p=w[114256];w[114256]=0;ka:{la:{if((p|0)!=1){b=w[b>>2];w[114256]=0;Q(326,e+128|0,e+48|0)|0;p=w[114256];w[114256]=0;if((p|0)==1){break u}b=b+C(C(d,o)+l|0,6)|0;d=u[e+48|0];if((d-1&255)>>>0>95){break la}u[b|0]=d+13;if(!f){break ka}u[b+3|0]=19;u[b+5|0]=((f|0)>=15?15:f)|208;break ka}break u}if((d|0)>=0){break ka}if(f){u[b+3|0]=19;u[b+5|0]=((f|0)>=15?15:f)|192;break ka}u[b|0]=254}if(x[e+49|0]){u[b+2|0]=1;d=x[e+49|0];u[b+4|0]=d>>>0>=64?64:d}d=x[e+50|0];if(d){u[b+1|0]=d}d=x[e+51|0];if(d|x[e+52|0]){u[b+3|0]=d;u[b+5|0]=x[e+52|0];w[114256]=0;X(312,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break u}}b=u[e+53|0];d=b&255;if((b|0)<0){w[114256]=0;b=Q(241,e+128|0,e+200|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break u}d=d<<8&32512|(b?x[e+200|0]:0)}b=w[a+480196>>2];w[114256]=0;h=d+h|0;U(327,e+200|0,h|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){d=w[e+200>>2];f=w[e+204>>2];continue}break}break u}b=w[e+132>>2];ma:{if(!b){break ma}d=w[b+4>>2];w[b+4>>2]=d-1;if(d){break ma}ob[w[w[b>>2]+8>>2]](b);Ib(b)}l=l+1|0;if(l>>>0<y[a+480188>>1]){continue}break ga}break}break u}b=w[k>>2];w[114256]=0;b=b+C(i,52)|0;V(218,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ea}if(!j){break ga}d=y[a+480188>>1];b=w[b>>2];h=0;while(1){i=d&65535;d=0;f=0;na:{if(!i){break na}while(1){oa:{w[114256]=0;Q(328,g|0,e+128|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break oa}d=w[e+128>>2];pa:{if(!t){if(d<<24>>24>0){u[b|0]=(C((d&240)>>>4|0,12)+(d&15)|0)+12}i=d>>>8|0;if((i&255)>>>0>=4){u[b+2|0]=1;u[b+4|0]=((i&252)>>>2|0)-1}u[b+5|0]=d>>>24;d=d>>>16|0;u[b+3|0]=d&15;u[b+1|0]=i<<4&48|(d&240)>>>4;break pa}w[114256]=0;w[e+40>>2]=d;w[e+8>>2]=d;T(329,e+8|0,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break oa}u[b+1|0]=x[b+1|0]|x[e+128|0]&48}w[114256]=0;X(312,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break oa}d=x[b+3|0];qa:{if(d>>>0>11){break qa}d=1<<d;ra:{if(!(d&2240)){if(!(d&12)){break qa}if(!x[b+5|0]){break ra}break qa}d=x[b+5|0];i=d&240;if(i){u[b+5|0]=i;break qa}if(d){break qa}}u[b+3|0]=0}b=b+6|0;d=y[a+480188>>1];f=f+1|0;if(d>>>0>(f&65535)>>>0){continue}break na}break}d=P()|0;break p}h=h+1|0;if((j|0)!=(h|0)){continue}break}}g=g+16|0;if((q|0)!=(g|0)){continue}break}}gc(e- -64|0);w[114256]=0;U(316,e+128|0,e+216|0,1346458702);b=w[114256];w[114256]=0;if((b|0)==1){d=P()|0;break c}b=w[e+128>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{if((d|0)!=1){Ga:{if(!b){break Ga}w[e+72>>2]=0;w[e+64>>2]=0;w[e+68>>2]=0;b=0;Ha:{while(1){Ia:{d=w[e+128>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+136>>2],1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Ia}if(!d|((w[a+484348>>2]-w[a+484344>>2]|0)/52&65535)>>>0<=b>>>0){break Ha}w[114256]=0;S(330,e+128|0,e- -64|0,32)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Ia}d=w[a+484344>>2];w[114256]=0;Q(270,d+C(b,52)|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Ia}b=b+1|0;continue}break}d=P()|0;if(u[e+75|0]>=0){break Fa}zb(w[e+64>>2]);break Fa}if(u[e+75|0]>=0){break Ga}zb(w[e+64>>2])}b=e+128|0;Bb(b);w[114256]=0;U(316,b|0,e+216|0,1414679374);b=w[114256];w[114256]=0;if((b|0)==1){break Ea}b=w[e+128>>2];d=w[w[b>>2]+8>>2];w[114256]=0;b=V(d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Aa}if(!b){break Ba}w[e+72>>2]=0;w[e+64>>2]=0;w[e+68>>2]=0;b=0;while(1){d=w[e+128>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+136>>2],1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break Da}if(!(d&y[a+480188>>1]>b>>>0)){break Ca}w[114256]=0;S(330,e+128|0,e- -64|0,32)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Da}w[114256]=0;w[e+204>>2]=20;w[e+200>>2]=((b<<5)+a|0)+480289;Q(200,e+200|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break Da}b=b+1|0;continue}}d=P()|0}Bb(e+128|0);break c}d=P()|0;break c}d=P()|0;if(u[e+75|0]>=0){break za}zb(w[e+64>>2]);break za}if(u[e+75|0]>=0){break Ba}zb(w[e+64>>2])}b=e+128|0;Bb(b);w[114256]=0;U(325,b|0,e+216|0,1145129300);b=w[114256];w[114256]=0;if((b|0)==1){break ya}b=w[e+128>>2];f=w[e+132>>2];if((b|0)!=(f|0)){g=c&2;while(1){w[114256]=0;c=Q(261,b|0,e- -64|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}d=0;if(c){c=y[e+64>>1];d=c<<8|c>>>8}Ja:{if(!g){break Ja}c=d&65535;if(c>>>0>=y[a+480190>>1]){break Ja}d=C(c,104)+a|0;c=y[d+484518>>1];w[114256]=0;v[e+66>>1]=1;u[e+65|0]=c&64?2:1;u[e+64|0]=c&1?16:8;S(214,e- -64|0,d+484484|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break w}}b=b+16|0;if((f|0)!=(b|0)){continue}break}}gc(e+128|0);if((m|0)!=841887798){break wa}w[114256]=0;b=Q(1,e+128|0,5406)|0;c=w[114256];w[114256]=0;if((c|0)==1){break xa}c=w[b>>2];w[e+32>>2]=w[b+4>>2];d=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+35|0]=d;u[e+36|0]=d>>>8;u[e+37|0]=d>>>16;u[e+38|0]=d>>>24;f=x[b+11|0];break va}d=P()|0}Bb(e+128|0);break c}d=P()|0;break c}d=P()|0;break c}w[114256]=0;U(316,e+128|0,e+216|0,1447383635);b=w[114256];w[114256]=0;Ka:{La:{Ma:{Na:{Oa:{if((b|0)!=1){b=w[e+128>>2];c=w[w[b>>2]+8>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ua}if(!b){break La}d=0;w[114256]=0;b=Q(268,e+128|0,e- -64|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Oa}if(b){b=w[e+64>>2];d=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}w[114256]=0;b=Q(1,e+16|0,10905)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Na}f=w[b>>2];w[e+204>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+207|0]=c;u[e+208|0]=c>>>8;u[e+209|0]=c>>>16;u[e+210|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[e+211|0]=c;w[e+200>>2]=f;w[e+48>>2]=d>>>4;w[e+12>>2]=d&15;Y(331,e- -64|0,e+200|0,e+48|0,e+12|0);c=w[114256];w[114256]=0;if((c|0)==1){break Ma}w[e+32>>2]=w[e+68>>2];c=x[e+71|0]|x[e+72|0]<<8|(x[e+73|0]<<16|x[e+74|0]<<24);u[e+35|0]=c;u[e+36|0]=c>>>8;u[e+37|0]=c>>>16;u[e+38|0]=c>>>24;f=x[e+75|0];u[e+75|0]=0;c=w[e+64>>2];u[e+64|0]=0;if(u[e+211|0]<0){zb(w[e+200>>2])}if(u[b+11|0]>=0){break Ka}zb(w[b>>2]);break Ka}d=P()|0;break c}d=P()|0;break x}d=P()|0;break x}d=P()|0;if(u[e+211|0]<0){zb(w[e+200>>2])}if(u[b+11|0]>=0){break x}zb(w[b>>2]);break x}w[114256]=0;b=Q(1,e- -64|0,4708)|0;c=w[114256];w[114256]=0;if((c|0)==1){break sa}c=w[b>>2];w[e+32>>2]=w[b+4>>2];d=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+35|0]=d;u[e+36|0]=d>>>8;u[e+37|0]=d>>>16;u[e+38|0]=d>>>24;f=x[b+11|0]}Bb(e+128|0)}w[114256]=0;d=Q(1,e+200|0,4708)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ta}b=a+1304436|0;if(u[a+1304447|0]<0){zb(w[b>>2])}g=w[d+4>>2];w[b>>2]=w[d>>2];w[b+4>>2]=g;w[b+8>>2]=w[d+8>>2];w[114256]=0;d=Q(1,e+48|0,6073)|0;b=w[114256];w[114256]=0;if((b|0)==1){break ta}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}g=w[d+4>>2];w[b>>2]=w[d>>2];w[b+4>>2]=g;w[b+8>>2]=w[d+8>>2];if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}w[a+1304460>>2]=c;w[a+1304464>>2]=w[e+32>>2];b=a+1304467|0;c=x[e+35|0]|x[e+36|0]<<8|(x[e+37|0]<<16|x[e+38|0]<<24);u[b|0]=c;u[b+1|0]=c>>>8;u[b+2|0]=c>>>16;u[b+3|0]=c>>>24;w[a+1304496>>2]=2;u[a+1304471|0]=f;d=1;break z}d=P()|0;break x}d=P()|0;if(f<<24>>24>=0){break c}zb(c);break c}d=P()|0;break x}d=P()|0;break p}d=P()|0;break p}d=P()|0;break p}d=0}Ac(e+216|0)}jb=e+256|0;return d|0}Bb(e+128|0);break c}d=P()|0;gc(e+128|0);break c}d=P()|0;break p}d=P()|0;Bb(e+128|0);break p}d=P()|0;break p}d=P()|0;break c}d=P()|0;break h}d=P()|0}gc(e- -64|0);break c}d=P()|0;if(u[e+211|0]>=0){break h}zb(w[e+200>>2]);break h}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=P()|0}Bb(e- -64|0);break c}d=P()|0;break c}d=P()|0;Bb(e+128|0);break c}d=P()|0;Bb(e+200|0);break c}d=P()|0;Bb(e+128|0)}Ac(e+216|0)}R(d|0);M()}function Fd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=D(0),l=0,m=0,n=0,o=0,p=0,q=0;e=jb-2752|0;jb=e;a:{b:{c:{d:{e:{f:{h=w[c>>2];g:{if(!(ob[w[w[h>>2]+8>>2]](h)|0)){break g}i=w[b>>2];if(i>>>0>=268435457){w[b>>2]=268435456;i=268435456}q=w[c+8>>2];h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{d=x[a+3|0];w:{if((d-4&255)>>>0<=4){d=w[c>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break o}f=d-w[c+8>>2]|0;break w}if(d>>>0>18){break t}h=1<<d;if(!(h&126991)){if(!(h&396800)){break t}break v}if(x[a|0]){break v}f=0}break u}w[114256]=0;d=Q(368,a|0,i|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}w[114256]=0;f=S(482,e+2728|0,c|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break s}d=0;g=w[f+4>>2];m=w[f+8>>2];g=g?g:w[f+12>>2]!=(m|0)?m:0;if(!g){break h}f=w[f>>2]}d=x[a+3|0]}x:{y:{h=d&255;if(h>>>0<=18){i=1<<h;if(i&126991){break y}h=0;if(i&396800){break x}}i=w[b>>2];break p}h=!x[a|0]}i=w[b>>2];if(h|i>>>0<262145){break p}h=0;d=d&255;j=f-(((d|0)==11)<<4)|0;j=f>>>0>=j>>>0?j:0;if(d>>>0>16){break r}z:{if(!(1<<d&126991)){if((d|0)==11){break z}break r}if(!(x[a|0]&7)){break r}}if((j|0)<0){break i}d=j<<1;break q}b=P()|0;break a}n=x[a+1|0]==1?1:2;A:{B:{switch(d|0){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:h=x[a|0];break A;case 9:h=16;break A;case 11:h=4;break A;case 10:case 17:case 18:break B;default:break A}}h=8}d=C(h,n)>>>3|0;h=(d+j|0)-1|0;d=((h>>>0<j>>>0?-1:h)>>>0)/(d>>>0)|0}h=d;if(d>>>0<i>>>0){break l}break i}d=d&255;if(d>>>0>8){break k}if(1<<d&432){break m}if((d|0)!=6){break k}d=0;if(f>>>0<10){break h}w[114256]=0;Q(242,c|0,4)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break n}}b=P()|0;break b}w[114256]=0;d=Q(232,c|0,e+576|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break j}h=w[e+576>>2];i=w[c+8>>2];j=i-8|0;w[c+8>>2]=i>>>0>=j>>>0?j:0;d=d?h:0;d=d>>>0>f>>>0?f:d;d=((d>>>0>50529027?-1:C(d,85))>>>0)/(x[a|0]>>>3>>>0)|0;h=d;i=w[b>>2];if(i>>>0>d>>>0){break l}break k}d=x[a+1|0]==1;h=C(d?8:4,f);d=(d?536870911:1073741823)>>>0<f>>>0?-1:h;if(i>>>0<=d>>>0){break k}}w[b>>2]=d;i=h}if(i){break i}d=0;break h}b=P()|0;break b}v[b+34>>1]=y[b+34>>1]&65470|x[a|0]>15|(x[a+1|0]!=1)<<6;w[114256]=0;d=V(252,b|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break c}if(!d){d=0;w[b>>2]=0;break h}w[e+576>>2]=184549640;C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))==184549640){d=0;w[114256]=0;a=Q(741,c|0,e+576|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(!a){break C}a=w[b>>2];d=w[c>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break L}a=a+1>>>1|0;d=d-w[c+8>>2]|0;f=a>>>0<d>>>0?a:d;if(f){a=g+16|0;b=w[b+20>>2];d=0;g=f;while(1){h=d;d=e+576|0;h=h+x[d|x[a|0]&15]|0;u[b|0]=h;d=x[d|x[a|0]>>>4]+(h&255)|0;u[b+1|0]=d;a=a+1|0;b=b+2|0;g=g-1|0;if(g){continue}break}}d=f+16|0;break C}b=P()|0;break b}M:{N:{O:{P:{i=x[a+3|0];switch(i-4|0){case 3:break K;case 4:break M;case 5:break N;case 2:break O;case 0:case 1:break P;default:break J}}w[114256]=0;a=Z(742,e+1640|0,c|0,b|0,(i|0)==5|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}a=w[a+4>>2];Q:{if(!a){break Q}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break Q}ob[w[w[a>>2]+8>>2]](a);Ib(a)}d=w[c+8>>2]-q|0;break C}if(x[a+1|0]!=1){break J}w[114256]=0;Q(242,c|0,4)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}w[114256]=0;a=Q(232,c|0,e+576|0)|0;d=w[114256];w[114256]=0;R:{S:{T:{if((d|0)!=1){w[114256]=0;d=w[e+576>>2];i=Q(241,c|0,e+576|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break T}w[114256]=0;j=x[e+576|0];f=a?d:0;a=Z(743,e+576|0,c|0,f|0,1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break R}n=w[a+12>>2];p=w[b+20>>2];d=w[a>>2];g=w[a+4>>2];h=w[a+8>>2];o=w[b>>2];b=y[b+34>>1];w[114256]=0;ga(744,(g?g:(h|0)!=(n|0)?h:0)|0,d|0,p|0,C(C(o,b&64?2:1),b&1?2:1)|0,(i?j:0)<<24>>24);b=w[114256];w[114256]=0;if((b|0)!=1){break S}b=P()|0;c=w[a+8>>2];if(!c){break b}w[a+12>>2]=c;zb(c);break b}b=P()|0;break b}b=P()|0;break b}d=(d>>>0>f>>>0?f:d)+9|0;b=w[a+8>>2];if(!b){break C}w[a+12>>2]=b;zb(b);break C}b=P()|0;break b}if(x[a+1|0]!=1){break J}h=x[a|0];if((h|0)!=16){break I}a=w[b>>2];d=f>>>1|0;f=a>>>0<d>>>0?a:d;if(f){a=w[b+20>>2];b=0;d=f;while(1){h=x[g|0]+b|0;b=h+x[g+1|0]|0;v[a>>1]=b<<8|h&255;a=a+2|0;g=g+2|0;d=d-1|0;if(d){continue}break}}d=f<<1;break C}if(x[a+1|0]!=1){break J}h=x[a|0];if(h>>>0>16){break H}f=w[c+8>>2];g=w[c>>2];h=w[w[g>>2]+36>>2];d=0;w[114256]=0;f=S(h|0,g|0,f|0,8)|0;g=w[114256];w[114256]=0;if((g|0)==1){break c}if(!f){break C}w[114256]=0;f=Q(232,c|0,e+576|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break c}f=f?w[e+576>>2]:0;if(f>>>0<4){break C}w[114256]=0;U(188,e+560|0,c|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}w[e+576>>2]=w[e+560>>2];d=w[e+564>>2];w[e+580>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+572>>2];w[e+584>>2]=w[e+568>>2];w[e+588>>2]=d;Cb(e+592|0,0,1040);Bb(e+560|0);d=w[e+576>>2];f=w[w[d>>2]+24>>2];w[114256]=0;g=V(f|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(!w[b>>2]){break E}j=x[a|0];n=(j|0)!=16;f=0;a=0;h=0;while(1){U:{if(n){break U}w[114256]=0;a=Q(131,e+576|0,8)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break U}b=W(75512)|0;break F}w[114256]=0;p=Q(131,e+576|0,1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break G}w[114256]=0;d=Q(131,e+576|0,1)|0;i=w[114256];w[114256]=0;if((i|0)==1){break G}V:{W:{X:{if(!d){i=8;while(1){w[114256]=0;d=Q(131,e+576|0,1)|0;o=w[114256];w[114256]=0;if((o|0)==1){break V}if(d){break X}i=i+16|0;continue}}w[114256]=0;d=Q(131,e+576|0,3)|0;i=w[114256];w[114256]=0;if((i|0)!=1){break W}break G}w[114256]=0;d=Q(131,e+576|0,4)|0;o=w[114256];w[114256]=0;if((o|0)==1){break G}d=d+i|0}h=(h&255)+(((p?-1:0)^d)&255)|0;Y:{if((j|0)!=16){u[w[b+20>>2]+f|0]=h;break Y}v[w[b+20>>2]+(f<<1)>>1]=a&255|h<<8}f=f+1|0;if(f>>>0<z[b>>2]){continue}break E}break}b=W(75512)|0;break F}b=P()|0;break b}if(x[a+1|0]!=1){break J}h=x[a|0];if(h>>>0>16){break H}d=0;if(f>>>0<5){break C}d=w[b+20>>2];f=w[b>>2];a=y[b+34>>1];w[114256]=0;d=S(745,c|0,d|0,C(C(f,a&64?2:1),a&1?2:1)|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}h=x[a|0]}d=h&255;if((d|0)!=16){if((d|0)!=8){break H}d=0;Z:{switch(x[a+1|0]-1|0){case 0:_:{$:{aa:{switch(i|0){default:switch(i-10|0){case 0:break _;case 2:break $;default:break C};case 0:a=w[b>>2];f=a>>>0<f>>>0?a:f;if(!f){break C}a=w[b+20>>2];b=f;while(1){u[a|0]=x[g|0];a=a+1|0;g=g+1|0;b=b-1|0;if(b){continue}break};d=f;break C;case 2:break $;case 1:break aa}}a=w[b>>2];f=a>>>0<f>>>0?a:f;if(!f){break C}a=w[b+20>>2];b=f;while(1){u[a|0]=x[g|0]^128;a=a+1|0;g=g+1|0;b=b-1|0;if(b){continue}break}d=f;break C}a=w[b>>2];f=a>>>0<f>>>0?a:f;if(!f){break C}a=w[b+20>>2];b=0;d=f;while(1){b=x[g|0]+b|0;u[a|0]=b;a=a+1|0;g=g+1|0;d=d-1|0;if(d){continue}break}d=f;break C}a=w[b>>2];f=a>>>0<f>>>0?a:f;if(!f){break C}a=w[b+20>>2];b=f;while(1){d=u[g|0];d=(d|0)>=63?63:d;u[a|0]=((d|0)<=-64?-64:d)<<1;a=a+1|0;g=g+1|0;b=b-1|0;if(b){continue}break};d=f;break C;case 2:ba:{switch(i|0){case 0:w[114256]=0;d=S(746,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 1:w[114256]=0;d=S(747,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;default:if((i|0)!=12){break C}break;case 2:break ba}}w[114256]=0;d=Z(748,b|0,g|0,f|0,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}if(x[a+3|0]!=12){break C}f=w[b>>2]<<1;if((f|0)<=0){break C}a=w[b+20>>2];b=f+a|0;while(1){u[a+1|0]=x[a+1|0]+x[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break};break C;case 1:break Z;default:break C}}ca:{switch(i|0){case 0:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){u[a|0]=x[g|0];u[a+1|0]=x[g+1|0];a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;case 1:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){u[a|0]=x[g|0]^128;u[a+1|0]=x[g+1|0]^128;a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;case 2:break ca;default:break C}}a=w[b>>2];d=f>>>1|0;f=a>>>0<d>>>0?a:d;if(f){a=w[b+20>>2];b=0;d=f;i=0;while(1){i=x[g|0]+i|0;u[a|0]=i;b=x[g+1|0]+b|0;u[a+1|0]=b;a=a+2|0;g=g+2|0;d=d-1|0;if(d){continue}break}}d=f<<1;break C}da:{ea:{fa:{ga:{ha:{d=x[a+1|0];switch(d-1|0){case 2:break ga;case 0:break ha;default:break fa}}ia:{switch(x[a+2|0]){case 0:ja:{switch(i|0){case 0:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){v[a>>1]=x[g|0]|x[g+1|0]<<8;a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;case 1:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){v[a>>1]=(x[g|0]|x[g+1|0]<<8)^32768;a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;default:d=0;if((i|0)!=12){break C}break;case 2:break ja}}a=w[b>>2];d=f>>>1|0;f=a>>>0<d>>>0?a:d;if(f){a=w[b+20>>2];b=0;d=f;while(1){b=(x[g|0]|x[g+1|0]<<8)+b|0;v[a>>1]=b;a=a+2|0;g=g+2|0;d=d-1|0;if(d){continue}break}}d=f<<1;break C;case 1:break ia;default:break ea}}d=0;ka:{switch(i|0){case 0:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){f=x[g|0]|x[g+1|0]<<8;v[a>>1]=f<<8|f>>>8;a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;case 1:a=w[b>>2];d=f>>>1|0;d=a>>>0<d>>>0?a:d;if(d){a=w[b+20>>2];b=d;while(1){f=x[g|0]|x[g+1|0]<<8;v[a>>1]=(f<<8|f>>>8)^32768;a=a+2|0;g=g+2|0;b=b-1|0;if(b){continue}break}}d=d<<1;break C;case 2:break ka;default:break C}}a=w[b>>2];d=f>>>1|0;f=a>>>0<d>>>0?a:d;if(f){a=w[b+20>>2];b=0;d=f;while(1){h=b;b=x[g|0]|x[g+1|0]<<8;b=h+(b<<8|b>>>8)|0;v[a>>1]=b;a=a+2|0;g=g+2|0;d=d-1|0;if(d){continue}break}}d=f<<1;break C}d=0;la:{switch(x[a+2|0]){case 0:ma:{switch(i|0){case 0:w[114256]=0;d=S(749,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 1:w[114256]=0;d=S(750,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;default:if((i|0)!=12){break C}break;case 2:break ma}}w[114256]=0;d=Z(751,b|0,g|0,f|0,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}if(x[a+3|0]!=12){break C}f=w[b>>2];if(f<<1<=0){break C}a=w[b+20>>2];b=a+(f<<2)|0;while(1){v[a+2>>1]=y[a+2>>1]+y[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break};break C;case 1:break la;default:break C}}na:{switch(i|0){case 0:w[114256]=0;d=S(752,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 1:w[114256]=0;d=S(753,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 2:break na;default:break C}}w[114256]=0;d=Z(754,b|0,g|0,f|0,0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}a=x[a+2|0];h=(d|0)==2;if(a|(d|0)!=2){break da}d=0;oa:{switch(i|0){case 0:w[114256]=0;d=S(755,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 1:w[114256]=0;d=S(756,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 2:break oa;default:break C}}w[114256]=0;d=Z(757,b|0,g|0,f|0,0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}a=x[a+2|0];h=0}d=0;if(!h|(a&255)!=1){break C}pa:{switch(i|0){case 0:w[114256]=0;d=S(758,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 1:w[114256]=0;d=S(759,b|0,g|0,f|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C;case 2:break pa;default:break C}}w[114256]=0;d=Z(760,b|0,g|0,f|0,0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}d=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{h=h&255;if((h|0)!=64){if((h|0)!=32){if((h|0)!=24){break C}Da:{switch(x[a+1|0]-1|0){case 0:if((i|0)==16){break ya}if(i){break C}d=w[b>>2];f=(f>>>0)/3|0;d=d>>>0<f>>>0?d:f;if(!x[a+2|0]){if(d){a=w[b+20>>2];b=d;while(1){v[a>>1]=x[g+1|0]|x[g+2|0]<<8;a=a+2|0;g=g+3|0;b=b-1|0;if(b){continue}break}}d=C(d,3);break C}if(d){a=w[b+20>>2];b=d;while(1){f=x[g|0]|x[g+1|0]<<8;v[a>>1]=f<<8|f>>>8;a=a+2|0;g=g+3|0;b=b-1|0;if(b){continue}break}}d=C(d,3);break C;case 1:break Da;default:break C}}if((i|0)==16){break ya}if(i){break C}if(!x[a+2|0]){w[114256]=0;v[e+36>>1]=y[e+552>>1];d=Z(761,b|0,g|0,f|0,e+36|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+38>>1]=y[e+544>>1];d=Z(762,b|0,g|0,f|0,e+38|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}Ea:{Fa:{j=x[a+1|0];switch(j-1|0){case 1:break Ea;case 0:break Fa;default:break C}}h=0;Ga:{switch(i|0){case 3:break Ca;case 0:break Ga;default:break xa}}d=w[b>>2];f=f>>>2|0;d=d>>>0<f>>>0?d:f;if(!x[a+2|0]){if(d){a=w[b+20>>2];b=d;while(1){v[a>>1]=x[g+2|0]|x[g+3|0]<<8;a=a+2|0;g=g+4|0;b=b-1|0;if(b){continue}break}}d=d<<2;break C}if(d){a=w[b+20>>2];b=d;while(1){f=x[g|0]|x[g+1|0]<<8;v[a>>1]=f<<8|f>>>8;a=a+2|0;g=g+4|0;b=b-1|0;if(b){continue}break}}d=d<<2;break C}h=1;Ha:{switch(i|0){case 3:break Ba;case 0:break Ha;default:break xa}}if(!x[a+2|0]){w[114256]=0;v[e+140>>1]=y[e+536>>1];d=Z(763,b|0,g|0,f|0,e+140|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+142>>1]=y[e+528>>1];d=Z(764,b|0,g|0,f|0,e+142|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}Ia:{switch(x[a+1|0]-1|0){case 0:Ja:{switch(i|0){case 3:break Aa;case 0:break Ja;case 1:case 2:break C;default:break wa}}d=w[b>>2];f=f>>>3|0;d=d>>>0<f>>>0?d:f;if(!x[a+2|0]){if(d){a=w[b+20>>2];b=d;while(1){v[a>>1]=x[g+6|0]|x[g+7|0]<<8;a=a+2|0;g=g+8|0;b=b-1|0;if(b){continue}break}}d=d<<3;break C}if(d){a=w[b+20>>2];b=d;while(1){f=x[g|0]|x[g+1|0]<<8;v[a>>1]=f<<8|f>>>8;a=a+2|0;g=g+8|0;b=b-1|0;if(b){continue}break}}d=d<<3;break C;case 1:break Ia;default:break C}}Ka:{switch(i|0){default:if((i|0)==15){break va}break C;case 3:break za;case 0:break Ka;case 1:case 2:break C}}if(!x[a+2|0]){w[114256]=0;v[e+216>>1]=y[e+520>>1];d=Z(765,b|0,g|0,f|0,e+216|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+218>>1]=y[e+512>>1];d=Z(766,b|0,g|0,f|0,e+218|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}if(!x[a+2|0]){w[114256]=0;v[e+136>>1]=y[e+504>>1];d=Z(767,b|0,g|0,f|0,e+136|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+138>>1]=y[e+496>>1];d=Z(768,b|0,g|0,f|0,e+138|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}if(!x[a+2|0]){w[114256]=0;v[e+144>>1]=y[e+488>>1];d=Z(769,b|0,g|0,f|0,e+144|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+146>>1]=y[e+480>>1];d=Z(770,b|0,g|0,f|0,e+146|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}if(!x[a+2|0]){w[114256]=0;v[e+148>>1]=y[e+472>>1];d=Z(771,b|0,g|0,f|0,e+148|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+150>>1]=y[e+464>>1];d=Z(772,b|0,g|0,f|0,e+150|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}if(!x[a+2|0]){w[114256]=0;v[e+220>>1]=y[e+456>>1];d=Z(773,b|0,g|0,f|0,e+220|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[114256]=0;v[e+222>>1]=y[e+448>>1];d=Z(774,b|0,g|0,f|0,e+222|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[e+576>>2]=-2147483648;La:{if(!x[a+2|0]){w[114256]=0;w[e+16>>2]=w[e+440>>2];w[e+436>>2]=0;a=w[e+436>>2];w[e+8>>2]=w[e+432>>2];w[e+12>>2]=a;d=da(775,b|0,g|0,f|0,e+576|0,e+8|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break La}break qa}w[114256]=0;w[e+32>>2]=w[e+424>>2];w[e+420>>2]=0;a=w[e+420>>2];w[e+24>>2]=w[e+416>>2];w[e+28>>2]=a;d=da(776,b|0,g|0,f|0,e+576|0,e+24|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break qa}}if(!d){break C}a=w[e+576>>2];if((a|0)==-2147483648){break C}v[b+34>>1]=y[b+34>>1]|8192;f=b;b=BV(y[b+32>>1],0,a,0)+1073741824|0;a=nb;a=b>>>0<1073741824?a+1|0:a;a=(a&2147483647)<<1|b>>>31;v[f+32>>1]=a?a>>>0>=64?64:a:1;break C}Ma:{switch(i-15|0){case 1:w[e+576>>2]=-2147483648;Na:{if(!x[a+2|0]){w[114256]=0;w[e+80>>2]=w[e+408>>2];w[e+404>>2]=0;a=w[e+404>>2];w[e+72>>2]=w[e+400>>2];w[e+76>>2]=a;d=da(777,b|0,g|0,f|0,e+576|0,e+72|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break Na}break ra}w[114256]=0;w[e+96>>2]=w[e+392>>2];w[e+388>>2]=0;a=w[e+388>>2];w[e+88>>2]=w[e+384>>2];w[e+92>>2]=a;d=da(778,b|0,g|0,f|0,e+576|0,e+88|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break ra}}if(!d){break C}a=w[e+576>>2];if((a|0)==-2147483648){break C}v[b+34>>1]=y[b+34>>1]|8192;f=b;b=BV(y[b+32>>1],0,a,0)+1073741824|0;a=nb;a=b>>>0<1073741824?a+1|0:a;a=(a&2147483647)<<1|b>>>31;v[f+32>>1]=a?a>>>0>=64?64:a:1;break C;case 0:break Ma;default:break ua}}w[e+576>>2]=1065353216;Oa:{if(!x[a+2|0]){w[114256]=0;w[e+372>>2]=0;w[e+376>>2]=1065353216;a=w[e+380>>2];w[e+112>>2]=w[e+376>>2];w[e+116>>2]=a;a=w[e+372>>2];w[e+104>>2]=w[e+368>>2];w[e+108>>2]=a;d=da(779,b|0,g|0,f|0,e+576|0,e+104|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break Oa}break sa}w[114256]=0;w[e+356>>2]=0;w[e+360>>2]=1065353216;a=w[e+364>>2];w[e+128>>2]=w[e+360>>2];w[e+132>>2]=a;a=w[e+356>>2];w[e+120>>2]=w[e+352>>2];w[e+124>>2]=a;d=da(780,b|0,g|0,f|0,e+576|0,e+120|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break sa}}if(!d){break C}k=A[e+576>>2];if(k==D(1)){break C}k=_b(D(H(D(G(D(k*D(y[b+32>>1])),D(64))),D(1))));a=65535;Pa:{if(k>=D(65535)){break Pa}a=0;if(k<=D(0)){break Pa}a=~~k>>>0;if(k<D(4294967296)&k>=D(0)){break Pa}a=0}v[b+32>>1]=a;v[b+34>>1]=y[b+34>>1]|8192;break C}if((i|0)!=15){break C}}w[e+576>>2]=0;w[e+580>>2]=1072693248;Qa:{if(!x[a+2|0]){w[114256]=0;w[e+336>>2]=0;w[e+340>>2]=1072693248;w[e+328>>2]=0;w[e+332>>2]=0;w[e+160>>2]=0;w[e+164>>2]=0;w[e+168>>2]=0;w[e+172>>2]=1072693248;a=w[e+348>>2];w[e+176>>2]=w[e+344>>2];w[e+180>>2]=a;a=w[e+324>>2];w[e+152>>2]=w[e+320>>2];w[e+156>>2]=a;d=da(781,b|0,g|0,f|0,e+576|0,e+152|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break Qa}break ta}w[114256]=0;w[e+304>>2]=0;w[e+308>>2]=1072693248;w[e+296>>2]=0;w[e+300>>2]=0;w[e+192>>2]=0;w[e+196>>2]=0;w[e+200>>2]=0;w[e+204>>2]=1072693248;a=w[e+316>>2];w[e+208>>2]=w[e+312>>2];w[e+212>>2]=a;a=w[e+292>>2];w[e+184>>2]=w[e+288>>2];w[e+188>>2]=a;d=da(782,b|0,g|0,f|0,e+576|0,e+184|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break ta}}if(!d){break C}l=B[e+576>>3];if(l==1){break C}l=Tb(H(G(l*+y[b+32>>1],64),1));a=65535;Ra:{if(l>=65535){break Ra}a=0;if(l<=0){break Ra}a=~~l>>>0;if(l<4294967296&l>=0){break Ra}a=0}v[b+32>>1]=a;v[b+34>>1]=y[b+34>>1]|8192;break C}Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{if((j|0)==1){_a:{switch(i-13|0){case 1:break Za;case 0:break _a;default:break Va}}if(!x[a+2|0]){w[e+280>>2]=939524096;a=e+280|0;break Ya}w[e+272>>2]=939524096;a=e+272|0;break Wa}if(!((i|0)==13&h)){break Va}if(!x[a+2|0]){w[e+264>>2]=939524096;a=e+264|0;break Ua}w[e+256>>2]=939524096;a=e+256|0;break Sa}if(x[a+2|0]){break Xa}w[e+248>>2]=872415232;a=e+248|0}w[114256]=0;d=w[a+4>>2];w[e+56>>2]=w[a>>2];w[e+60>>2]=d;d=Z(783,b|0,g|0,f|0,e+56|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[e+240>>2]=872415232;a=e+240|0}w[114256]=0;d=w[a+4>>2];w[e+64>>2]=w[a>>2];w[e+68>>2]=d;d=Z(784,b|0,g|0,f|0,e- -64|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}if(!((i|0)==14&h)){break C}if(x[a+2|0]){break Ta}w[e+232>>2]=872415232;a=e+232|0}w[114256]=0;d=w[a+4>>2];w[e+40>>2]=w[a>>2];w[e+44>>2]=d;d=Z(785,b|0,g|0,f|0,e+40|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}w[e+224>>2]=872415232;a=e+224|0}w[114256]=0;d=w[a+4>>2];w[e+48>>2]=w[a>>2];w[e+52>>2]=d;d=Z(786,b|0,g|0,f|0,e+48|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}break C}b=P()|0;break b}b=P()|0;break b}b=P()|0;break b}b=P()|0;break b}b=W(75512)|0}if((kb|0)!=(fa(75512)|0)){break e}$(b|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break D}}d=g+4|0;Bb(e+576|0);break C}b=P()|0;break e}a=d+q|0;if(a>>>0>z[c+8>>2]){b=w[c>>2];f=w[w[b>>2]+24>>2];w[114256]=0;b=V(f|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}if(a>>>0>b>>>0){break h}}w[c+8>>2]=a}if(!m){break g}zb(m)}jb=e+2752|0;return d|0}b=P()|0}Bb(e+576|0);break b}b=P()|0;break b}b=P()|0}if(!m){break a}zb(m)}R(b|0);M()}function wO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-48|0;jb=g;i=Hb(g+32|0,7439);f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;a:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break a}d=(k|0)<0?w[i>>2]:i;b:{c:{h=(e|0)<0;if(!h){if(e){break c}break b}if(!j){break b}h=!Jb(h?w[c>>2]:c,d,j);break a}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break a}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break a}h=1}if((k|0)<0){zb(w[i>>2])}d:{if(h){Ve(a,0,w[b+24>>2]+1304448|0);break d}i=Hb(g+32|0,6904);h=0;f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;e:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break e}d=(k|0)<0?w[i>>2]:i;f:{g:{h=(e|0)<0;if(!h){if(e){break g}break f}if(!j){break f}h=!Jb(h?w[c>>2]:c,d,j);break e}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break e}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break e}h=1}if((k|0)<0){zb(w[i>>2])}if(h){Ve(a,0,w[b+24>>2]+1304436|0);break d}i=Hb(g+32|0,7269);h=0;f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;h:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break h}d=(k|0)<0?w[i>>2]:i;i:{j:{h=(e|0)<0;if(!h){if(e){break j}break i}if(!j){break i}h=!Jb(h?w[c>>2]:c,d,j);break h}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break h}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break h}h=1}if((k|0)<0){zb(w[i>>2])}if(h){Ve(a,0,w[b+24>>2]+1304484|0);break d}i=Hb(g+32|0,6896);h=0;f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;k:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break k}d=(k|0)<0?w[i>>2]:i;l:{m:{h=(e|0)<0;if(!h){if(e){break m}break l}if(!j){break l}h=!Jb(h?w[c>>2]:c,d,j);break k}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break k}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break k}h=1}if((k|0)<0){zb(w[i>>2])}if(h){Ve(a,0,w[b+24>>2]+1304472|0);break d}i=Hb(g+32|0,4428);h=0;f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;n:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break n}d=(k|0)<0?w[i>>2]:i;o:{p:{h=(e|0)<0;if(!h){if(e){break p}break o}if(!j){break o}h=!Jb(h?w[c>>2]:c,d,j);break n}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break n}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break n}h=1}if((k|0)<0){zb(w[i>>2])}q:{if(h){e=g+32|0;d=w[w[b+24>>2]+480184>>2];b=jb-16|0;jb=b;c=77360;r:{while(1){if((d|0)==w[c>>2]){c=w[c+8>>2];s:{if(c){Hb(b,c);break s}w[b+8>>2]=0;w[b>>2]=0;w[b+4>>2]=0}w[114256]=0;U(6,e|0,0,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[b+11|0]>=0){break r}zb(w[b>>2]);break r}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}c=c+12|0;if((c|0)!=77408){continue}break}w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0}jb=b+16|0;w[114256]=0;U(9,a|0,0,e|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0;if(u[g+43|0]>=0){break q}zb(w[g+32>>2]);break q}i=Hb(g+32|0,6881);h=0;f=x[c+11|0];e=f<<24>>24;d=x[i+11|0];k=d<<24>>24;j=(e|0)<0?w[c+4>>2]:f;t:{if((j|0)!=(((k|0)<0?w[i+4>>2]:d)|0)){break t}d=(k|0)<0?w[i>>2]:i;u:{v:{h=(e|0)<0;if(!h){if(e){break v}break u}if(!j){break u}h=!Jb(h?w[c>>2]:c,d,j);break t}e=c;while(1){j=x[e|0];l=x[d|0];h=(j|0)==(l|0);if((j|0)!=(l|0)){break t}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}break t}h=1}if((k|0)<0){zb(w[i>>2])}if(h){h=w[w[b+24>>2]+480184>>2];b=jb+-64|0;jb=b;w[b+44>>2]=0;w[b+48>>2]=0;w[b+40>>2]=b+40|4;e=g+32|0;w[e+8>>2]=0;w[e>>2]=0;w[e+4>>2]=0;c=77360;w:{x:{y:{z:{while(1){A:{if((h|0)!=w[c>>2]){break A}d=w[c+4>>2];w[114256]=0;d=Q(1,b+24|0,d|0)|0;f=w[114256];w[114256]=0;B:{C:{D:{if((f|0)!=1){w[114256]=0;Y(916,b+56|0,b+40|0,d|0,d|0);f=w[114256];w[114256]=0;if((f|0)==1){break z}if(!x[b+60|0]){break B}f=x[e+11|0];E:{if(!(f<<24>>24<0?w[e+4>>2]:f)){break E}w[114256]=0;f=Q(1,b+8|0,13502)|0;i=w[114256];w[114256]=0;if((i|0)==1){break D}i=w[f>>2];w[114256]=0;m=i;i=x[b+19|0];k=i<<24>>24<0;S(2,e|0,(k?m:f)|0,(k?w[b+12>>2]:i)|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break C}if(u[b+19|0]>=0){break E}zb(w[f>>2])}f=w[d>>2];w[114256]=0;m=f;f=x[b+35|0];i=f<<24>>24<0;S(2,e|0,(i?m:d)|0,(i?w[b+28>>2]:f)|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break B}c=P()|0;break y}c=P()|0;break x}c=P()|0;break y}c=P()|0;if(u[b+19|0]>=0){break y}zb(w[f>>2]);break y}if(u[b+35|0]>=0){break A}zb(w[d>>2])}c=c+12|0;if((c|0)!=77408){continue}break}_j(b+40|0,w[b+44>>2]);jb=b- -64|0;break w}c=P()|0}if(u[b+35|0]>=0){break x}zb(w[d>>2])}if(u[e+11|0]<0){zb(w[e>>2])}_j(b+40|0,w[b+44>>2]);R(c|0);M()}w[114256]=0;U(9,a|0,0,e|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0;if(u[g+43|0]>=0){break q}zb(w[g+32>>2]);break q}e=Hb(g+32|0,4494);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}if(d){Ve(a,0,w[b+24>>2]+1304460|0);break d}e=Hb(g+32|0,2106);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}if(d){Ve(a,0,w[b+24>>2]+1304412|0);break d}e=Hb(g+32|0,7807);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}if(d){d=w[b+24>>2];F:{if(u[d+1304411|0]>=0){b=d+1304400|0;w[g+40>>2]=w[b+8>>2];c=w[b+4>>2];w[g+32>>2]=w[b>>2];w[g+36>>2]=c;break F}Ge(g+32|0,w[d+1304400>>2],w[d+1304404>>2]);d=w[b+24>>2]}b=w[d+1304496>>2];w[114256]=0;Y(229,a|0,0,b|0,g+32|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0;if(u[g+43|0]>=0){break q}zb(w[g+32>>2]);break q}e=Hb(g+32|0,7212);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}if(d){b=w[b+24>>2];c=w[b+1304504>>2];if(!(w[c-36>>2]?(c|0)!=w[b+1304500>>2]:0)){w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break d}j=g+32|0;b=jb-144|0;jb=b;c=c-48|0;Fb(b+96|0,c,44);h=w[c+44>>2];if(h){Fb(b+44|0,c,44);c=w[b+44>>2];e=c>>31;m=c;d=C(w[b+48>>2],60);f=C(w[b+52>>2],3600);i=f;c=d+f|0;f=(d>>31)+(f>>31)|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=m+d|0;e=e+f|0;e=c>>>0<d>>>0?e+1|0:e;f=c;d=(w[b+60>>2]+10|0)%12|0;c=(w[b+64>>2]+((d<<24>>24)/-10<<24>>24)|0)+1900|0;c=(((((w[b+56>>2]+((c|0)/4|0)|0)+C(c,365)|0)+((c|0)/-100|0)|0)+((c|0)/400|0)|0)+((C(d,20054016)+327680>>16)/10<<16>>16)|0)-719469|0;d=BV(c,c>>31,86400,0);c=f+d|0;e=nb+e|0;w[b+88>>2]=c;w[b+92>>2]=c>>>0<d>>>0?e+1|0:e;d=2147483647;n=Tb(+(h>>>0)*.054945054945054944);c=-1;G:{if(n>=0x8000000000000000){break G}d=-2147483648;c=0;if(n<=-0x8000000000000000){break G}if(E(n)<0x8000000000000000){d=E(n)>=1?~~(n>0?G(I(n*2.3283064365386963e-10),4294967295):J((n-+(~~n>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~n>>>0;break G}c=0}h=w[b+88>>2];f=c+h|0;e=w[b+92>>2]+d|0;w[b+88>>2]=f;w[b+92>>2]=f>>>0<h>>>0?e+1|0:e;c=w[b+92>>2];l=c;h=w[b+88>>2];c=CV(h,c,86400,0);f=c+719468|0;e=f>>31;c=f;k=e;d=BV(c,e,1e4,0)+14780|0;e=nb;i=d;e=d>>>0<14780?e+1|0:e;d=e;e=CV(i,d,-14609700,-1)+c|0;f=k+nb|0;o=CV(i,d,365242500,0);m=o+e|0;e=nb+(c>>>0>e>>>0?f+1|0:f)|0;e=m>>>0<o>>>0?e+1|0:e;o=CV(i,d,-146097e4,-1);m=o+m|0;f=nb+e|0;f=m>>>0<o>>>0?f+1|0:f;e=m;d=CV(i,d,3652425,0);i=nb;m=i;o=BV(d,i,-365,-1);i=o+e|0;e=nb+f|0;e=i>>>0<o>>>0?e+1|0:e;H:{if((e|0)>0|(e|0)>=0){c=d;break H}e=d-1|0;d=BV(e,m-!d|0,-365,-1)+c|0;f=k+nb|0;f=c>>>0>d>>>0?f+1|0:f;c=e;e=(c|0)/-4|0;i=e;d=e+d|0;e=(e>>31)+f|0;e=d>>>0<i>>>0?e+1|0:e;f=(c|0)/100|0;d=f+d|0;e=(f>>31)+e|0;e=d>>>0<f>>>0?e+1|0:e;f=(c|0)/-400|0;i=f;d=f+d|0;f=(f>>31)+e|0;f=d>>>0<i>>>0?f+1|0:f;i=d;e=f}w[b+120>>2]=0;w[b+124>>2]=0;w[b+136>>2]=0;w[b+128>>2]=0;w[b+132>>2]=0;p=b,q=DV(CV(h,l,3600,0),nb,24),w[p+104>>2]=q;d=CV(h,l,60,0);f=nb;p=b,q=DV(d,f,60),w[p+100>>2]=q;p=b,q=h-BV(d,f,60,0)|0,w[p+96>>2]=q;h=c;c=BV(i,e,100,0)+52|0;f=nb;c=CV(c,c>>>0<52?f+1|0:f,3060,0);e=c+2|0;d=(e|0)/12|0;w[b+116>>2]=(h+d|0)-1900;w[b+112>>2]=e-C(d,12);c=BV(c,nb,306,0)+5|0;e=nb;c=CV(c,c>>>0<5?e+1|0:e,-10,-1)+i|0;w[b+108>>2]=c+1}c=Fb(b,b+96|0,44);b=jb-208|0;jb=b;w[b+176>>2]=0;w[114256]=0;w[b+168>>2]=0;w[b+172>>2]=0;e=Q(1,b+152|0,9284)|0;d=w[114256];w[114256]=0;I:{J:{K:{if((d|0)!=1){d=w[c+20>>2];if(!d){break J}w[114256]=0;w[b+120>>2]=d+1900;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=4;U(101,b+136|0,b+120|0,b+184|0);d=w[114256];w[114256]=0;L:{M:{N:{if((d|0)!=1){w[114256]=0;d=u[b+147|0];f=(d|0)<0;S(2,b+168|0,(f?w[b+136>>2]:b+136|0)|0,(f?w[b+140>>2]:d&255)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break N}if(u[b+147|0]<0){zb(w[b+136>>2])}if(z[c+16>>2]<=11){break M}break J}a=P()|0;break L}a=P()|0;if(u[b+147|0]>=0){break L}zb(w[b+136>>2]);break L}w[114256]=0;f=Q(1,b+120|0,12628)|0;d=w[114256];w[114256]=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{if((d|0)!=1){d=w[c+16>>2];w[114256]=0;w[b+88>>2]=d+1;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=2;U(101,b+104|0,b+88|0,b+184|0);d=w[114256];w[114256]=0;if((d|0)==1){break ra}w[114256]=0;d=u[b+115|0];h=(d|0)<0;d=S(2,f|0,(h?w[b+104>>2]:b+104|0)|0,(h?w[b+108>>2]:d&255)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break qa}w[b+144>>2]=w[d+8>>2];h=w[d+4>>2];w[b+136>>2]=w[d>>2];w[b+140>>2]=h;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;w[114256]=0;d=x[b+147|0];h=d<<24>>24<0;S(2,b+168|0,(h?w[b+136>>2]:b+136|0)|0,(h?w[b+140>>2]:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break pa}if(u[b+147|0]<0){zb(w[b+136>>2])}if(u[b+115|0]<0){zb(w[b+104>>2])}if(u[f+11|0]<0){zb(w[f>>2])}if(w[c+12>>2]-32>>>0<4294967265){break J}w[114256]=0;f=Q(1,b+104|0,12628)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ma}w[114256]=0;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=2;U(101,b+88|0,c+12|0,b+184|0);d=w[114256];w[114256]=0;if((d|0)==1){break la}w[114256]=0;d=u[b+99|0];h=(d|0)<0;d=S(2,f|0,(h?w[b+88>>2]:b+88|0)|0,(h?w[b+92>>2]:d&255)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break ka}w[b+144>>2]=w[d+8>>2];h=w[d+4>>2];w[b+136>>2]=w[d>>2];w[b+140>>2]=h;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;w[114256]=0;d=x[b+147|0];h=d<<24>>24<0;S(2,b+168|0,(h?w[b+136>>2]:b+136|0)|0,(h?w[b+140>>2]:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ja}if(u[b+147|0]<0){zb(w[b+136>>2])}if(u[b+99|0]<0){zb(w[b+88>>2])}if(u[f+11|0]<0){zb(w[f>>2])}d=w[c+8>>2];f=w[c+4>>2];if(!(w[c>>2]|(d|f))|d>>>0>23|f>>>0>59){break J}w[114256]=0;d=Q(1,b+136|0,9435)|0;f=w[114256];w[114256]=0;if((f|0)==1){break ga}h=w[d>>2];i=w[d+4>>2];f=x[d+11|0];w[114256]=0;m=h;h=f<<24>>24<0;S(2,b+168|0,(h?m:d)|0,(h?i:f)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break fa}if(u[d+11|0]<0){zb(w[d>>2])}if(w[c+32>>2]>0){w[114256]=0;d=Q(1,b+88|0,11521)|0;f=w[114256];w[114256]=0;if((f|0)==1){break O}if(u[e+11|0]<0){zb(w[e>>2])}f=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+8>>2]}w[114256]=0;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=2;U(101,b+40|0,c+8|0,b+184|0);d=w[114256];w[114256]=0;if((d|0)==1){break ea}w[114256]=0;d=Q(1,b+24|0,10095)|0;f=w[114256];w[114256]=0;if((f|0)==1){break da}h=w[d>>2];i=w[d+4>>2];f=x[d+11|0];w[114256]=0;m=h;h=f<<24>>24<0;f=S(2,b+40|0,(h?m:d)|0,(h?i:f)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break ca}w[b- -64>>2]=w[f+8>>2];h=w[f+4>>2];w[b+56>>2]=w[f>>2];w[b+60>>2]=h;w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;w[114256]=0;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=2;U(101,b+8|0,c+4|0,b+184|0);f=w[114256];w[114256]=0;if((f|0)==1){break ba}w[114256]=0;f=u[b+19|0];h=(f|0)<0;f=S(2,b+56|0,(h?w[b+8>>2]:b+8|0)|0,(h?w[b+12>>2]:f&255)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break aa}w[b+80>>2]=w[f+8>>2];h=w[f+4>>2];w[b+72>>2]=w[f>>2];w[b+76>>2]=h;w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;w[114256]=0;f=x[b+83|0];h=f<<24>>24<0;S(2,b+168|0,(h?w[b+72>>2]:b+72|0)|0,(h?w[b+76>>2]:f)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break $}if(u[b+83|0]<0){zb(w[b+72>>2])}if(u[b+19|0]<0){zb(w[b+8>>2])}if(u[b+67|0]<0){zb(w[b+56>>2])}if(u[d+11|0]<0){zb(w[d>>2])}if(u[b+51|0]<0){zb(w[b+40>>2])}if(z[c>>2]<62){break W}w[114256]=0;U(102,j|0,b+168|0,e|0);d=w[114256];w[114256]=0;if((d|0)==1){break V}break I}a=P()|0;break L}a=P()|0;break na}a=P()|0;break oa}a=P()|0;if(u[b+147|0]>=0){break oa}zb(w[b+136>>2])}if(u[b+115|0]>=0){break na}zb(w[b+104>>2])}if(u[f+11|0]>=0){break L}zb(w[f>>2]);break L}a=P()|0;break L}a=P()|0;break ha}a=P()|0;break ia}a=P()|0;if(u[b+147|0]>=0){break ia}zb(w[b+136>>2])}if(u[b+99|0]>=0){break ha}zb(w[b+88>>2])}if(u[f+11|0]>=0){break L}zb(w[f>>2]);break L}a=P()|0;break L}a=P()|0;if(u[d+11|0]>=0){break L}zb(w[d>>2]);break L}a=P()|0;break L}a=P()|0;break X}a=P()|0;break Y}a=P()|0;break Z}a=P()|0;break _}a=P()|0;if(u[b+83|0]>=0){break _}zb(w[b+72>>2])}if(u[b+19|0]>=0){break Z}zb(w[b+8>>2])}if(u[b+67|0]>=0){break Y}zb(w[b+56>>2])}if(u[d+11|0]>=0){break X}zb(w[d>>2])}if(u[b+51|0]>=0){break L}zb(w[b+40>>2]);break L}w[114256]=0;f=Q(1,b+56|0,10095)|0;d=w[114256];w[114256]=0;if((d|0)==1){break U}w[114256]=0;u[b+200|0]=44;w[b+192>>2]=-1;w[b+196>>2]=0;w[b+184>>2]=1025;w[b+188>>2]=2;U(101,b+40|0,c|0,b+184|0);d=w[114256];w[114256]=0;if((d|0)==1){break T}w[114256]=0;d=u[b+51|0];h=(d|0)<0;d=S(2,f|0,(h?w[b+40>>2]:b+40|0)|0,(h?w[b+44>>2]:d&255)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break S}w[b+80>>2]=w[d+8>>2];h=w[d+4>>2];w[b+72>>2]=w[d>>2];w[b+76>>2]=h;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;w[114256]=0;d=x[b+83|0];h=d<<24>>24<0;S(2,b+168|0,(h?w[b+72>>2]:b+72|0)|0,(h?w[b+76>>2]:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break R}if(u[b+83|0]<0){zb(w[b+72>>2])}if(u[b+51|0]<0){zb(w[b+40>>2])}if(u[f+11|0]<0){zb(w[f>>2])}f=w[e>>2];h=w[e+4>>2];d=x[e+11|0];w[114256]=0;i=f;f=d<<24>>24<0;S(2,b+168|0,(f?i:e)|0,(f?h:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break J}}a=P()|0;break L}a=P()|0;break L}a=P()|0;break P}a=P()|0;break Q}a=P()|0;if(u[b+83|0]>=0){break Q}zb(w[b+72>>2])}if(u[b+51|0]>=0){break P}zb(w[b+40>>2])}if(u[f+11|0]>=0){break L}zb(w[f>>2]);break L}a=P()|0}if(u[e+11|0]>=0){break K}zb(w[e>>2]);break K}a=P()|0}if(u[b+179|0]<0){zb(w[b+168>>2])}R(a|0);M()}d=w[b+172>>2];w[j>>2]=w[b+168>>2];w[j+4>>2]=d;w[j+8>>2]=w[b+176>>2];w[b+176>>2]=0;w[b+168>>2]=0;w[b+172>>2]=0}if(u[e+11|0]<0){zb(w[e>>2])}if(u[b+179|0]<0){zb(w[b+168>>2])}jb=b+208|0;jb=c+144|0;w[114256]=0;U(9,a|0,0,j|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0;if(u[g+43|0]>=0){break q}zb(w[g+32>>2]);break q}e=Hb(g+32|0,7998);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if(d){Qo(g+32|0,w[b+24>>2]+1304424|0);c=x[g+43|0];if(c<<24>>24<0?w[g+36>>2]:c){break ua}c=w[b+24>>2];w[114256]=0;c=V(1468,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ta}Ca:{switch(c|0){case 0:w[114256]=0;T(1469,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;break ua}d=P()|0;break sa;case 1:w[114256]=0;T(1470,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;break ua}d=P()|0;break sa;case 2:d=x[g+43|0];f=d<<24>>24;c=w[g+36>>2];if(!((f|0)<0?c:d)){w[114256]=0;T(1469,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break Ba}if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;d=x[g+43|0];f=d;c=w[g+36>>2]}if(f<<24>>24<0?c:d){break ua}w[114256]=0;T(1470,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;break ua}d=P()|0;break sa;case 3:d=x[g+43|0];f=d<<24>>24;c=w[g+36>>2];if(!((f|0)<0?c:d)){w[114256]=0;T(1470,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break Aa}if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;d=x[g+43|0];f=d;c=w[g+36>>2]}if(f<<24>>24<0?c:d){break ua}w[114256]=0;T(1469,g+16|0,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[g+43|0]<0){zb(w[g+32>>2])}w[g+40>>2]=w[g+24>>2];c=w[g+20>>2];w[g+32>>2]=w[g+16>>2];w[g+36>>2]=c;break ua}d=P()|0;break sa;case 4:w[114256]=0;T(1469,g+16|0,b|0);c=w[114256];w[114256]=0;Da:{Ea:{if((c|0)!=1){w[114256]=0;T(1470,g|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break Da}e=x[g+27|0];c=e<<24>>24<0;e=c?w[g+20>>2]:e;if(!e){break Ea}w[114256]=0;S(92,g+32|0,(c?w[g+16>>2]:g+16|0)|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break Ea}break wa}d=P()|0;break sa}e=x[g+11|0];c=e<<24>>24;e=(c|0)<0?w[g+4>>2]:e;if(e){w[114256]=0;S(92,g+32|0,((c|0)<0?w[g>>2]:g)|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break wa}c=x[g+11|0]}if(c<<24>>24<0){zb(w[g>>2])}if(u[g+27|0]>=0){break ua}zb(w[g+16>>2]);break ua}d=P()|0;break va;case 5:break Ca;default:break ua}}w[114256]=0;T(1469,g+16|0,b|0);c=w[114256];w[114256]=0;Fa:{Ga:{if((c|0)!=1){w[114256]=0;T(1470,g|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break Fa}e=x[g+11|0];c=e<<24>>24<0;e=c?w[g+4>>2]:e;if(!e){break Ga}w[114256]=0;S(92,g+32|0,(c?w[g>>2]:g)|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break Ga}break ya}d=P()|0;break sa}e=x[g+27|0];c=e<<24>>24;e=(c|0)<0?w[g+20>>2]:e;if(e){w[114256]=0;S(92,g+32|0,((c|0)<0?w[g+16>>2]:g+16|0)|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ya}}if(u[g+11|0]<0){zb(w[g>>2])}if(u[g+27|0]>=0){break ua}zb(w[g+16>>2]);break ua}d=P()|0;break xa}e=Hb(g+32|0,1958);d=Yd(c,e);if(u[e+11|0]<0){zb(w[e>>2])}if(d){c=g+32|0;Qo(c,w[b+24>>2]+1304424|0);b=w[w[b+24>>2]+1304496>>2];w[114256]=0;Y(229,a|0,0,b|0,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0;if(u[g+43|0]>=0){break q}zb(w[g+32>>2]);break q}e=c;c=Hb(g+32|0,3559);e=Yd(e,c);if(u[c+11|0]<0){zb(w[c>>2])}if(e){w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;d=w[b+68>>2];c=w[b+72>>2];if((d|0)==(c|0)){break d}e=1;while(1){if(!(e&1)){w[114256]=0;Q(1315,a|0,17238)|0;b=w[114256];w[114256]=0;if((b|0)==1){break za}}e=w[d>>2];f=w[d+4>>2];b=x[d+11|0];w[114256]=0;i=e;e=b<<24>>24<0;S(92,a|0,(e?i:d)|0,(e?f:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break za}e=0;d=d+12|0;if((c|0)!=(d|0)){continue}break}break d}Hb(a,17256);break d}d=P()|0;break sa}d=P()|0;break sa}d=P()|0;if(u[a+11|0]>=0){break q}zb(w[a>>2]);break q}d=P()|0;if(u[g+11|0]>=0){break xa}zb(w[g>>2])}if(u[g+27|0]>=0){break sa}zb(w[g+16>>2]);break sa}d=P()|0;if(u[g+11|0]>=0){break va}zb(w[g>>2])}if(u[g+27|0]>=0){break sa}zb(w[g+16>>2]);break sa}b=w[w[b+24>>2]+1304496>>2];w[114256]=0;Y(229,a|0,0,b|0,g+32|0);a=w[114256];w[114256]=0;if((a|0)==1){break ta}if(u[g+43|0]>=0){break d}zb(w[g+32>>2]);break d}d=P()|0}if(u[g+43|0]>=0){break q}zb(w[g+32>>2])}R(d|0);M()}jb=g+48|0}function Is(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,v=0,y=0,A=0,B=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;r=jb-48|0;jb=r;a:{if(c>>>0<=2){c=c<<2;H=w[c+60988>>2];I=w[c+60976>>2];while(1){c=w[b+4>>2];b:{if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break b}c=ac(b)}if(mf(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=w[b+4>>2];if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break c}c=ac(b)}e:{f:{while(1){if(u[g+1459|0]==(c|32)){g:{if(g>>>0>6){break g}c=w[b+4>>2];if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break g}c=ac(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=w[b+116>>2];if((c|0)>0|(c|0)>=0){w[b+4>>2]=w[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){w[b+4>>2]=w[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}k=jb-16|0;jb=k;g=(p(D(D(o|0)*D(O))),j(2));b=g&2147483647;h:{if(b-8388608>>>0<=2130706431){l=b<<25;c=(b>>>7|0)+1065353216|0;break h}l=g<<25;c=g>>>7|2147418112;if(b>>>0>=2139095040){break h}l=0;c=0;if(!b){break h}c=b;b=F(b);$c(k,c,0,0,0,b+81|0);i=w[k>>2];h=w[k+4>>2];l=w[k+8>>2];c=w[k+12>>2]^65536|16265-b<<16}w[r>>2]=i;w[r+4>>2]=h;w[r+8>>2]=l;w[r+12>>2]=g&-2147483648|c;jb=k+16|0;i=w[r+8>>2];h=w[r+12>>2];l=w[r>>2];k=w[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(u[g+5923|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=w[b+4>>2];if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break l}c=ac(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=w[b+4>>2];o:{if((g|0)!=w[b+104>>2]){w[b+4>>2]=g+1;g=x[g|0];break o}g=ac(b)}if((g&-33)==88){f=jb-432|0;jb=f;c=w[b+4>>2];p:{if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;g=x[c|0];break p}g=ac(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=w[b+4>>2];if((c|0)==w[b+104>>2]){break s}w[b+4>>2]=c+1;g=x[c|0];break r}}else{c=w[b+4>>2];if((c|0)!=w[b+104>>2]){v=1;w[b+4>>2]=c+1;g=x[c|0]}else{v=1;g=ac(b)}continue}break}g=ac(b)}e=1;if((g|0)!=48){break q}while(1){c=s;s=c-1|0;t=t-!c|0;c=w[b+4>>2];t:{if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;g=x[c|0];break t}g=ac(b)}if((g|0)==48){continue}break}v=1}k=1073676288;while(1){u:{c=g|32;v:{w:{K=g-48|0;if(K>>>0<10){break w}if((g|0)!=46&c-97>>>0>=6){break u}if((g|0)!=46){break w}if(e){break u}e=1;s=i;t=h;break v}c=(g|0)>57?c-87|0:K;x:{if((h|0)<=0&i>>>0<=7|(h|0)<0){y=c+(y<<4)|0;break x}if(!h&i>>>0<=28){Bd(f+48|0,c);jc(f+32|0,E,G,l,k,0,0,0,1073414144);E=w[f+32>>2];G=w[f+36>>2];l=w[f+40>>2];k=w[f+44>>2];jc(f+16|0,w[f+48>>2],w[f+52>>2],w[f+56>>2],w[f+60>>2],E,G,l,k);qd(f,w[f+16>>2],w[f+20>>2],w[f+24>>2],w[f+28>>2],m,q,A,B);A=w[f+8>>2];B=w[f+12>>2];m=w[f>>2];q=w[f+4>>2];break x}if(!c|n){break x}jc(f+80|0,E,G,l,k,0,0,0,1073610752);qd(f- -64|0,w[f+80>>2],w[f+84>>2],w[f+88>>2],w[f+92>>2],m,q,A,B);A=w[f+72>>2];B=w[f+76>>2];n=1;m=w[f+64>>2];q=w[f+68>>2]}c=i+1|0;h=c?h:h+1|0;i=c;v=1}c=w[b+4>>2];if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;g=x[c|0]}else{g=ac(b)}continue}break}y:{if(!v){c=w[b+116>>2];z:{A:{if((c|0)>0|(c|0)>=0){c=w[b+4>>2];w[b+4>>2]=c-1;if(!d){break A}w[b+4>>2]=c-2;if(!e){break z}w[b+4>>2]=c-3;break z}if(d){break z}}ce(b,0,0)}te(f+96|0,+(o|0)*0);m=w[f+96>>2];q=w[f+100>>2];c=w[f+108>>2];b=w[f+104>>2];break y}if((h|0)<=0&i>>>0<=7|(h|0)<0){l=i;k=h;while(1){y=y<<4;c=l+1|0;k=c?k:k+1|0;l=c;if((c|0)!=8|k){continue}break}}B:{C:{D:{if((g&-33)==80){l=Hs(b,d);c=nb;k=c;if(l|(c|0)!=-2147483648){break B}if(d){c=w[b+116>>2];if((c|0)>0|(c|0)>=0){break D}break C}m=0;q=0;ce(b,0,0);c=0;b=0;break y}l=0;k=0;if(w[b+116>>2]<0){break B}}w[b+4>>2]=w[b+4>>2]-1}l=0;k=0}if(!y){te(f+112|0,+(o|0)*0);m=w[f+112>>2];q=w[f+116>>2];c=w[f+124>>2];b=w[f+120>>2];break y}b=e?s:i;h=(e?t:h)<<2|b>>>30;b=l+(b<<2)|0;d=h+k|0;d=b>>>0<l>>>0?d+1|0:d;i=b-32|0;h=d-(b>>>0<32)|0;b=h;if(i>>>0>0-H>>>0&(b|0)>=0|(b|0)>0){w[114084]=68;Bd(f+160|0,o);jc(f+144|0,w[f+160>>2],w[f+164>>2],w[f+168>>2],w[f+172>>2],-1,-1,-1,2147418111);jc(f+128|0,w[f+144>>2],w[f+148>>2],w[f+152>>2],w[f+156>>2],-1,-1,-1,2147418111);m=w[f+128>>2];q=w[f+132>>2];c=w[f+140>>2];b=w[f+136>>2];break y}b=H-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=i>>>0|(c|0)<(h|0)){if((y|0)>=0){while(1){qd(f+416|0,m,q,A,B,0,0,0,-1073807360);c=Ns(m,q,A,B,1073610752);b=(c|0)<0;qd(f+400|0,m,q,A,B,b?m:w[f+416>>2],b?q:w[f+420>>2],b?A:w[f+424>>2],b?B:w[f+428>>2]);b=i;i=b-1|0;h=h-!b|0;A=w[f+408>>2];B=w[f+412>>2];m=w[f+400>>2];q=w[f+404>>2];y=y<<1|(c|0)>=0;if((y|0)>=0){continue}break}}d=h-((H>>31)+(i>>>0<H>>>0)|0)|0;b=(i-H|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<I>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:I;E:{if((c|0)>=113){Bd(f+384|0,o);s=w[f+392>>2];t=w[f+396>>2];E=w[f+384>>2];G=w[f+388>>2];h=0;b=0;break E}te(f+352|0,vf(1,144-c|0));Bd(f+336|0,o);E=w[f+336>>2];G=w[f+340>>2];s=w[f+344>>2];t=w[f+348>>2];Ms(f+368|0,w[f+352>>2],w[f+356>>2],w[f+360>>2],w[f+364>>2],E,G,s,t);J=w[f+376>>2];L=w[f+380>>2];h=w[f+372>>2];b=w[f+368>>2]}c=!(y&1)&((Yf(m,q,A,B,0,0,0,0)|0)!=0&(c|0)<32);Ig(f+320|0,c+y|0);jc(f+304|0,E,G,s,t,w[f+320>>2],w[f+324>>2],w[f+328>>2],w[f+332>>2]);d=b;qd(f+272|0,w[f+304>>2],w[f+308>>2],w[f+312>>2],w[f+316>>2],b,h,J,L);b=c;jc(f+288|0,E,G,s,t,b?0:m,b?0:q,b?0:A,b?0:B);qd(f+256|0,w[f+288>>2],w[f+292>>2],w[f+296>>2],w[f+300>>2],w[f+272>>2],w[f+276>>2],w[f+280>>2],w[f+284>>2]);cm(f+240|0,w[f+256>>2],w[f+260>>2],w[f+264>>2],w[f+268>>2],d,h,J,L);b=w[f+240>>2];c=w[f+244>>2];d=w[f+248>>2];h=w[f+252>>2];if(!Yf(b,c,d,h,0,0,0,0)){w[114084]=68}Ls(f+224|0,b,c,d,h,i);m=w[f+224>>2];q=w[f+228>>2];c=w[f+236>>2];b=w[f+232>>2];break y}w[114084]=68;Bd(f+208|0,o);jc(f+192|0,w[f+208>>2],w[f+212>>2],w[f+216>>2],w[f+220>>2],0,0,0,65536);jc(f+176|0,w[f+192>>2],w[f+196>>2],w[f+200>>2],w[f+204>>2],0,0,0,65536);m=w[f+176>>2];q=w[f+180>>2];c=w[f+188>>2];b=w[f+184>>2]}w[r+16>>2]=m;w[r+20>>2]=q;w[r+24>>2]=b;w[r+28>>2]=c;jb=f+432|0;i=w[r+24>>2];h=w[r+28>>2];l=w[r+16>>2];k=w[r+20>>2];break a}if(w[b+116>>2]<0){break n}w[b+4>>2]=w[b+4>>2]-1}g=b;f=o;y=d;d=0;o=0;e=jb-8976|0;jb=e;K=0-H|0;L=K-I|0;F:{G:{while(1){if((c|0)!=48){H:{if((c|0)!=46){break F}b=w[g+4>>2];if((b|0)==w[g+104>>2]){break H}w[g+4>>2]=b+1;c=x[b|0];break G}}else{b=w[g+4>>2];if((b|0)!=w[g+104>>2]){d=1;w[g+4>>2]=b+1;c=x[b|0]}else{d=1;c=ac(g)}continue}break}c=ac(g)}n=1;if((c|0)!=48){break F}while(1){b=i;i=b-1|0;h=h-!b|0;b=w[g+4>>2];I:{if((b|0)!=w[g+104>>2]){w[g+4>>2]=b+1;c=x[b|0];break I}c=ac(g)}if((c|0)==48){continue}break}d=1}w[e+784>>2]=0;J:{K:{b=(c|0)==46;m=c-48|0;L:{M:{N:{O:{if(b|m>>>0<=9){while(1){P:{if(b&1){if(!n){i=l;h=k;n=1;break P}b=!d;break O}b=l+1|0;k=b?k:k+1|0;l=b;if((o|0)<=2044){J=(c|0)==48?J:l;b=(e+784|0)+(o<<2)|0;if(v){m=(C(w[b>>2],10)+c|0)-48|0}w[b>>2]=m;d=1;c=v+1|0;b=(c|0)==9;v=b?0:c;o=b+o|0;break P}if((c|0)==48){break P}w[e+8960>>2]=w[e+8960>>2]|1;J=18396}b=w[g+4>>2];Q:{if((b|0)!=w[g+104>>2]){w[g+4>>2]=b+1;c=x[b|0];break Q}c=ac(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}i=n?i:l;h=n?h:k;if(!(!d|(c&-33)!=69)){m=Hs(g,y);b=nb;q=b;R:{if(m|(b|0)!=-2147483648){break R}if(!y){break L}m=0;q=0;if(w[g+116>>2]<0){break R}w[g+4>>2]=w[g+4>>2]-1}if(!d){break M}h=h+q|0;b=i+m|0;h=b>>>0<m>>>0?h+1|0:h;i=b;break K}b=!d;if((c|0)<0){break N}}if(w[g+116>>2]<0){break N}w[g+4>>2]=w[g+4>>2]-1}if(!b){break K}}w[114084]=28}l=0;k=0;ce(g,0,0);c=0;b=0;break J}b=w[e+784>>2];if(!b){te(e,+(f|0)*0);l=w[e>>2];k=w[e+4>>2];c=w[e+12>>2];b=w[e+8>>2];break J}if(!((i|0)!=(l|0)|(h|0)!=(k|0)|(l>>>0>9&(k|0)>=0|(k|0)>0)|(b>>>I|0?(I|0)<=30:0))){Bd(e+48|0,f);Ig(e+32|0,b);jc(e+16|0,w[e+48>>2],w[e+52>>2],w[e+56>>2],w[e+60>>2],w[e+32>>2],w[e+36>>2],w[e+40>>2],w[e+44>>2]);l=w[e+16>>2];k=w[e+20>>2];c=w[e+28>>2];b=w[e+24>>2];break J}if(i>>>0>K>>>1>>>0&(h|0)>=0|(h|0)>0){w[114084]=68;Bd(e+96|0,f);jc(e+80|0,w[e+96>>2],w[e+100>>2],w[e+104>>2],w[e+108>>2],-1,-1,-1,2147418111);jc(e- -64|0,w[e+80>>2],w[e+84>>2],w[e+88>>2],w[e+92>>2],-1,-1,-1,2147418111);l=w[e+64>>2];k=w[e+68>>2];c=w[e+76>>2];b=w[e+72>>2];break J}b=H-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){w[114084]=68;Bd(e+144|0,f);jc(e+128|0,w[e+144>>2],w[e+148>>2],w[e+152>>2],w[e+156>>2],0,0,0,65536);jc(e+112|0,w[e+128>>2],w[e+132>>2],w[e+136>>2],w[e+140>>2],0,0,0,65536);l=w[e+112>>2];k=w[e+116>>2];c=w[e+124>>2];b=w[e+120>>2];break J}if(v){if((v|0)<=8){b=(e+784|0)+(o<<2)|0;g=w[b>>2];while(1){g=C(g,10);v=v+1|0;if((v|0)!=9){continue}break}w[b>>2]=g}o=o+1|0}S:{n=i;if((J|0)>(i|0)|(J|0)>=9|(i|0)>17){break S}if((n|0)==9){Bd(e+192|0,f);Ig(e+176|0,w[e+784>>2]);jc(e+160|0,w[e+192>>2],w[e+196>>2],w[e+200>>2],w[e+204>>2],w[e+176>>2],w[e+180>>2],w[e+184>>2],w[e+188>>2]);l=w[e+160>>2];k=w[e+164>>2];c=w[e+172>>2];b=w[e+168>>2];break J}if((n|0)<=8){Bd(e+272|0,f);Ig(e+256|0,w[e+784>>2]);jc(e+240|0,w[e+272>>2],w[e+276>>2],w[e+280>>2],w[e+284>>2],w[e+256>>2],w[e+260>>2],w[e+264>>2],w[e+268>>2]);Bd(e+224|0,w[(0-n<<2)+60976>>2]);Ks(e+208|0,w[e+240>>2],w[e+244>>2],w[e+248>>2],w[e+252>>2],w[e+224>>2],w[e+228>>2],w[e+232>>2],w[e+236>>2]);l=w[e+208>>2];k=w[e+212>>2];c=w[e+220>>2];b=w[e+216>>2];break J}b=(C(n,-3)+I|0)+27|0;c=w[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break S}Bd(e+352|0,f);Ig(e+336|0,c);jc(e+320|0,w[e+352>>2],w[e+356>>2],w[e+360>>2],w[e+364>>2],w[e+336>>2],w[e+340>>2],w[e+344>>2],w[e+348>>2]);Bd(e+304|0,w[(n<<2)+60904>>2]);jc(e+288|0,w[e+320>>2],w[e+324>>2],w[e+328>>2],w[e+332>>2],w[e+304>>2],w[e+308>>2],w[e+312>>2],w[e+316>>2]);l=w[e+288>>2];k=w[e+292>>2];c=w[e+300>>2];b=w[e+296>>2];break J}while(1){c=o;o=c-1|0;if(!w[(e+784|0)+(o<<2)>>2]){continue}break}v=0;d=(n|0)%9|0;T:{if(!d){b=0;break T}b=0;d=(n|0)<0?d+9|0:d;U:{if(!c){c=0;break U}i=w[(0-d<<2)+60976>>2];k=1e9/(i|0)|0;m=0;g=0;while(1){h=m;l=(e+784|0)+(g<<2)|0;o=w[l>>2];m=(o>>>0)/(i>>>0)|0;h=h+m|0;w[l>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=C(k,o-C(i,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break U}w[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;V:{while(1){if(((n|0)!=36|z[l>>2]>=10384593)&(n|0)>=36){break V}d=c+2047|0;m=0;while(1){g=d&2047;o=(e+784|0)+(g<<2)|0;d=w[o>>2];k=d>>>3|0;h=d<<29;i=h+m|0;d=k;d=h>>>0>i>>>0?d+1|0:d;h=d;if(!h&i>>>0<1000000001){m=0}else{d=i;m=EV(d,h,1e9,0);i=d-BV(m,nb,1e9,0)|0}w[o>>2]=i;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:i?c:g;d=g-1|0;if((b|0)!=(g|0)){continue}break}v=v-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;i=d+((c+2046&2047)<<2)|0;c=c-1&2047;w[i>>2]=w[i>>2]|w[d+(c<<2)>>2]}n=n+9|0;w[(e+784|0)+(b<<2)>>2]=m;continue}break}W:{X:while(1){i=c+1&2047;k=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;Y:{while(1){d=b;g=0;Z:{while(1){_:{b=d+g&2047;if((b|0)==(c|0)){break _}b=w[(e+784|0)+(b<<2)>>2];l=w[(g<<2)+60928>>2];if(b>>>0<l>>>0){break _}if(b>>>0>l>>>0){break Z}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break Z}i=0;h=0;g=0;l=0;k=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;w[(e+(c<<2)|0)+780>>2]=0}Ig(e+768|0,w[(e+784|0)+(b<<2)>>2]);jc(e+752|0,i,h,l,k,0,0,1342177280,1075633366);qd(e+736|0,w[e+752>>2],w[e+756>>2],w[e+760>>2],w[e+764>>2],w[e+768>>2],w[e+772>>2],w[e+776>>2],w[e+780>>2]);l=w[e+744>>2];k=w[e+748>>2];i=w[e+736>>2];h=w[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Bd(e+720|0,f);jc(e+704|0,i,h,l,k,w[e+720>>2],w[e+724>>2],w[e+728>>2],w[e+732>>2]);l=w[e+712>>2];k=w[e+716>>2];i=0;h=0;m=w[e+704>>2];q=w[e+708>>2];y=v+113|0;g=y-H|0;o=(g|0)<(I|0);b=o?(g|0)>0?g:0:I;if((b|0)<=112){break Y}break W}v=h+v|0;b=c;if((d|0)==(b|0)){continue}break}l=1e9>>>h|0;o=-1<<h^-1;g=0;b=d;while(1){m=(e+784|0)+(d<<2)|0;y=w[m>>2];g=(y>>>h|0)+g|0;w[m>>2]=g;g=!g&(b|0)==(d|0);b=g?b+1&2047:b;n=g?n-9|0:n;g=C(l,o&y);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(i|0)){w[(e+784|0)+(c<<2)>>2]=g;c=i;continue X}w[k>>2]=w[k>>2]|1;continue}break}break}te(e+656|0,vf(1,225-b|0));Ms(e+688|0,w[e+656>>2],w[e+660>>2],w[e+664>>2],w[e+668>>2],m,q,l,k);E=w[e+696>>2];G=w[e+700>>2];A=w[e+688>>2];B=w[e+692>>2];te(e+640|0,vf(1,113-b|0));Js(e+672|0,m,q,l,k,w[e+640>>2],w[e+644>>2],w[e+648>>2],w[e+652>>2]);i=w[e+672>>2];h=w[e+676>>2];s=w[e+680>>2];t=w[e+684>>2];cm(e+624|0,m,q,l,k,i,h,s,t);qd(e+608|0,A,B,E,G,w[e+624>>2],w[e+628>>2],w[e+632>>2],w[e+636>>2]);l=w[e+616>>2];k=w[e+620>>2];m=w[e+608>>2];q=w[e+612>>2]}n=d+4&2047;$:{if((n|0)==(c|0)){break $}n=w[(e+784|0)+(n<<2)>>2];aa:{if(n>>>0<=499999999){if(!n&(d+5&2047)==(c|0)){break aa}te(e+496|0,+(f|0)*.25);qd(e+480|0,i,h,s,t,w[e+496>>2],w[e+500>>2],w[e+504>>2],w[e+508>>2]);s=w[e+488>>2];t=w[e+492>>2];i=w[e+480>>2];h=w[e+484>>2];break aa}if((n|0)!=5e8){te(e+592|0,+(f|0)*.75);qd(e+576|0,i,h,s,t,w[e+592>>2],w[e+596>>2],w[e+600>>2],w[e+604>>2]);s=w[e+584>>2];t=w[e+588>>2];i=w[e+576>>2];h=w[e+580>>2];break aa}M=+(f|0);if((d+5&2047)==(c|0)){te(e+528|0,M*.5);qd(e+512|0,i,h,s,t,w[e+528>>2],w[e+532>>2],w[e+536>>2],w[e+540>>2]);s=w[e+520>>2];t=w[e+524>>2];i=w[e+512>>2];h=w[e+516>>2];break aa}te(e+560|0,M*.75);qd(e+544|0,i,h,s,t,w[e+560>>2],w[e+564>>2],w[e+568>>2],w[e+572>>2]);s=w[e+552>>2];t=w[e+556>>2];i=w[e+544>>2];h=w[e+548>>2]}if((b|0)>111){break $}Js(e+464|0,i,h,s,t,0,0,0,1073676288);if(Yf(w[e+464>>2],w[e+468>>2],w[e+472>>2],w[e+476>>2],0,0,0,0)){break $}qd(e+448|0,i,h,s,t,0,0,0,1073676288);s=w[e+456>>2];t=w[e+460>>2];i=w[e+448>>2];h=w[e+452>>2]}qd(e+432|0,m,q,l,k,i,h,s,t);cm(e+416|0,w[e+432>>2],w[e+436>>2],w[e+440>>2],w[e+444>>2],A,B,E,G);l=w[e+424>>2];k=w[e+428>>2];m=w[e+416>>2];q=w[e+420>>2];ba:{if((L-2|0)>=(y&2147483647)){break ba}w[e+408>>2]=l;w[e+412>>2]=k&2147483647;w[e+400>>2]=m;w[e+404>>2]=q;jc(e+384|0,m,q,l,k,0,0,0,1073610752);d=Ns(w[e+400>>2],w[e+404>>2],w[e+408>>2],w[e+412>>2],1081081856);c=(d|0)<0;l=c?l:w[e+392>>2];k=c?k:w[e+396>>2];m=c?m:w[e+384>>2];q=c?q:w[e+388>>2];v=((d|0)>=0)+v|0;if(!((Yf(i,h,s,t,0,0,0,0)|0)!=0&(c?o:o&(b|0)!=(g|0)))&(v+110|0)<=(L|0)){break ba}w[114084]=68}Ls(e+368|0,m,q,l,k,v);l=w[e+368>>2];k=w[e+372>>2];c=w[e+380>>2];b=w[e+376>>2]}w[r+40>>2]=b;w[r+44>>2]=c;w[r+32>>2]=l;w[r+36>>2]=k;jb=e+8976|0;i=w[r+40>>2];h=w[r+44>>2];l=w[r+32>>2];k=w[r+36>>2];break a;case 3:break j;default:break m}}c=w[b+116>>2];if((c|0)>0|(c|0)>=0){w[b+4>>2]=w[b+4>>2]-1}break i}ca:{c=w[b+4>>2];da:{if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break da}c=ac(b)}if((c|0)==40){g=1;break ca}h=2147450880;if(w[b+116>>2]<0){break a}w[b+4>>2]=w[b+4>>2]-1;break a}while(1){c=w[b+4>>2];ea:{if((c|0)!=w[b+104>>2]){w[b+4>>2]=c+1;c=x[c|0];break ea}c=ac(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=w[b+116>>2];if((c|0)>0|(c|0)>=0){w[b+4>>2]=w[b+4>>2]-1}fa:{if(d){if(g){break fa}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){w[b+4>>2]=w[b+4>>2]-1}if(g){continue}break}break a}w[114084]=28;ce(b,0,0)}h=0}w[a>>2]=l;w[a+4>>2]=k;w[a+8>>2]=i;w[a+12>>2]=h;jb=r+48|0}function bB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0,D=0,E=0;d=jb-336|0;jb=d;w[b+8>>2]=0;a:{b:{c:{d:{e:{f:{g:{if(!Ei(b,d+232|0)){break g}if(!$o(d+232|0)){break g}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],y[d+264>>1]+(y[d+268>>1]+y[d+266>>1]<<1)|0)|0)){break g}e=1;if(!c){break g}tc(a,2);w[a+480260>>2]=64;w[a+480264>>2]=32767;e=0;w[d+224>>2]=0;w[d+216>>2]=0;w[d+220>>2]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{i=y[d+272>>1];switch((i&61440)-4096>>>12|0){case 6:break y;case 5:break z;case 4:break A;case 3:break B;case 2:break C;case 1:break D;case 0:break E;default:break x}}if((i|0)!=4896){break s}f=y[d+294>>1];if(f){e=x[d+284|0];break t}e=x[d+284|0];if(e|x[d+264|0]&15){break t}e=0;if(y[d+270>>1]&65455){break t}F:{if(u[d+283|0]<0){w[a+1074308>>2]=18219008;w[114256]=0;f=Q(1,d+200|0,10276)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break F}b=P()|0;break a}w[a+1074308>>2]=16777216;w[114256]=0;f=Q(1,d+200|0,9168)|0;e=w[114256];w[114256]=0;if((e|0)==1){break w}}if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[f+8>>2];e=w[f+4>>2];w[d+216>>2]=w[f>>2];w[d+220>>2]=e;e=a+1074320|0;w[e>>2]=w[e>>2]|131072;f=0;g=1;e=1;break p}w[114256]=0;e=Q(1,d+200|0,3098)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;e=0;g=1;break r}b=P()|0;break a}if(i>>>0<=12820){w[114256]=0;e=Q(1,d+200|0,4724)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;break u}b=P()|0;break a}w[114256]=0;e=Q(1,d+184|0,11258)|0;f=w[114256];w[114256]=0;G:{if((f|0)!=1){h=w[e>>2];w[d+204>>2]=w[e+4>>2];f=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+207|0]=f;u[d+208|0]=f>>>8;u[d+209|0]=f>>>16;u[d+210|0]=f>>>24;w[e>>2]=0;w[e+4>>2]=0;f=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+211|0]=f;w[d+200>>2]=h;w[d+168>>2]=y[d+272>>1]-12820;U(121,d+16|0,d+200|0,d+168|0);f=w[114256];w[114256]=0;if((f|0)==1){break G}if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[d+24>>2];f=w[d+20>>2];w[d+216>>2]=w[d+16>>2];w[d+220>>2]=f;u[d+16|0]=0;u[d+27|0]=0;if(u[d+211|0]<0){zb(w[d+200>>2])}if(u[e+11|0]>=0){break u}zb(w[e>>2]);break u}b=P()|0;break a}b=P()|0;if(u[d+211|0]<0){zb(w[d+200>>2])}if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}H:{if((i|0)==16640){w[114256]=0;e=Q(1,d+200|0,4525)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;e=a+1074320|0;w[e>>2]=w[e>>2]|131072;break H}b=P()|0;break a}w[114256]=0;U(381,d+16|0,i|0,y[d+286>>1]);e=w[114256];w[114256]=0;if((e|0)==1){break v}if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[d+24>>2];e=w[d+20>>2];w[d+216>>2]=w[d+16>>2];w[d+220>>2]=e;w[a+480260>>2]=1;if(y[d+272>>1]<18850){break H}e=a+1074316|0;w[e>>2]=w[e>>2]|64}g=1;e=0;f=0;h=(i|0)!=16640;break o}e=i&4095;w[a+1074308>>2]=e<<16|(e>>>0>296?y[d+286>>1]:0)&65535;w[114256]=0;f=Q(1,d+200|0,13266)|0;e=w[114256];w[114256]=0;I:{J:{K:{if((e|0)!=1){w[114256]=0;T(120,d+16|0,a+1074308|0);e=w[114256];w[114256]=0;if((e|0)==1){break K}w[114256]=0;e=x[d+27|0];h=e<<24>>24<0;e=S(2,f|0,(h?w[d+16>>2]:d+16|0)|0,(h?w[d+20>>2]:e)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break J}g=w[e>>2];w[d+168>>2]=w[e+4>>2];h=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+171|0]=h;u[d+172|0]=h>>>8;u[d+173|0]=h>>>16;u[d+174|0]=h>>>24;w[e>>2]=0;w[e+4>>2]=0;h=x[e+11|0];w[e+8>>2]=0;if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+216>>2]=g;w[d+220>>2]=w[d+168>>2];e=x[d+171|0]|x[d+172|0]<<8|(x[d+173|0]<<16|x[d+174|0]<<24);u[d+223|0]=e;u[d+224|0]=e>>>8;u[d+225|0]=e>>>16;u[d+226|0]=e>>>24;u[d+227|0]=h;if(u[d+27|0]<0){zb(w[d+16>>2])}if(u[f+11|0]>=0){break q}zb(w[f>>2]);break q}b=P()|0;break a}b=P()|0;break I}b=P()|0;if(u[d+27|0]>=0){break I}zb(w[d+16>>2])}if(u[f+11|0]>=0){break a}zb(w[f>>2]);break a}w[114256]=0;e=Q(1,d+200|0,4525)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;e=a+1074320|0;w[e>>2]=w[e>>2]|131072;break q}b=P()|0;break a}w[114256]=0;e=Q(1,d+200|0,4551)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;break q}b=P()|0;break a}f=0;h=0;if((i|0)!=51712){break o}w[114256]=0;e=Q(1,d+200|0,5205)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;break q}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}L:{e=y[d+272>>1];if(e>>>0<12807){break L}f=w[d+288>>2];if(!f){break L}w[114256]=0;e=Q(383,e|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){f=d+16|0;Cb(f,0,44);w[114256]=0;w[d+60>>2]=e;T(384,a+1304500|0,f|0);e=w[114256];w[114256]=0;if((e|0)!=1){break L}b=P()|0;break a}b=P()|0;break a}g=1;w[a+480260>>2]=1;w[a+1074312>>2]=w[a+1074312>>2]|8388608;e=a+1074316|0;w[e>>2]=w[e>>2]|64;e=a+1074324|0;w[e>>2]=w[e>>2]|2048;e=0;f=0;h=0;if(i>>>0>12820){break o}break r}if(x[d+285|0]|(y[d+270>>1]|(f|e&255))){break s}w[114256]=0;e=Q(1,d+200|0,5392)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;break q}b=P()|0;break a}w[114256]=0;e=Q(1,d+200|0,4693)|0;f=w[114256];w[114256]=0;if((f|0)!=1){if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[e+8>>2];f=w[e+4>>2];w[d+216>>2]=w[e>>2];w[d+220>>2]=f;e=1;break r}b=P()|0;break a}f=e;w[114256]=0;e=Q(1,d+136|0,10556)|0;h=w[114256];w[114256]=0;if((h|0)==1){break n}i=w[e>>2];w[d+156>>2]=w[e+4>>2];h=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+159|0]=h;u[d+160|0]=h>>>8;u[d+161|0]=h>>>16;u[d+162|0]=h>>>24;w[e>>2]=0;w[e+4>>2]=0;h=x[e+11|0];w[e+8>>2]=0;w[114256]=0;u[d+163|0]=h;w[d+152>>2]=i;h=y[d+272>>1];w[d+104>>2]=h>>>8&15;w[d>>2]=h&255;u[d+32|0]=44;w[d+24>>2]=-1;w[d+28>>2]=0;w[d+16>>2]=1042;w[d+20>>2]=2;U(101,d+120|0,d|0,d+16|0);h=w[114256];w[114256]=0;if((h|0)==1){break m}w[114256]=0;ga(563,d+168|0,d+152|0,d+216|0,d+104|0,d+120|0);h=w[114256];w[114256]=0;if((h|0)==1){break l}if(u[d+227|0]<0){zb(w[d+216>>2])}w[d+224>>2]=w[d+176>>2];h=w[d+172>>2];w[d+216>>2]=w[d+168>>2];w[d+220>>2]=h;u[d+168|0]=0;u[d+179|0]=0;if(u[d+131|0]<0){zb(w[d+120>>2])}if(u[d+163|0]<0){zb(w[d+152>>2])}if(u[e+11|0]<0){zb(w[e>>2])}e=0;break p}g=0;f=0;e=0}h=0}w[114256]=0;j=Q(1,d+168|0,10589)|0;i=w[114256];w[114256]=0;if((i|0)==1){break j}i=a+1304436|0;if(u[a+1304447|0]<0){zb(w[i>>2])}k=w[j+4>>2];w[i>>2]=w[j>>2];w[i+4>>2]=k;w[i+8>>2]=w[j+8>>2];w[114256]=0;j=Q(1,d+152|0,6414)|0;i=w[114256];w[114256]=0;if((i|0)==1){break i}i=a+1304448|0;if(u[a+1304459|0]<0){zb(w[i>>2])}k=w[j+4>>2];w[i>>2]=w[j>>2];w[i+4>>2]=k;w[i+8>>2]=w[j+8>>2];i=a+1304460|0;if(u[a+1304471|0]<0){zb(w[i>>2])}j=w[d+220>>2];w[i>>2]=w[d+216>>2];w[i+4>>2]=j;w[i+8>>2]=w[d+224>>2];u[d+227|0]=0;u[d+216|0]=0;w[a+1304496>>2]=w[a+1074308>>2]?7:4;if(g){g=a+1074320|0;w[g>>2]=w[g>>2]&-385025;g=a+1074324|0;w[g>>2]=w[g>>2]&-2}g=y[d+272>>1];i=g&61440;if(i>>>0>=4097){e=(i|0)!=12288|g>>>0>12819|e}w[114256]=0;g=a+901404|0;X(564,g|0);i=w[114256];w[114256]=0;if((i|0)!=1){if(e){break h}w[114256]=0;X(356,g|0);e=w[114256];w[114256]=0;if((e|0)!=1){break h}}b=P()|0;break a}b=P()|0;break a}b=P()|0;break k}b=P()|0;if(u[d+131|0]>=0){break k}zb(w[d+120>>2])}if(u[d+163|0]<0){zb(w[d+152>>2])}if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}b=P()|0;break a}b=P()|0;break a}w[114256]=0;Y(209,d+16|0,1,d+232|0,28);e=w[114256];w[114256]=0;M:{N:{O:{P:{Q:{R:{if((e|0)!=1){e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}g=w[d+20>>2];w[e>>2]=w[d+16>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+24>>2];e=y[d+270>>1];if(e&16){w[a+480208>>2]=w[a+480208>>2]|65536}if(e&1){w[a+480208>>2]=w[a+480208>>2]|131072}i=y[d+272>>1];if(!(!(e&64)&(i|0)!=4864)){w[a+480208>>2]=w[a+480208>>2]|2}e=x[d+281|0];w[a+480196>>2]=e;if(!(!f|(e|0)!=255?e:0)){w[a+480196>>2]=6}e=x[d+282|0];w[a+480204>>2]=e>>>0<33?f?125e4:32e4:C(e,1e4);e=x[d+280|0];e=e>>>0>=64?64:e;g=e<<2;w[a+480200>>2]=e?g:i>>>0<4896?256:g;g=x[d+283|0];S:{if(!(y[d+274>>1]!=1|g>>>0>7)){e=g<<4;e=(e>>>0>=111?111:e)+16|0;break S}e=32;if((g|16)==18){break S}j=g&127;e=48;if(!j){break S}e=j>>>0<=16?16:j}w[a+480228>>2]=e;j=w[a+1074308>>2]!=0|g<<24>>24<0;if(!j){w[a+480228>>2]=((e<<3|5)>>>0)/11}v[a+480188>>1]=4;w[a+480232>>2]=h?i>>>0<19763?64:36:36;e=0;g=0;while(1){w[114256]=0;h=(e<<5)+a|0;k=h+480280|0;X(224,k|0);i=w[114256];w[114256]=0;if((i|0)==1){break R}i=x[(d+e|0)+296|0];l=i&126;T:{if((i|0)!=255){i=i<<24>>24;v[a+480188>>1]=e+1;if(j){v[h+480284>>1]=i&8?204:51}if((i|0)>=0){break T}}w[k>>2]=1024}if((l-16&255)>>>0<=13){v[h+480284>>1]=128;g=1<<e|g}e=e+1|0;if((e|0)!=32){continue}break}if(!y[a+480188>>1]){v[a+480188>>1]=1}e=x[a+484376|0];h=w[a+484360>>2];w[114256]=0;da(317,h+(e<<5)|0,b|0,y[d+264>>1],255,254)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;w[d+128>>2]=0;w[d+120>>2]=0;w[d+124>>2]=0;S(212,b|0,d+120|0,y[d+266>>1])|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;w[d+112>>2]=0;w[d+104>>2]=0;w[d+108>>2]=0;S(212,b|0,d+104|0,y[d+268>>1])|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(x[d+285|0]==252){e=0;w[114256]=0;Q(565,b|0,d+16|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}while(1){h=x[(d+16|0)+e|0];if(!(!(h&32)|(g>>>e&1?f:0))){v[((e<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}e=y[d+266>>1];e=e>>>0>=3999?3999:e;v[a+480190>>1]=e;if(e){g=c&2;i=d- -64|0;e=0;while(1){U:{h=w[d+120>>2]+(e<<1)|0;h=(x[h|0]|x[h+1|0]<<8)<<4;if(h>>>0>z[b+8>>2]){j=w[b>>2];k=w[w[j>>2]+24>>2];w[114256]=0;j=V(k|0,j|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break Q}if(h>>>0>j>>>0){break U}}w[b+8>>2]=h;w[114256]=0;h=Q(566,b|0,d+16|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break Q}if(!h){break U}w[114256]=0;h=e+1|0;j=(C(h,104)+a|0)+484380|0;U(567,d+16|0,j|0,f|0);k=w[114256];w[114256]=0;if((k|0)==1){break Q}w[114256]=0;Y(209,d|0,1,i|0,28);k=w[114256];w[114256]=0;V:{W:{if((k|0)!=1){w[114256]=0;w[d+332>>2]=32;w[d+328>>2]=((h<<5)+a|0)+946304;Q(200,d+328|0,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break W}if(u[d+11|0]<0){zb(w[d>>2])}if(!w[d+32>>2]|(!g|x[d+16|0]>1)){break U}h=x[d+31|0]<<12|x[d+30|0]<<4|x[d+29|0]<<20;if(h>>>0>z[b+8>>2]){k=w[b>>2];l=w[w[k>>2]+24>>2];w[114256]=0;k=V(l|0,k|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break V}if(h>>>0>k>>>0){break U}}w[b+8>>2]=h;w[114256]=0;U(568,d|0,d+16|0,y[d+274>>1]==1|0);h=w[114256];w[114256]=0;if((h|0)!=1){w[114256]=0;S(214,d|0,j|0,b|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){break U}}b=P()|0;break e}b=P()|0;break e}b=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2]);break e}b=P()|0;break e}e=e+1|0;if(e>>>0<y[a+480190>>1]){continue}break}}if(!(c&1)){break M}k=0;w[114256]=0;c=y[d+272>>1];h=a+484344|0;e=y[d+268>>1];n=e>>>0>=255?255:e;T(215,h|0,n|0);e=w[114256];w[114256]=0;X:{if((e|0)!=1){o=c>>>0<4896;if(n){break X}i=0;break N}b=P()|0;break e}c=d+16|0;s=c|5;t=c|3;A=c|4;B=c|2;D=c|1;c=0;i=0;while(1){w[114256]=0;e=S(216,h|0,c&65535,64)|0;f=w[114256];w[114256]=0;if((f|0)==1){break P}Y:{if(!e){break Y}e=w[d+104>>2]+(c<<1)|0;e=x[e|0]|x[e+1|0]<<8;if(!e){break Y}e=e<<4;if(e>>>0>z[b+8>>2]){f=w[b>>2];g=w[w[f>>2]+24>>2];w[114256]=0;f=V(g|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break P}if(e>>>0>f>>>0){break Y}}w[b+8>>2]=e;f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;e=S(g|0,f|0,e|0,2)|0;f=w[114256];w[114256]=0;if((f|0)==1){break P}Z:{if(e){e=w[b+8>>2]+2|0;break Z}e=w[b>>2];f=w[w[e>>2]+24>>2];w[114256]=0;e=V(f|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break P}}w[b+8>>2]=e;e=w[h>>2];w[114256]=0;p=C(c,52);e=e+p|0;V(218,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break O}f=w[e>>2];l=0;while(1){w[114256]=0;e=Q(241,b|0,d+16|0)|0;g=w[114256];w[114256]=0;_:{$:{aa:{if((g|0)==1){break aa}e=e?x[d+16|0]:0;m=e&255;if(m){break $}if((l|0)==63){break Y}e=w[h>>2];w[114256]=0;e=e+p|0;f=V(218,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break aa}l=l+1|0;f=w[e>>2]+C(C(f,l),6)|0;break _}b=P()|0;break e}v[d+20>>1]=0;w[d+16>>2]=0;q=e<<24>>24;g=q&31;e=C(g,6)+f|0;j=g>>>0<y[a+480188>>1];r=j?e:d+16|0;if(m&32){w[114256]=0;Q(562,b|0,d|0)|0;g=w[114256];w[114256]=0;ba:{ca:{da:{if((g|0)!=1){g=x[d|0];if(g>>>0>239){break da}g=C(g>>>4|0,12)+(g&15)|0;g=((g|0)>=107?107:g)+13|0;break ca}b=P()|0;break e}ea:{switch(g-254|0){case 0:break ca;case 1:break ea;default:break ba}}g=0}u[r|0]=g}u[(j?e+1|0:D)|0]=x[d+1|0]}if(m&64){w[114256]=0;m=Q(241,b|0,d|0)|0;g=w[114256];w[114256]=0;fa:{ga:{if((g|0)!=1){E=j?e+4|0:A;g=j?e+2|0:B;m=(m?x[d|0]:0)<<24>>24;if((m|0)>-64){break ga}u[g|0]=2;g=m^-128;break fa}b=P()|0;break e}u[g|0]=1;g=m&255;g=g>>>0>=64?64:g}u[E|0]=g}if((q|0)>=0){break _}w[114256]=0;Q(562,b|0,d|0)|0;g=w[114256];w[114256]=0;ha:{ia:{if((g|0)!=1){g=j?e+3|0:t;u[g|0]=x[d|0];e=j?e+5|0:s;u[e|0]=x[d+1|0];Lk(r,0);j=x[g|0];if((j|0)==10){break ha}if((j|0)==31){break ia}if((j|0)!=20){break _}g=x[e|0];if((g&240)!=160|y[d+272>>1]>4895){break _}u[e|0]=g&15^136;break _}b=P()|0;break e}e=x[e|0];if(e>>>0>15){o=0;break _}if(e>>>0<=7){i=i+1|0;break _}k=((e|0)!=8)+k|0;break _}if(x[e|0]|y[d+272>>1]>4865){break _}u[g|0]=42}if(l>>>0<64){continue}break}}c=c+1|0;if((n|0)!=(c|0)){continue}break}break N}b=P()|0;break e}b=P()|0;break a}b=P()|0;break a}b=P()|0;break e}b=P()|0;break e}b=P()|0;break e}if(!o){break M}a=y[a+480188>>1];if((a|0)>(i+k|0)|(a|0)<=(k-i|0)){break M}b=0;c=w[h>>2];e=(w[h+4>>2]-c|0)/52&65535;if(e){while(1){f=c+C(b,52)|0;a=w[f>>2];f=w[f+4>>2];if((a|0)!=(f|0)){while(1){if(x[a+3|0]==31){u[a+3|0]=20;u[a+5|0]=x[a+5|0]|128}a=a+6|0;if((f|0)!=(a|0)){continue}break}}b=b+1|0;if((e|0)!=(b|0)){continue}break}}}a=w[d+104>>2];if(a){w[d+108>>2]=a;zb(a)}a=w[d+120>>2];if(a){w[d+124>>2]=a;zb(a)}if(u[d+227|0]<0){zb(w[d+216>>2])}e=1}jb=d+336|0;return e|0}b=P()|0}a=w[d+104>>2];if(!a){break c}w[d+108>>2]=a;zb(a);break c}b=P()|0}a=w[d+120>>2];if(!a){break a}w[d+124>>2]=a;zb(a);break a}b=P()|0}if(u[d+227|0]<0){zb(w[d+216>>2])}R(b|0);M()}function SM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=D(0),q=0,r=0,s=0,t=0,z=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=D(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=D(0),Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=D(0);j=jb-17168|0;jb=j;a:{b:{c:{d:{if((c|0)<=4){Cb(a,0,6668);break d}Q=a+6152|0;e:{if(x[a+6152|0]!=255){break e}if(!ei(Q,b)){break e}g=Mm(b,w[a+6148>>2]);i=g+(x[b+2|0]&2?(x[b+1|0]&6)==6?4:1:0)|0;if((c|0)==(i|0)){i=c;break b}if((i+4|0)>(c|0)){break e}if(!ei(b,b+i|0)){break e}if(i){break b}}o=Cb(a,0,6668);J=c-4|0;f=b;while(1){if(Au(f)){l=0;h=Mm(f,0);i=h+(x[f+2|0]&2?(x[f+1|0]&6)==6?4:1:0)|0;f:{g:{h:{i:{j:{if(h){break j}g=4;H=k+4|0;while(1){if((J|0)<=((g<<1)+k|0)){break i}m=f+g|0;k:{if(!ei(f,m)){h=0;break k}h=0;r=(x[f+2|0]&2?(x[f+1|0]&6)==6?-4:-1:0)+g|0;E=r+(x[m+2|0]&2?(x[m+1|0]&6)==6?4:1:0)|0;if((E+(g+H|0)|0)>(c|0)){break k}if(!ei(f,m+E|0)){break k}w[o+6148>>2]=r;h=r;i=g}l=!h;if(h){break j}r=g>>>0<2303;g=g+1|0;if(r){continue}break}}if(l){break i}z=i+k|0;if((z|0)>(c|0)){break i}r=c-k|0;m=0;g=0;while(1){H=f+g|0;E=Mm(H,h);g=(g+E|0)+(x[H+2|0]&2?(x[H+1|0]&6)==6?4:1:0)|0;if((g+4|0)<=(r|0)){if(!ei(f,f+g|0)){break i}m=m+1|0;if((m|0)!=10){continue}break g}break}if(m){break h}}if((c|0)!=(i|0)|k){break f}i=c}z=i+k|0}if(!i|(c|0)<(z|0)){break c}break b}w[o+6148>>2]=0}f=f+1|0;k=k+1|0;if((J|0)!=(k|0)){continue}break}}k=c}w[e>>2]=k;a=0;break a}q=b+k|0;w[Q>>2]=x[q|0]|x[q+1|0]<<8|(x[q+2|0]<<16|x[q+3|0]<<24);w[e+4>>2]=k;w[e>>2]=i+k;w[e+8>>2]=x[q+3|0]>191?1:2;b=x[q+1|0]^-1;w[e+12>>2]=w[(x[q+2|0]&12)+39220>>2]>>>(b>>>3&1)>>>(b>>>4&1);b=4-(x[q+1|0]>>>1&3)|0;w[e+16>>2]=b;c=x[q+1|0];w[e+20>>2]=x[(C(c>>>1&3,15)+C(c>>>3&1,45)+(x[q+2|0]>>>4)|0)+39217|0]<<1;if(!d){a=x[q+1|0];a=(a&6)==6?384:1152>>>((a&14)==2)|0;break a}w[j+17156>>2]=0;w[j+17152>>2]=q+4;w[j+17160>>2]=(i<<3)-32;if(!(u[q+1|0]&1)){xc(j+17152|0,16);b=w[e+16>>2]}l:{m:{n:{if((b|0)==3){g=0;h=x[q+1|0];b=C((h>>>3&1)+(h>>>4&1)|0,3)+(x[q+2|0]>>>2&3)|0;c=b-((b|0)!=0)|0;i=x[q+3|0]>191?1:2;o:{if(h&8){b=j+17152|0;N=xc(b,9);i=i<<1;g=xc(b,i+7|0);break o}N=xc(j+17152|0,i|8)>>>i|0}b=C(c,40);J=b+39520|0;H=b+39840|0;E=C(c,23)+39328|0;T=j+3740|0;f=T;k=0;while(1){c=x[q+3|0];b=j+17152|0;r=xc(b,12);v[f+4>>1]=r;b=xc(b,9);v[f+6>>1]=b;if((b&65535)>>>0>288){break n}h=c>>>0>191?g<<4:g;c=j+17152|0;ea=f,fa=xc(c,8),u[ea+10|0]=fa;b=xc(c,x[q+1|0]&8?4:9);u[f+13|0]=22;u[f+14|0]=0;w[f>>2]=E;v[f+8>>1]=b;p:{if(xc(c,1)){b=xc(j+17152|0,2);u[f+11|0]=b;if(!(b&255)){break n}b=xc(j+17152|0,1);v[f+18>>1]=65287;u[f+12|0]=b;if(x[f+11|0]==2){q:{if(!(b&255)){w[f>>2]=J;u[f+18|0]=8;l=0;b=39;break q}w[f>>2]=H;l=x[q+1|0]&8?8:6;b=30}u[f+14|0]=b;u[f+13|0]=l;h=h&3855}c=j+17152|0;b=xc(c,10);ea=f,fa=xc(c,3),u[ea+21|0]=fa;ea=f,fa=xc(c,3),u[ea+22|0]=fa;ea=f,fa=xc(j+17152|0,3),u[ea+23|0]=fa;g=b<<5;break p}u[f+11|0]=0;u[f+12|0]=0;b=j+17152|0;g=xc(b,15);ea=f,fa=xc(b,4),u[ea+18|0]=fa;b=xc(b,3);u[f+20|0]=255;u[f+19|0]=b}u[f+17|0]=g&31;u[f+15|0]=g>>>10;u[f+16|0]=g>>>5&31;k=(r&65535)+k|0;r:{if(x[q+1|0]&8){b=xc(j+17152|0,1);break r}b=y[f+8>>1]>499}u[f+24|0]=b;ea=f,fa=xc(j+17152|0,1),u[ea+25|0]=fa;b=xc(j+17152|0,1);u[f+27|0]=h>>>12&15;u[f+26|0]=b;f=f+28|0;g=h<<4;i=i-1|0;if(i){continue}break}f=w[j+17156>>2];i=w[j+17160>>2];if((N|0)<0|(f+k|0)>(i+(N<<3)|0)|(f|0)>(i|0)){break n}h=0;$=a+6156|0;U=w[a+6144>>2];b=U-N|0;c=(N|0)>(U|0);g=c?U:N;Y=Fb(j+924|0,$+((b|0)>0?b:0)|0,g);b=(i-f|0)/8|0;Fb(Y+g|0,w[j+17152>>2]+((f|0)/8|0)|0,b);f=b+g<<3;w[j+920>>2]=f;w[j+916>>2]=0;w[j+912>>2]=Y;if(!c){ba=a+2304|0;R=w[e+8>>2];ca=j|8;da=j|4;J=j+8620|0;E=j+6156|0;Z=j+17107|0;r=j+8460|0;L=j+3852|0;aa=1;f=0;while(1){H=Cb(L,0,4608);G=C(C(f,R),28)+T|0;Q=(R|0)<=0;if(!Q){O=0;V=w[j+916>>2];while(1){t=C(O,28)+G|0;l=C(!x[t+13|0]+(x[t+14|0]!=0)|0,28)+40160|0;m=(j+912|0)+C(O,39)|0;f=y[t+4>>1];B=x[t+25|0];s:{if(x[a+6153|0]&8){b=x[t+27|0];g=x[y[t+8>>1]+40256|0];c=g&3;u[j+17167|0]=c;u[j+17166|0]=c;c=g>>>2|0;u[j+17165|0]=c;u[j+17164|0]=c;break s}b=(x[a+6155|0]&16)>>>4&(O|0)!=0;i=b?12:0;k=y[t+8>>1]>>>b|0;while(1){g=1;h=3;while(1){b=h;c=x[(b+i|0)+40272|0];u[b+(j+17164|0)|0]=((k|0)/(g|0)|0)%(c|0);g=C(c,g);h=b-1|0;if(b){continue}break}i=i+4|0;k=k-g|0;if((k|0)>=0){continue}break}l=i+l|0;b=-16}k=m+16156|0;V=f+V|0;o=B+1|0;m=0;i=j;while(1){F=x[l+m|0];if(F){t:{if(b&8){Fb(i,k,F);break t}h=x[(j+17164|0)+m|0];if(!h){Cb(i,0,F);Cb(k,0,F);break t}c=(b|0)>=0?-1:-1<<h^-1;f=0;while(1){g=xc(j+912|0,h);u[f+k|0]=(c|0)==(g|0)?-1:g;u[f+i|0]=g;f=f+1|0;if((F|0)!=(f|0)){continue}break}}b=b<<1;i=i+F|0;k=k+F|0;m=m+1|0;if((m|0)!=4){continue}}break}u[i+2|0]=0;u[i|0]=0;u[i+1|0]=0;k=x[t+14|0];u:{if(k){b=2-B|0;i=x[t+21|0]<<b;h=x[t+23|0]<<b;c=x[t+22|0]<<b;b=x[t+13|0];g=0;while(1){f=(b+g|0)+j|0;u[f|0]=i+x[f|0];u[f+1|0]=c+x[f+1|0];u[f+2|0]=h+x[f+2|0];g=g+3|0;if(k>>>0>g>>>0){continue}break}break u}f=0;if(!x[t+24|0]){break u}while(1){b=f+j|0;u[b+11|0]=x[b+11|0]+x[f+40296|0];f=f+1|0;if((f|0)!=10){continue}break}}f=((((x[a+6155|0]&224)==96)<<1)-x[t+10|0]|0)+258|0;p=D(2048);while(1){b=(f|0)>=120?120:f;p=D(D(A[((b&3)<<2)+40320>>2]*p)*D(1073741824>>>(b>>2)|0));f=f-b|0;if((f|0)>0){continue}break}h=0;if((k|0)!=(0-x[t+13|0]|0)){while(1){f=x[h+j|0]<<o;n=p;while(1){b=(f|0)>=120?120:f;n=D(D(A[((b&3)<<2)+40320>>2]*n)*D(1073741824>>>(b>>2)|0));f=f-b|0;if((f|0)>0){continue}break}A[r+(h<<2)>>2]=n;h=h+1|0;if(h>>>0<x[t+14|0]+x[t+13|0]>>>0){continue}break}}b=w[j+916>>2];g=w[j+912>>2]+((b|0)/8|0)|0;c=x[g|0]|x[g+1|0]<<8|(x[g+2|0]<<16|x[g+3|0]<<24);i=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))<<(b&7);f=b|-8;g=g+4|0;k=(C(O,2304)+j|0)+3852|0;I=w[t>>2];z=y[t+6>>1];v:{if(!z){n=D(0);z=0;c=r;break v}_=0;c=r;while(1){b=t+_|0;h=x[b+15|0];W=(v[(h<<1)+44720>>1]<<1)+40336|0;S=x[b+18|0];w:{if(h>>>0>=16){K=x[h+44784|0];B=32-K|0;while(1){F=x[I|0]>>>1|0;b=(z|0)<(F|0)?z:F;n=A[c>>2];while(1){h=v[(i>>>26&62)+W>>1];if((h|0)<0){l=5;while(1){i=i<<l;f=f+l|0;m=h&7;l=m;h=v[((i>>>32-m|0)-(h<<16>>19)<<1)+W>>1];if((h|0)<0){continue}break}}s=h&65535;h=s>>>8|0;f=h+f|0;i=i<<h;m=1;while(1){l=s&15;x:{if((l|0)==15){h=i<<K;o=i>>>B|0;l=o+15|0;f=f+K|0;if((f|0)>=0){while(1){h=x[g|0]<<f|h;i=f>>>0>7;f=f-8|0;g=g+1|0;if(i){continue}break}}P=D(n*D(h>>31|1));if((l|0)<=128){p=A[(o<<2)+44940>>2]}else{i=l>>>0<1024;M=i?l<<3:l;o=M<<1&64;p=D(D((M&63)-o|0)/D(o+(M&-64)|0));p=D(D(D(D(D(D(p*D(.2222222238779068))+D(1.3333333730697632))*p)+D(1))*(i?D(16):D(256)))*A[(o+M>>6<<2)+44880>>2])}p=D(P*p);break x}h=i;p=D(A[(((h>>>27&16|l)^16)<<2)+44816>>2]*n)}A[k>>2]=p;s=s>>>4|0;k=k+4|0;i=(l|0)!=0;f=i+f|0;i=h<<i;h=m&1;m=0;if(h){continue}break}if((f|0)>=0){while(1){i=x[g|0]<<f|i;h=f>>>0>7;f=f-8|0;g=g+1|0;if(h){continue}break}}b=b-1|0;if(b){continue}break}c=c+4|0;I=I+1|0;z=z-F|0;if((z|0)<=0){break w}b=(S|0)>0;S=S-1|0;if(b){continue}break}break w}while(1){o=x[I|0]>>>1|0;m=(o|0)>(z|0)?z:o;n=A[c>>2];while(1){h=v[(i>>>26&62)+W>>1];if((h|0)<0){l=5;while(1){i=i<<l;f=f+l|0;b=h&7;l=b;h=v[((i>>>32-b|0)-(h<<16>>19)<<1)+W>>1];if((h|0)<0){continue}break}}h=h&65535;b=h>>>8|0;f=b+f|0;i=i<<b;l=1;while(1){b=h&15;A[k>>2]=A[(((b|i>>>27&16)^16)<<2)+44816>>2]*n;h=h>>>4|0;k=k+4|0;b=(b|0)!=0;f=b+f|0;i=i<<b;b=l&1;l=0;if(b){continue}break}if((f|0)>=0){while(1){i=x[g|0]<<f|i;b=f>>>0>7;f=f-8|0;g=g+1|0;if(b){continue}break}}m=m-1|0;if(m){continue}break}c=c+4|0;I=I+1|0;z=z-o|0;if((z|0)<=0){break w}b=(S|0)>0;S=S-1|0;if(b){continue}break}}_=_+1|0;if((z|0)>0){continue}break}}l=1-z|0;while(1){y:{b=x[t+26|0]?44704:44672;h=x[b+(i>>>28|0)|0];if(!(h&8)){h=x[b+((i<<4>>>32-(h&3))+(h>>>3)|0)|0]}m=h&7;f=m+f|0;if(((f+(g-w[j+912>>2]<<3)|0)-24|0)>(V|0)){break y}l=l-1|0;if(!l){b=x[I|0];if(b>>>0<2){break y}l=b>>>1|0;I=I+1|0;n=A[c>>2];c=c+4|0}i=i<<m;if(h>>>0>=128){A[k>>2]=(i|0)<0?D(-n):n;f=f+1|0;i=i<<1}if(h&64){A[k+4>>2]=(i|0)<0?D(-n):n;f=f+1|0;i=i<<1}l=l-1|0;if(!l){b=x[I|0];if(b>>>0<2){break y}l=b>>>1|0;I=I+1|0;n=A[c>>2];c=c+4|0}if(h&32){A[k+8>>2]=(i|0)<0?D(-n):n;f=f+1|0;i=i<<1}if(h&16){A[k+12>>2]=(i|0)<0?D(-n):n;f=f+1|0;i=i<<1}if((f|0)>=0){while(1){i=x[g|0]<<f|i;b=f>>>0>7;f=f-8|0;g=g+1|0;if(b){continue}break}}k=k+16|0;continue}break}w[j+916>>2]=V;O=O+1|0;if((R|0)!=(O|0)){continue}break}}M=x[a+6155|0];z:{if(M&16){o=x[G+14|0];m=x[G+13|0];c=w[G>>2];w[j+8>>2]=-1;w[j>>2]=-1;w[j+4>>2]=-1;k=0;g=E;i=m+o|0;if(i){while(1){f=0;h=x[c+k|0];A:{if(!h){break A}while(1){b=f<<2;if(!(A[b+g>>2]!=D(0)|A[(b|4)+g>>2]!=D(0))){f=f+2|0;if(h>>>0>f>>>0){continue}break A}break}w[((k>>>0)%3<<2)+j>>2]=k}g=(h<<2)+g|0;k=k+1|0;if((i|0)!=(k|0)){continue}break}}if(m){c=w[j>>2];b=w[j+4>>2];c=(b|0)<(c|0)?c:b;b=w[j+8>>2];b=(b|0)<(c|0)?c:b;w[j+8>>2]=b;w[j+4>>2]=b;w[j>>2]=b}h=o?3:1;g=i-h|0;f=0;while(1){c=f+g|0;b=c-h|0;if((b|0)<=w[(f<<2)+j>>2]){b=x[a+6153|0]<<28>>31&3}else{b=x[b+Z|0]}u[c+Z|0]=b;f=f+1|0;if((h|0)!=(f|0)){continue}break}b=w[G>>2];i=x[b|0];if(!i){break z}K=x[a+6153|0]&8;F=K?7:64;B=v[G+36>>1]&1;o=M&32;X=o?D(1.4142135381698608):D(1);s=0;m=b;h=H;while(1){B:{C:{if(w[((s>>>0)%3<<2)+j>>2]>=(s|0)){break C}g=x[s+Z|0];if(g>>>0>=F>>>0){break C}D:{if(K){c=(g<<3)+45408|0;p=A[c>>2];P=A[c+4>>2];break D}f=g+1>>>1<<B;n=D(1);while(1){c=(f|0)>=120?120:f;n=D(D(A[((c&3)<<2)+40320>>2]*n)*D(1073741824>>>(c>>2)|0));f=f-c|0;if((f|0)>0){continue}break}c=g&1;P=c?D(1):n;p=c?n:D(1)}c=i&255;f=0;while(1){g=(f<<2)+h|0;n=D(A[g>>2]*X);A[g+2304>>2]=n*P;A[g>>2]=n*p;f=f+1|0;if((c|0)!=(f|0)){continue}break}break B}if(!o){break B}k=h+2304|0;i=i&255;f=0;while(1){c=f<<2;g=c+h|0;c=c+k|0;n=A[c>>2];p=A[g>>2];A[g>>2]=n+p;A[c>>2]=p-n;f=f+1|0;if((i|0)!=(f|0)){continue}break}}h=(x[m|0]<<2)+h|0;s=s+1|0;m=b+s|0;i=x[m|0];if(i){continue}break}break z}f=0;if((M&224)!=96){break z}while(1){b=f<<2;c=b+H|0;b=b+E|0;n=A[b>>2];p=A[c>>2];A[c>>2]=n+p;A[b>>2]=p-n;f=f+1|0;if((f|0)!=576){continue}break}}b=0;if(!Q){while(1){c=x[a+6153|0];B=(x[G+12|0]!=0)<<1<<((C((c>>>3&1)+(c>>>4&1)|0,3)+(x[a+6154|0]>>>2&3)|0)==2);E:{F:{G:{H:{if(!x[G+14|0]){c=(C(b,2304)+j|0)+3852|0;k=31;break H}g=J;c=(C(b,2304)+j|0)+3852|0;m=c+C(B,72)|0;f=m;s=w[G>>2]+x[G+13|0]|0;h=x[s|0];if(h){while(1){o=h&255;k=o<<1;i=0;while(1){A[g>>2]=A[f>>2];A[g+4>>2]=A[(o<<2)+f>>2];h=k<<2;A[g+8>>2]=A[h+f>>2];f=f+4|0;g=g+12|0;i=i+1|0;if((o|0)!=(i|0)){continue}break}f=f+h|0;h=x[s+3|0];s=s+3|0;if(h){continue}break}}Fb(m,J,g-J|0);if(!B){break G}k=B-1|0}g=c;while(1){f=0;while(1){h=f<<2;i=h+g|0;h=h+45472|0;P=A[h>>2];X=A[i+72>>2];n=A[h+32>>2];h=(17-f<<2)+g|0;p=A[h>>2];A[i+72>>2]=D(P*X)-D(n*p);A[h>>2]=D(n*X)+D(P*p);f=f+1|0;if((f|0)!=8){continue}break}g=g+72|0;h=(k|0)>1;k=k-1|0;if(h){continue}break}h=x[G+11|0];g=C(b,1152)+a|0;if(!B){break F}zu(c,g,45536,B);g=g+C(B,36)|0;f=((C(b,2304)+j|0)+C(B,72)|0)+3852|0;break E}h=x[G+11|0];g=C(b,1152)+a|0}f=c}h=h&255;I:{if((h|0)==2){h=32-B|0;while(1){k=Fb(j,f,72);i=w[g+20>>2];w[f+16>>2]=w[g+16>>2];w[f+20>>2]=i;i=w[g+12>>2];w[f+8>>2]=w[g+8>>2];w[f+12>>2]=i;i=w[g+4>>2];w[f>>2]=w[g>>2];w[f+4>>2]=i;i=g+24|0;Lm(k,f+24|0,i);Lm(da,f+48|0,i);Lm(ca,g,i);f=f+72|0;g=g+36|0;i=h>>>0>1;h=h-1|0;if(i){continue}break}break I}zu(f,g,C((h|0)==3,72)+45536|0,32-B|0)}h=c+72|0;i=0;while(1){f=1;while(1){c=(f<<2)+h|0;A[c>>2]=-A[c>>2];c=f>>>0<16;f=f+2|0;if(c){continue}break}h=h+144|0;c=i>>>0<30;i=i+2|0;if(c){continue}break}G=G+28|0;b=b+1|0;if((R|0)!=(b|0)){continue}break}}yu(ba,H,18,w[e+8>>2],d,J);R=w[e+8>>2];d=C(R,1152)+d|0;b=(x[q+1|0]&8)>>>3&aa;f=1;aa=0;if(b){continue}break}f=w[j+920>>2];h=w[j+916>>2]+7>>>3|0}b=f>>>3|0;d=b-h|0;c=(d|0)>=511?511:d;if((d|0)>0){Fb($,(d>>>0>511?b-511|0:h)+Y|0,c)}w[a+6144>>2]=c;b=(N|0)<=(U|0);break l}f=0;J:{K:{L:{b=x[q+3|0];c=b>>>6|0;switch(c-1|0){case 2:break J;case 0:break L;default:break K}}f=(b>>>2&12)+4|0;break J}f=32}g=x[q+1|0];M:{if((g&6)==6){g=46940;c=32;break M}if(!(g&8)){g=46943;c=30;break M}b=x[q+2|0];h=b>>>2&3;b=x[(C(g>>>3&1,45)+C(g>>>1&3,15)+(b>>>4)|0)+39217|0]<<1>>>((c|0)!=3)|0;b=b?b:192;if(b>>>0<=55){g=46964;c=(h|0)==2?12:8;break M}g=46952;c=b>>>0<=95?27:(h|0)!=1?30:27}u[j+768|0]=c;i=(c|0)>(f|0)?f:c;u[j+769|0]=i;k=46848;l=0;f=0;while(1){if((f|0)==(s|0)){k=x[g|0]+46848|0;s=x[g+2|0]+s|0;l=x[g+1|0];g=g+3|0}h=f<<1;b=x[xc(j+17152|0,l)+k|0];u[(h+j|0)+770|0]=b;h=(h|1)+j|0;if(f>>>0<i>>>0){b=x[xc(j+17152|0,l)+k|0]}u[h+770|0]=i?b:0;f=f+1|0;if((c|0)!=(f|0)){continue}break}r=c<<1;f=0;while(1){b=f+j|0;c=6;N:{if(!x[b+770|0]){break N}c=2;if((x[q+1|0]&6)==6){break N}c=xc(j+17152|0,2)}u[b+834|0]=c;f=f+1|0;if((r|0)!=(f|0)){continue}break}l=j+770|0;h=j+834|0;s=0;g=j;while(1){i=0;b=x[l|0];i=b?19>>>x[h+s|0]&3|4:i;l=l+1|0;c=C(b,3)-6|0;f=4;n=D(0);while(1){if(f&i){b=xc(j+17152|0,6);k=(b|0)/3|0;n=D(A[(c+(b-C(k,3)|0)<<2)+46976>>2]*D(2097152>>>k|0))}A[g>>2]=n;g=g+4|0;b=f>>>0>1;f=f>>>1|0;if(b){continue}break}s=s+1|0;if((r|0)!=(s|0)){continue}break}f=x[j+769|0];b=x[j+768|0];if(f>>>0<b>>>0){while(1){u[((f<<1)+j|0)+771|0]=0;f=f+1|0;if((b|0)!=(f|0)){continue}break}}c=0;E=Cb(j+3852|0,0,4608);F=a+2304|0;B=j+8620|0;o=j+6156|0;b=0;while(1){r=x[j+768|0];g=r<<1;J=g>>>0<=1?1:g;L=w[e+16>>2]|1;H=E+(b<<2)|0;f=576;g=r;l=0;while(1){if(g&255){h=H+(C(l,L)<<2)|0;m=0;while(1){i=f;k=x[(j+m|0)+770|0];O:{if(!k){break O}if(k>>>0<=16){if((L|0)<=0){break O}g=(-1<<k-1)+1|0;f=0;while(1){ea=(f<<2)+h|0,ga=D(xc(j+17152|0,k)+g|0),A[ea>>2]=ga;f=f+1|0;if((L|0)!=(f|0)){continue}break}break O}g=2<<k-17;f=xc(j+17152|0,(g-(g>>>3|0)|0)+3|0);if((L|0)<=0){break O}K=g|1;k=g>>>1|0;g=0;while(1){T=f;f=(f>>>0)/(K>>>0)|0;A[(g<<2)+h>>2]=(T-C(K,f)|0)-k|0;g=g+1|0;if((L|0)!=(g|0)){continue}break}}f=18-i|0;h=(i<<2)+h|0;m=m+1|0;if((J|0)!=(m|0)){continue}break}g=r}else{g=0}l=l+1|0;if((l|0)!=4){continue}break}b=(L<<2)+b|0;if((b|0)==12){g=x[j+769|0];b=C(g,72);Fb(b+o|0,b+E|0,C(r-g|0,72));if(r){i=(c<<2)+j|0;k=0;h=E;while(1){n=A[i+12>>2];p=A[i>>2];f=0;while(1){b=(f<<2)+h|0;A[b>>2]=A[b>>2]*p;b=b+2304|0;A[b>>2]=A[b>>2]*n;f=f+1|0;if((f|0)!=12){continue}break}i=i+24|0;h=h+72|0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}yu(F,E,12,w[e+8>>2],d,B);Cb(E,0,4608);d=C(w[e+8>>2],768)+d|0;b=0}if(w[j+17156>>2]>w[j+17160>>2]){break n}c=c+1|0;if((c|0)!=3){continue}break}break m}u[Q|0]=0;a=0;break a}b=1}a=x[a+6153|0];a=C(b,(a&6)==6?384:1152>>>((a&14)==2)|0)}jb=j+17168|0;return a|0}function Bu(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,P=0,Q=0;N=jb-144|0;jb=N;a:{b:{if(d>>>0<=e>>>0){E=w[f>>2]+e|0;O=g&4;L=O?-1:E+(d^-1)|0;D=L+1|0;if(!(D&L)){break b}}w[f>>2]=0;w[c>>2]=0;k=-3;break a}F=w[c>>2];s=F+b|0;G=w[a+60>>2];r=w[a+40>>2];j=w[a+36>>2];A=w[a+32>>2];m=w[a+56>>2];i=w[a+4>>2];l=b;p=e;q=-1;k=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{t=w[a>>2];switch(t|0){case 35:break h;case 17:break i;case 21:break j;case 37:break k;case 34:break l;case 42:break p;case 41:break q;case 53:break r;case 52:break s;case 51:break t;case 38:break u;case 27:break v;case 26:break w;case 25:break x;case 24:break y;case 23:break z;case 18:break A;case 16:break B;case 14:break C;case 11:break D;case 9:break E;case 7:break F;case 6:break G;case 3:break H;case 32:break I;case 5:break J;case 2:break L;case 1:break M;case 0:break N;case 36:break e;case 39:break f;case 10:break g;default:break c}}w[a+28>>2]=1;m=0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+16>>2]=1;r=0;j=0;A=0;i=0;if(g&1){break M}break K}if((F|0)<=0){w[a>>2]=1;break d}w[a+8>>2]=x[b|0];l=b+1|0}if(l>>>0>=s>>>0){w[a>>2]=2;k=g&2?1:-4;break c}k=x[l|0];w[a+12>>2]=k;j=1;l=l+1|0;t=36;h=w[a+8>>2];if(((k|h<<8)>>>0)%31|k&32){break e}k=h&15;if(!O){h=256<<(h>>>4);if(h>>>0>32768|h>>>0>D>>>0){break e}if((k|0)==8){break K}break e}if((k|0)!=8){break e}}h=0;break o}if((F|0)<=0){w[a>>2]=5;break d}P=i+8|0;l=b+1|0;m=x[b|0]<<i|m;h=2;break o}if((F|0)<=0){w[a>>2]=32;break d}i=i+8|0;l=b+1|0;B=j;break n}h=1;break o}h=4;break o}h=3;break o}h=7;break o}h=9;break o}h=10;break o}h=11;break o}h=12;break o}h=13;break o}h=14;break o}h=15;break o}h=16;break o}h=17;break o}h=8;break o}h=5;break o}h=6;break o}h=18;break o}n=2;break m}n=1;break m}O:while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:j=B;if(i>>>0>2){break Ca}h=1;continue;case 17:break ka;case 16:break la;case 15:break ma;case 14:break na;case 13:break oa;case 12:break pa;case 11:break qa;case 10:break ra;case 9:break sa;case 8:break ua;case 7:break va;case 6:break wa;case 5:break xa;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ja}}while(1){if(l>>>0>=s>>>0){w[a>>2]=3;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}B=j}k=m&7;w[a+20>>2]=k;h=k>>>1|0;w[a+24>>2]=h;i=i-3|0;m=m>>>3|0;if(k>>>0>=2){break ta}P=i;break ia}i=P&-8;m=m>>>(P&7)|0;j=0;h=0;break ga}if(l>>>0<s>>>0){break ya}w[a>>2]=7;k=g&2?1:-4;break c}while(1){if(l>>>0>=s>>>0){w[a>>2]=6;k=g&2?1:-4;break c}m=x[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}h=1;break ga}u[(a+j|0)+10528|0]=x[l|0];l=l+1|0;h=2;break ga}while(1){if(l>>>0>=s>>>0){w[a>>2]=51;k=g&2?1:-4;break c}m=x[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}break S}if(p>>>0<E>>>0){u[p|0]=A;j=j-1|0;p=p+1|0;break T}q=2;t=52;break e}if(p>>>0<E>>>0){break ha}q=2;t=9;break e}if(l>>>0<s>>>0){k=E-p|0;h=s-l|0;h=h>>>0>k>>>0?k:h;h=h>>>0<j>>>0?h:j;j=j-h|0;p=Fb(p,l,h)+h|0;l=h+l|0;break R}w[a>>2]=38;k=g&2?1:-4;break c}k=0;j=B;Ea:{switch(h-1|0){case 0:break Ea;case 2:break g;default:break fa}}w[a+44>>2]=288;w[a+48>>2]=32;h=a+3552|0;w[h>>2]=84215045;w[h+4>>2]=84215045;h=a+3560|0;w[h>>2]=84215045;w[h+4>>2]=84215045;h=a+3568|0;w[h>>2]=84215045;w[h+4>>2]=84215045;h=a+3576|0;w[h>>2]=84215045;w[h+4>>2]=84215045;Cb(a- -64|0,8,144);Cb(a+208|0,9,112);u[a+336|0]=7;u[a+337|0]=7;u[a+338|0]=7;u[a+339|0]=7;u[a+340|0]=7;u[a+341|0]=7;u[a+342|0]=7;u[a+343|0]=7;u[a+328|0]=7;u[a+329|0]=7;u[a+330|0]=7;u[a+331|0]=7;u[a+332|0]=7;u[a+333|0]=7;u[a+334|0]=7;u[a+335|0]=7;u[a+320|0]=7;u[a+321|0]=7;u[a+322|0]=7;u[a+323|0]=7;u[a+324|0]=7;u[a+325|0]=7;u[a+326|0]=7;u[a+327|0]=7;u[a+344|0]=8;u[a+345|0]=8;u[a+346|0]=8;u[a+347|0]=8;u[a+348|0]=8;u[a+349|0]=8;u[a+350|0]=8;u[a+351|0]=8;H=1;break X}while(1){if(l>>>0>=s>>>0){w[a>>2]=11;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;I=u[j+17249|0];if(i>>>0<I>>>0){continue}break}k=j;j=1;break Z}while(1){if(l>>>0>=s>>>0){w[a>>2]=14;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}h=1;break Y}if(l>>>0>=s>>>0){w[a>>2]=16;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ea}break da}while(1){if(l>>>0>=s>>>0){w[a>>2]=18;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(r>>>0>i>>>0){continue}break}Q=A-16|0;h=3;break W}if(l>>>0>=s>>>0){w[a>>2]=23;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ca}break ba}if(p>>>0>=E>>>0){q=2;t=24;break e}u[p|0]=j;p=p+1|0;n=m;break V}while(1){if(l>>>0>=s>>>0){w[a>>2]=25;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(r>>>0>i>>>0){continue}break}h=3;break U}if(l>>>0>=s>>>0){w[a>>2]=26;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break aa}break $}while(1){if(l>>>0>=s>>>0){w[a>>2]=27;k=g&2?1:-4;break c}m=x[l|0]<<i|m;l=l+1|0;i=i+8|0;if(r>>>0>i>>>0){continue}break}h=6;break U}if(p>>>0>=E>>>0){q=2;t=53;break e}u[p|0]=x[(G-A&L)+d|0];p=p+1|0;G=G+1|0;break _}h=2;continue}h=8;continue}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{switch(h|0){case 0:if(j>>>0>3){break Ia}if(!i){i=0;h=3;continue O}if(i>>>0>7){break Ga}h=4;continue O;case 1:u[(a+j|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break Fa;default:break Ja}}j=j+1|0;break Ha}j=y[a+10528>>1];if((j|0)==(y[a+10530>>1]^65535)){break T}break f}h=0;continue}h=1;continue}h=2;continue}}j=0;break Z}h=1;break W}h=2;break W}h=0;break U}h=1;break U}h=4;break U}h=5;break U}h=7;break U}while(1){Ka:{La:{Ma:{if(!j){if(k>>>0>2){break Ma}j=k;I=u[j+17249|0];if(I>>>0<=i>>>0){break Ka}h=9;continue O}j=k<<2;w[(j+a|0)+44>>2]=w[j+39184>>2]+((-1<<I^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break La}j=0;Cb(a+7040|0,0,288);h=0;break Y}j=0;continue}j=1;continue}}while(1){Na:{Oa:{Pa:{if(!h){if(z[a+52>>2]<=j>>>0){break Pa}if(i>>>0>2){break Na}h=10;continue O}u[(x[j+39200|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Oa}w[a+52>>2]=19;H=w[a+24>>2];B=j;break X}h=0;continue}h=1;continue}}h=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(h|0){case 0:j=0;if((H|0)<0){n=m;j=B;break V}J=Cb(N,0,64);h=C(H,3488)+a|0;Cb(h+352|0,0,3200);F=h- -64|0;q=w[a+24>>2];D=w[((q<<2)+a|0)+44>>2];if(D){while(1){h=J+(x[j+F|0]<<2)|0;w[h>>2]=w[h>>2]+1;j=j+1|0;if((D|0)!=(j|0)){continue}break}}w[J+64>>2]=0;w[J+68>>2]=0;k=0;o=0;j=1;while(1){h=j<<2;j=j+1|0;h=w[h+J>>2];k=h+k<<1;w[(J- -64|0)+(j<<2)>>2]=k;o=h+o|0;if((j|0)!=16){continue}break};if(!((k|0)==65536|o>>>0<=1)){j=B;break h}if(D){h=-1;K=0;t=C(H,3488)+a|0;while(1){q=x[F+K|0];Za:{if(!q){break Za}k=(J- -64|0)+(q<<2)|0;j=w[k>>2];w[k>>2]=j+1;k=0;o=q;while(1){D=k<<1;k=D|j&1;j=j>>>1|0;o=o-1|0;if(o){continue}break}if(q>>>0<=10){if(k>>>0>1023){break Za}o=q<<9|K;j=1<<q;while(1){v[(t+(k<<1)|0)+352>>1]=o;k=j+k|0;if(k>>>0<1024){continue}break}break Za}k=t+((k&1023)<<1)|0;j=v[k+352>>1];_a:{if(j){k=h;h=j;break _a}v[k+352>>1]=h;k=h-2|0}j=D>>>9|0;if(q>>>0>=12){while(1){j=j>>>1|0;o=(t+((j&1)+(h^-1)<<1)|0)+2400|0;h=v[o>>1];if(!h){v[o>>1]=k;h=k;k=h-2|0}q=q-1|0;if(q>>>0>11){continue}break}}v[(t+((j>>>1&1)+(h^-1)<<1)|0)+2400>>1]=K;h=k}K=K+1|0;q=w[a+24>>2];if(K>>>0<z[((q<<2)+a|0)+44>>2]){continue}break}}j=0;if((q|0)!=2){break Ra}break Va;case 1:h=v[(((m&1023)<<1)+a|0)+7328>>1];$a:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break $a}break Ua}if(i>>>0<11){break $a}k=10;while(1){h=v[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break Ua}}h=11;continue O;case 2:k=v[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Xa}h=10;while(1){o=m>>>h|0;h=h+1|0;k=v[(((o&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break Wa;default:break Ya}}o=u[Q+13560|0]+((-1<<r^-1)&m)|0;i=i-r|0;m=m>>>r|0;k=a+j|0;Cb(k+10532|0,(A|0)==16?x[k+10531|0]:0,o);j=j+o|0;break Va}h=k>>>9|0;k=k&511}i=i-h|0;m=m>>>h|0;A=k;if(k>>>0>15){break Ta}u[(a+j|0)+10532|0]=A;j=j+1|0}k=w[a+48>>2];o=w[a+44>>2];h=k+o|0;if(h>>>0<=j>>>0){break Sa}if(i>>>0>14){break Ua}if((s-l|0)<=1){h=1;continue}m=x[l|0]<<i|x[l+1|0]<<i+8|m;i=i+16|0;l=l+2|0}h=2;continue}if(!((A|0)!=16|j)){j=0;A=16;break i}Q=A-16|0;r=u[Q+17245|0];if(r>>>0<=i>>>0){break Qa}h=12;continue O}if((h|0)!=(j|0)){break j}h=a+10532|0;Fb(a- -64|0,h,o);Fb(a+3552|0,h+o|0,k);q=w[a+24>>2];B=j}H=q-1|0;w[a+24>>2]=H;h=0;continue}h=3;continue}}h=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(h|0){case 0:h=v[(((m&1023)<<1)+a|0)+352>>1];qb:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break qb}break bb}if(i>>>0<11){break qb}k=10;while(1){h=v[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break bb}}h=13;continue O;case 1:k=v[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break ob}h=10;while(1){j=m>>>h|0;h=h+1|0;k=v[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){m=s-l|0;if(!((E-p|0)>1&(m|0)>=4)){if(i>>>0>14){m=n;break bb}if((m|0)<=1){m=n;h=0;continue ab}m=x[l|0]<<i|x[l+1|0]<<i+8|n;i=i+16|0;l=l+2|0;break bb}if(i>>>0>14){h=l}else{n=(x[l|0]|x[l+1|0]<<8)<<i|n;i=i+16|0;h=l+2|0}j=v[(((n&1023)<<1)+a|0)+352>>1];rb:{if((j|0)<0){l=10;while(1){m=n>>>l|0;l=l+1|0;j=v[(((m&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break rb}l=j>>>9|0}i=i-l|0;m=n>>>l|0;if(j&256){l=h;break mb}if(i>>>0>14){k=i}else{m=(x[h|0]|x[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=v[(((m&1023)<<1)+a|0)+352>>1];sb:{if((h|0)<0){n=10;while(1){i=m>>>n|0;n=n+1|0;h=v[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break sb}n=h>>>9|0}u[p|0]=j;i=k-n|0;n=m>>>n|0;if(!(h&256)){u[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=n;j=h;break mb}h=k>>>9|0;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break mb}h=14;continue O}B=256;k=j&511;if((k|0)==256){break Q}h=k-257<<2;j=w[h+38672>>2];r=0;if(k-285>>>0<4294967276){break db}r=w[h+38800>>2];if(r>>>0>i>>>0){h=15;continue O}h=3;continue}if(!j){n=m;j=-1;break hb}j=j-1|0;h=18;continue O}i=i-r|0;n=m>>>r|0;A=((-1<<r^-1)&m)+A|0;break ib}r=v[(((m&1023)<<1)+a|0)+3840>>1];tb:{if((r|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;r=v[(((k&1)+(r^-1)<<1)+a|0)+5888>>1];if((r|0)<0){continue}break}k=r;break tb}h=r>>>9|0;k=r&511}o=k<<2;A=w[o+38928>>2];i=i-h|0;m=m>>>h|0;r=0;if(k-30>>>0<4294967270){n=m;break ib}r=w[o+39056>>2];if(r>>>0<=i>>>0){break gb}h=17;continue O}G=p-d|0;if(!(!O|(A|0)!=0&G>>>0>=A>>>0)){m=n;break k}h=(G-A&L)+d|0;if((h>>>0<p>>>0?p:h)+j>>>0>E>>>0){m=n;h=7;continue}if(j>>>0>2){while(1){u[p|0]=x[h|0];u[p+1|0]=x[h+1|0];u[p+2|0]=x[h+2|0];h=h+3|0;p=p+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break hb}u[p|0]=x[h|0];if((j|0)!=1){u[p+1|0]=x[h+1|0]}p=j+p|0}h=2;continue}h=6;continue}h=v[(((m&1023)<<1)+a|0)+3840>>1];ub:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break ub}break cb}if(i>>>0<11){break ub}k=10;while(1){h=v[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break cb}}h=16;continue O}i=i-r|0;j=((-1<<r^-1)&m)+j|0;m=m>>>r|0}if(i>>>0>14){break cb}if((s-l|0)<=1){h=4;continue}m=m|(x[l|0]<<i|x[l+1|0]<<i+8);i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(!j|!i){break R}if(i>>>0>7){break S}h=5;continue}i=i-8|0;A=m&255;m=m>>>8|0;h=6;continue}if(j){break P}B=0}if(u[a+20|0]&1){break n}h=0;continue}h=7;continue}}i=i&-8;if(!(!i|b>>>0>=l>>>0)){m=i-8|0;j=m>>>3|0;d=(b^-1)+l|0;d=d>>>0>j>>>0?j:d;l=(d^-1)+l|0;i=m-(d<<3)|0}if(!i){m=0;o=0;h=0;j=B;i=0;if(!(g&1)){break l}n=0;break m}ha(3164,8986,2797,3174);M()}while(1){vb:{wb:{xb:{yb:{zb:{Ab:{switch(n|0){case 0:if(o>>>0>3){j=o;i=h;break l}i=0;if(h){break zb}j=o;n=1;continue;case 1:break Ab;default:break yb}}if(l>>>0<s>>>0){break wb}w[a>>2]=42;k=g&2?1:-4;break c}j=o;i=h;if(h>>>0>7){break xb}n=2;continue}while(1){if(l>>>0>=s>>>0){w[a>>2]=41;k=g&2?1:-4;break c}m=x[l|0]<<i|m;d=i>>>0>4294967287;l=l+1|0;h=i+8|0;i=h;if(d){continue}break}o=j}n=m&255;m=m>>>8|0;h=h-8|0;break vb}n=x[l|0];l=l+1|0;o=j;h=i}w[a+16>>2]=w[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}q=0;t=34;break e}t=37;q=-1;break e}t=21;q=-1;break e}t=17;q=-1;break e}t=35;q=-1;break e}t=10;q=-1;break e}t=39;q=-1}w[a>>2]=t;if(!(i>>>0<8|b>>>0>=l>>>0)){B=i-8|0;h=B>>>3|0;d=(b^-1)+l|0;d=d>>>0>h>>>0?h:d;l=(d^-1)+l|0;i=B-(d<<3)|0}k=q;break c}k=g&2?1:-4}w[a+4>>2]=i;w[a+60>>2]=G;w[a+40>>2]=r;w[a+36>>2]=j;w[a+32>>2]=A;w[a+56>>2]=(((i&63)>>>0<32?-1<<i:0)^-1)&m;w[c>>2]=l-b;h=p-e|0;w[f>>2]=h;if(!(g&9)|(k|0)<0){break a}b=w[a+28>>2];l=b>>>16|0;i=b&65535;if(h){n=(h>>>0)%5552|0;while(1){j=0;if(n>>>0>=8){j=n&8184;m=0;while(1){q=x[e|0]+i|0;o=q+x[e+1|0]|0;B=o+x[e+2|0]|0;f=B+x[e+3|0]|0;d=f+x[e+4|0]|0;c=d+x[e+5|0]|0;b=c+x[e+6|0]|0;i=b+x[e+7|0]|0;l=i+(b+(c+(d+(f+(B+(o+(l+q|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;m=m+8|0;if((m|7)>>>0<n>>>0){continue}break}}if(j>>>0<n>>>0){b=n-j|0;m=e;while(1){i=x[m|0]+i|0;l=l+i|0;m=m+1|0;j=j+1|0;if((n|0)!=(j|0)){continue}break}e=b+e|0}h=h-n|0;l=(l>>>0)%65521|0;i=(i>>>0)%65521|0;n=5552;if(h){continue}break}}b=l<<16|i;w[a+28>>2]=b;if(k){break a}k=0;if(!(g&1)){break a}k=(b|0)!=w[a+16>>2]?-2:0}jb=N+144|0;return k}function eV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=jb-688|0;jb=d;w[b+8>>2]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!Mc(b,d+672|0)|w[d+672>>2]!=1179011410|z[d+676>>2]<81){break q}if(!Nc(b,d+664|0)){break q}g=w[d+664>>2];i=(g|0)==1179012417;k=(g|0)!=538987841;if(!i&k|!(k?i:1)){break q}w[d+648>>2]=w[b>>2];e=w[b+4>>2];w[d+652>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=i?1313423693:1414090313;i=w[b+12>>2];w[d+656>>2]=w[b+8>>2];w[d+660>>2]=i;w[d+640>>2]=0;w[d+632>>2]=0;w[d+636>>2]=0;b=(g|0)==1179012417?1:2;r:{s:{t:{u:{v:{w:{x:{if(!c){w[114256]=0;Y(923,d+72|0,d+648|0,b|0,e|0);b=w[114256];w[114256]=0;if((b|0)!=1){break x}b=P()|0;break a}w[114256]=0;U(924,d+72|0,d+648|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break w}}b=d+632|0;jp(b);w[d+632>>2]=w[d+72>>2];i=w[d+76>>2];k=w[d+80>>2];w[d+80>>2]=0;w[d+636>>2]=i;w[d+640>>2]=k;w[d+72>>2]=0;w[d+76>>2]=0;Ac(d+72|0);w[114256]=0;U(925,d+616|0,b|0,e|0);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[d+616>>2];e=w[w[b>>2]+8>>2];w[114256]=0;b=V(e|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}e=0;if(!b){break r}w[114256]=0;b=Q(926,d+616|0,d+536|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break v}if(!b){break r}b=x[d+601|0];if(!b){break r}e=w[d+616>>2];i=w[w[e>>2]+36>>2];w[114256]=0;e=S(i|0,e|0,w[d+624>>2],b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break v}if(!c|e^1){break r}w[114256]=0;T(236,a|0,8388608);b=w[114256];w[114256]=0;if((b|0)==1){break v}w[a+480208>>2]=u[d+600|0]&1?12:28;b=x[d+601|0];v[a+480188>>1]=b>>>0>=127?127:b;w[a+480196>>2]=x[d+602|0];w[a+480204>>2]=C(x[d+603|0],1e4);w[a+480200>>2]=x[d+608|0]<<1;w[114256]=0;Q(460,a+1304436|0,((g|0)==1179012417?12733:12699)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break v}w[114256]=0;e=Q(1,d+520|0,9077)|0;b=w[114256];w[114256]=0;if((b|0)==1){break t}b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}i=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=i;w[b+8>>2]=w[e+8>>2];w[a+1304496>>2]=4;w[114256]=0;Y(209,d+72|0,2,d+536|0,64);b=w[114256];w[114256]=0;if((b|0)==1){break u}b=a+1304400|0;if(u[a+1304411|0]<0){zb(w[b>>2])}e=w[d+76>>2];w[b>>2]=w[d+72>>2];w[b+4>>2]=e;w[b+8>>2]=w[d+80>>2];if(!y[a+480188>>1]){break s}b=0;k=(g|0)==1179012417;while(1){w[114256]=0;i=(b<<5)+a|0;m=i+480280|0;X(224,m|0);e=w[114256];w[114256]=0;y:{z:{A:{B:{C:{if((e|0)!=1){w[114256]=0;e=Q(241,d+616|0,d+72|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break C}e=e?x[d+72|0]:0;if(k){break A}e=e&255;if(e>>>0<129){break B}break z}b=P()|0;break b}b=P()|0;break b}v[i+480284>>1]=e<<1;break y}if(e<<24>>24<0){break z}e=e<<2&1020;v[i+480284>>1]=e>>>0>=256?256:e;break y}w[m>>2]=1024}b=b+1|0;if(b>>>0<y[a+480188>>1]){continue}break}break s}b=P()|0;break a}b=P()|0;break a}b=P()|0;break b}b=P()|0;break b}b=P()|0;break b}D:{E:{b=w[d+632>>2];e=w[d+636>>2];if((b|0)==(e|0)){break E}while(1){if(w[b>>2]==1380209231){break E}b=b+24|0;if((e|0)!=(b|0)){continue}break}break D}if((b|0)==(e|0)){break D}w[114256]=0;U(925,d+72|0,d+632|0,1380209231);b=w[114256];w[114256]=0;F:{if((b|0)!=1){w[114256]=0;b=Q(241,d+72|0,d+424|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break F}e=x[d+424|0];i=x[a+484376|0];k=w[a+484360>>2];w[114256]=0;da(317,k+(i<<5)|0,d+72|0,(b?e+1&255:1)|0,255,254)|0;b=w[114256];w[114256]=0;if((b|0)==1){break F}Bb(d+72|0);break D}b=P()|0;break b}b=P()|0;Bb(d+72|0);break b}if(c&1){w[114256]=0;U(927,d+488|0,d+632|0,1414807888);b=w[114256];w[114256]=0;G:{H:{if((b|0)!=1){w[114256]=0;l=a+484344|0;T(215,l|0,w[d+492>>2]-w[d+488>>2]>>>4&65535);b=w[114256];w[114256]=0;I:{J:{if((b|0)!=1){i=w[d+488>>2];o=w[d+492>>2];if((i|0)==(o|0)){break G}q=d+16|2;r=(g|0)==1179012417;k=0;K:{L:{while(1){w[d+424>>2]=w[i>>2];b=w[i+4>>2];w[d+428>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[i+8>>2];e=w[i+12>>2];w[114256]=0;w[d+432>>2]=b;w[d+436>>2]=e;e=Q(241,d+424|0,d+72|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break L}w[114256]=0;m=x[d+72|0];b=Q(232,d+424|0,d+72|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break K}w[114256]=0;U(188,d+504|0,d+424|0,(b?w[d+72>>2]:0)|0);b=w[114256];w[114256]=0;if((b|0)==1){break K}b=w[d+516>>2];h=w[d+512>>2];w[d+80>>2]=h;w[d+84>>2]=b;f=w[d+508>>2];b=w[d+504>>2];w[d+72>>2]=b;w[d+76>>2]=f;f=w[w[b>>2]+36>>2];w[114256]=0;b=S(f|0,b|0,h|0,1)|0;h=w[114256];w[114256]=0;if((h|0)!=1){m=e?m:0;M:{if(!b){break M}w[114256]=0;b=Q(241,d+72|0,d+40|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}w[114256]=0;p=b?x[d+40|0]+1|0:1;b=S(216,l|0,m|0,p|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}if(!b){break M}b=y[a+480188>>1];if(!b){break M}s=b-1|0;e=0;while(1){b=w[d+72>>2];h=w[w[b>>2]+36>>2];w[114256]=0;b=S(h|0,b|0,w[d+80>>2],1)|0;h=w[114256];w[114256]=0;N:{O:{if((h|0)!=1){if(!b){break M}w[114256]=0;b=Q(241,d+72|0,d+40|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break J}f=b?x[d+40|0]:0;h=f&255;if(h){break O}e=e+1|0;break N}break J}b=w[l>>2];w[114256]=0;b=b+C(m,52)|0;j=V(218,b|0)|0;n=w[114256];w[114256]=0;P:{Q:{if((n|0)!=1){if(h>>>0<32){break N}n=w[b>>2];t=C(e,j);b=s&65535;j=f&31;b=n+C(t+(b>>>0<j>>>0?b:j)|0,6)|0;if(f<<24>>24>=0){break P}w[114256]=0;f=Q(241,d+72|0,d+40|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break J}u[b+5|0]=f?x[d+40|0]:0;w[114256]=0;f=Q(241,d+72|0,d+40|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break J}f=(f?x[d+40|0]:0)&255;if(f>>>0<26){break Q}u[b+3|0]=0;break P}break J}f=x[f+35664|0];u[b+3|0]=f;R:{switch(f-1|0){case 0:if(x[b+5|0]){break P}u[b+3|0]=0;break P;case 12:if(x[b+2|0]){break P}u[b+2|0]=1;f=x[b+5|0];u[b+4|0]=f>>>0>=64?64:f;u[b+3|0]=0;u[b+5|0]=0;break P;case 5:case 6:case 10:case 23:case 28:f=x[b+5|0]&240;if(!f){break P}u[b+5|0]=f;break P;case 8:f=x[b+5|0];if(f>>>0<=128){f=f<<1;u[b+5|0]=(f|0)>=255?255:f;break P}if((f|0)!=164){break P}u[b+3|0]=20;u[b+5|0]=145;break P;case 13:f=x[b+5|0];u[b+5|0]=C(f>>>4|0,10)+(f&15);break P;case 18:w[114256]=0;X(342,b|0);f=w[114256];w[114256]=0;if((f|0)!=1){break P}break J;case 16:if(x[b+5|0]>31){break P}u[b+3|0]=16;break P;case 27:break R;default:break P}}j=x[b+5|0];f=j&240;S:{if((f|0)==16){f=2}else{if((f|0)!=32){break S}f=3}u[b+3|0]=f}u[b+5|0]=j&15|224}T:{if(!(h&64)){break T}f=w[d+72>>2];j=w[w[f>>2]+36>>2];w[114256]=0;f=S(j|0,f|0,w[d+80>>2],2)|0;j=w[114256];w[114256]=0;if((j|0)==1){break J}U:{if(f){w[d+44>>2]=q;w[d+40>>2]=d+16;f=w[d+72>>2];j=w[w[f>>2]+32>>2];w[114256]=0;f=S(j|0,f|0,w[d+80>>2],d+40|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break J}w[d+80>>2]=f+w[d+80>>2];f=x[d+16|0];break U}v[d+16>>1]=0;f=0}u[b+1|0]=f;f=x[d+17|0];u[b|0]=f;j=255;if((f|0)!=128){j=253;if(f>>>0<129){break T}}u[b|0]=j}if(!(h&32)){break N}u[b+2|0]=1;w[114256]=0;h=Q(241,d+72|0,d+40|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break J}h=h?x[d+40|0]:0;u[b+4|0]=h;if(r){break N}u[b+4|0]=((h&255)<<6>>>0)/127}if(e>>>0<p>>>0){continue}break}}b=w[d+76>>2];V:{if(!b){break V}e=w[b+4>>2];w[b+4>>2]=e-1;if(e){break V}ob[w[w[b>>2]+8>>2]](b);Ib(b)}e=k&65535;k=e>>>0>m>>>0;b=w[d+428>>2];W:{if(!b){break W}h=w[b+4>>2];w[b+4>>2]=h-1;if(h){break W}ob[w[w[b>>2]+8>>2]](b);Ib(b)}k=k?e:m;i=i+16|0;if((o|0)==(i|0)){break H}continue}break}break J}b=P()|0;break I}b=P()|0;break I}b=P()|0;break c}b=P()|0;Bb(d+72|0)}Bb(d+424|0);break c}b=P()|0;break b}if(!k){break G}b=0;while(1){X:{e=w[a+484344>>2];if(((w[a+484348>>2]-e|0)/52&65535)>>>0>b>>>0){e=e+C(b,52)|0;if(w[e>>2]!=w[e+4>>2]){break X}}w[114256]=0;S(216,l|0,b&65535,64)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break X}b=P()|0;break c}b=b+1|0;if((k|0)!=(b|0)){continue}break}}gc(d+488|0)}Y:{if((g|0)==1179012417){w[114256]=0;U(927,d+40|0,d+632|0,1414745673);b=w[114256];w[114256]=0;if((b|0)==1){break h}Z:{g=w[d+40>>2];i=w[d+44>>2];if((g|0)!=(i|0)){k=c&2;m=d+432|0;while(1){w[d+488>>2]=w[g>>2];b=w[g+4>>2];w[d+492>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[g+8>>2];c=w[g+12>>2];w[114256]=0;w[d+496>>2]=b;w[d+500>>2]=c;b=Q(928,d+488|0,d+72|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break Z}_:{if(!b){break _}b=x[d+73|0];if((b|0)==255){break _}w[114256]=0;b=S(243,a|0,b+1|0,0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}if(!b){break _}c=y[a+480190>>1];w[114256]=0;U(929,d+72|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){break i}b=0;if(!x[d+102|0]){break _}while(1){$:{if(y[a+480190>>1]>3998){break $}w[114256]=0;c=Q(930,d+488|0,d+424|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}if(!c){break $}c=y[a+480190>>1]+1|0;v[a+480190>>1]=c;if(w[d+424>>2]!=1347240275){break $}w[114256]=0;Y(209,d+16|0,2,m|0,28);e=w[114256];w[114256]=0;aa:{ba:{if((e|0)!=1){w[114256]=0;w[d+412>>2]=32;c=c&65535;w[d+408>>2]=((c<<5)+a|0)+946304;Q(200,d+408|0,d+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ba}if(u[d+27|0]<0){zb(w[d+16>>2])}w[114256]=0;e=C(c,104)+a|0;c=e+484380|0;U(931,d+424|0,d+72|0,c|0);l=w[114256];w[114256]=0;if((l|0)==1){break e}if(!k){break aa}w[114256]=0;u[d+19|0]=0;u[d+16|0]=y[d+462>>1]&4?16:8;u[d+17|0]=1;u[d+18|0]=0;S(214,d+16|0,c|0,d+488|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break $}b=P()|0;break d}b=P()|0;break d}b=P()|0;if(u[d+27|0]>=0){break d}zb(w[d+16>>2]);break d}e=y[e+484414>>1];l=w[d+488>>2];h=w[w[l>>2]+36>>2];c=w[c>>2];w[114256]=0;c=C(C(c,e&64?2:1),e&1?2:1);e=S(h|0,l|0,w[d+496>>2],c|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break e}ca:{if(e){e=c+w[d+496>>2]|0;break ca}c=w[d+488>>2];e=w[w[c>>2]+24>>2];w[114256]=0;e=V(e|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}}w[d+496>>2]=e}b=b+1|0;if(b>>>0<x[d+102|0]){continue}break}}b=w[d+492>>2];da:{if(!b){break da}c=w[b+4>>2];w[b+4>>2]=c-1;if(c){break da}ob[w[w[b>>2]+8>>2]](b);Ib(b)}g=g+16|0;if((i|0)!=(g|0)){continue}break}}gc(d+40|0);break Y}b=P()|0;break d}w[114256]=0;U(927,d+408|0,d+632|0,1179011410);b=w[114256];w[114256]=0;if((b|0)==1){break k}b=w[d+408>>2];i=w[d+412>>2];if((b|0)!=(i|0)){k=c&2;m=d+424|4;while(1){w[d+488>>2]=w[b>>2];c=w[b+4>>2];w[d+492>>2]=c;if(c){w[c+4>>2]=w[c+4>>2]+1}c=w[b+8>>2];e=w[b+12>>2];w[114256]=0;w[d+496>>2]=c;w[d+500>>2]=e;c=Q(232,d+488|0,d+72|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}ea:{if(!(c&w[d+72>>2]==538986817)){break ea}w[114256]=0;c=Q(932,d+488|0,d+400|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}if(!(c&w[d+400>>2]==1414745673)){break ea}w[114256]=0;c=Q(933,d+488|0,d+72|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break n}if(!c){break ea}c=x[d+77|0];if((c|0)==255){break ea}w[114256]=0;c=S(243,a|0,c+1|0,0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break o}if(!c){break ea}e=y[a+480190>>1];w[114256]=0;U(934,d+72|0,c|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break o}w[114256]=0;U(924,d+424|0,d+488|0,2);c=w[114256];w[114256]=0;if((c|0)==1){break g}w[114256]=0;U(927,d+56|0,d+424|0,1179011410);c=w[114256];w[114256]=0;if((c|0)==1){break p}Ac(d+424|0);e=w[d+56>>2];l=w[d+60>>2];fa:{if((e|0)==(l|0)){break fa}while(1){w[d+40>>2]=w[e>>2];c=w[e+4>>2];w[d+44>>2]=c;if(c){w[c+4>>2]=w[c+4>>2]+1}c=w[e+8>>2];g=w[e+12>>2];w[114256]=0;w[d+48>>2]=c;w[d+52>>2]=g;c=Q(232,d+40|0,d+424|0)|0;g=w[114256];w[114256]=0;ga:{ha:{ia:{ja:{if((g|0)!=1){g=22;if(!(c&w[d+424>>2]==538989377)){break ga}c=y[a+480190>>1];if(c>>>0>=3999){break ga}g=y[d+396>>1];v[d+396>>1]=g-1;if(!g){g=21;break ga}c=c+1|0;v[a+480190>>1]=c;w[114256]=0;h=Q(932,d+40|0,d+32|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break ja}g=21;if(!(h&w[d+32>>2]==1347240275)){break ga}w[114256]=0;U(188,d+16|0,d+40|0,w[d+36>>2]);g=w[114256];w[114256]=0;ka:{la:{ma:{if((g|0)!=1){w[114256]=0;h=Q(935,d+16|0,d+424|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break la}g=21;if(h){break ma}break ha}b=P()|0;break ia}w[114256]=0;Y(209,d|0,2,m|0,32);g=w[114256];w[114256]=0;na:{if((g|0)!=1){w[114256]=0;w[d+684>>2]=32;c=c&65535;w[d+680>>2]=((c<<5)+a|0)+946304;Q(200,d+680|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break na}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;h=(C(c,104)+a|0)+484380|0;U(936,d+424|0,d+72|0,h|0);c=w[114256];w[114256]=0;if((c|0)==1){break la}g=0;if(!k){break ha}c=w[d+424>>2]+4|0;oa:{if(c>>>0>z[d+24>>2]){f=w[d+16>>2];j=w[w[f>>2]+24>>2];w[114256]=0;f=V(j|0,f|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break la}if(c>>>0>f>>>0){break oa}}w[d+24>>2]=c}w[114256]=0;u[d+3|0]=0;u[d|0]=y[d+464>>1]&4?16:8;u[d+1|0]=1;u[d+2|0]=0;S(214,d|0,h|0,d+16|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break ha}b=P()|0;break ka}b=P()|0;break ka}b=P()|0;if(u[d+11|0]>=0){break ka}zb(w[d>>2]);break ka}b=P()|0}Bb(d+16|0);break ia}b=P()|0;break ia}b=P()|0}Bb(d+40|0);gc(d+56|0);break f}Bb(d+16|0)}c=w[d+44>>2];pa:{if(!c){break pa}h=w[c+4>>2];w[c+4>>2]=h-1;if(h){break pa}ob[w[w[c>>2]+8>>2]](c);Ib(c)}if(g?(g|0)!=22:0){break fa}e=e+16|0;if((l|0)!=(e|0)){continue}break}}gc(d+56|0)}c=w[d+492>>2];qa:{if(!c){break qa}e=w[c+4>>2];w[c+4>>2]=e-1;if(e){break qa}ob[w[w[c>>2]+8>>2]](c);Ib(c)}b=b+16|0;if((i|0)!=(b|0)){continue}break}}gc(d+408|0)}e=1}a=w[d+620>>2];ra:{if(!a){break ra}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break ra}ob[w[w[a>>2]+8>>2]](a);Ib(a)}Ac(d+632|0);a=w[d+652>>2];if(!a){break q}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break q}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+688|0;return e|0}b=P()|0;Ac(d+424|0);break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break b}b=P()|0;break d}b=P()|0;break d}b=P()|0;break b}b=P()|0}Bb(d+488|0);gc(d+408|0);break b}b=P()|0}Bb(d+488|0);gc(d+40|0);break b}gc(d+488|0)}Bb(d+616|0)}Ac(d+632|0);Bb(d+648|0);R(b|0);M()}function OE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-304|0;jb=e;w[b+8>>2]=0;a:{if(!gd(b,13548,7)){break a}w[114256]=0;w[e+296>>2]=0;w[e+288>>2]=0;w[e+292>>2]=0;f=S(222,b|0,e+288|0,-1)|0;g=w[114256];w[114256]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((g|0)!=1){if(!f){break b}w[114256]=0;f=Q(235,b|0,e+280|0)|0;g=w[114256];w[114256]=0;t:{if((g|0)==1){break t}if(!f|x[e+281|0]!=2|x[e+280|0]>2){break b}f=w[b+8>>2];g=w[b>>2];j=w[w[g>>2]+36>>2];w[114256]=0;f=S(j|0,g|0,f|0,(((x[e+283|0]|x[e+284|0]<<8)<<2)+(x[e+282|0]+(x[e+285|0]|x[e+286|0]<<8)<<1)|0)+47|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break t}if(!f){break b}if(!c){break c}w[114256]=0;T(236,a|0,4096);d=w[114256];w[114256]=0;if((d|0)==1){break t}w[114256]=0;Q(237,a+1304400|0,e+288|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break t}d=x[e+282|0];v[a+480188>>1]=32;v[a+480192>>1]=d;w[114256]=0;T(238,a|0,1);d=w[114256];w[114256]=0;if((d|0)==1){break t}w[114256]=0;f=Q(1,e+264|0,5392)|0;d=w[114256];w[114256]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)!=1){d=a+1304436|0;if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];w[114256]=0;f=Q(1,e+248|0,3356)|0;d=w[114256];w[114256]=0;if((d|0)==1){break D}d=a+1304448|0;if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];w[114256]=0;d=Q(1,e+216|0,10971)|0;f=w[114256];w[114256]=0;if((f|0)==1){break C}g=w[d>>2];w[e+236>>2]=w[d+4>>2];f=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[e+239|0]=f;u[e+240|0]=f>>>8;u[e+241|0]=f>>>16;u[e+242|0]=f>>>24;w[d>>2]=0;w[d+4>>2]=0;f=x[d+11|0];w[d+8>>2]=0;w[114256]=0;u[e+243|0]=f;w[e+232>>2]=g;u[e+8|0]=x[e+281|0];u[e+24|0]=x[e+280|0];u[e+96|0]=44;w[e+88>>2]=-1;w[e+92>>2]=0;w[e+80>>2]=1025;w[e+84>>2]=2;U(239,e+200|0,e+24|0,e+80|0);f=w[114256];w[114256]=0;if((f|0)==1){break B}w[114256]=0;Y(240,e+40|0,e+232|0,e+8|0,e+200|0);f=w[114256];w[114256]=0;if((f|0)==1){break A}f=a+1304460|0;if(u[a+1304471|0]<0){zb(w[f>>2])}g=w[e+44>>2];w[f>>2]=w[e+40>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+48>>2];u[e+51|0]=0;u[e+40|0]=0;if(u[e+211|0]<0){zb(w[e+200>>2])}if(u[e+243|0]<0){zb(w[e+232>>2])}if(u[d+11|0]<0){zb(w[d>>2])}w[a+1304496>>2]=4;if(x[e+280|0]<2){break v}w[114256]=0;d=Q(197,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break y}f=y[e+80>>1];w[a+480204>>2]=d?C(f>>>0<=8192?8192:f,1e4)>>>8|0:32e4;w[114256]=0;d=Q(241,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break w}f=x[e+80|0];w[a+480196>>2]=d?f>>>0<=1?1:f:1;w[114256]=0;Q(242,b|0,3)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}w[114256]=0;d=Q(197,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break x}f=d?y[e+80>>1]:0;break u}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break z}b=P()|0;if(u[e+211|0]>=0){break z}zb(w[e+200>>2])}if(u[e+243|0]<0){zb(w[e+232>>2])}if(u[d+11|0]>=0){break d}zb(w[d>>2]);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}w[114256]=0;d=Q(241,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}f=x[e+80|0];w[a+480204>>2]=d?C(f>>>0<=32?32:f,1e4):32e4;w[114256]=0;d=Q(241,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}f=x[e+80|0];w[a+480196>>2]=d?f>>>0<=1?1:f:1;w[114256]=0;d=Q(241,b|0,e+80|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}f=d?x[e+80|0]:0}w[a+480208>>2]=f>>>2&16|12;w[e+240>>2]=0;w[e+232>>2]=0;w[e+236>>2]=0;w[e+208>>2]=0;w[e+200>>2]=0;w[e+204>>2]=0;E:{F:{if(!y[a+480192>>1]){break F}k=e+80|12;j=1;while(1){w[114256]=0;f=S(243,a|0,j&65535,0)|0;d=w[114256];w[114256]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{if((d|0)==1){break P}if(!f){break F}w[114256]=0;d=S(223,b|0,f+492|0,-1)|0;g=w[114256];w[114256]=0;if((g|0)==1){break P}if(!d){break F}w[114256]=0;d=Q(241,b|0,e+80|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break O}g=x[e+80|0];Cb(e+80|0,0,120);h=(d?g:0)&255;if(!h){break G}Q:{if(x[e+280|0]){w[114256]=0;d=Q(244,b|0,e+80|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break N}if(!d){break G}if(x[e+280|0]){break Q}}d=w[b+8>>2];g=w[b>>2];i=w[w[g>>2]+28>>2];w[114256]=0;d=Z(i|0,g|0,k|0,d|0,96)|0;g=w[114256];w[114256]=0;if((g|0)==1){break N}w[b+8>>2]=d+w[b+8>>2];if(!d){break G}}g=f+236|0;d=0;while(1){v[g+(d<<1)>>1]=(x[(e+80|0)+d|0]+y[a+480190>>1]|0)+1;d=d+1|0;if((d|0)!=120){continue}break}w[114256]=0;g=f+48|0;U(245,e+8|0,g|0,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break K}w[114256]=0;i=f+68|0;U(245,e+24|0,i|0,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break K}w[114256]=0;l=f+88|0;U(245,e+72|0,l|0,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break K}w[114256]=0;d=Q(246,b|0,e- -64|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break J}if(!d){break M}d=x[e+65|0]|x[e+66|0]<<8;break L}b=P()|0;break h}b=P()|0;break h}b=P()|0;break h}u[e+68|0]=0;w[e+64>>2]=0;d=0}w[f>>2]=d&4095;m=x[e+65|0]|x[e+66|0]<<8;d=e- -64|0;fl(d,g,0);fl(d,i,1);fl(d,l,2);d=w[f+48>>2];g=w[f+52>>2];if((d|0)!=(g|0)){break I}break H}b=P()|0;break h}b=P()|0;break h}while(1){i=((x[d+2|0]<<6)- -64>>>0)/127&255;u[d+2|0]=i>>>0>=64?64:i;d=d+4|0;if((g|0)!=(d|0)){continue}break}}d=w[f+68>>2];g=w[f+72>>2];if((d|0)!=(g|0)){while(1){u[d+2|0]=((x[d+2|0]<<6)+128>>>0)/255;d=d+4|0;if((g|0)!=(d|0)){continue}break}}d=w[f+88>>2];i=w[f+92>>2];if((d|0)!=(i|0)){l=1<<(m>>>12&3);while(1){f=u[d+2|0];f=BV(f^-128,f>>31^-1,l,0);g=nb;R:{if((g|0)>=-1&f>>>0>=4294967292|(g|0)>=0){f=f+4|0;g=f>>>0<4?g+1|0:g;f=((g&7)<<29|f>>>3)&536870911;break R}g=0-((f>>>0>3)+g|0)|0;f=3-f|0;f=0-(((g&7)<<29|f>>>3)&536870911)|0}u[d+2|0]=f^128;d=d+4|0;if((i|0)!=(d|0)){continue}break}}v[e+62>>1]=y[a+480190>>1]+1;d=0;f=0;S:{T:{U:{V:{while(1){W:{g=y[e+62>>1]+d|0;if(g>>>0>=4e3){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,20)|0;f=w[114256];w[114256]=0;X:{if((f|0)==1){break X}Y:{if(d){d=w[b+8>>2]+20|0;break Y}d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break X}}w[b+8>>2]=d;break W}b=P()|0;break h}w[114256]=0;S(223,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=w[114256];w[114256]=0;if((g|0)==1){break i}w[114256]=0;g=Q(247,b|0,e+40|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break V}if(!g){w[e+56>>2]=0;w[e+48>>2]=0;w[e+52>>2]=0;w[e+40>>2]=0;w[e+44>>2]=0}w[114256]=0;T(248,e+40|0,(C(y[e+62>>1]+d|0,104)+a|0)+484380|0);d=w[114256];w[114256]=0;if((d|0)==1){break V}g=x[e+64|0]|f<<8&32512|((x[e+59|0]&3)!=0)<<15;v[e+38>>1]=g;d=w[e+204>>2];Z:{if((d|0)!=w[e+208>>2]){v[d>>1]=g;w[e+204>>2]=d+2;break Z}w[114256]=0;T(249,e+200|0,e+38|0);d=w[114256];w[114256]=0;if((d|0)==1){break U}}f=f+1|0;d=f&65535;if(h>>>0>d>>>0){continue}}break}d=w[e+236>>2];if((d|0)==w[e+240>>2]){break T}v[d>>1]=y[e+62>>1];w[e+236>>2]=d+2;break S}b=P()|0;break h}b=P()|0;break h}w[114256]=0;T(249,e+232|0,e+62|0);d=w[114256];w[114256]=0;if((d|0)==1){break E}}d=h+y[a+480190>>1]|0;v[a+480190>>1]=d>>>0>=3999?3999:d}j=j+1|0;if(y[a+480192>>1]>=(j&65535)>>>0){continue}break}}w[114256]=0;w[e+88>>2]=0;w[e+80>>2]=0;w[e+84>>2]=0;d=S(222,b|0,e+80|0,-1)|0;f=w[114256];w[114256]=0;_:{$:{aa:{if((f|0)!=1){if(d){w[114256]=0;U(6,e+40|0,6,e+80|0);d=w[114256];w[114256]=0;if((d|0)==1){break _}d=a+1304412|0;if(u[a+1304423|0]<0){zb(w[d>>2])}f=w[e+44>>2];w[d>>2]=w[e+40>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+48>>2]}if(u[e+91|0]<0){zb(w[e+80>>2])}d=0;while(1){w[114256]=0;f=(d<<5)+a|0;X(224,f+480280|0);g=w[114256];w[114256]=0;if((g|0)==1){break aa}w[114256]=0;S(225,b|0,f+480289|0,-1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break aa}d=d+1|0;if((d|0)!=32){continue}break}w[114256]=0;d=Q(250,b|0,e+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(!d){break k}d=w[e+24>>2];if(d>>>0<12){break o}f=w[b+8>>2];g=w[b>>2];j=w[w[g>>2]+36>>2];w[114256]=0;d=S(j|0,g|0,f|0,d-11|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(d){break $}break o}break p}b=P()|0;break h}w[114256]=0;d=w[e+24>>2];w[e+88>>2]=0;w[e+80>>2]=0;w[e+84>>2]=0;g=d-11|0;S(228,b|0,e+80|0,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}w[114256]=0;w[e+48>>2]=0;w[e+40>>2]=0;w[e+44>>2]=0;d=w[e+28>>2];f=C(g>>>0>=50529027?50529027:g,85);T(72,e+40|0,(d>>>0<f>>>0?d:f)|0);d=w[114256];w[114256]=0;if((d|0)==1){break s}if(g){f=0;while(1){ba:{j=w[e+80>>2];h=j+f|0;k=x[h|0];d=f+1|0;if(!((k|0)!=255|g-d>>>0<2)){d=u[d+j|0];j=x[h+2|0];w[114256]=0;h=e+40|0;i=h;h=x[e+51|0];k=h<<24>>24<0;Z(251,i|0,(k?w[e+40>>2]:i)+(k?w[e+44>>2]:h)|0,j|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){d=f+3|0;break ba}break s}w[114256]=0;T(71,e+40|0,k<<24>>24);f=w[114256];w[114256]=0;if((f|0)!=1){break ba}break s}f=d;if(d>>>0<g>>>0){continue}break}}w[114256]=0;Y(229,e+8|0,4,6,e+40|0);d=w[114256];w[114256]=0;ca:{if((d|0)!=1){if(u[e+51|0]<0){zb(w[e+40>>2])}w[e+48>>2]=w[e+16>>2];w[114256]=0;d=w[e+12>>2];f=w[e+8>>2];w[e+40>>2]=f;w[e+44>>2]=d;h=f;d=u[e+51|0];f=(d|0)<0;da(230,a+1304424|0,(f?h:e+40|0)|0,(f?w[e+44>>2]:d&255)|0,74,0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ca}if(u[e+51|0]<0){zb(w[e+40>>2])}d=w[e+80>>2];if(!d){break o}w[e+84>>2]=d;zb(d);break o}break s}break s}break p}b=P()|0;break h}b=P()|0;break d}b=P()|0;break d}b=P()|0;if(u[e+51|0]>=0){break q}zb(w[e+40>>2]);break q}b=P()|0}a=w[e+80>>2];if(!a){break h}w[e+84>>2]=a;zb(a);break h}b=P()|0;if(u[e+91|0]>=0){break h}zb(w[e+80>>2]);break h}d=x[a+484376|0];f=w[a+484360>>2];w[114256]=0;da(231,f+(d<<5)|0,b|0,x[e+285|0]|x[e+286|0]<<8,65535,65535)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}j=c&1;if(j){w[114256]=0;T(215,a+484344|0,x[e+283|0]|x[e+284|0]<<8);d=w[114256];w[114256]=0;if((d|0)==1){break n}}if(!(x[e+283|0]|x[e+284|0]<<8)){break l}g=a+484344|0;f=0;while(1){d=w[b+8>>2];h=w[b>>2];k=w[w[h>>2]+36>>2];w[114256]=0;d=S(k|0,h|0,d|0,4)|0;h=w[114256];w[114256]=0;da:{if((h|0)!=1){if(d){break da}break l}b=P()|0;break h}w[114256]=0;d=Q(232,b|0,e+80|0)|0;h=w[114256];w[114256]=0;ea:{fa:{ga:{ha:{if((h|0)!=1){w[114256]=0;U(188,e+80|0,b|0,(d?w[e+80>>2]:0)|0);d=w[114256];w[114256]=0;if((d|0)==1){break ha}if(!j){break fa}w[114256]=0;h=Q(241,e+80|0,e+40|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break ea}k=x[e+40|0];d=w[e+80>>2];i=w[w[d>>2]+36>>2];w[114256]=0;d=S(i|0,d|0,w[e+88>>2],1)|0;i=w[114256];w[114256]=0;if((i|0)==1){break ea}ia:{if(d){d=w[e+88>>2]+1|0;break ia}d=w[e+80>>2];i=w[w[d>>2]+24>>2];w[114256]=0;d=V(i|0,d|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break ea}}w[114256]=0;w[e+88>>2]=d;d=S(216,g|0,f&65535,(h?k+1|0:1)|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break ea}if(!d){break fa}w[114256]=0;d=S(226,e+80|0,e+40|0,-1)|0;h=w[114256];w[114256]=0;if((h|0)==1){break m}if(!d){break ga}d=w[g>>2];w[114256]=0;S(227,d+C(f,52)|0,e+40|0,11)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break ga}break m}b=P()|0;break h}b=P()|0;break h}d=w[g>>2];w[114256]=0;U(233,d+C(f,52)|0,1,e+80|0);d=w[114256];w[114256]=0;if((d|0)==1){break m}}d=w[e+84>>2];ja:{if(!d){break ja}h=w[d+4>>2];w[d+4>>2]=h-1;if(h){break ja}ob[w[w[d>>2]+8>>2]](d);Ib(d)}f=f+1|0;if(f>>>0<(x[e+283|0]|x[e+284|0]<<8)>>>0){continue}break l}break}break m}b=P()|0;break h}b=P()|0;Bb(e+80|0);break h}if(!(c&2)){break k}f=y[a+480190>>1];if(!f){break k}d=0;ka:{while(1){la:{c=y[w[e+200>>2]+(d<<1)>>1];ma:{if(c&255){d=d+1|0;break ma}d=d+1|0;f=C(d,104)+a|0;g=y[f+484414>>1];w[114256]=0;u[e+83|0]=c<<16>>16<0?6:0;u[e+81|0]=1;u[e+82|0]=0;u[e+80|0]=g&1?16:8;S(214,e+80|0,f+484380|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break la}f=y[a+480190>>1]}if((f&65535)>>>0>d>>>0){continue}break ka}break}b=P()|0;break h}if(!(f&65535)){break k}b=0;while(1){c=y[w[e+200>>2]+(b<<1)>>1];d=c&255;na:{if(!d){break na}d=d-1&65535;g=w[e+232>>2];if(d>>>0>=w[e+236>>2]-g>>1>>>0){break na}c=y[g+(d<<1)>>1]+(c>>>8&127)&65535;if(c>>>0>(f&65535)>>>0){break na}c=C(c,104);d=c+a|0;f=d+484400|0;if(!w[f>>2]){break na}d=d+484380|0;g=w[d>>2];if(!g){break na}h=c;c=a+484380|0;j=h+c|0;h=y[j+34>>1];k=C(b+1|0,104);c=k+c|0;w[c>>2]=g;v[c+34>>1]=y[c+34>>1]&65534|h&1;w[114256]=0;c=V(252,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}if(!c){break na}c=y[j+34>>1];Fb(w[(a+k|0)+484400>>2],w[f>>2],C(C(w[d>>2],c&64?2:1),c&1?2:1))}b=b+1|0;f=y[a+480190>>1];if(b>>>0<f>>>0){continue}break}}a=w[e+200>>2];if(a){w[e+204>>2]=a;zb(a)}a=w[e+232>>2];if(!a){break c}w[e+236>>2]=a;zb(a);break c}b=P()|0;break h}b=P()|0}a=w[e+200>>2];if(a){w[e+204>>2]=a;zb(a)}a=w[e+232>>2];if(!a){break d}w[e+236>>2]=a;zb(a);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0}if(u[e+299|0]<0){zb(w[e+288>>2])}R(b|0);M()}d=1}if(u[e+299|0]>=0){break a}zb(w[e+288>>2])}jb=e+304|0;return d|0}function mG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-16|0;jb=j;m=gd(b,9569,4);a:{if(!m){break a}e=w[b>>2];if(!(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],6)|0)){break a}while(1){e=Nc(b,j);g=e?w[j>>2]:0;if((g|0)==1297110099|!(g&1616928864)|(g|0)==70791730|g&-2139062144){c=b;a=w[b+8>>2];b=a-4|0;w[c+8>>2]=a>>>0>=b>>>0?b:0;break a}c=cd(b,j+8|0);e=y[a+480192>>1];if(e){n=c?y[j+8>>1]:0;k=1;while(1){f=w[(((k&65535)<<2)+a|0)+900380>>2];if(f){c=n&65535;b:{c:{if((g|0)==1264266798){break c}e=0;h=jb-48|0;jb=h;d:{e:{f:{g:{if(!f){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((g|0)<=1347628589){if((g|0)<=1297100333){if((g|0)<=1179931727){if((g|0)<=1145263149){if((g|0)==1095062094){break r}if((g|0)==1095126087){break o}if((g|0)!=1129524782|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+23|0]=p;e=1;break g}if((g|0)<=1179463213){if((g|0)==1145263150){break L}if((g|0)!=1145979182|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+18|0]=p;e=1;break g}if((g|0)==1179463214){break u}if((g|0)!=1179594286|c>>>0>4){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Yi(b,c),w[o>>2]=p;e=1;break g}if((g|0)<=1229345325){if((g|0)==1179931728){break h}if((g|0)==1196830254){break V}if((g|0)!=1229341486|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+21|0]=p;e=1;break g}if((g|0)<=1296182829){if((g|0)==1229345326){break I}if((g|0)!=1264266798|c>>>0>256){break g}d=f+236|0;oc(h+24|0,b,c);while(1){w[114256]=0;i=Q(197,h+24|0,h+8|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break y}v[d+(e<<1)>>1]=i?y[h+8>>1]:0;e=e+1|0;if((e|0)!=128){continue}break}Bb(h+24|0);e=1;break g}if((g|0)==1296182830){break H}if((g|0)!=1296248366|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+31|0]=p;e=1;break g}if((g|0)<=1346720333){if((g|0)<=1313692461){if((g|0)==1297100334){break G}if((g|0)==1297110852){break m}if((g|0)!=1298747438|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+34|0]=p;e=1;break g}if((g|0)<=1345203757){if((g|0)==1313692462){break z}if((g|0)!=1313751342|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+16|0]=p;e=1;break g}if((g|0)==1345203758){break U}if((g|0)!=1346711086){break g}e=Hh(b,c);Hd(f+68|0,e>>>0>=240?240:e);e=1;break g}if((g|0)<=1347179309){if((g|0)<=1346784326){if((g|0)==1346720334){break s}if((g|0)!=1346722606){break g}oc(h+24|0,b,c);if(w[f+72>>2]!=w[f+68>>2]){while(1){w[114256]=0;d=Q(201,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break B}i=w[f+68>>2];u[(i+(e<<2)|0)+2|0]=d?x[h+8|0]:0;e=e+1|0;if(e>>>0<w[f+72>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}if((g|0)==1346784327){break p}if((g|0)!=1347175726|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+82|0]=p;e=1;break g}if((g|0)<=1347441453){if((g|0)==1347179310){break R}if((g|0)!=1347437358|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+27|0]=p;e=1;break g}if((g|0)==1347441454){break F}if((g|0)!=1347443502){break g}oc(h+24|0,b,c);if(w[f+72>>2]!=w[f+68>>2]){while(1){w[114256]=0;d=Q(197,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break E}i=w[f+68>>2];v[i+(e<<2)>>1]=d?y[h+8>>1]:0;e=e+1|0;if(e>>>0<w[f+72>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}if((g|0)<=1447374381){if((g|0)<=1349078084){if((g|0)<=1347831111){if((g|0)<=1347634477){if((g|0)==1347628590){break K}if((g|0)!=1347633710|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+83|0]=p;e=1;break g}if((g|0)==1347634478){break Q}if((g|0)!=1347703884){break g}o=f,p=C(Gl(b,c),1e4)+(z[f+40>>2]%1e4|0)|0,w[o+40>>2]=p;e=1;break g}if((g|0)<=1349076269){if((g|0)==1347831112){break t}if((g|0)!=1347833672|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+36|0]=p;e=1;break g}if((g|0)==1349076270){break j}if((g|0)!=1349076315){break g}oc(h+24|0,b,c);if(w[f+92>>2]!=w[f+88>>2]){while(1){w[114256]=0;d=Q(201,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break A}i=w[f+88>>2];u[(i+(e<<2)|0)+2|0]=d?x[h+8|0]:0;e=e+1|0;if(e>>>0<w[f+92>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}if((g|0)<=1349079873){if((g|0)==1349078085){break O}if((g|0)==1349078099){break P}if((g|0)!=1349079131){break g}oc(h+24|0,b,c);if(w[f+92>>2]!=w[f+88>>2]){while(1){w[114256]=0;d=Q(197,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break D}i=w[f+88>>2];v[i+(e<<2)>>1]=d?y[h+8>>1]:0;e=e+1|0;if(e>>>0<w[f+92>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}W:{switch(g-1349079874|0){case 1:case 2:break g;case 3:break M;case 0:break N;default:break W}}if((g|0)==1378758190){break l}if((g|0)!=1381183022|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+24|0]=p;e=1;break g}if((g|0)<=1448226349){if((g|0)<=1447447622){if((g|0)==1447374382){break k}if((g|0)==1447383630){break q}if((g|0)!=1447385902){break g}oc(h+24|0,b,c);if(w[f+52>>2]!=w[f+48>>2]){while(1){w[114256]=0;d=Q(201,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break C}i=w[f+48>>2];u[(i+(e<<2)|0)+2|0]=d?x[h+8|0]:0;e=e+1|0;if(e>>>0<w[f+52>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}if((g|0)<=1447842605){if((g|0)==1447447623){break n}if((g|0)!=1447839022|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+62|0]=p;e=1;break g}if((g|0)==1447842606){break T}if((g|0)!=1448106798){break g}oc(h+24|0,b,c);if(w[f+52>>2]!=w[f+48>>2]){while(1){w[114256]=0;d=Q(197,h+24|0,h+8|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break i}i=w[f+48>>2];v[i+(e<<2)>>1]=d?y[h+8>>1]:0;e=e+1|0;if(e>>>0<w[f+52>>2]-i>>2>>>0){continue}break}}Bb(h+24|0);e=1;break g}if((g|0)<=1448297773){if((g|0)==1448226350){break v}if((g|0)==1448291886){break J}if((g|0)!=1448297006|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+63|0]=p;e=1;break g}if((g|0)<=1718508333){if((g|0)==1448297774){break S}if((g|0)!=1682320942|c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+15|0]=p;e=1;break g}if((g|0)==1718508334){break w}if((g|0)!=1851469358|c>>>0>32){break g}oc(h+24|0,b,c);w[h+16>>2]=0;w[h+8>>2]=0;w[h+12>>2]=0;if(c){while(1){w[114256]=0;d=Q(202,h+24|0,h+40|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break x}w[114256]=0;T(71,h+8|0,(d?x[h+40|0]:0)<<24>>24);d=w[114256];w[114256]=0;if((d|0)==1){break x}e=e+1|0;if((c|0)!=(e|0)){continue}break}}w[114256]=0;w[h+44>>2]=32;w[h+40>>2]=f+492;Q(200,h+40|0,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break x}if(u[h+19|0]<0){zb(w[h+8>>2])}Bb(h+24|0);e=1;break g}if(c>>>0>4){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Yi(b,c),w[o+4>>2]=p;e=1;break g}if(c>>>0>4){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Yi(b,c),w[o+8>>2]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+61|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f- -64|0,p=ic(b,c),u[o|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+81|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+84|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+101|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+102|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+103|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+104|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+17|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+19|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+20|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+22|0]=p;e=1;break g}if(c>>>0>2){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Dl(b,c),v[o+28>>1]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+30|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Yq(b,c),u[o+26|0]=p;e=1;break g}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}if(c>>>0>128){break g}d=f+108|0;oc(h+24|0,b,c);X:{while(1){w[114256]=0;i=Q(201,h+24|0,h+8|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break X}u[e+d|0]=i?x[h+8|0]:0;e=e+1|0;if((e|0)!=128){continue}break}Bb(h+24|0);e=1;break g}e=P()|0;break e}e=P()|0;break e}e=P()|0;if(u[h+19|0]<0){zb(w[h+8>>2])}break e}if(c>>>0>32){break g}oc(h+24|0,b,c);w[h+16>>2]=0;w[h+8>>2]=0;w[h+12>>2]=0;if(c){while(1){w[114256]=0;d=Q(202,h+24|0,h+40|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break f}w[114256]=0;T(71,h+8|0,(d?x[h+40|0]:0)<<24>>24);d=w[114256];w[114256]=0;if((d|0)==1){break f}e=e+1|0;if((c|0)!=(e|0)){continue}break}}w[114256]=0;w[h+44>>2]=32;w[h+40>>2]=f+524;Q(200,h+40|0,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[h+19|0]<0){zb(w[h+8>>2])}Bb(h+24|0);e=1;break g}break f}if(c>>>0>2){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Dl(b,c),v[o+12>>1]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+25|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+35|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+105|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+85|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+65|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+100|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+80|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=ic(b,c),u[o+60|0]=p;e=1;break g}if(c>>>0>1){break g}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){break g}o=f,p=Yq(b,c),u[o+33|0]=p;e=1;break g}e=1;d=Hh(b,c);if(d>>>0>4){break g}u[f+14|0]=d;break g}e=Hh(b,c);Hd(f+48|0,e>>>0>=240?240:e);e=1;break g}e=Hh(b,c);Hd(f+88|0,e>>>0>=240?240:e);e=1;break g}e=P()|0;break e}d=(Gl(b,c)>>>0)%1e4|0;e=w[f+40>>2];w[f+40>>2]=d+e-(e>>>0)%1e4;e=1}jb=h+48|0;break d}e=P()|0;if(u[h+19|0]<0){zb(w[h+8>>2])}}Bb(h+24|0);R(e|0);M()}if(!e){break c}if((g|0)==1682320942){e=x[f+15|0];u[f+15|0]=0;u[f+100|0]=x[f+100|0]&224|(e>>>5&4|e>>>6&1);u[f+60|0]=e>>>1&2|(e<<1&4|(x[f+60|0]&240|e&1));u[f+80|0]=x[f+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}break b}e=w[b>>2];Y:{if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],c)|0){c=c+w[b+8>>2]|0;break Y}e=w[b>>2];c=ob[w[w[e>>2]+24>>2]](e)|0}w[b+8>>2]=c}e=y[a+480192>>1]}k=k+1|0;if((k&65535)>>>0<=e>>>0){continue}break}}e=w[b>>2];if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],6)|0){continue}break}}jb=j+16|0;return m|0}function Wu(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-288|0;jb=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(g){if(f>>>0>=4294967280){break E}G:{H:{I:{if(f>>>0<=10){u[h+259|0]=f;if(f){break I}u[h+248|0]=0;u[h+243|0]=0;j=h+232|0;break G}j=(f|15)+1|0;l=Kb(j);i=j|-2147483648;w[h+256>>2]=i;w[h+248>>2]=l;w[h+252>>2]=f;n=Cb(l,32,f)+f|0,o=0,u[n|0]=o;w[114256]=0;j=V(22,j|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break D}w[h+240>>2]=i;w[h+232>>2]=j;w[h+236>>2]=f;break H}j=h+248|0;Cb(j,32,f);u[f+j|0]=0;u[h+243|0]=f;j=h+232|0}Cb(j,32,f)}u[f+j|0]=0;break F}w[h+256>>2]=0;w[h+248>>2]=0;w[h+252>>2]=0;w[h+240>>2]=0;w[h+232>>2]=0;w[h+236>>2]=0}J:{K:{if(c>>>0>65535){break K}l=w[b+24>>2];j=w[l+484344>>2];if(((w[l+484348>>2]-j|0)/52&65535)>>>0<=(c&65535)>>>0){break K}i=j+C(c,52)|0;if(w[i>>2]!=w[i+4>>2]){break J}}w[114256]=0;S(1473,a|0,h+248|0,h+232|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break h}g=P()|0;break b}L:{M:{if((d|0)<0){break M}c=j+C(c,52)|0;if((e|0)<0|w[c+12>>2]<=(d|0)){break M}if(y[l+480188>>1]>e>>>0){break L}}w[114256]=0;S(1473,a|0,h+248|0,h+232|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break h}g=P()|0;break b}w[114256]=0;j=V(218,c|0)|0;l=w[114256];w[114256]=0;if((l|0)==1){break g}j=C(d,j)+(e&65535)|0;e=C(j,6);d=w[c>>2];N:{if(u[h+259|0]<0){u[w[h+248>>2]]=0;w[h+252>>2]=0;break N}u[h+259|0]=0;u[h+248|0]=0}l=d+e|0;O:{if(u[h+243|0]<0){u[w[h+232>>2]]=0;w[h+236>>2]=0;break O}u[h+243|0]=0;u[h+232|0]=0}P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{c=x[l|0];e=c>>>0>250|(c-1&255)>>>0<120;ha:{if(e){i=x[(d+C(j,6)|0)+1|0];k=w[b+24>>2];w[114256]=0;Y(1474,h+216|0,k|0,c|0,i|0);c=w[114256];w[114256]=0;if((c|0)==1){break ga}w[114256]=0;U(9,h+264|0,0,h+216|0);c=w[114256];w[114256]=0;if((c|0)!=1){break ha}g=P()|0;break da}w[114256]=0;Q(5,h+264|0,12594)|0;c=w[114256];w[114256]=0;if((c|0)==1){break fa}}w[114256]=0;c=x[h+275|0];i=c<<24>>24<0;S(92,h+248|0,(i?w[h+264>>2]:h+264|0)|0,(i?w[h+268>>2]:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ea}if(u[h+275|0]<0){zb(w[h+264>>2])}if(!(!e|u[h+227|0]>=0)){zb(w[h+216>>2])}c=x[l|0];w[114256]=0;c=Q(5,h+200|0,((c-1&255)>>>0<120?5913:c>>>0>250?6218:12594)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ca}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+232|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break ba}if(u[c+11|0]<0){zb(w[c>>2])}if(f-6>>>0>4294967290){break j}w[114256]=0;c=Q(5,h+184|0,13546)|0;e=w[114256];w[114256]=0;if((e|0)==1){break aa}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+248|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break $}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,h+168|0,13546)|0;e=w[114256];w[114256]=0;if((e|0)==1){break _}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+232|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Z}if(u[c+11|0]<0){zb(w[c>>2])}e=d+C(j,6)|0;c=e+1|0;ia:{if(x[e+1|0]){w[114256]=0;u[h+280|0]=44;w[h+272>>2]=-1;w[h+276>>2]=0;w[h+264>>2]=1058;w[h+268>>2]=2;U(465,h+152|0,c|0,h+264|0);e=w[114256];w[114256]=0;if((e|0)!=1){break ia}break c}w[114256]=0;Q(5,h+152|0,12599)|0;e=w[114256];w[114256]=0;if((e|0)==1){break c}}w[114256]=0;e=x[h+163|0];i=e<<24>>24<0;S(92,h+248|0,(i?w[h+152>>2]:h+152|0)|0,(i?w[h+156>>2]:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break Y}if(u[h+163|0]<0){zb(w[h+152>>2])}c=x[c|0];w[114256]=0;c=Q(5,h+152|0,(c?6700:12599)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break X}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+232|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break W}if(u[c+11|0]<0){zb(w[c>>2])}if(f-9>>>0>4294967287){break j}e=x[l|0]+5|0;if((e&255)>>>0>1){break V}w[114256]=0;c=Q(5,h+120|0,13546)|0;i=w[114256];w[114256]=0;if((i|0)==1){break P}i=x[(d+C(j,6)|0)+4|0];w[114256]=0;w[h+88>>2]=i;u[h+280|0]=44;w[h+272>>2]=-1;w[h+276>>2]=0;w[h+264>>2]=1058;w[h+268>>2]=2;U(464,h+104|0,h+88|0,h+264|0);i=w[114256];w[114256]=0;if((i|0)==1){break U}w[114256]=0;m=c;c=u[h+115|0];i=(c|0)<0;c=S(92,m|0,(i?w[h+104>>2]:h+104|0)|0,(i?w[h+108>>2]:c&255)|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break T}break C}g=P()|0;break b}g=P()|0;break b}g=P()|0;if(u[h+275|0]<0){zb(w[h+264>>2])}if(!e){break b}}if(u[h+227|0]>=0){break b}zb(w[h+216>>2]);break b}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}g=P()|0;if(u[h+163|0]>=0){break b}zb(w[h+152>>2]);break b}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}c=x[(d+C(j,6)|0)+2|0];if(!c){break S}i=w[w[b+24>>2]+8>>2];w[114256]=0;c=Q(1475,i|0,c|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break Q}w[114256]=0;u[h+121|0]=0;u[h+120|0]=c;u[h+131|0]=1;u[h+280|0]=44;w[h+272>>2]=-1;w[h+276>>2]=0;w[h+264>>2]=1058;w[h+268>>2]=2;U(465,h+104|0,(d+C(j,6)|0)+4|0,h+264|0);c=w[114256];w[114256]=0;if((c|0)==1){break R}w[114256]=0;c=u[h+115|0];i=(c|0)<0;c=S(92,h+120|0,(i?w[h+104>>2]:h+104|0)|0,(i?w[h+108>>2]:c&255)|0)|0;i=w[114256];w[114256]=0;if((i|0)!=1){break C}g=P()|0;break A}g=P()|0;break d}g=P()|0;break e}w[114256]=0;Q(5,h+136|0,12598)|0;i=w[114256];w[114256]=0;c=0;if((i|0)!=1){break B}g=P()|0;break b}g=P()|0;if(u[h+131|0]>=0){break b}zb(w[h+120>>2]);break b}g=P()|0;break b}g=P()|0;break b}zc(h+248|0);M()}g=P()|0;break a}w[h+144>>2]=w[c+8>>2];i=w[c+4>>2];w[h+136>>2]=w[c>>2];w[h+140>>2]=i;w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;c=(e&255)>>>0>1}w[114256]=0;i=x[h+147|0];k=i<<24>>24<0;S(92,h+248|0,(k?w[h+136>>2]:h+136|0)|0,(k?w[h+140>>2]:i)|0)|0;i=w[114256];w[114256]=0;if((i|0)!=1){if(u[h+147|0]<0){zb(w[h+136>>2])}ja:{if(!c){break ja}if(u[h+115|0]<0){zb(w[h+104>>2])}if(u[h+131|0]>=0){break ja}zb(w[h+120>>2])}ka:{if((e&255)>>>0>1){break ka}if(u[h+115|0]<0){zb(w[h+104>>2])}if(u[h+131|0]>=0){break ka}zb(w[h+120>>2])}c=(x[l|0]+5&255)>>>0<2?1974:x[(d+C(j,6)|0)+2|0]?1970:12598;w[114256]=0;c=Q(5,h+136|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break z}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+232|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break y}if(u[c+11|0]<0){zb(w[c>>2])}if(f-13>>>0>4294967283){break j}w[114256]=0;c=Q(5,h+88|0,13546)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+248|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break u}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,h+72|0,13546)|0;e=w[114256];w[114256]=0;if((e|0)==1){break t}i=w[c>>2];k=w[c+4>>2];e=x[c+11|0];w[114256]=0;m=i;i=e<<24>>24<0;S(92,h+232|0,(i?m:c)|0,(i?k:e)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break s}if(u[c+11|0]<0){zb(w[c>>2])}e=d+C(j,6)|0;c=x[e+3|0];if((x[l|0]+5&255)>>>0>1){break x}b=x[e+5|0];e=0;w[114256]=0;w[h+8>>2]=b|c<<8&3840;u[h+280|0]=44;w[h+272>>2]=-1;w[h+276>>2]=0;w[h+264>>2]=1058;w[h+268>>2]=3;U(464,h+56|0,h+8|0,h+264|0);b=w[114256];w[114256]=0;if((b|0)!=1){break w}g=P()|0;break b}g=P()|0;if(u[h+147|0]<0){zb(w[h+136>>2]);if(c){break A}break f}if(!c){break f}}if(u[h+115|0]<0){zb(w[h+104>>2])}if(u[h+131|0]<0){zb(w[h+120>>2]);if((e&255)>>>0<2){break e}break b}if((e&255)>>>0>=2){break b}break e}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}if(c){b=w[w[b+24>>2]+8>>2];w[114256]=0;b=Q(1476,b|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break r}w[114256]=0;u[h+41|0]=0;u[h+40|0]=b;u[h+51|0]=1;u[h+280|0]=44;w[h+272>>2]=-1;w[h+276>>2]=0;w[h+264>>2]=1058;w[h+268>>2]=2;U(465,h+24|0,(d+C(j,6)|0)+5|0,h+264|0);b=w[114256];w[114256]=0;if((b|0)==1){break q}w[114256]=0;b=u[h+35|0];c=(b|0)<0;b=S(92,h+40|0,(c?w[h+24>>2]:h+24|0)|0,(c?w[h+28>>2]:b&255)|0)|0;c=w[114256];w[114256]=0;e=1;if((c|0)==1){g=P()|0;break n}w[h- -64>>2]=w[b+8>>2];c=w[b+4>>2];w[h+56>>2]=w[b>>2];w[h+60>>2]=c;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;break w}e=0;w[114256]=0;Q(5,h+56|0,12594)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}}w[114256]=0;b=x[h+67|0];c=b<<24>>24<0;S(92,h+248|0,(c?w[h+56>>2]:h+56|0)|0,(c?w[h+60>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break o}if(u[h+67|0]<0){zb(w[h+56>>2])}la:{if(!e){break la}if(u[h+35|0]<0){zb(w[h+24>>2])}if(u[h+51|0]>=0){break la}zb(w[h+40>>2])}b=(x[l|0]+5&255)>>>0<2?6986:x[(d+C(j,6)|0)+3|0]?6986:12594;w[114256]=0;b=Q(5,h+264|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break l}d=w[b>>2];e=w[b+4>>2];c=x[b+11|0];w[114256]=0;i=d;d=c<<24>>24<0;S(92,h+232|0,(d?i:b)|0,(d?e:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break k}if(u[b+11|0]<0){zb(w[b>>2])}if(f){break j}break i}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}g=P()|0;break b}g=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}g=P()|0;break b}g=P()|0;break m}g=P()|0;break b}g=P()|0;if(u[h+67|0]<0){zb(w[h+56>>2])}if(!e){break b}}if(u[h+35|0]>=0){break m}zb(w[h+24>>2])}if(u[h+51|0]>=0){break b}zb(w[h+40>>2]);break b}g=P()|0;break b}g=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}ma:{na:{oa:{pa:{qa:{ra:{b=x[h+259|0];b=b<<24>>24<0?w[h+252>>2]:b;sa:{if(b>>>0>f>>>0){w[114256]=0;b=h+248|0;b=da(114,h+56|0,b|0,0,f|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[h+259|0]<0){zb(w[h+248>>2])}w[h+256>>2]=w[b+8>>2];c=w[b+4>>2];w[h+248>>2]=w[b>>2];w[h+252>>2]=c;b=u[h+243|0];c=(b|0)<0?w[h+236>>2]:b&255;if(f>>>0<c>>>0){break oa}if(!g){break i}break sa}g=P()|0;break b}if(!g){break pa}w[114256]=0;b=S(1477,h+56|0,f-b|0,32)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ra}d=w[b>>2];e=w[b+4>>2];c=x[b+11|0];w[114256]=0;g=d;d=c<<24>>24<0;S(92,h+248|0,(d?g:b)|0,(d?e:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break qa}if(u[b+11|0]<0){zb(w[b>>2])}b=x[h+243|0];c=b<<24>>24<0?w[h+236>>2]:b;if(f>>>0<c>>>0){break oa}}w[114256]=0;b=S(1477,h+8|0,f-c|0,32)|0;c=w[114256];w[114256]=0;if((c|0)==1){break na}d=w[b>>2];e=w[b+4>>2];c=x[b+11|0];w[114256]=0;f=d;d=c<<24>>24<0;S(92,h+232|0,(d?f:b)|0,(d?e:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break ma}if(u[b+11|0]>=0){break i}zb(w[b>>2]);break i}g=P()|0;break b}g=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}b=x[h+243|0];if((b<<24>>24<0?w[h+236>>2]:b)>>>0<=f>>>0){break i}}w[114256]=0;b=h+232|0;b=da(114,h+8|0,b|0,0,f|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[h+243|0]<0){zb(w[h+232>>2])}w[h+240>>2]=w[b+8>>2];c=w[b+4>>2];w[h+232>>2]=w[b>>2];w[h+236>>2]=c;break i}g=P()|0;break b}g=P()|0;break b}g=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}w[114256]=0;S(1473,a|0,h+248|0,h+232|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break g}}if(u[h+243|0]<0){zb(w[h+232>>2])}if(u[h+259|0]<0){zb(w[h+248>>2])}jb=h+288|0;return}g=P()|0;break b}if((e&255)>>>0>1){break b}}if(u[h+115|0]>=0){break d}zb(w[h+104>>2])}if(u[h+131|0]>=0){break b}zb(w[h+120>>2]);break b}g=P()|0}if(u[h+243|0]>=0){break a}zb(w[h+232>>2])}if(u[h+259|0]<0){zb(w[h+248>>2])}R(g|0);M()}function EB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-208|0;jb=e;w[b+8>>2]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(gd(b,9833,8)){w[114256]=0;w[e+96>>2]=0;w[e+88>>2]=0;w[e+92>>2]=0;w[e+80>>2]=0;w[e+72>>2]=0;w[e+76>>2]=0;w[e+64>>2]=0;w[e+56>>2]=0;w[e+60>>2]=0;T(236,a|0,32768);d=w[114256];w[114256]=0;if((d|0)==1){break d}w[114256]=0;f=Q(1,e+40|0,4354)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}h=a+1304436|0;if(u[a+1304447|0]<0){zb(w[h>>2])}d=w[f+4>>2];w[h>>2]=w[f>>2];w[h+4>>2]=d;w[h+8>>2]=w[f+8>>2];w[114256]=0;f=Q(1,e+24|0,2480)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}h=a+1304448|0;if(u[a+1304459|0]<0){zb(w[h>>2])}n=e+80|0;o=e+96|0;d=w[f+4>>2];w[h>>2]=w[f>>2];w[h+4>>2]=d;w[h+8>>2]=w[f+8>>2];w[a+1304496>>2]=2;m:{n:{while(1){h=w[b+8>>2];f=w[b>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,h|0,8)|0;d=w[114256];w[114256]=0;o:{p:{if((d|0)!=1){if(!f){break n}w[114256]=0;f=Q(519,b|0,e+16|0)|0;d=w[114256];w[114256]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((d|0)!=1){if(!f){break n}w[114256]=0;d=w[e+20>>2];U(188,e|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=w[114256];w[114256]=0;if((d|0)==1){break A}f=w[e>>2];d=w[w[f>>2]+8>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}d=3;if(!f){break o}d=w[e+16>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)>1396788559){break y}if((d|0)>1346522947){break z}if((d|0)==1129140036){break x}if((d|0)!=1346458708){break r}j=w[a+484360>>2];h=x[a+484376|0];f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}w[114256]=0;da(317,j+(h<<5)|0,e|0,f|0,255,254)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break p}break c}g=P()|0;break a}g=P()|0;break a}if((d|0)==1346522948){break t}if((d|0)!=1347175758){break r}f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(f>>>0<2){break p}w[114256]=0;f=Q(261,e|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}m=0;if(!f){break p}d=y[e+120>>1];m=d<<8|d>>>8;break p}if((d|0)<=1397507405){if((d|0)==1396788560){break w}if((d|0)!=1396854596){break r}if(w[e+76>>2]-w[e+72>>2]>>>0>63983){break p}f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(!f){break p}f=w[e+76>>2];if((f|0)==w[e+80>>2]){break s}w[f>>2]=w[e>>2];d=w[e+4>>2];w[f+4>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+12>>2];w[f+8>>2]=w[e+8>>2];w[f+12>>2]=d;w[e+76>>2]=f+16;break p}if((d|0)==1397507406){break p}if((d|0)!=1397769541){break r}f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(f>>>0<2){break p}w[114256]=0;f=Q(261,e|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(!f){break v}d=y[e+120>>1];if(!d){break v}d=(d<<8|d>>>8)&65535;d=d>>>0>=255?255:d;break u}if(y[a+480188>>1]){break p}f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}g=0;if(f>>>0<8){break p}B:{C:{while(1){w[114256]=0;j=Q(241,e|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}w[114256]=0;h=x[e+120|0];f=Q(241,e|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break B}i=y[a+480188>>1];if(((f?x[e+120|0]:0)|(j?h:0))&255){w[114256]=0;X(224,((i<<5)+a|0)+480280|0);d=w[114256];w[114256]=0;if((d|0)==1){break B}d=y[a+480188>>1];i=d+1|0;v[a+480188>>1]=i;v[((d<<5)+a|0)+480284>>1]=g-1>>>0<2?192:64}w[114256]=0;X(224,(((i&65535)<<5)+a|0)+480280|0);d=w[114256];w[114256]=0;if((d|0)==1){break B}d=y[a+480188>>1];v[a+480188>>1]=d+1;v[((d<<5)+a|0)+480284>>1]=g-1>>>0<2?192:64;g=g+1|0;if((g|0)!=4){continue}break}if(c){break p}l=1;d=1;break o}g=P()|0;break b}g=P()|0;break b}if(y[a+480190>>1]){break p}f=w[e>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}d=f-w[e+8>>2]>>>5&65535;d=d>>>0>=3999?3999:d;v[a+480190>>1]=d;w[114256]=0;U(520,e+56|0,d|0,0);d=w[114256];w[114256]=0;if((d|0)==1){break c}i=1;k=1;if(!y[a+480190>>1]){break p}while(1){w[114256]=0;f=Q(521,e|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break q}j=C(i,104)+a|0;h=j+484380|0;if(!f){w[e+144>>2]=0;w[e+148>>2]=0;w[e+136>>2]=0;w[e+140>>2]=0;w[e+128>>2]=0;w[e+132>>2]=0;w[e+120>>2]=0;w[e+124>>2]=0}w[114256]=0;T(266,h|0,0);d=w[114256];w[114256]=0;if((d|0)==1){break q}w[114256]=0;Y(209,e+104|0,2,e+120|0,20);d=w[114256];w[114256]=0;if((d|0)==1){break q}w[114256]=0;w[e+156>>2]=32;w[e+152>>2]=((i<<5)+a|0)+946304;Q(200,e+152|0,e+104|0)|0;d=w[114256];w[114256]=0;D:{E:{F:{G:{if((d|0)!=1){if(u[e+115|0]<0){zb(w[e+104>>2])}v[j+484412>>1]=64;w[j+484404>>2]=8287;d=y[e+148>>1];d=(d<<8|d>>>8)&65535;v[j+484410>>1]=(d>>>0>=64?64:d)<<2;d=w[e+140>>2];f=d<<24|d<<8&16711680|(d>>>8&65280|(d&-33554432)>>>24);w[h>>2]=f;d=y[e+146>>1];d=(d<<8|d>>>8)&65535;H:{if(d>>>0<2){break H}g=f;h=d;d=y[e+144>>1];f=(d<<8|d>>>8)&65535;d=h+f<<1;if(g>>>0<d>>>0){break H}w[j+484396>>2]=d;w[j+484392>>2]=f<<1;d=j+484414|0;v[d>>1]=y[d>>1]|8}f=y[e+150>>1];if(f){break G}d=i-1|0;i=1<<d;g=w[e+56>>2]+(d>>>3&536870908)|0;break F}g=P()|0;if(u[e+115|0]>=0){break b}zb(w[e+104>>2]);break b}d=i-1|0;i=1<<d;g=w[e+56>>2]+(d>>>3&536870908)|0;if((f|0)!=512){break E}}w[g>>2]=w[g>>2]|i;break D}w[g>>2]=w[g>>2]&(i^-1)}k=k+1|0;i=k&65535;if(i>>>0<=y[a+480190>>1]){continue}break}break p}d=1}w[a+480196>>2]=d;break p}f=w[e+92>>2];d=f-w[e+88>>2]|0;if(d>>>0>4095){break p}if((f|0)!=w[e+96>>2]){w[f>>2]=w[e>>2];d=w[e+4>>2];w[f+4>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+12>>2];w[f+8>>2]=w[e+8>>2];w[f+12>>2]=d;w[e+92>>2]=f+16;break p}w[114256]=0;h=d>>>3|0;f=d>>4;d=f+1|0;h=Z(522,e+160|0,(d>>>0<h>>>0?h:d)|0,f|0,o|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}f=w[e+168>>2];w[f>>2]=w[e>>2];d=w[e+4>>2];w[f+4>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+12>>2];w[f+8>>2]=w[e+8>>2];w[f+12>>2]=d;k=w[e+168>>2]+16|0;w[e+168>>2]=k;i=w[e+164>>2];g=w[e+92>>2];d=w[e+88>>2];I:{if((g|0)==(d|0)){f=d;break I}while(1){j=i-16|0;g=g-16|0;w[j>>2]=w[g>>2];w[j+4>>2]=w[g+4>>2];w[g>>2]=0;w[g+4>>2]=0;f=w[g+12>>2];w[j+8>>2]=w[g+8>>2];w[j+12>>2]=f;i=w[e+164>>2]-16|0;w[e+164>>2]=i;if((d|0)!=(g|0)){continue}break}k=w[e+168>>2];d=w[e+92>>2];f=w[e+88>>2]}w[e+164>>2]=f;w[e+88>>2]=i;w[e+92>>2]=k;w[e+168>>2]=d;d=w[e+96>>2];w[e+96>>2]=w[e+172>>2];w[e+172>>2]=d;w[h>>2]=f;xg(h);break p}j=f-w[e+72>>2]|0;f=j>>4;h=f+1|0;if(h>>>0>=268435456){w[114256]=0;X(523,e+72|0);a=w[114256];w[114256]=0;if((a|0)==1){break g}M()}w[114256]=0;d=j>>3;h=Z(522,e+184|0,(j>>>0>=2147483632?268435455:d>>>0>h>>>0?d:h)|0,f|0,n|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}f=w[e+192>>2];w[f>>2]=w[e>>2];d=w[e+4>>2];w[f+4>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+12>>2];w[f+8>>2]=w[e+8>>2];w[f+12>>2]=d;k=w[e+192>>2]+16|0;w[e+192>>2]=k;i=w[e+188>>2];g=w[e+76>>2];d=w[e+72>>2];J:{if((g|0)==(d|0)){f=d;break J}while(1){j=i-16|0;g=g-16|0;w[j>>2]=w[g>>2];w[j+4>>2]=w[g+4>>2];w[g>>2]=0;w[g+4>>2]=0;f=w[g+12>>2];w[j+8>>2]=w[g+8>>2];w[j+12>>2]=f;i=w[e+188>>2]-16|0;w[e+188>>2]=i;if((d|0)!=(g|0)){continue}break}k=w[e+192>>2];d=w[e+76>>2];f=w[e+72>>2]}w[e+188>>2]=f;w[e+72>>2]=i;w[e+76>>2]=k;w[e+192>>2]=d;d=w[e+80>>2];w[e+80>>2]=w[e+196>>2];w[e+196>>2]=d;w[h>>2]=f;xg(h);break p}if(!(d&-2139062144)){break p}l=0;d=1;break o}g=P()|0;break b}g=P()|0;break a}d=0}h=w[e+4>>2];K:{if(!h){break K}f=w[h+4>>2];w[h+4>>2]=f-1;if(f){break K}ob[w[w[h>>2]+8>>2]](h);Ib(h)}if(!d){continue}break}if((d|0)!=3){break m}}if(!y[a+480188>>1]){l=0;break m}w[a+480200>>2]=256;w[a+480204>>2]=125e4;w[a+480260>>2]=452;w[a+480264>>2]=3424;w[a+480228>>2]=48;w[a+480232>>2]=48;d=w[a+484360>>2];b=x[a+484376|0];w[114256]=0;v[e+120>>1]=65535;U(524,d+(b<<5)|0,m&65535,e+120|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}L:{if(!(c&1)){break L}w[114256]=0;i=a+484344|0;T(215,i|0,w[e+92>>2]-w[e+88>>2]>>>4&65535);b=w[114256];w[114256]=0;if((b|0)==1){break d}g=w[e+88>>2];if((g|0)==w[e+92>>2]){break L}k=0;l=0;while(1){n=(k<<4)+g|0;f=w[n+8>>2];d=w[n>>2];b=w[w[d>>2]+36>>2];w[114256]=0;d=S(b|0,d|0,f|0,2)|0;b=w[114256];w[114256]=0;if((b|0)==1){break h}M:{if(!d){w[114256]=0;S(216,i|0,l&65535,64)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break M}break h}w[114256]=0;d=Q(261,n|0,e+120|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break h}N:{O:{if(!d){break O}b=y[e+120>>1];if(!b){break O}b=(b<<8|b>>>8)&65535;f=b>>>0>=1024?1024:b;break N}f=1}w[114256]=0;d=S(216,i|0,l&65535,f|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break h}if(!d|!f){break M}o=y[a+480188>>1];m=0;while(1){b=w[i>>2];w[114256]=0;h=b+C(k,52)|0;d=V(218,h|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break j}if(o){j=w[h>>2]+C(C(d,m),6)|0;b=0;while(1){w[114256]=0;Q(328,n|0,e+120|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}d=j+C(b,6)|0;g=x[e+123|0];u[d+5|0]=g;h=x[e+120|0];if((h-1&255)>>>0<=35){u[d|0]=h+48;h=x[e+121|0]+1|0}else{h=0}u[d+1|0]=h;P:{Q:{R:{switch(x[e+122|0]){case 1:u[d+3|0]=2;u[d+5|0]=g&15;break P;case 2:u[d+3|0]=3;u[d+5|0]=g&15;break P;case 12:if(!g){break P}u[d+3|0]=1;break P;case 13:if(!g){break P}u[d+3|0]=36;u[d+5|0]=(g>>>0>=15?15:g)|16;break P;case 30:if(!g){break P}u[d+3|0]=35;u[d+5|0]=(g>>>0>=15?15:g)|16;break P;case 21:if(!g){break P}u[d+3|0]=36;u[d+5|0]=(g>>>0>=15?15:g)|80;break P;case 17:if(!g){break P}u[d+3|0]=35;u[d+5|0]=(g>>>0>=15?15:g)|80;break P;case 15:u[d+3|0]=19;u[d+5|0]=(g|0)!=0;break P;case 25:u[d+3|0]=12;break P;case 27:u[d+1|0]=0;u[d+2|0]=0;u[d+3|0]=0;u[d+4|0]=0;u[d|0]=255;break Q;case 28:u[d+3|0]=16;break P;case 31:u[d+3|0]=11;S:{T:{U:{switch(g>>>4|0){case 4:if((g|0)==64){break T}u[d+5|0]=g&15;break P;case 5:u[d+5|0]=g<<4;break P;case 6:u[d+5|0]=(g&15)==15?-2:g|240;break P;case 0:case 1:case 2:case 3:break T;case 7:break U;default:break S}}u[d+5|0]=(g&15)==15?-17:g<<4|15;break P}u[d+4|0]=g;u[d+2|0]=1}u[d+3|0]=0;break Q;case 0:break Q;default:break R}}u[d+3|0]=0}u[d+5|0]=0}b=b+1|0;if((o|0)!=(b|0)){continue}break}}m=m+1|0;if((f|0)!=(m|0)){continue}break}}l=l+1|0;k=l&65535;g=w[e+88>>2];if(k>>>0<w[e+92>>2]-g>>4>>>0){continue}break}}l=1;d=y[a+480190>>1];if(!(c&2)|d>>>0<2){break m}b=0;g=1;while(1){c=w[e+72>>2];if(w[e+76>>2]-c>>4>>>0<=b>>>0){break m}h=(C(g,104)+a|0)+484380|0;if(w[h>>2]){f=b<<4;d=w[f+c>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break l}if(d>>>0<z[h>>2]){w[h>>2]=d}d=g-1|0;c=w[w[e+56>>2]+(d>>>3&536870908)>>2];w[114256]=0;v[e+120>>1]=264;u[e+122|0]=1;u[e+123|0]=0-(c>>>d&1)&10;S(214,e+120|0,h|0,f+w[e+72>>2]|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break k}d=y[a+480190>>1];b=b+1|0}g=g+1|0;if(g>>>0<(d&65535)>>>0){continue}break}}a=w[e+56>>2];if(a){zb(a)}gc(e+72|0);gc(e+88|0)}jb=e+208|0;return l|0}g=P()|0;break a}g=P()|0;break a}g=P()|0;break a}g=P()|0;break a}g=P()|0;break a}g=P()|0;break b}g=P()|0;break a}g=P()|0;break a}g=P()|0;break a}g=P()|0}Bb(e)}a=w[e+56>>2];if(a){zb(a)}gc(e+72|0);gc(e+88|0);R(g|0);M()}function fc(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=w[114132];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+456568|0;d=w[a+456576>>2];a=w[d+8>>2];l:{if((b|0)==(a|0)){m=456528,n=FV(-2,c)&e,w[m>>2]=n;break l}w[a+12>>2]=b;w[b+8>>2]=a}a=d+8|0;b=c<<3;w[d+4>>2]=b|3;b=b+d|0;w[b+4>>2]=w[b+4>>2]|1;break a}k=w[114134];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+456568|0;g=w[a+456576>>2];a=w[g+8>>2];m:{if((b|0)==(a|0)){e=FV(-2,d)&e;w[114132]=e;break m}w[a+12>>2]=b;w[b+8>>2]=a}w[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;w[c+4>>2]=d|1;w[a+g>>2]=d;if(k){b=(k&-8)+456568|0;f=w[114137];a=1<<(k>>>3);n:{if(!(a&e)){w[114132]=a|e;a=b;break n}a=w[b+8>>2]}w[b+8>>2]=f;w[a+12>>2]=f;w[f+12>>2]=b;w[f+8>>2]=a}a=g+8|0;w[114137]=c;w[114134]=d;break a}j=w[114133];if(!j){break k}b=j-1&(j^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=w[((c|a)+(b>>>a|0)<<2)+456832>>2];f=(w[c+4>>2]&-8)-h|0;b=c;while(1){o:{a=w[b+16>>2];if(!a){a=w[b+20>>2];if(!a){break o}}b=(w[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=w[c+24>>2];d=w[c+12>>2];if((d|0)!=(c|0)){a=w[c+8>>2];w[a+12>>2]=d;w[d+8>>2]=a;break b}b=c+20|0;a=w[b>>2];if(!a){a=w[c+16>>2];if(!a){break j}b=c+16|0}while(1){g=b;d=a;b=a+20|0;a=w[b>>2];if(a){continue}b=d+16|0;a=w[d+16>>2];if(a){continue}break}w[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=w[114133];if(!j){break k}f=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}b=w[(e<<2)+456832>>2];q:{r:{s:{if(!b){a=0;break s}a=0;c=h<<((e|0)!=31?25-(e>>>1|0)|0:0);while(1){t:{g=(w[b+4>>2]&-8)-h|0;if(g>>>0>=f>>>0){break t}d=b;f=g;if(f){break t}f=0;a=b;break r}g=w[b+20>>2];b=w[((c>>>29&4)+b|0)+16>>2];a=g?(g|0)==(b|0)?a:g:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=w[((c|a)+(b>>>a|0)<<2)+456832>>2]}if(!a){break q}}while(1){b=(w[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=w[a+16>>2];if(b){a=b}else{a=w[a+20>>2]}if(a){continue}break}}if(!d|w[114134]-h>>>0<=f>>>0){break k}e=w[d+24>>2];c=w[d+12>>2];if((d|0)!=(c|0)){a=w[d+8>>2];w[a+12>>2]=c;w[c+8>>2]=a;break c}b=d+20|0;a=w[b>>2];if(!a){a=w[d+16>>2];if(!a){break i}b=d+16|0}while(1){g=b;c=a;b=a+20|0;a=w[b>>2];if(a){continue}b=c+16|0;a=w[c+16>>2];if(a){continue}break}w[g>>2]=0;break c}c=w[114134];if(c>>>0>=h>>>0){d=w[114137];b=c-h|0;u:{if(b>>>0>=16){w[114134]=b;a=d+h|0;w[114137]=a;w[a+4>>2]=b|1;w[c+d>>2]=b;w[d+4>>2]=h|3;break u}w[114137]=0;w[114134]=0;w[d+4>>2]=c|3;a=c+d|0;w[a+4>>2]=w[a+4>>2]|1}a=d+8|0;break a}i=w[114135];if(i>>>0>h>>>0){b=i-h|0;w[114135]=b;c=w[114138];a=c+h|0;w[114138]=a;w[a+4>>2]=b|1;w[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(w[114250]){c=w[114252]}else{w[114253]=-1;w[114254]=-1;w[114251]=4096;w[114252]=4096;w[114250]=l+12&-16^1431655768;w[114255]=0;w[114243]=0;c=4096}g=j+c|0;f=0-c|0;b=g&f;if(b>>>0<=h>>>0){break a}d=w[114242];if(d){c=w[114240];e=c+b|0;if(d>>>0<e>>>0|c>>>0>=e>>>0){break a}}if(x[456972]&4){break f}v:{w:{d=w[114138];if(d){a=456976;while(1){c=w[a>>2];if(c>>>0<=d>>>0&d>>>0<c+w[a+4>>2]>>>0){break w}a=w[a+8>>2];if(a){continue}break}}c=gg(0);if((c|0)==-1){break g}e=b;d=w[114251];a=d-1|0;if(a&c){e=(b-c|0)+(a+c&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=w[114242];if(d){a=w[114240];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=gg(e);if((c|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}c=gg(e);if((c|0)==(w[a>>2]+w[a+4>>2]|0)){break h}a=c}if(!((a|0)==-1|h+48>>>0<=e>>>0)){c=w[114252];c=c+(j-e|0)&0-c;if(c>>>0>2147483646){c=a;break e}if((gg(c)|0)!=-1){e=c+e|0;c=a;break e}gg(0-e|0);break g}c=a;if((a|0)!=-1){break e}break g}d=0;break b}c=0;break c}if((c|0)!=-1){break e}}w[114243]=w[114243]|4}if(b>>>0>2147483646){break d}c=gg(b);a=gg(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}e=a-c|0;if(e>>>0<=h+40>>>0){break d}}a=w[114240]+e|0;w[114240]=a;if(a>>>0>z[114241]){w[114241]=a}x:{y:{z:{g=w[114138];if(g){a=456976;while(1){d=w[a>>2];b=w[a+4>>2];if((d+b|0)==(c|0)){break z}a=w[a+8>>2];if(a){continue}break}break y}a=w[114136];if(!(a>>>0<=c>>>0?a:0)){w[114136]=c}a=0;w[114245]=e;w[114244]=c;w[114140]=-1;w[114141]=w[114250];w[114247]=0;while(1){d=a<<3;b=d+456568|0;w[d+456576>>2]=b;w[d+456580>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;w[114135]=b;a=a+c|0;w[114138]=a;w[a+4>>2]=b|1;w[(c+d|0)+4>>2]=40;w[114139]=w[114254];break x}if(x[a+12|0]&8|d>>>0>g>>>0|c>>>0<=g>>>0){break y}w[a+4>>2]=b+e;a=g+8&7?-8-g&7:0;c=a+g|0;w[114138]=c;b=w[114135]+e|0;a=b-a|0;w[114135]=a;w[c+4>>2]=a|1;w[(b+g|0)+4>>2]=40;w[114139]=w[114254];break x}if(z[114136]>c>>>0){w[114136]=c}b=c+e|0;a=456976;A:{B:{C:{D:{E:{F:{while(1){if((b|0)!=w[a>>2]){a=w[a+8>>2];if(a){continue}break F}break}if(!(x[a+12|0]&8)){break E}}a=456976;while(1){b=w[a>>2];if(b>>>0<=g>>>0){f=b+w[a+4>>2]|0;if(f>>>0>g>>>0){break D}}a=w[a+8>>2];continue}}w[a>>2]=c;w[a+4>>2]=w[a+4>>2]+e;j=(c+8&7?-8-c&7:0)+c|0;w[j+4>>2]=h|3;e=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=e-i|0;if((e|0)==(g|0)){w[114138]=i;a=w[114135]+a|0;w[114135]=a;w[i+4>>2]=a|1;break B}if(w[114137]==(e|0)){w[114137]=i;a=w[114134]+a|0;w[114134]=a;w[i+4>>2]=a|1;w[a+i>>2]=a;break B}f=w[e+4>>2];if((f&3)==1){g=f&-8;G:{if(f>>>0<=255){d=w[e+8>>2];b=f>>>3|0;c=w[e+12>>2];if((c|0)==(d|0)){m=456528,n=w[114132]&FV(-2,b),w[m>>2]=n;break G}w[d+12>>2]=c;w[c+8>>2]=d;break G}h=w[e+24>>2];c=w[e+12>>2];H:{if((e|0)!=(c|0)){b=w[e+8>>2];w[b+12>>2]=c;w[c+8>>2]=b;break H}I:{f=e+20|0;b=w[f>>2];if(b){break I}f=e+16|0;b=w[f>>2];if(b){break I}c=0;break H}while(1){d=f;c=b;f=b+20|0;b=w[f>>2];if(b){continue}f=c+16|0;b=w[c+16>>2];if(b){continue}break}w[d>>2]=0}if(!h){break G}d=w[e+28>>2];b=(d<<2)+456832|0;J:{if(w[b>>2]==(e|0)){w[b>>2]=c;if(c){break J}m=456532,n=w[114133]&FV(-2,d),w[m>>2]=n;break G}w[h+(w[h+16>>2]==(e|0)?16:20)>>2]=c;if(!c){break G}}w[c+24>>2]=h;b=w[e+16>>2];if(b){w[c+16>>2]=b;w[b+24>>2]=c}b=w[e+20>>2];if(!b){break G}w[c+20>>2]=b;w[b+24>>2]=c}e=e+g|0;f=w[e+4>>2];a=a+g|0}w[e+4>>2]=f&-2;w[i+4>>2]=a|1;w[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+456568|0;c=w[114132];a=1<<(a>>>3);K:{if(!(c&a)){w[114132]=a|c;a=b;break K}a=w[b+8>>2]}w[b+8>>2]=i;w[a+12>>2]=i;w[i+12>>2]=b;w[i+8>>2]=a;break B}f=31;if(a>>>0<=16777215){b=a>>>8|0;f=b+1048320>>>16&8;b=b<<f;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|f))|0;f=(b<<1|a>>>b+21&1)+28|0}w[i+28>>2]=f;w[i+16>>2]=0;w[i+20>>2]=0;b=(f<<2)+456832|0;d=w[114133];c=1<<f;L:{if(!(d&c)){w[114133]=c|d;w[b>>2]=i;break L}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=w[b>>2];while(1){b=c;if((w[b+4>>2]&-8)==(a|0)){break C}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=w[d+16>>2];if(c){continue}break}w[d+16>>2]=i}w[i+24>>2]=b;w[i+12>>2]=i;w[i+8>>2]=i;break B}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;w[114135]=b;a=a+c|0;w[114138]=a;w[a+4>>2]=b|1;w[(c+d|0)+4>>2]=40;w[114139]=w[114254];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<g+16>>>0?g:a;w[d+4>>2]=27;a=w[114247];w[d+16>>2]=w[114246];w[d+20>>2]=a;a=w[114245];w[d+8>>2]=w[114244];w[d+12>>2]=a;w[114246]=d+8;w[114245]=e;w[114244]=c;w[114247]=0;a=d+24|0;while(1){w[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(g|0)){break x}w[d+4>>2]=w[d+4>>2]&-2;f=d-g|0;w[g+4>>2]=f|1;w[d>>2]=f;if(f>>>0<=255){b=(f&-8)+456568|0;c=w[114132];a=1<<(f>>>3);M:{if(!(c&a)){w[114132]=a|c;a=b;break M}a=w[b+8>>2]}w[b+8>>2]=g;w[a+12>>2]=g;w[g+12>>2]=b;w[g+8>>2]=a;break x}a=31;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}w[g+28>>2]=a;w[g+16>>2]=0;w[g+20>>2]=0;b=(a<<2)+456832|0;d=w[114133];c=1<<a;N:{if(!(d&c)){w[114133]=c|d;w[b>>2]=g;break N}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=w[b>>2];while(1){b=d;if((f|0)==(w[b+4>>2]&-8)){break A}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=w[c+16>>2];if(d){continue}break}w[c+16>>2]=g}w[g+24>>2]=b;w[g+12>>2]=g;w[g+8>>2]=g;break x}a=w[b+8>>2];w[a+12>>2]=i;w[b+8>>2]=i;w[i+24>>2]=0;w[i+12>>2]=b;w[i+8>>2]=a}a=j+8|0;break a}a=w[b+8>>2];w[a+12>>2]=g;w[b+8>>2]=g;w[g+24>>2]=0;w[g+12>>2]=b;w[g+8>>2]=a}a=w[114135];if(a>>>0<=h>>>0){break d}b=a-h|0;w[114135]=b;c=w[114138];a=c+h|0;w[114138]=a;w[a+4>>2]=b|1;w[c+4>>2]=h|3;a=c+8|0;break a}w[114084]=48;a=0;break a}O:{if(!e){break O}b=w[d+28>>2];a=(b<<2)+456832|0;P:{if(w[a>>2]==(d|0)){w[a>>2]=c;if(c){break P}j=FV(-2,b)&j;w[114133]=j;break O}w[e+(w[e+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}w[c+24>>2]=e;a=w[d+16>>2];if(a){w[c+16>>2]=a;w[a+24>>2]=c}a=w[d+20>>2];if(!a){break O}w[c+20>>2]=a;w[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;w[d+4>>2]=a|3;a=a+d|0;w[a+4>>2]=w[a+4>>2]|1;break Q}w[d+4>>2]=h|3;e=d+h|0;w[e+4>>2]=f|1;w[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+456568|0;c=w[114132];a=1<<(f>>>3);R:{if(!(c&a)){w[114132]=a|c;a=b;break R}a=w[b+8>>2]}w[b+8>>2]=e;w[a+12>>2]=e;w[e+12>>2]=b;w[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=f>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|f>>>a+21&1)+28|0}w[e+28>>2]=a;w[e+16>>2]=0;w[e+20>>2]=0;b=(a<<2)+456832|0;S:{c=1<<a;T:{if(!(c&j)){w[114133]=c|j;w[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=w[b>>2];while(1){b=h;if((w[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=w[c+16>>2];if(h){continue}break}w[c+16>>2]=e}w[e+24>>2]=b;w[e+12>>2]=e;w[e+8>>2]=e;break Q}a=w[b+8>>2];w[a+12>>2]=e;w[b+8>>2]=e;w[e+24>>2]=0;w[e+12>>2]=b;w[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=w[c+28>>2];a=(b<<2)+456832|0;V:{if(w[a>>2]==(c|0)){w[a>>2]=d;if(d){break V}m=456532,n=FV(-2,b)&j,w[m>>2]=n;break U}w[i+(w[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}w[d+24>>2]=i;a=w[c+16>>2];if(a){w[d+16>>2]=a;w[a+24>>2]=d}a=w[c+20>>2];if(!a){break U}w[d+20>>2]=a;w[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;w[c+4>>2]=a|3;a=a+c|0;w[a+4>>2]=w[a+4>>2]|1;break W}w[c+4>>2]=h|3;d=c+h|0;w[d+4>>2]=f|1;w[d+f>>2]=f;if(k){b=(k&-8)+456568|0;g=w[114137];a=1<<(k>>>3);X:{if(!(a&e)){w[114132]=a|e;a=b;break X}a=w[b+8>>2]}w[b+8>>2]=g;w[a+12>>2]=g;w[g+12>>2]=b;w[g+8>>2]=a}w[114137]=d;w[114134]=f}a=c+8|0}jb=l+16|0;return a|0}function lF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-208|0;jb=d;w[b+8>>2]=0;a:{if(!yq(b,d+152|0)){break a}if(!zq(d+152|0)){break a}if(!c){r=1;break a}tc(a,2048);je(a);f=Hb(d+120|0,11209);e=w[f>>2];w[d+140>>2]=w[f+4>>2];g=x[f+7|0]|x[f+8|0]<<8|(x[f+9|0]<<16|x[f+10|0]<<24);u[d+143|0]=g;u[d+144|0]=g>>>8;u[d+145|0]=g>>>16;u[d+146|0]=g>>>24;w[f>>2]=0;w[f+4>>2]=0;g=x[f+11|0];w[f+8>>2]=0;w[114256]=0;u[d+147|0]=g;w[d+136>>2]=e;U(203,d+48|0,d+136|0,d+152|3);g=w[114256];w[114256]=0;b:{if((g|0)!=1){e=a+1304436|0;if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[d+52>>2];w[e>>2]=w[d+48>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+56>>2];u[d+59|0]=0;u[d+48|0]=0;if(u[d+147|0]<0){zb(w[d+136>>2])}if(u[f+11|0]<0){zb(w[f>>2])}f=a+1304448|0;e=Hb(d+48|0,6982);if(u[a+1304459|0]<0){zb(w[f>>2])}g=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+8>>2];w[a+1304496>>2]=4;v[a+480188>>1]=x[d+192|0];v[a+480190>>1]=x[d+188|0];Vb(d+48|0,2,d+152|4,32);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}g=w[d+52>>2];w[e>>2]=w[d+48>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+56>>2];g=x[d+155|0];if(g>>>0<=8){v[a+480188>>1]=4;e=w[b+8>>2];g=e-1|0;w[b+8>>2]=e>>>0>=g>>>0?g:0;Ce(a,1);g=x[d+155|0]}g=g&255;c:{if(g>>>0>=11){h=(g|0)==11?16:32;f=0;while(1){g=Xb(b,d+48|0);g=g?x[d+48|0]:0;d:{if((g&255)==100){w[((f<<5)+a|0)+480280>>2]=256;break d}e=g<<24>>24;g=e<<1;v[((f<<5)+a|0)+480284>>1]=(e|0)>=-64?((g|0)>=128?128:g)+128|0:0}f=f+1|0;if((h|0)!=(f|0)){continue}break}break c}if(g>>>0<9){break c}xq(b,d+48|0);f=0;while(1){v[((f<<5)+a|0)+480284>>1]=u[(d+48|0)+f|0]&1?64:192;f=f+1|0;if((f|0)!=16){continue}break}}e:{if(x[d+155|0]>=13){Pi(b,d+48|0);g=x[d+48|0];w[a+480204>>2]=C(g>>>0<32?125:g,1e4);w[a+480196>>2]=x[d+49|0];break e}w[a+480196>>2]=6;w[a+480204>>2]=125e4}f=x[a+484376|0];e=w[a+484360>>2];g=x[d+189|0];v[d+48>>1]=65535;$d(e+(f<<5)|0,g,d+48|0);f=0;w[d+144>>2]=0;w[d+136>>2]=0;w[d+140>>2]=0;m=w[b+8>>2];f:{g:{o=x[d+155|0];if(o>>>0<14){break g}w[114256]=0;T(204,d+136|0,x[d+189|0]);g=w[114256];w[114256]=0;if((g|0)!=1){break g}b=P()|0;break f}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(x[d+189|0]){while(1){h=f<<1;v[h+w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]>>1]=f;if(x[d+155|0]>=14){w[114256]=0;e=Q(197,b|0,d+48|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}v[h+w[d+136>>2]>>1]=e?y[d+48>>1]:0}l=w[b+8>>2];h=w[b>>2];e=w[w[h>>2]+36>>2];g=y[a+480188>>1];w[114256]=0;i=h;h=g<<1;e=S(e|0,i|0,l|0,h|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}s:{if(e){i=h+w[b+8>>2]|0;break s}e=w[b>>2];g=w[w[e>>2]+24>>2];w[114256]=0;i=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break r}}w[b+8>>2]=i;f=f+1|0;if(f>>>0<x[d+189|0]){continue}break}}g=0;t:{u:{v:{if(x[d+155|0]!=10){break v}h=w[b+8>>2];w:{if(y[a+480190>>1]){j=1;while(1){w[114256]=0;e=Q(205,b|0,d+48|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break u}x:{if(!e){break x}y:{if(x[d+188|0]<(y[d+94>>1]|y[d+96>>1]<<16)>>>0|x[d+48|0]>1){break y}g=y[d+98>>1]|y[d+100>>1]<<16;if(g>>>0>1048576|x[d+104|0]>64|g>>>0<(x[d+105|0]|x[d+106|0]<<8|(x[d+107|0]<<16|x[d+108|0]<<24))>>>0){break y}if(g>>>0>=(x[d+109|0]|x[d+110|0]<<8|(x[d+111|0]<<16|x[d+112|0]<<24))>>>0){break x}}g=1;break w}j=j+1|0;if(y[a+480190>>1]>=(j&65535)>>>0){continue}break}}g=0}if(h>>>0>z[b+8>>2]){f=w[b>>2];e=w[w[f>>2]+24>>2];w[114256]=0;f=V(e|0,f|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break t}if(f>>>0<h>>>0){break v}}w[b+8>>2]=h}e=y[a+480190>>1];w[114256]=0;w[d+48>>2]=0;p=S(206,d+32|0,e|0,d+48|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(y[a+480190>>1]){l=g?59:65;j=d+48|1;f=1;i=1;while(1){z:{if(x[d+155|0]<=9){w[114256]=0;h=Q(207,b|0,d+48|0)|0;e=w[114256];w[114256]=0;A:{B:{C:{if((e|0)==1){break C}if(!h){Cb(d+48|0,0,59)}w[114256]=0;T(208,d+48|0,(C(f,104)+a|0)+484380|0);e=w[114256];w[114256]=0;if((e|0)==1){break C}w[114256]=0;Y(209,d+16|0,2,j|0,32);e=w[114256];w[114256]=0;if((e|0)==1){break B}w[114256]=0;w[d+4>>2]=32;w[d>>2]=((f<<5)+a|0)+946304;Q(200,d|0,d+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break A}break z}b=P()|0;break h}b=P()|0;break h}b=P()|0;if(u[d+27|0]>=0){break h}zb(w[d+16>>2]);break h}w[114256]=0;S(210,b|0,d+48|0,l|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break i}w[114256]=0;U(211,d+48|0,(C(f,104)+a|0)+484380|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break i}w[114256]=0;Y(209,d+16|0,2,j|0,32);e=w[114256];w[114256]=0;if((e|0)==1){break j}w[114256]=0;w[d+4>>2]=32;w[d>>2]=((f<<5)+a|0)+946304;Q(200,d|0,d+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}}if(u[d+27|0]<0){zb(w[d+16>>2])}w[(w[p>>2]+(f<<2)|0)-4>>2]=y[d+94>>1]|y[d+96>>1]<<16;i=i+1|0;f=i&65535;if(f>>>0<=y[a+480190>>1]){continue}break}}w[114256]=0;w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;r=S(212,b|0,d+16|0,y[d+190>>1])|0;g=w[114256];w[114256]=0;if((g|0)==1){break q}if(!r){break l}j=w[d+16>>2];h=w[d+20>>2];if((j|0)!=(h|0)){f=j+2|0;if((h|0)!=(f|0)){n=x[j|0]|x[j+1|0]<<8;while(1){e=n&65535;g=x[f|0]|x[f+1|0]<<8;n=e>>>0>g>>>0?e:g;j=e>>>0<g>>>0?f:j;f=f+2|0;if((h|0)!=(f|0)){continue}break}}n=x[j|0]|x[j+1|0]<<8}w[114256]=0;q=Q(213,d|0,n|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){D:{if(n){i=0;while(1){w[114256]=0;l=Q(197,b|0,d+48|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break p}h=y[d+48>>1];f=w[b+8>>2];e=w[b>>2];g=w[w[e>>2]+36>>2];w[114256]=0;e=S(g|0,e|0,f|0,1)|0;g=w[114256];w[114256]=0;if((g|0)==1){break p}E:{if(e){f=w[b+8>>2]+1|0;break E}e=w[b>>2];g=w[w[e>>2]+24>>2];w[114256]=0;f=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break p}}w[b+8>>2]=f;g=(l?h:0)&65535;F:{if(!g){break F}w[114256]=0;U(188,d+48|0,b|0,C(g,3)+(x[d+155|0]==1?3:0)|0);g=w[114256];w[114256]=0;if((g|0)==1){break D}e=w[q>>2]+(i<<4)|0;he(e,d+48|0);g=w[d+60>>2];w[e+8>>2]=w[d+56>>2];w[e+12>>2]=g;e=w[d+52>>2];if(!e){break F}g=w[e+4>>2];w[e+4>>2]=g-1;if(g){break F}ob[w[w[e>>2]+8>>2]](e);Ib(e)}i=i+1|0;if((n|0)!=(i|0)){continue}break}}G:{if(!(c&2)){break G}w[d+48>>2]=16777480;if(!y[a+480190>>1]){break G}j=1;g=1;while(1){h=w[b+8>>2];f=w[b>>2];e=w[w[f>>2]+36>>2];w[114256]=0;f=S(e|0,f|0,h|0,1)|0;e=w[114256];w[114256]=0;H:{I:{J:{if((e|0)!=1){if(!f){break G}f=0;i=y[a+480190>>1];if(!i){break I}l=w[b+8>>2];while(1){K:{if(w[w[p>>2]+(f<<2)>>2]!=(j|0)){f=f+1|0;break K}L:{if(l>>>0>z[b+8>>2]){h=w[b>>2];e=w[w[h>>2]+24>>2];w[114256]=0;h=V(e|0,h|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}if(h>>>0<l>>>0){break L}}w[b+8>>2]=l}w[114256]=0;f=f+1|0;S(214,d+48|0,(C(f,104)+a|0)+484380|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break J}i=y[a+480190>>1]}if((i&65535)>>>0>f>>>0){continue}break}break H}b=P()|0;break o}b=P()|0;break o}i=0}g=g+1|0;j=g&65535;if(j>>>0<=(i&65535)>>>0){continue}break}}if(!(c&1)){break m}w[114256]=0;j=a+484344|0;T(215,j|0,x[d+189|0]);c=w[114256];w[114256]=0;M:{if((c|0)!=1){if(!x[d+189|0]){break m}h=m+((o>>>0>13)<<1)|0;g=0;while(1){N:{i=64;c=w[d+136>>2];if(w[d+140>>2]-c>>1>>>0>g>>>0){i=y[c+(g<<1)>>1]}w[114256]=0;e=S(216,j|0,g&65535,i&65535)|0;c=w[114256];w[114256]=0;if((c|0)==1){break M}O:{P:{if(!e){break P}f=C(((x[d+155|0]>13)<<1)+(y[a+480188>>1]<<1)|0,g)+h|0;Q:{if(f>>>0>z[b+8>>2]){e=w[b>>2];c=w[w[e>>2]+24>>2];w[114256]=0;e=V(c|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break M}if(e>>>0<f>>>0){break Q}}w[b+8>>2]=f}w[d+56>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0;c=y[a+480188>>1];w[114256]=0;e=S(212,b|0,d+48|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break N}i=0;if(e&y[a+480188>>1]!=0){while(1){c=w[d+48>>2]+(i<<1)|0;c=x[c|0]|x[c+1|0]<<8;R:{if(!c|c>>>0>y[d+190>>1]){break R}c=(w[d+16>>2]+(c<<1)|0)-2|0;c=(x[c|0]|x[c+1|0]<<8)-1&65535;if(c>>>0>=n>>>0){break R}f=w[j>>2];m=w[q>>2]+(c<<4)|0;w[m+8>>2]=0;e=w[m>>2];c=w[w[e>>2]+36>>2];w[114256]=0;e=S(c|0,e|0,0,3)|0;c=w[114256];w[114256]=0;if((c|0)==1){break N}if(!e){break R}o=f+C(g,52)|0;while(1){w[114256]=0;Q(217,m|0,d+200|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break O}f=x[d+200|0];if(f>>>0>=z[o+12>>2]){break R}w[114256]=0;e=V(218,o|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break O}k=w[o>>2]+C(C(e,f)+i|0,6)|0;c=x[d+201|0];S:{if(c>>>0<=126){if(!(c|x[d+202|0])){u[k|0]=254;break S}u[k|0]=c+1;if(x[d+202|0]==255){break S}u[k+2|0]=1;u[k+4|0]=x[d+202|0];break S}T:{switch(c-127|0){case 1:u[k+1|0]=x[d+202|0]+1;break S;case 0:break S;default:break T}}e=u[d+202|0];l=c&127;if(l>>>0>23){c=0}else{c=x[l+23200|0]}f=e;U:{V:{W:{X:{switch(l-2|0){case 0:case 8:case 9:if((e|0)>=0){break W}f=0-e&15;break V;case 1:e=e&255;f=e>>>0>=64?64:e;if(x[k+2|0]>1){break V}u[k+2|0]=1;u[k+4|0]=f;break S;case 2:if((e|0)>=0){c=3;break U}f=0-e&127;break V;case 15:if(!e){break S}if((e|0)<0){f=0-e|-16;break V}f=e<<4|15;break V;case 16:case 20:if(!e){break S}c=e<<24>>31;f=(c^e)-c|-16;c=(e|0)>=0?3:2;break U;case 17:f=e&15|-48;break V;case 18:f=e&15|-64;break V;case 21:break X;default:break V}}f=164;if((e|0)==100){break V}f=(e|0)>=-64?((e|0)>=64?64:e)- -64|0:0;if(!x[k+3|0]){break V}Y:{switch(x[k+2|0]){case 0:case 2:break Y;default:break S}}u[k+2|0]=2;u[k+4|0]=(f&254)>>>1;break S}f=e<<4}if(!(c&255)){break S}}u[k+5|0]=f;u[k+3|0]=c}f=w[m+8>>2];e=w[m>>2];c=w[w[e>>2]+36>>2];w[114256]=0;e=S(c|0,e|0,f|0,3)|0;c=w[114256];w[114256]=0;if((c|0)==1){break O}if(e){continue}break}}i=i+1|0;if(i>>>0<y[a+480188>>1]){continue}break}}c=w[d+48>>2];if(!c){break P}w[d+52>>2]=c;zb(c)}g=g+1|0;if(g>>>0>=x[d+189|0]){break m}continue}}break}b=P()|0;a=w[d+48>>2];if(!a){break o}w[d+52>>2]=a;zb(a);break o}b=P()|0;break o}b=P()|0;break o}b=P()|0;break o}b=P()|0;break n}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break n}b=P()|0}gc(q)}a=w[d+16>>2];if(!a){break h}w[d+20>>2]=a;zb(a);break h}gc(q)}a=w[d+16>>2];if(a){w[d+20>>2]=a;zb(a)}a=w[p>>2];if(a){w[p+4>>2]=a;zb(a)}a=w[d+136>>2];if(!a){break a}w[d+140>>2]=a;zb(a);break a}b=P()|0;if(u[d+27|0]>=0){break h}zb(w[d+16>>2]);break h}b=P()|0;break h}b=P()|0}a=w[p>>2];if(!a){break f}w[p+4>>2]=a;zb(a)}a=w[d+136>>2];if(!a){break b}w[d+140>>2]=a;zb(a);break b}b=P()|0;if(u[d+147|0]<0){zb(w[d+136>>2])}if(u[f+11|0]>=0){break b}zb(w[f>>2])}R(b|0);M()}jb=d+208|0;return r|0}function lV(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0;h=jb-48|0;jb=h;j=w[a+1074312>>2];c=w[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){j=j&-2;w[a+1074312>>2]=j}i=a+1074312|0;o=w[a+480180>>2];m=(o&16777248)!=0&j;if(c>>>0<=18874367){a:{if(!y[a+480192>>1]){break a}e=1;while(1){b:{b=w[(((e&65535)<<2)+a|0)+900380>>2];if(!b){break b}d=C(x[b+20|0],100)>>>6|0;u[b+20|0]=d>>>0>=100?100:d;c:{if(m){if(c>>>0>18350079){break b}d=u[b+26|0];u[b+26|0]=((d>>31|1)+d|0)/2;if(c>>>0<18285314){break c}break b}c=u[b+26|0];u[b+26|0]=((c>>31|1)+c|0)/2}Fk(b+88|0,4,w[a+480180>>2]);c=w[a+1074308>>2];d:{if(c>>>0<18284544){break d}if(c>>>0>18285135){break b}if(!x[b+34|0]|(x[b+31|0]-1&255)>>>0>16){break d}w[i>>2]=w[i>>2]|4}if(!(x[b+24|0]|(x[b+23|0]|(x[b+19|0]|x[b+20|0])))){break b}w[i>>2]=w[i>>2]|2;break a}e=e+1|0;if(y[a+480192>>1]>=(e&65535)>>>0){continue}break}}e:{if(!(w[a+480180>>2]&16777248)|c>>>0>18285313&m){break e}e=y[a+480190>>1];if(!e){break e}c=e+1&65535;b=1;while(1){e=C(b,104)+a|0;d=e+484419|0;if(!(x[d|0]|!(x[e+484421|0]|x[e+484420|0]))){u[d|0]=255}b=b+1|0;if((c|0)!=(b|0)){continue}break}}e=a+901404|0;f=e+4896|0;while(1){d=0;c=e;while(1){b=x[c|0];f:{g:{if((b-97&255)>>>0<=5){g=b-32|0;break g}g=99;h:{if(b>>>0<=106){if(b-88>>>0<2){break h}if((b|0)==75){break g}break f}if(b-120>>>0<2){break h}if((b|0)==107){break g}break f}g=122}u[c|0]=g}d=d+1|0;c=d+e|0;if((d|0)!=32){continue}break}e=e+32|0;if((f|0)!=(e|0)){continue}break}c=w[a+1074308>>2]}i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(c>>>0>18874895){break x}if(!(w[a+480180>>2]&16777252)|(c|0)==18874368){break w}e=y[a+480192>>1];if(!e){break w}e=e+1&65535;d=0;b=1;while(1){y:{g=w[((b<<2)+a|0)+900380>>2];if(!(x[g+31|0]?g:0)){b=b+1|0;if((e|0)!=(b|0)){continue}if(d){break y}break x}u[g+33|0]=13;d=1;b=b+1|0;if((e|0)!=(b|0)){continue}}break}w[i>>2]=w[i>>2]|8}if(c>>>0>19006225){break v}if((c|0)==19005440){break u}}if(!(w[a+480180>>2]&16777248)|!(x[i|0]&3)){break u}e=y[a+480192>>1];if(!e){break u}d=e+1&65535;b=1;while(1){e=w[((b<<2)+a|0)+900380>>2];if(!(!e|!x[e+19|0]|!(u[e+80|0]&1))){u[e+19|0]=0}b=b+1|0;if((d|0)!=(b|0)){continue}break}}if(c>>>0>19007232){break t}}e=a+946300|0;b=a+906300|0;while(1){c=h+16|0;d=b+80|0;Vb(c,1,d,64);w[114256]=0;Y(229,h+32|0,0,7,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break s}if(u[h+27|0]<0){zb(w[h+16>>2])}w[114256]=0;f=d;c=u[h+43|0];d=(c|0)<0;ga(922,1,f|0,64,(d?w[h+32>>2]:h+32|0)|0,(d?w[h+36>>2]:c&255)|0);c=w[114256];w[114256]=0;if((c|0)==1){break r}if(u[h+43|0]<0){zb(w[h+32>>2])}b=b+160|0;if((e|0)!=(b|0)){continue}break}}z:{A:{B:{if(w[a+480180>>2]!=4){break B}e=w[a+1074308>>2];if(e>>>0<19007257){break z}if(e>>>0>19071235){break A}if(w[a+1074372>>2]!=4){break B}ik(a,5)}e=w[a+1074308>>2]}if(e>>>0>19202054){break o}c=19202048;if((e|0)==19202048){break n}}c=y[a+480192>>1];if(c){break p}c=e;break n}a=P()|0;if(u[h+27|0]>=0){break q}zb(w[h+16>>2]);break q}a=P()|0;if(u[h+43|0]>=0){break q}zb(w[h+32>>2])}R(a|0);M()}g=c+1&65535;c=1;while(1){d=w[((c<<2)+a|0)+900380>>2];C:{if(!d|!x[d+20|0]|!x[d+31|0]){break C}f=d+492|0;b=d+236|0;while(1){if(y[b>>1]){break C}b=b+2|0;if((f|0)!=(b|0)){continue}break}u[d+20|0]=0}c=c+1|0;if((g|0)!=(c|0)){continue}break}}c=e;if(c>>>0>19267583){break m}}e=y[a+480192>>1];if(!e){break l}d=!m|c>>>0<18350080;g=e+1&65535;b=1;while(1){e=w[((b<<2)+a|0)+900380>>2];D:{if(!e){break D}f=u[e+26|0];u[e+26|0]=((f>>31|1)+f|0)/2;if(!d){break D}u[e+19|0]=x[e+19|0]+3>>>2}b=b+1|0;if((g|0)!=(b|0)){continue}break}}if(c>>>0>19398673){break k}}e=y[a+480192>>1];if(!e){break j}b=1;while(1){d=w[(((b&65535)<<2)+a|0)+900380>>2];if(!(!d|x[d+65|0]==255)){e=a+1074320|0;w[e>>2]=w[e>>2]|1073741824;break k}b=b+1|0;if(e>>>0>=(b&65535)>>>0){continue}break}}if(c>>>0>19399427){break i}}e=y[a+480192>>1];if(!e){break i}b=1;while(1){c=w[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|x[c+36|0]>1)){e=a+1074324|0;w[e>>2]=w[e>>2]|32;break i}b=b+1|0;if(e>>>0>=(b&65535)>>>0){continue}break}}c=w[a+484348>>2];b=w[a+484344>>2];u[h+38|0]=u[a+1074312|0]&1;v[h+36>>1]=0;w[h+32>>2]=a;e=w[h+36>>2];w[h+8>>2]=w[h+32>>2];w[h+12>>2]=e;e=0;g=jb-16|0;jb=g;p=((c-b|0)/52|0)-1&65535;n=a+484344|0;if(p>>>0<((w[n+4>>2]-w[n>>2]|0)/52&65535)>>>0){s=w[h+8>>2];t=w[h+12>>2];while(1){c=w[n>>2]+C(e&65535,52)|0;b=w[c>>2];q=w[c+4>>2];if((b|0)!=(q|0)){w[g+8>>2]=s;w[g+12>>2]=t;while(1){k=y[g+12>>1];c=k+1|0;d=w[g+8>>2];v[g+12>>1]=y[d+480188>>1]>(c&65535)>>>0?c:0;E:{if((x[b|0]+5&255)>>>0<2){break E}c=w[d+1074308>>2];F:{G:{H:{I:{l=w[d+480180>>2];J:{K:{if((l|0)==2){if(c>>>0>18415615){break K}d=x[b+3|0];if((d|0)!=23){break H}if(x[b+5|0]<65){break I}u[b+5|0]=64;break I}if(l&16777248){L:{M:{if(c>>>0>=18285314){if(x[g+14|0]){break M}d=0;f=0;if(c>>>0>18874367){break L}}N:{switch(x[b+3|0]-20|0){case 3:if(x[b+5|0]<129){break M}u[b+5|0]=128;break M;case 0:break N;default:break M}}d=x[b+5|0];if((d|0)!=208){if((d|0)!=192){break M}u[b|0]=254;u[b+3|0]=0;break M}u[b+3|0]=0}O:{P:{Q:{if(c>>>0>=18350080){if(x[g+14|0]){break Q}d=0;f=0;if(c>>>0>18874367){break L}}f=x[b+3|0];if(f>>>0>29){break P}d=1;if(!(1<<f&536873152)){break P}break O}d=0;f=0;if(c>>>0>18874367){break L}f=x[b+3|0]}d=0}f=(f|0)==24|(f|0)==22}R:{if(!(d|f)){break R}f=x[b+5|0];d=f&15;if(!d|(d|0)==15){break R}f=f&240;if(!f|(f|0)==240){break R}u[b+5|0]=x[b+3|0]==24?f:d}S:{if((c|0)==19005440|c>>>0>19005699){break S}d=y[w[g+8>>2]+480192>>1];if(x[g+14|0]|(!d|d>>>0>=x[b+1|0])){break S}u[b+4|0]=0;u[b+2|0]=1}if(x[b+3|0]!=18|x[b+5|0]!=17){break K}if(c>>>0>=19468802){d=x[b+2|0];break F}d=w[g+8>>2];if(!(x[d+1074314|0]&64)|x[d+480208|0]&4){break K}u[b+5|0]=0;break K}if((l|0)!=4){break K}d=!x[g+14|0];T:{if((d|c>>>0<18285314)&c>>>0<18874368){break T}if(c>>>0>19137025){break G}if(x[b+3|0]!=23|x[b+5|0]<65){break T}u[b+3|0]=0}U:{V:{W:{if(!(!(d&c>>>0<18874368)&c>>>0>=18415616)){f=x[b+3|0];d=x[b+2|0];if((f|0)!=10|(d|0)!=11){break W}u[b+3|0]=0;break J}if(c>>>0>18874639){break V}f=x[b+3|0];d=x[b+2|0]}if((d|0)!=11|(f|0)!=4){break U}d=x[b+4|0];if(!(d|x[g+14|0])){break K}f=x[b+5|0];if(!f){break K}u[b+2|0]=0;d=f+(d<<4)|0;u[b+5|0]=d>>>0>=255?255:d;break K}if(c>>>0>19007240){break G}f=x[b+3|0]}if(x[b+5|0]|(f|0)!=16){break K}u[b+3|0]=0}if(c>>>0>18874367){break G}}d=x[b+3|0];break H}d=23}f=x[b+5|0]&240;X:{Y:{if((d|0)!=28|(f|0)!=96){r=0}else{if(!x[g+14|0]|(l|0)!=4){break Y}r=c>>>0<18350080}if(!(r|(d|0)==20&(f|0)==96)){break X}}if(!k){break G}d=C(k,-6)+b|0;while(1){if(!((x[d+3|0]|8)!=28|(x[d+5|0]&240)!=96)){u[d+3|0]=0}d=d+6|0;if(d>>>0<b>>>0){continue}break}d=x[b+3|0]}if(!k|((d|0)!=20|(f|0)!=224)){break G}d=C(k,-6)+b|0;while(1){if(!(x[d+3|0]!=20|(x[d+5|0]&240)!=224)){u[d+3|0]=0}d=d+6|0;if(d>>>0<b>>>0){continue}break}}d=x[b+2|0];if((d|0)!=8|c>>>0>19333174|(c|0)==19333120){break F}d=x[b+4|0];c=x[b+3|0];if(!(!d|(c|0)!=7)){u[b+3|0]=11;break E}Z:{_:{switch(c-5|0){default:if((c|0)!=26){break E}break;case 1:break E;case 2:break Z;case 0:break _}}f=x[b+5|0];if(!(f&15)){u[b+2|0]=0;u[b+3|0]=5;u[b+5|0]=f|d&15;break E}$:{switch(c-5|0){case 1:break E;case 0:case 2:break Z;default:break $}}if((c|0)!=26){break E}}u[b+2|0]=0;break E}if(x[b+3|0]|((l|0)==16777216|(d&255)!=15)){break E}u[b+2|0]=0;u[b+3|0]=10;u[b+5|0]=x[b+4|0]<<3}b=b+6|0;if((q|0)!=(b|0)){continue}break}}e=e+1|0;if((e&65535)>>>0<=p>>>0){continue}break}}e=w[h+12>>2];w[h+16>>2]=w[h+8>>2];w[h+20>>2]=e;jb=g+16|0;e=z[a+1074308>>2]<19267584;aa:{if(e&m){b=34880;while(1){e=w[a+1074308>>2];c=w[b+4>>2];jn(i,w[b>>2],e>>>0>=c>>>0|(e|0)==(c&-65536));b=b+8|0;if((b|0)!=35224){continue}break}break aa}if(!(e&((o|0)==4&j))){break aa}b=35232;while(1){jn(i,w[b>>2],z[a+1074308>>2]>=z[b+4>>2]);b=b+8|0;if((b|0)!=35472){continue}break}}ba:{d=w[a+480180>>2];ca:{da:{if(d&16777248){b=35472;e=w[a+1074308>>2];while(1){c=w[b+4>>2];g=c&-65536;ea:{fa:{if(g>>>0>e>>>0){c=w[b>>2];if(c>>>0<110){break fa}break ba}if(e>>>0<=g>>>0|c>>>0<=e>>>0){break ea}c=w[b>>2];if(c>>>0>=110){break ba}}g=i+(c>>>3&536870908)|0;f=w[g>>2];A=g,B=FV(-2,c)&f,w[A>>2]=B}b=b+8|0;if((b|0)!=35520){continue}break}break da}ga:{switch(d-2|0){default:e=w[a+1074308>>2];break ca;case 2:b=35520;e=w[a+1074308>>2];while(1){if(z[b+4>>2]>e>>>0){c=w[b>>2];if(c>>>0>=110){break ba}g=i+(c>>>3&536870908)|0;f=w[g>>2];A=g,B=FV(-2,c)&f,w[A>>2]=B}b=b+8|0;if((b|0)!=35576){continue}break};break da;case 0:break ga}}b=35584;e=w[a+1074308>>2];while(1){if(z[b+4>>2]>e>>>0){c=w[b>>2];if(c>>>0>=110){break ba}g=i+(c>>>3&536870908)|0;f=w[g>>2];A=g,B=FV(-2,c)&f,w[A>>2]=B}b=b+8|0;if((b|0)!=35664){continue}break}}if((d|0)!=4|e>>>0>18415615){break ca}c=a+1074324|0;w[c>>2]=w[c>>2]|4}if(e-19333159>>>0<=33){b=0;while(1){e=b+77|0;c=i+(e>>>3&536870908)|0;jn(i,b+86|0,w[c>>2]>>>e&1);A=c,B=w[c>>2]&FV(-2,e),w[A>>2]=B;b=b+1|0;if((b|0)!=5){continue}break}e=w[a+1074308>>2]}b=256;ha:{ia:{ja:{ka:{if(e>>>0>=18284544){if(e>>>0>18874627){break ka}b=64;if((e|0)==18874368){break ja}}w[i>>2]=w[i>>2]|b;break ja}if(e>>>0<19136512){break ja}if(!(w[a+480180>>2]&16777248)|e>>>0>19267583){break ha}c=w[i>>2]|128;break ia}c=w[i>>2]&-129}w[i>>2]=c}la:{if(e>>>0<19071234|w[i>>2]>=0|e>>>0>19398722){break la}i=y[a+480192>>1];if(!i){break la}b=1;while(1){ma:{c=w[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break ma}d=x[c+65|0];if(!(x[c+60|0]&4)|(d|0)==255|d>>>0<=x[c- -64|0]){break ma}c=a+1074324|0;w[c>>2]=w[c>>2]|2;break la}b=b+1|0;if(i>>>0>=(b&65535)>>>0){continue}break}}c=w[a+480180>>2];na:{if(!(c&16777218)){break na}i=y[a+480190>>1];if(!i){break na}b=1;while(1){if(!(x[(C(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(i>>>0>=(b&65535)>>>0){continue}break na}break}if((c|0)!=2){if(!(!y[a+480192>>1]|e>>>0<19398688|e>>>0>19464277|(c|0)!=16777216)){e=a+1074324|0;w[e>>2]=w[e>>2]|8192}a=a+1074324|0;w[a>>2]=w[a>>2]&-4097;break na}if(e>>>0>19464191){break na}a=a+1074324|0;w[a>>2]=w[a>>2]|4096}jb=h+48|0;return}hi(7900);M()}function JD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-272|0;jb=e;w[b+8>>2]=0;f=jb-16|0;jb=f;g=w[b+8>>2];h=w[b>>2];k=e+104|0;w[f+8>>2]=k;w[f+12>>2]=k+157;g=ob[w[w[h>>2]+32>>2]](h,g,f+8|0)|0;if((g|0)==157){h=w[b>>2];a:{if(ob[w[w[h>>2]+36>>2]](h,w[b+8>>2],157)|0){h=w[b+8>>2]+157|0;break a}h=w[b>>2];h=ob[w[w[h>>2]+24>>2]](h)|0}w[b+8>>2]=h}jb=f+16|0;b:{c:{d:{e:{f:{g:{h:{if((g|0)!=157){break h}if(!Wp(e+104|0)){break h}if(!c){d=1;break h}tc(a,w[(y[e+220>>1]<<2)+23376>>2]);w[a+480208>>2]=w[a+480208>>2]|16777216;d=a+1304436|0;f=Hb(e+8|0,8931);if(u[a+1304447|0]<0){zb(w[d>>2])}h=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=h;w[d+8>>2]=w[f+8>>2];d=a+1304448|0;f=Hb(e+8|0,6253);if(u[a+1304459|0]<0){zb(w[d>>2])}h=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=h;w[d+8>>2]=w[f+8>>2];f=Hb(e+72|0,11002);h=w[f>>2];w[e+92>>2]=w[f+4>>2];d=x[f+7|0]|x[f+8|0]<<8|(x[f+9|0]<<16|x[f+10|0]<<24);u[e+95|0]=d;u[e+96|0]=d>>>8;u[e+97|0]=d>>>16;u[e+98|0]=d>>>24;w[f>>2]=0;w[f+4>>2]=0;d=x[f+11|0];w[f+8>>2]=0;w[114256]=0;u[e+99|0]=d;w[e+88>>2]=h;Y(219,e+8|0,e+88|0,e+183|0,e+180|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}d=a+1304460|0;if(u[a+1304471|0]<0){zb(w[d>>2])}h=w[e+12>>2];w[d>>2]=w[e+8>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+16>>2];u[e+19|0]=0;u[e+8|0]=0;if(u[e+99|0]<0){zb(w[e+88>>2])}if(u[f+11|0]<0){zb(w[f>>2])}d=(y[e+220>>1]<<2)+23424|0;Jf(a+1304484|0,d,ec(d));d=w[(y[e+220>>1]<<2)+75888>>2];Jf(a+1304472|0,d,ec(d));w[a+1304496>>2]=4;Vb(e+8|0,2,e+104|4,32);d=a+1304400|0;if(u[a+1304411|0]<0){zb(w[d>>2])}f=w[e+12>>2];w[d>>2]=w[e+8>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+16>>2];Vb(e+8|0,2,e+140|0,32);i:{j:{d=x[e+19|0];k:{if(((d<<24>>24<0?w[e+12>>2]:d)|0)==7){w[114256]=0;d=da(186,e+8|0,0,-1,5621,7)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}if(!d){break k}}w[114256]=0;U(6,e+88|0,4,e+8|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}d=a+1304412|0;if(u[a+1304423|0]<0){zb(w[d>>2])}f=w[e+92>>2];w[d>>2]=w[e+88>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+96>>2]}if(u[e+19|0]<0){zb(w[e+8>>2])}v[a+480188>>1]=32;f=0;l:{while(1){h=(f<<5)+a|0;g=h+480280|0;Qd(g);d=x[(e+f|0)+185|0];m:{if(d>>>0<=15){v[h+480284>>1]=d<<4|8;break m}if((d|0)!=16){if((d|0)!=255){break m}v[a+480188>>1]=f;break l}v[h+480284>>1]=128;w[g>>2]=256}f=f+1|0;if((f|0)!=32){continue}break}f=y[a+480188>>1]}d=0;if(!(f&65535)){break h}f=x[e+217|0]<<2;w[a+480200>>2]=f>>>0>=256?256:f;w[a+480196>>2]=x[e+218|0];w[a+480204>>2]=C(x[e+219|0],1e4);f=y[e+222>>1]|y[e+224>>1]<<16;n:{if(f>>>0>z[b+8>>2]){h=w[b>>2];if(ob[w[w[h>>2]+24>>2]](h)>>>0<f>>>0){break n}}w[b+8>>2]=f;wh(w[a+484360>>2]+(x[a+484376|0]<<5)|0,b,x[e+226|0]+1|0,255,254)}f=w[e+232>>2];if(f>>>0>z[b+8>>2]){h=w[b>>2];if(ob[w[w[h>>2]+24>>2]](h)>>>0<f>>>0){break h}}w[b+8>>2]=f;v[a+480190>>1]=x[e+240|0]+1;k=e+40|0;f=1;h=1;while(1){d=jb-16|0;jb=d;i=w[b+8>>2];g=w[b>>2];j=e+8|0;w[d+8>>2]=j;w[d+12>>2]=j+62;i=ob[w[w[g>>2]+32>>2]](g,i,d+8|0)|0;if((i|0)==62){g=w[b>>2];o:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],62)|0){g=w[b+8>>2]+62|0;break o}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=d+16|0;if((i|0)==62){d=C(f,104)+a|0;g=d+484380|0;lc(g,0);i=e+88|0;Vb(i,2,e+8|0,32);w[114256]=0;w[e+268>>2]=32;w[e+264>>2]=((f<<5)+a|0)+946304;Q(200,e+264|0,i|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}if(u[e+99|0]<0){zb(w[e+88>>2])}f=e+88|0;Vb(f,2,k,12);w[114256]=0;w[e+268>>2]=22;w[e+264>>2]=d+484423;Q(200,e+264|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}if(u[e+99|0]<0){zb(w[e+88>>2])}i=y[e+66>>1];w[d+484404>>2]=i;f=0;p:{if(!(w[a+480180>>2]&740327453)){break p}while(1){if((i|0)==y[(f<<1)+23472>>1]){u[d+484417|0]=f<<4;break p}f=f+1|0;if((f|0)!=16){continue}break}}v[d+484412>>1]=64;i=x[e+53|0]|x[e+54|0]<<8|(x[e+55|0]<<16|x[e+56|0]<<24);w[g>>2]=i;f=x[e+65|0];if(f&2){j=d+484414|0;v[j>>1]=y[j>>1]|1;w[g>>2]=i>>>1}w[d+484384>>2]=x[e+57|0]|x[e+58|0]<<8|(x[e+59|0]<<16|x[e+60|0]<<24);w[d+484388>>2]=(x[e+61|0]|x[e+62|0]<<8|(x[e+63|0]<<16|x[e+64|0]<<24))-1;if(f&1){g=d+484414|0;v[g>>1]=y[g>>1]|2}q:{if(f&4){g=x[e+68|0];v[d+484410>>1]=(g>>>0>=64?64:g)<<2;break q}g=d+484414|0;v[g>>1]=y[g>>1]|32768}g=d+484408|0;if(f&8){f=d+484414|0;d=y[f>>1];i=d|288;j=d&65247|32;d=x[e+69|0];v[f>>1]=(d|0)==16?i:j;d=d>>>0>15?128:d<<4|8}else{d=128}v[g>>1]=d;h=h+1|0;f=h&65535;if(f>>>0<=y[a+480190>>1]){continue}}break}r:{if(!(c&2)){break r}d=w[e+236>>2];if(d>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<d>>>0){break r}}w[b+8>>2]=d;if(!y[a+480190>>1]){break r}f=1;while(1){d=C(f&65535,104)+a|0;h=y[d+484414>>1];u[e+11|0]=1;u[e+9|0]=1;u[e+10|0]=0;u[e+8|0]=h&1?16:8;Fd(e+8|0,d+484380|0,b);f=f+1|0;if(y[a+480190>>1]>=(f&65535)>>>0){continue}break}}m=a+484344|0;td(m,x[e+231|0]+1|0);d=77868;s:{t:{u:{v:{w:{f=$g(a);switch(f-2|0){case 1:break t;case 0:break u;case 2:break v;default:break w}}if((f|0)==16777216){break s}if((f|0)!=32){break t}d=77884;break s}d=77880;break s}d=77876;break s}d=77872}k=w[d>>2];d=x[e+227|0]|x[e+228|0]<<8|(x[e+229|0]<<16|x[e+230|0]<<24);x:{if(d>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<d>>>0){break x}}w[b+8>>2]=d}p=c&1;n=e+264|2;i=0;j=1;while(1){c=cd(b,e+8|0);c=(c?y[e+8>>1]:0)&65535;y:{if(c>>>0<3){break y}oc(e+8|0,b,c-2|0);z:{if(!p){break z}c=w[e+8>>2];d=w[w[c>>2]+8>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}if(!c){break z}w[114256]=0;c=S(216,m|0,i&65535,64)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}l=0;if(!c){break z}while(1){c=w[m>>2];w[114256]=0;c=c+C(i,52)|0;d=V(218,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}q=w[c>>2]+C(C(d,l),6)|0;A:while(1){B:{w[114256]=0;c=Q(241,e+8|0,e+88|0)|0;d=w[114256];w[114256]=0;C:{D:{if((d|0)!=1){d=c?x[e+88|0]:0;c=d&255;if(!c){break B}d=d&31;if(d>>>0>=y[a+480188>>1]){break B}g=C(d,6)+q|0;if(!(c&32)){break C}d=w[e+8>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+16>>2],2)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break D}break g}break g}E:{if(d){w[e+92>>2]=n;w[e+88>>2]=e+264;d=w[e+8>>2];f=w[w[d>>2]+32>>2];w[114256]=0;d=S(f|0,d|0,w[e+16>>2],e+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}w[e+16>>2]=d+w[e+16>>2];d=x[e+264|0];if(!d){break E}d=(d&127)-1|0;d=C((d&240)>>>4|0,12)+(d&15)|0;u[g|0]=d+13;j=((d-108&255)>>>0<136|(d-36&255)>>>0<36)&j;break E}v[e+264>>1]=0}u[g+1|0]=x[e+265|0]}if(!(c&64)){continue}u[g+2|0]=0;u[g+3|0]=0;c=g+5|0;while(1){d=w[e+8>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+16>>2],2)|0;f=w[114256];w[114256]=0;F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{if((f|0)!=1){if(!d){continue A}o=x[g+5|0];h=x[g+3|0];d=w[e+8>>2];f=w[w[d>>2]+36>>2];w[114256]=0;d=S(f|0,d|0,w[e+16>>2],2)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}Q:{if(d){w[e+92>>2]=n;w[e+88>>2]=e+264;d=w[e+8>>2];f=w[w[d>>2]+32>>2];w[114256]=0;d=S(f|0,d|0,w[e+16>>2],e+88|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}w[e+16>>2]=d+w[e+16>>2];f=x[e+265|0];break Q}v[e+264>>1]=0;f=0}u[c|0]=f;d=x[(x[e+264|0]&31)+23504|0];u[g+3|0]=d;switch(d-2|0){case 4:case 5:break J;case 18:break K;case 13:break L;case 17:break M;case 11:break N;case 1:break O;case 0:break P;default:break H}}break g}if((f&255)>>>0<224){break F}break G}if((f&255)>>>0>=224){break G}break F}u[e+88|0]=64;u[c|0]=x[((f&255)>>>0>64?e+88|0:c)|0];w[114256]=0;d=Q(340,k|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(!d){break I}u[g+2|0]=1;u[g+4|0]=x[c|0];u[g+3|0]=h;u[c|0]=o;d=h;break H}R:{switch(((f&240)>>>4|0)-8|0){case 0:u[g+3|0]=2;u[c|0]=f&15|224;break F;case 1:u[g+3|0]=3;u[c|0]=f&15|224;break F;default:break R}}w[114256]=0;d=Q(341,k|0,19)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(d){break I}w[114256]=0;X(342,g|0);d=w[114256];w[114256]=0;if((d|0)!=1){break I}break g}w[114256]=0;d=Q(341,k|0,15)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(d){break I}w[114256]=0;d=Q(341,k|0,19)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(!d){break I}u[g+3|0]=19;u[c|0]=x[c|0]&15|144;break F}if((f&255)==1){u[c|0]=145;break F}if((f&240)==128){w[114256]=0;d=Q(341,k|0,20)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(d){break I}u[g+3|0]=19;break F}u[g+3|0]=0;break F}d=f&240;if(!d){break F}u[c|0]=d}d=x[g+3|0]}if((d&255)!=20){break F}d=x[c|0];if(x[g+2|0]|(d&240)!=128){break F}u[g+2|0]=2;u[g+4|0]=(((d&15)<<6|8)>>>0)/15;u[g+3|0]=h;u[c|0]=o;break F}u[c|0]=223}if(x[e+264|0]&32){continue}break}continue}break}l=l+1|0;if((l|0)!=64){continue}break}}c=w[e+12>>2];if(!c){break y}d=w[c+4>>2];w[c+4>>2]=d-1;if(d){break y}ob[w[w[c>>2]+8>>2]](c);Ib(c)}c=x[e+231|0]>i>>>0;i=i+1|0;if(c){continue}break}break i}W(0)|0;Eb();M()}if(w[a+480180>>2]!=1){c=w[a+480208>>2]&-8454145}else{c=w[a+480208>>2]&-8454145|(y[a+480188>>1]==4&j?8454144:0)}w[a+480208>>2]=c;d=1;f=x[e+245|0]|x[e+246|0]<<8|(x[e+247|0]<<16|x[e+248|0]<<24);if(!f){break h}c=x[e+241|0]|x[e+242|0]<<8|(x[e+243|0]<<16|x[e+244|0]<<24);if(c>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<c>>>0){break h}f=x[e+245|0]|x[e+246|0]<<8|(x[e+247|0]<<16|x[e+248|0]<<24)}w[b+8>>2]=c;Jk(a+1304424|0,b,f,4)}jb=e+272|0;return d|0}d=P()|0;Bb(e+8|0);break b}d=P()|0;if(u[e+99|0]>=0){break b}zb(w[e+88>>2]);break b}d=P()|0;if(u[e+99|0]>=0){break b}zb(w[e+88>>2]);break b}d=P()|0;if(u[e+19|0]>=0){break b}zb(w[e+8>>2]);break b}d=P()|0;if(u[e+99|0]<0){zb(w[e+88>>2])}if(u[f+11|0]>=0){break b}zb(w[f>>2])}R(d|0);M()}function Es(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,y=0,z=0,E=0,F=0,G=0,H=D(0),I=0;d=jb-144|0;jb=d;e=Cb(d,0,144);w[e+76>>2]=-1;w[e+44>>2]=a;w[e+32>>2]=1702;w[e+84>>2]=a;d=b;t=c;a=0;i=jb-304|0;jb=i;a:{b:{c:{d:{if(w[e+4>>2]){break d}vm(e);if(w[e+4>>2]){break d}break c}b=x[d|0];if(!b){break a}e:{f:{g:{h:{while(1){i:{j:{if(mf(b&255)){while(1){b=d;d=d+1|0;if(mf(x[b+1|0])){continue}break}ce(e,0,0);while(1){c=w[e+4>>2];k:{if((c|0)!=w[e+104>>2]){w[e+4>>2]=c+1;c=x[c|0];break k}c=ac(e)}if(mf(c)){continue}break}d=w[e+4>>2];c=w[e+116>>2];if((c|0)>0|(c|0)>=0){d=d-1|0;w[e+4>>2]=d}c=d-w[e+44>>2]|0;d=c>>31;h=c;g=n+w[e+124>>2]|0;c=m+w[e+120>>2]|0;g=c>>>0<m>>>0?g+1|0:g;f=c;c=h+c|0;g=d+g|0;m=c;n=c>>>0<f>>>0?g+1|0:g;break j}l:{m:{n:{if(x[d|0]==37){b=x[d+1|0];if((b|0)==42){break n}if((b|0)!=37){break m}}ce(e,0,0);o:{if(x[d|0]==37){while(1){b=w[e+4>>2];p:{if((b|0)!=w[e+104>>2]){w[e+4>>2]=b+1;b=x[b|0];break p}b=ac(e)}if(mf(b)){continue}break}d=d+1|0;break o}b=w[e+4>>2];if((b|0)!=w[e+104>>2]){w[e+4>>2]=b+1;b=x[b|0];break o}b=ac(e)}if(x[d|0]!=(b|0)){c=w[e+116>>2];if((c|0)>0|(c|0)>=0){w[e+4>>2]=w[e+4>>2]-1}if((b|0)>=0){break a}h=0;if(y){break a}break c}b=w[e+4>>2]-w[e+44>>2]|0;f=b>>31;h=b;c=n+w[e+124>>2]|0;b=m+w[e+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;g=b;b=h+b|0;h=c+f|0;m=b;n=b>>>0<g>>>0?h+1|0:h;b=d;break j}k=0;b=d+2|0;break l}if(!(!Wd(b)|x[d+2|0]!=36)){b=x[d+1|0]-48|0;c=jb-16|0;w[c+12>>2]=t;b=(b>>>0>1?(b<<2)-4|0:0)+t|0;w[c+8>>2]=b+4;k=w[b>>2];b=d+3|0;break l}k=w[t>>2];t=t+4|0;b=d+1|0}s=0;d=0;if(Wd(x[b|0])){while(1){d=(x[b|0]+C(d,10)|0)-48|0;c=x[b+1|0];b=b+1|0;if(Wd(c)){continue}break}}o=x[b|0];if((o|0)==109){p=0;s=(k|0)!=0;o=x[b+1|0];a=0;b=b+1|0}c=b;b=c+1|0;f=3;h=s;q:{r:{switch(o-65|0){case 39:f=c+2|0;c=x[c+1|0]==104;b=c?f:b;f=c?-2:-1;break q;case 43:f=c+2|0;c=x[c+1|0]==108;b=c?f:b;f=c?3:1;break q;case 51:case 57:f=1;break q;case 11:f=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}f=0;b=c}h=f;c=x[b|0];f=(c&47)==3;z=f?1:h;q=f?c|32:c;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}d=(d|0)<=1?1:d;break s}Fs(k,z,m,n);break j}ce(e,0,0);while(1){c=w[e+4>>2];u:{if((c|0)!=w[e+104>>2]){w[e+4>>2]=c+1;c=x[c|0];break u}c=ac(e)}if(mf(c)){continue}break}c=w[e+4>>2];f=w[e+116>>2];if((f|0)>0|(f|0)>=0){c=c-1|0;w[e+4>>2]=c}c=c-w[e+44>>2]|0;f=c>>31;j=c;g=n+w[e+124>>2]|0;c=m+w[e+120>>2]|0;g=c>>>0<m>>>0?g+1|0:g;h=c;c=j+c|0;n=f+g|0;n=c>>>0<h>>>0?n+1|0:n;m=c}j=d;l=d>>31;ce(e,d,l);c=w[e+4>>2];v:{if((c|0)!=w[e+104>>2]){w[e+4>>2]=c+1;break v}if((ac(e)|0)<0){break f}}c=w[e+116>>2];if((c|0)>0|(c|0)>=0){w[e+4>>2]=w[e+4>>2]-1}c=16;w:{x:{y:{z:{A:{switch(q-88|0){default:c=q-65|0;if(c>>>0>6|!(1<<c&113)){break w}case 9:case 13:case 14:case 15:Is(i+8|0,e,z,0);c=w[e+4>>2]-w[e+44>>2]|0;if(w[e+120>>2]!=(0-c|0)|w[e+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Cb(i+32|0,-1,257);u[i+32|0]=0;if((q|0)!=115){break x}u[i+65|0]=0;u[i+46|0]=0;v[i+42>>1]=0;v[i+44>>1]=0;break x}f=x[b+1|0];g=(f|0)==94;Cb(i+32|0,g,257);u[i+32|0]=0;c=g?b+2|0:b+1|0;B:{C:{D:{b=x[(g?2:1)+b|0];if((b|0)!=45){if((b|0)==93){break D}f=(f|0)!=94;b=c;break B}f=(f|0)!=94;u[i+78|0]=f;break C}f=(f|0)!=94;u[i+126|0]=f}b=c+1|0}while(1){c=x[b|0];E:{if((c|0)!=45){if(!c){break f}if((c|0)==93){break x}break E}c=45;g=x[b+1|0];if(!g|(g|0)==93){break E}h=b+1|0;b=x[b-1|0];F:{if(g>>>0<=b>>>0){c=g;break F}while(1){b=b+1|0;u[b+(i+32|0)|0]=f;c=x[h|0];if(c>>>0>b>>>0){continue}break}}b=h}u[(c+i|0)+33|0]=f;b=b+1|0;continue};case 23:c=8;break z;case 12:case 29:c=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}c=0}j=0;g=0;f=0;h=0;o=0;E=jb-16|0;jb=E;G:{if(!((c|0)!=1&c>>>0<=36)){w[114084]=28;break G}while(1){d=w[e+4>>2];H:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break H}d=ac(e)}if(mf(d)){continue}break}I:{J:{switch(d-43|0){case 0:case 2:break J;default:break I}}o=(d|0)==45?-1:0;d=w[e+4>>2];if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break I}d=ac(e)}K:{L:{M:{N:{if(!((c|0)!=0&(c|0)!=16|(d|0)!=48)){d=w[e+4>>2];O:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break O}d=ac(e)}if((d&-33)==88){c=16;d=w[e+4>>2];P:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break P}d=ac(e)}if(x[d+61009|0]<16){break M}c=w[e+116>>2];if((c|0)>0|(c|0)>=0){w[e+4>>2]=w[e+4>>2]-1}ce(e,0,0);break G}if(c){break N}c=8;break M}c=c?c:10;if(c>>>0>x[d+61009|0]){break N}c=w[e+116>>2];if((c|0)>0|(c|0)>=0){w[e+4>>2]=w[e+4>>2]-1}ce(e,0,0);w[114084]=28;break G}if((c|0)!=10){break M}f=d-48|0;if(f>>>0<=9){c=0;while(1){c=C(c,10)+f|0;h=c>>>0<429496729;d=w[e+4>>2];Q:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break Q}d=ac(e)}f=d-48|0;if(h&f>>>0<=9){continue}break}j=c}R:{if(f>>>0>9){break R}l=BV(j,0,10,0);h=nb;c=f;while(1){d=w[e+4>>2];S:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break S}d=ac(e)}f=d-48|0;r=f>>>0>9;g=h;j=c+l|0;g=j>>>0<c>>>0?g+1|0:g;if((g|0)==429496729&j>>>0>=2576980378|g>>>0>429496729|r){break R}l=BV(j,g,10,0);h=nb;c=f;if((h|0)==-1&l>>>0<=(c^-1)>>>0|(h|0)!=-1){continue}break}c=10;break L}c=10;if(f>>>0<=9){break L}break K}if(c-1&c){h=x[d+61009|0];if(h>>>0<c>>>0){while(1){f=C(c,f)+h|0;j=f>>>0<119304647;d=w[e+4>>2];T:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break T}d=ac(e)}h=x[d+61009|0];if(j&h>>>0<c>>>0){continue}break}j=f}if(c>>>0<=h>>>0){break L}while(1){l=BV(j,g,c,0);f=nb;h=h&255;if((f|0)==-1&(h^-1)>>>0<l>>>0){break L}d=h+l|0;g=d>>>0<h>>>0?f+1|0:f;j=d;d=w[e+4>>2];U:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break U}d=ac(e)}h=x[d+61009|0];if(c>>>0<=h>>>0){break L}Rc(E,c,0,0,0,j,g,0,0);if(!(w[E+8>>2]|w[E+12>>2])){continue}break}break L}l=u[(C(c,23)>>>5&7)+61265|0];f=x[d+61009|0];if(f>>>0<c>>>0){while(1){h=h<<l|f;j=h>>>0<134217728;d=w[e+4>>2];V:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break V}d=ac(e)}f=x[d+61009|0];if(j&f>>>0<c>>>0){continue}break}j=h}if(c>>>0<=f>>>0){break L}h=l;r=h&31;if((h&63)>>>0>=32){h=0;r=-1>>>r|0}else{h=-1>>>r|0;r=h|(1<<r)-1<<32-r}if(!h&j>>>0>r>>>0){break L}while(1){F=f&255;f=j;d=l&31;if((l&63)>>>0>=32){g=f<<d;d=0}else{g=(1<<d)-1&f>>>32-d|g<<d;d=f<<d}j=F|d;d=w[e+4>>2];W:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break W}d=ac(e)}f=x[d+61009|0];if(c>>>0<=f>>>0){break L}if((g|0)==(h|0)&j>>>0<=r>>>0|g>>>0<h>>>0){continue}break}}if(x[d+61009|0]>=c>>>0){break K}while(1){d=w[e+4>>2];X:{if((d|0)!=w[e+104>>2]){w[e+4>>2]=d+1;d=x[d|0];break X}d=ac(e)}if(x[d+61009|0]<c>>>0){continue}break}w[114084]=68;o=0;j=-1;g=-1}c=w[e+116>>2];if((c|0)>0|(c|0)>=0){w[e+4>>2]=w[e+4>>2]-1}if(!(o|1)&(g&j)==-1){w[114084]=68;j=-2;g=-1;break G}c=o;d=c^j;j=d-c|0;f=c>>31;g=(f^g)-((c>>>0>d>>>0)+f|0)|0}jb=E+16|0;c=w[e+4>>2]-w[e+44>>2]|0;if(w[e+120>>2]==(0-c|0)&w[e+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break g}if(!(!k|(q|0)!=112)){w[k>>2]=j;break w}Fs(k,z,j,g);break w}if(!k){break w}c=w[i+16>>2];d=w[i+20>>2];f=w[i+8>>2];g=w[i+12>>2];Y:{switch(z|0){case 0:G=k,H=Gs(f,g,c,d),A[G>>2]=H;break w;case 1:G=k,I=xm(f,g,c,d),B[G>>3]=I;break w;case 2:break Y;default:break w}}w[k>>2]=f;w[k+4>>2]=g;w[k+8>>2]=c;w[k+12>>2]=d;break w}o=(q|0)==99;f=o?d+1|0:31;Z:{if((z|0)==1){c=k;if(s){c=fc(f<<2);if(!c){break h}}w[i+296>>2]=0;w[i+300>>2]=0;d=0;while(1){a=c;_:{while(1){c=w[e+4>>2];$:{if((c|0)!=w[e+104>>2]){w[e+4>>2]=c+1;c=x[c|0];break $}c=ac(e)}if(!x[(c+i|0)+33|0]){break _}u[i+27|0]=c;c=Rh(i+28|0,i+27|0,1,i+296|0);if((c|0)==-2){continue}p=0;if((c|0)==-1){break f}if(a){w[(d<<2)+a>>2]=w[i+28>>2];d=d+1|0}if(!((d|0)==(f|0)&s)){continue}break}h=1;f=f<<1|1;c=Hj(a,f<<2);if(c){continue}break e}break}p=0;f=a;if(i+296|0?w[i+296>>2]:0){break f}break Z}if(s){d=0;c=fc(f);if(!c){break h}while(1){a=c;while(1){c=w[e+4>>2];aa:{if((c|0)!=w[e+104>>2]){w[e+4>>2]=c+1;c=x[c|0];break aa}c=ac(e)}if(!x[(c+i|0)+33|0]){f=0;p=a;break Z}u[a+d|0]=c;d=d+1|0;if((f|0)!=(d|0)){continue}break}h=1;f=f<<1|1;c=Hj(a,f);if(c){continue}break}p=a;a=0;break e}d=0;if(k){while(1){a=w[e+4>>2];ba:{if((a|0)!=w[e+104>>2]){w[e+4>>2]=a+1;a=x[a|0];break ba}a=ac(e)}if(x[(a+i|0)+33|0]){u[d+k|0]=a;d=d+1|0;continue}else{f=0;a=k;p=a;break Z}}}while(1){a=w[e+4>>2];ca:{if((a|0)!=w[e+104>>2]){w[e+4>>2]=a+1;a=x[a|0];break ca}a=ac(e)}if(x[(a+i|0)+33|0]){continue}break}a=0;p=0;f=0}c=w[e+4>>2];g=w[e+116>>2];if((g|0)>0|(g|0)>=0){c=c-1|0;w[e+4>>2]=c}g=c-w[e+44>>2]|0;h=g;c=g+w[e+120>>2]|0;g=w[e+124>>2]+(g>>31)|0;g=c>>>0<h>>>0?g+1|0:g;if(!(g|c)|((c|0)!=(j|0)|(g|0)!=(l|0))&(q|0)==99){break i}if(s){w[k>>2]=a}da:{if(o){break da}if(f){w[(d<<2)+f>>2]=0}if(!p){p=0;break da}u[d+p|0]=0}a=f}c=w[e+4>>2]-w[e+44>>2]|0;f=c>>31;j=c;c=n+w[e+124>>2]|0;d=m+w[e+120>>2]|0;c=d>>>0<m>>>0?c+1|0:c;h=d;d=j+d|0;g=c+f|0;m=d;n=d>>>0<h>>>0?g+1|0:g;y=((k|0)!=0)+y|0}d=b+1|0;b=x[b+1|0];if(b){continue}break a}break}a=f;break g}h=1;p=0;a=0;break e}h=s;break b}h=s}if(y){break b}}y=-1}if(!h){break a}zb(p);zb(a)}jb=i+304|0;jb=e+144|0;return y}function HD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-1312|0;jb=d;w[b+8>>2]=0;f=jb-16|0;jb=f;h=w[b+8>>2];g=w[b>>2];i=d+728|0;w[f+8>>2]=i;w[f+12>>2]=i+576;h=ob[w[w[g>>2]+32>>2]](g,h,f+8|0)|0;if((h|0)==576){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],576)|0){g=w[b+8>>2]+576|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{c:{if((h|0)!=576){break c}if(!Vp(d+728|0)){break c}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],(C(y[d+764>>1],384)+(y[d+762>>1]<<2)|0)+256|0)|0)){break c}if(!c){e=1;break c}q=1;f=0;d:{while(1){g=(e<<5)+a|0;h=g+480280|0;Qd(h);i=(d+728|0)+(e<<4)|0;v[g+480284>>1]=((x[i+78|0]<<8&65280)>>>0)/255;l=d+80|0;Vb(l,1,i- -64|0,12);w[114256]=0;w[d+468>>2]=20;w[d+464>>2]=g+480289;Q(200,d+464|0,l|0)|0;g=w[114256];w[114256]=0;e:{f:{g:{h:{if((g|0)!=1){if(u[d+91|0]<0){zb(w[d+80>>2])}switch(x[i+79|0]){case 2:break f;case 1:break g;case 0:break h;default:break d}}e=P()|0;if(u[d+91|0]>=0){break b}zb(w[d+80>>2]);break b}j=e+1|0;break e}w[h>>2]=1024;j=f+1|0;break e}w[h>>2]=1024;k=1<<e|k}q=e>>>0<31;f=f+1|0;e=e+1|0;if((e|0)!=32){continue}break}tc(a,33554432);v[a+480188>>1]=j&255;e=a+1304436|0;f=Hb(d+80|0,3098);if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];e=a+1304448|0;f=Hb(d+80|0,6974);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];w[a+1304496>>2]=4;i:{if(x[d+807|0]){break i}h=1;while(1){if(x[((h<<4)+d|0)+807|0]!=1){break i}e=1;h=h+1|0;if((h|0)!=16){continue}break}while(1){f=((e<<5)+a|0)+480280|0;w[f>>2]=w[f>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}Vb(d+80|0,1,d+728|0,32);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+84>>2];w[e>>2]=w[d+80>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+88>>2];w[a+480208>>2]=w[a+480208>>2]&-17|y[d+766>>1]<<4&16;w[a+480196>>2]=x[d+776|0];w[a+480204>>2]=C(x[d+777|0],1e4);w[a+480200>>2]=x[d+778|0]<<2;w[a+480228>>2]=x[d+779|0];e=y[d+764>>1];v[a+480190>>1]=0;v[a+480192>>1]=e;e=d+464|0;ll(b,e);Pf(w[a+484360>>2]+(x[a+484376|0]<<5)|0,e,y[d+760>>1],65535,255);o=c&1;if(o){td(a+484344|0,y[d+762>>1])}j:{if(!y[d+762>>1]){break j}l=a+484344|0;e=d+1304|0;p=e|2;r=e|4;j=0;while(1){k:{e=d+80|0;f=cd(b,e);g=y[d+80>>1];h=cd(b,e);i=y[d+80>>1];oc(e,b,f?g-4|0:-4);l:{if(!o){break l}w[114256]=0;m=h?i:0;e=S(216,l|0,j&65535,m|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break k}if(!e){break l}h=0;v[d+4>>1]=0;w[d>>2]=0;if(!m){break l}while(1){w[114256]=0;e=Q(241,d+80|0,d+16|0)|0;f=w[114256];w[114256]=0;m:{n:{if((f|0)!=1){if(e){g=x[d+16|0];if(g){break n}}h=h+1|0;break m}break k}e=d;n=g&31;if(n>>>0<y[a+480188>>1]){e=w[l>>2];w[114256]=0;e=e+C(j,52)|0;f=V(218,e|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break k}e=w[e>>2]+C(n+C(f,h)|0,6)|0}o:{if(!(g&32)){break o}f=w[d+80>>2];i=w[w[f>>2]+36>>2];w[114256]=0;f=S(i|0,f|0,w[d+88>>2],2)|0;i=w[114256];w[114256]=0;if((i|0)==1){break k}p:{q:{if(f){w[d+20>>2]=p;w[d+16>>2]=d+1304;f=w[d+80>>2];i=w[w[f>>2]+32>>2];w[114256]=0;f=S(i|0,f|0,w[d+88>>2],d+16|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break k}w[d+88>>2]=f+w[d+88>>2];f=x[d+1304|0];u[e|0]=f;u[e+1|0]=x[d+1305|0];i=255;if((f|0)==160){break p}if((f|0)!=255){break q}i=0;break p}f=0;v[d+1304>>1]=0;u[e|0]=0;u[e+1|0]=x[d+1305|0]}f=C(f>>>4|0,12)+(f&15)|0;i=(f&255)>>>0<108?f+13|0:0}u[e|0]=i}f=g&192;r:{if(!f){break r}s:{t:{if((f|0)==192){f=w[d+80>>2];g=w[w[f>>2]+36>>2];w[114256]=0;f=S(g|0,f|0,w[d+88>>2],4)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}u:{v:{if(f){w[d+20>>2]=r;w[d+16>>2]=d+1304;f=w[d+80>>2];g=w[w[f>>2]+32>>2];w[114256]=0;f=S(g|0,f|0,w[d+88>>2],d+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}w[d+88>>2]=f+w[d+88>>2];f=x[d+1304|0];if((f|0)==12){f=x[d+1305|0];u[e+2|0]=1;u[e+4|0]=f>>>0>=64?64:f;u[e+3|0]=x[d+1306|0];break u}g=x[d+1306|0];if((g|0)==12){break t}if((f|0)==10){f=x[d+1305|0];u[e+2|0]=2;u[e+4|0]=(f<<6>>>0)/255;u[e+3|0]=x[d+1306|0];break u}if((g|0)!=10){break v}g=x[d+1307|0];u[e+3|0]=f;u[e+2|0]=2;u[e+4|0]=(g<<6>>>0)/255;g=x[d+1305|0];break s}g=0;w[d+1304>>2]=0}u[e+3|0]=g}g=x[d+1307|0];break s}f=w[d+80>>2];g=w[w[f>>2]+36>>2];w[114256]=0;i=S(g|0,f|0,w[d+88>>2],2)|0;f=w[114256];w[114256]=0;w:{if((f|0)==1){break w}g=0;f=0;if(i){w[d+20>>2]=p;w[d+16>>2]=d+1304;f=w[d+80>>2];g=w[w[f>>2]+32>>2];w[114256]=0;f=S(g|0,f|0,w[d+88>>2],d+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break w}w[d+88>>2]=f+w[d+88>>2];g=x[d+1305|0];f=x[d+1304|0]}u[e+5|0]=g;u[e+3|0]=f;break r}break k}g=x[d+1305|0];i=x[d+1307|0];u[e+3|0]=f;u[e+2|0]=1;u[e+4|0]=i>>>0>=64?64:i}u[e+5|0]=g}x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{g=x[e+3|0];switch(g-14|0){case 2:case 3:case 4:case 5:case 10:case 11:case 12:case 13:case 14:case 15:case 16:case 18:break C;case 19:break D;case 17:break E;case 9:break F;case 8:break G;case 6:case 7:break H;case 1:break I;case 0:break J;default:break K}}if(g){break C}f=g;break x}f=x[e+5|0];if((f|0)==240){break B}L:{if((f|0)!=15){if(f){break L}f=11;u[e+3|0]=11;break x}u[e+5|0]=254;break A}if(f>>>0>=16){u[e+5|0]=f|15;break A}u[e+5|0]=f|240;break A}u[e+5|0]=x[e+5|0]>>>4|32;g=15;break z}f=x[e+5|0];if(f>>>0>=16){u[e+5|0]=f>>>4|240;break z}u[e+5|0]=f|224;break z}u[e+5|0]=((x[e+5|0]^-1)&254)>>>1;g=22;break z}u[e+5|0]=x[e+5|0]&15|128;g=23;break z}f=x[e+5|0]<<1;u[e+5|0]=f>>>0>=255?255:f;g=31;break z}f=32;g=33;M:{N:{O:{P:{Q:{R:{S:{T:{i=x[e+5|0];switch(i>>>4|0){case 0:break z;case 3:break M;case 5:break N;case 14:break O;case 12:case 13:break P;case 11:break Q;case 10:break R;case 8:break S;default:break T}}g=0;break z}f=64;break M}f=176;break M}f=224;break M}g=i?33:0;break z}U:{switch(i&15){case 0:case 1:u[e+5|0]=119;break z;case 2:u[e+5|0]=121;break z;case 3:break U;default:break z}}u[e+5|0]=123;break z}f=48}u[e+5|0]=i&15|f;break z}if(g>>>0<36){break y}f=0;u[e+3|0]=0;break x}u[e+5|0]=239}g=14}f=x[g+23536|0];u[e+3|0]=f;break x}f=x[g+23536|0];u[e+3|0]=f;if(x[e+2|0]|(g|0)!=12){break x}u[e+2|0]=1;u[e+3|0]=0;g=x[e+5|0];f=0;u[e+5|0]=0;u[e+4|0]=g}if(!(k>>>n&1)){break m}g=x[e+5|0];w[114256]=0;f=Q(273,f&255,g|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}if(!f){break m}u[e+3|0]=0}if(h>>>0<m>>>0){continue}break}}e=w[d+84>>2];V:{if(!e){break V}f=w[e+4>>2];w[e+4>>2]=f-1;if(f){break V}ob[w[w[e>>2]+8>>2]](e);Ib(e)}j=j+1|0;if(j>>>0<y[d+762>>1]){continue}break j}break}e=P()|0;Bb(d+80|0);break b}if(!y[a+480192>>1]){break d}l=c&2;g=0;f=1;while(1){g=g+1|0;p=g&65535;c=wn(a,p,0);e=jb-16|0;jb=e;j=w[b+8>>2];h=w[b>>2];i=d+80|0;w[e+8>>2]=i;w[e+12>>2]=i+384;j=ob[w[w[h>>2]+32>>2]](h,j,e+8|0)|0;if((j|0)==384){h=w[b>>2];W:{if(ob[w[w[h>>2]+36>>2]](h,w[b+8>>2],384)|0){i=w[b+8>>2]+384|0;break W}h=w[b>>2];i=ob[w[w[h>>2]+24>>2]](h)|0}w[b+8>>2]=i}jb=e+16|0;if(!(!c|(j|0)!=384)){i=f&65535;e=jb-32|0;jb=e;j=e+8|0;h=d+80|0;Vb(j,1,h,32);w[114256]=0;w[e+28>>2]=32;w[e+24>>2]=c+492;Q(200,e+24|0,j|0)|0;j=w[114256];w[114256]=0;X:{if((j|0)!=1){if(u[e+19|0]<0){zb(w[e+8>>2])}if(x[h+378|0]|x[h+379|0]<<8){k=c+236|0;j=0;while(1){v[(k+(j<<1)|0)+24>>1]=i+x[(h+j|0)+32|0];j=j+1|0;if((j|0)!=116){continue}break}}w[c>>2]=x[h+376|0]|x[h+377|0]<<8;Yk(h,c+48|0,0);Yk(h,c+68|0,1);Yk(h,c+88|0,2);h=x[c+100|0];if(h&1){u[c+100|0]=h|16}if(!(w[c>>2]|u[c+60|0]&1)){w[c>>2]=32767}jb=e+32|0;break X}a=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}R(a|0);M()}h=0;if(y[d+458>>1]){e=0;while(1){if(!xh(b,d+16|0)){Cb(d+16|0,0,64)}Y:{if((x[d+76|0]|x[d+77|0]<<8|(x[d+78|0]<<16|x[d+79|0]<<24))!=808538953){break Y}c=e+f|0;i=c&65535;if(i>>>0>3999){break Y}v[a+480190>>1]=c;j=jb-32|0;jb=j;k=C(i,104)+a|0;c=k+484380|0;lc(c,0);h=j+8|0;Vb(h,1,d+16|0,13);w[114256]=0;w[j+28>>2]=22;w[j+24>>2]=c+43;Q(200,j+24|0,h|0)|0;h=w[114256];w[114256]=0;Z:{if((h|0)!=1){if(u[j+19|0]<0){zb(w[j+8>>2])}m=x[d+32|0]|x[d+33|0]<<8|(x[d+34|0]<<16|x[d+35|0]<<24);w[c>>2]=m;n=x[d+36|0]|x[d+37|0]<<8|(x[d+38|0]<<16|x[d+39|0]<<24);w[c+4>>2]=n;o=x[d+40|0]|x[d+41|0]<<8|(x[d+42|0]<<16|x[d+43|0]<<24);w[c+8>>2]=o;w[c+24>>2]=x[d+44|0]|x[d+45|0]<<8|(x[d+46|0]<<16|x[d+47|0]<<24);v[c+30>>1]=x[d+48|0]<<2;v[c+28>>1]=x[d+49|0];h=x[d+64|0];if(h&1){v[c+34>>1]=y[c+34>>1]|2;h=x[d+64|0]}if(h&2){v[c+34>>1]=y[c+34>>1]|4;h=x[d+64|0]}if(h&4){w[c+8>>2]=o>>>1;w[c+4>>2]=n>>>1;w[c>>2]=m>>>1;v[c+34>>1]=y[c+34>>1]|1;h=x[d+64|0]}if(h&8){v[c+34>>1]=y[c+34>>1]|32}jb=j+32|0;break Z}a=P()|0;if(u[j+19|0]<0){zb(w[j+8>>2])}R(a|0);M()}w[d+1308>>2]=22;w[d+1304>>2]=k+484423;h=d+1304|0;bj(d,h);w[114256]=0;w[d+1308>>2]=32;w[d+1304>>2]=((i<<5)+a|0)+946304;Q(200,h|0,d|0)|0;h=w[114256];w[114256]=0;_:{if((h|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}h=w[d+32>>2];if(!h){break Y}oc(d,b,h);if(!l){break _}h=y[k+484414>>1];w[114256]=0;u[d+1307|0]=0;u[d+1305|0]=1;u[d+1306|0]=0;u[d+1304|0]=h&1?16:8;S(214,d+1304|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break _}e=P()|0;Bb(d);break b}e=P()|0;if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}c=w[d+4>>2];if(!c){break Y}h=w[c+4>>2];w[c+4>>2]=h-1;if(h){break Y}ob[w[w[c>>2]+8>>2]](c);Ib(c)}e=e+1|0;h=y[d+458>>1];if(e>>>0<h>>>0){continue}break}}f=f+h|0}if(p>>>0<y[a+480192>>1]){continue}break}}e=!q}jb=d+1312|0;return e&1}R(e|0);M()}function jK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-160|0;jb=e;w[b+8>>2]=0;g=w[a+4>>2];f=w[a>>2];if((g|0)!=(f|0)){while(1){g=g-32|0;Tg(g);if((f|0)!=(g|0)){continue}break}}w[a+4>>2]=f;a:{if(!Sl(b,e+120|0)){break a}if(!vw(e+120|0)){break a}d=0;m=jb-16|0;jb=m;i=ec(8925);b:{if(!i){break b}h=w[b+8>>2];g=x[e+136|0]|x[e+137|0]<<8|(x[e+138|0]<<16|x[e+139|0]<<24);c:{if(h>>>0<g>>>0){f=w[b>>2];d=0;if(ob[w[w[f>>2]+24>>2]](f)>>>0<g>>>0){break c}}w[b+8>>2]=g;d:{if(!(x[e+132|0]|x[e+133|0]<<8|(x[e+134|0]<<16|x[e+135|0]<<24))){break d}while(1){d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],4)|0)){break d}e:{if((x[e+124|0]|x[e+125|0]<<8)>>>0>=64){if((_d(b)|0)<=0){break e}}d=0;f=1;f:{if(!Xb(b,m+15|0)){g=1;break f}g=1;k=x[m+15|0];if(!k){break f}while(1){n=d>>>0>=i>>>0;g=n&f;o=wo(k<<24>>24);g=n|!(f&1)?g:x[d+8925|0]==(o&255);d=d+1|0;if(!Xb(b,m+15|0)){break f}f=g;k=x[m+15|0];if(k){continue}break}}l=(d|0)==(i|0)?g?1:l:l;d=w[b>>2];g:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],4)|0){d=w[b+8>>2]+4|0;break g}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d}j=j+1|0;if(j>>>0<(x[e+132|0]|x[e+133|0]<<8|(x[e+134|0]<<16|x[e+135|0]<<24))>>>0){continue}break}}d=l&1}if(h>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<h>>>0){break b}}w[b+8>>2]=h}jb=m+16|0;if(!d){break a}if(!c){p=1;break a}l=0;h=jb-48|0;jb=h;i=e+104|0;w[i+8>>2]=0;w[i>>2]=0;w[i+4>>2]=0;h:{i:{j:{k:{l:{f=x[e+136|0]|x[e+137|0]<<8|(x[e+138|0]<<16|x[e+139|0]<<24);if(f>>>0>z[b+8>>2]){d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break l}if(d>>>0<f>>>0){break h}}w[b+8>>2]=f;f=x[e+132|0]|x[e+133|0]<<8|(x[e+134|0]<<16|x[e+135|0]<<24);d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break j}c=w[b+8>>2];w[114256]=0;c=(d-c>>>0)/5|0;n=c>>>0<f>>>0?c:f;T(918,i|0,n|0);c=w[114256];w[114256]=0;if((c|0)==1){break k}if(!n){break h}g=i+8|0;m:{while(1){f=w[b+8>>2];d=w[b>>2];c=w[w[d>>2]+36>>2];w[114256]=0;d=S(c|0,d|0,f|0,5)|0;c=w[114256];w[114256]=0;n:{if((c|0)!=1){if(d){break n}break h}f=P()|0;break i}c=x[e+124|0]|x[e+125|0]<<8;w[114256]=0;U(919,h+8|0,b|0,c|0);c=w[114256];w[114256]=0;if((c|0)!=1){f=w[i+4>>2];d=w[i+8>>2];o:{if(f>>>0<d>>>0){c=w[h+12>>2];w[f>>2]=w[h+8>>2];w[f+4>>2]=c;w[f+8>>2]=w[h+16>>2];w[i+4>>2]=f+12;break o}c=w[i>>2];f=(f-c|0)/12|0;j=f+1|0;if(j>>>0>=357913942){w[114256]=0;X(920,i|0);a=w[114256];w[114256]=0;if((a|0)==1){break m}M()}w[114256]=0;d=(d-c|0)/12|0;c=d<<1;o=Z(921,h+24|0,(d>>>0>=178956970?357913941:c>>>0>j>>>0?c:j)|0,f|0,g|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break m}c=w[h+12>>2];d=w[h+32>>2];w[d>>2]=w[h+8>>2];w[d+4>>2]=c;w[d+8>>2]=w[h+16>>2];w[h+16>>2]=0;w[h+8>>2]=0;w[h+12>>2]=0;k=w[h+32>>2]+12|0;w[h+32>>2]=k;j=w[h+28>>2];f=w[i+4>>2];d=w[i>>2];p:{if((f|0)==(d|0)){c=d;break p}while(1){f=f-12|0;c=w[f+4>>2];j=j-12|0;w[j>>2]=w[f>>2];w[j+4>>2]=c;w[j+8>>2]=w[f+8>>2];w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;j=w[h+28>>2]-12|0;w[h+28>>2]=j;if((d|0)!=(f|0)){continue}break}d=w[i+4>>2];k=w[h+32>>2];c=w[i>>2]}w[i>>2]=j;w[h+28>>2]=c;w[i+4>>2]=k;w[h+32>>2]=d;d=w[i+8>>2];w[i+8>>2]=w[h+36>>2];w[h+36>>2]=d;w[o>>2]=c;sc(o);if(u[h+19|0]>=0){break o}zb(w[h+8>>2])}l=l+1|0;if((n|0)!=(l|0)){continue}break h}break}f=P()|0;break i}f=P()|0;if(u[h+19|0]>=0){break i}zb(w[h+8>>2]);break i}f=P()|0;break i}f=P()|0;break i}f=P()|0}bc(i);R(f|0);M()}jb=h+48|0;q:{r:{s:{t:{u:{v:{w:{x:{y:{f=w[e+152>>2];if(f>>>0>z[b+8>>2]){d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break y}if(d>>>0<f>>>0){break q}}w[b+8>>2]=f;w[e+96>>2]=0;w[e+88>>2]=0;w[e+92>>2]=0;d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;f=w[e+148>>2];d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break x}c=w[b+8>>2];w[114256]=0;c=d-c>>>2|0;j=c>>>0<f>>>0?c:f;T(182,e+88|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break v}if(!j){break w}c=0;while(1){g=w[b+8>>2];f=w[b>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,g|0,4)|0;d=w[114256];w[114256]=0;z:{if((d|0)!=1){if(f){break z}break w}g=P()|0;break u}w[114256]=0;g=Q(183,b|0,y[e+124>>1])|0;d=w[114256];w[114256]=0;A:{if((d|0)!=1){f=w[e+104>>2];d=w[e+108>>2];w[e+24>>2]=g;if(g>>>0>=(d-f|0)/12>>>0){break A}d=w[e+92>>2];if((d|0)!=w[e+96>>2]){w[d>>2]=g;w[e+92>>2]=d+4;break A}w[114256]=0;T(184,e+88|0,e+24|0);d=w[114256];w[114256]=0;if((d|0)!=1){break A}}g=P()|0;break u}c=c+1|0;if((j|0)!=(c|0)){continue}break}break w}g=P()|0;break t}g=P()|0;break u}f=w[e+144>>2];if(f>>>0>z[b+8>>2]){d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break v}if(d>>>0<f>>>0){break r}}w[b+8>>2]=f;if(!w[e+140>>2]){break s}c=0;B:{C:{D:{E:{F:{G:{H:{while(1){g=w[b+8>>2];f=w[b>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,g|0,4)|0;d=w[114256];w[114256]=0;I:{if((d|0)!=1){if(f){break I}break s}g=P()|0;break u}w[114256]=0;ia(185,b|0,e+84|0,e+80|0,e+76|0,e+72|0,y[e+124>>1]);d=w[114256];w[114256]=0;if((d|0)==1){break F}J:{K:{if(w[e+76>>2]<=0){break K}d=w[e+84>>2];if((d|0)>=0){break K}f=d^-1;w[e+84>>2]=f;d=w[e+88>>2];if(f>>>0>=w[e+92>>2]-d>>2>>>0){break K}f=w[e+104>>2]+C(w[d+(f<<2)>>2],12)|0;d=x[f+11|0];if(((d<<24>>24<0?w[f+4>>2]:d)|0)!=5){break K}w[114256]=0;f=da(186,f|0,0,-1,8925,5)|0;d=w[114256];w[114256]=0;if((d|0)==1){break E}if(f){break K}w[114256]=0;Y(130,e+56|0,b|0,w[e+80>>2],w[e+76>>2]);d=w[114256];w[114256]=0;if((d|0)==1){break D}f=w[e+56>>2];d=w[w[f>>2]+8>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}if(f){d=y[e+124>>1];if(d>>>0<=39){f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}L:{if(f){g=w[e+64>>2]+8|0;break L}f=w[e+56>>2];d=w[w[f>>2]+24>>2];w[114256]=0;g=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}}w[e+64>>2]=g;d=y[e+124>>1]}if((d&65535)>>>0<=59){f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],16)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}M:{if(f){g=w[e+64>>2]+16|0;break M}f=w[e+56>>2];d=w[w[f>>2]+24>>2];w[114256]=0;g=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}}w[e+64>>2]=g}w[114256]=0;V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}N:{O:{P:{d=y[e+124>>1];if(d>>>0>=120){w[114256]=0;V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}if(!f){break P}g=w[e+64>>2]+8|0;break O}if(d>>>0>=100){f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}Q:{if(f){g=w[e+64>>2]+4|0;break Q}f=w[e+56>>2];d=w[w[f>>2]+24>>2];w[114256]=0;g=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}}w[114256]=0;w[e+64>>2]=g;V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}if(!f){break P}g=w[e+64>>2]+4|0;break O}if(d>>>0>=62){w[114256]=0;V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}f=w[e+56>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,w[e+64>>2],4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}if(!f){break P}g=w[e+64>>2]+4|0;break O}w[114256]=0;V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break N}break C}f=w[e+56>>2];d=w[w[f>>2]+24>>2];w[114256]=0;g=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break C}}w[e+64>>2]=g}w[114256]=0;f=V(187,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break G}w[114256]=0;w[e+32>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;g=V(22,16)|0;d=w[114256];w[114256]=0;if((d|0)==1){break J}w[g+4>>2]=0;w[g+8>>2]=0;w[g+12>>2]=75696;w[g>>2]=75656;w[e+44>>2]=0;w[e+48>>2]=0;w[e+40>>2]=g;w[e+36>>2]=g+12;w[e+52>>2]=0;g=w[e+72>>2];R:{if((g|0)<0){break R}d=w[e+104>>2];if(g>>>0>=(w[e+108>>2]-d|0)/12>>>0){break R}w[114256]=0;U(6,e+8|0,2,d+C(g,12)|0);d=w[114256];w[114256]=0;if((d|0)==1){break H}if(u[e+35|0]<0){zb(w[e+24>>2])}w[e+32>>2]=w[e+16>>2];d=w[e+12>>2];w[e+24>>2]=w[e+8>>2];w[e+28>>2]=d}w[114256]=0;U(188,e+8|0,e+56|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){break H}f=w[e+8>>2];d=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+40>>2];w[e+36>>2]=f;w[e+40>>2]=d;S:{if(!g){break S}d=w[g+4>>2];w[g+4>>2]=d-1;if(d){break S}ob[w[w[g>>2]+8>>2]](g);Ib(g)}d=w[e+20>>2];w[e+44>>2]=w[e+16>>2];w[e+48>>2]=d;Bb(e+8|0);w[114256]=0;T(189,a|0,e+24|0);d=w[114256];w[114256]=0;if((d|0)==1){break H}Tg(e+24|0)}f=w[e+60>>2];if(!f){break K}d=w[f+4>>2];w[f+4>>2]=d-1;if(d){break K}ob[w[w[f>>2]+8>>2]](f);Ib(f)}c=c+1|0;if(c>>>0<z[e+140>>2]){continue}break s}break}g=P()|0;break B}g=P()|0;Tg(e+24|0);break B}g=P()|0;break B}g=P()|0;break u}W(0)|0;Eb();M()}g=P()|0;break u}g=P()|0}Bb(e+56|0);break u}g=P()|0}a=w[e+88>>2];if(!a){break t}w[e+92>>2]=a;zb(a)}bc(e+104|0);R(g|0);M()}p=w[a>>2]!=w[a+4>>2]}a=w[e+88>>2];if(!a){break q}w[e+92>>2]=a;zb(a)}bc(e+104|0)}jb=e+160|0;return p|0}function bC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=jb-368|0;jb=d;a:{if(z[b+8>>2]<=1079){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<1080){break a}}w[b+8>>2]=1080;if(!vh(b,d+364|0)){break a}tc(a,1);v[d+358>>1]=0;v[d+354>>1]=0;v[d+356>>1]=0;v[d+352>>1]=1084;w[d+344>>2]=0;w[d+348>>2]=40;if(!yp(d+364|0,d+344|0)){break a}e=y[d+354>>1];if(!e|e>>>0>127){break a}if(!c){f=1;break a}v[a+480188>>1]=e;L=x[d+357|0];f=x[d+356|0];if(x[d+359|0]){w[a+1074312>>2]=w[a+1074312>>2]|32}n=a+480188|0;D=w[d+364>>2];s=x[d+358|0];t=w[d+364>>2];w[b+8>>2]=0;Li(b,a+1304400|0,20);v[a+480190>>1]=31;A=(e|0)==8&(L|0)!=0;l=(f|0)!=0;q=(t|0)==1414743366;p=(t|0)!=558573133;f=1;i=(t|0)==776678989;g=i;while(1){e=C(f,104)+a|0;m=e+484380|0;r=Rk(b,d+208|0,m,((f<<5)+a|0)+946304|0,y[a+480188>>1]==4);m=w[m>>2];b:{if(p?q:1){u[e+484417|0]=0-(x[d+232|0]<<3);break b}l=m>>>0<65536&l}e=y[d+230>>1];c:{if(e){N=!y[d+236>>1]|N;break c}O=x[d+233|0]==64|O}o=g&1;g=0;d:{if(!o){break d}h=(((e<<8|e>>>8)&65535)<<1)+h|0;o=x[d+232|0];g=!o;if(o|!e){break d}g=x[d+233|0]==64}H=r+H|0;j=j+m|0;f=f+1|0;if((f|0)!=32){continue}break}e:{f:{g:{h:{T=w[d+348>>2];if(T>>>0>=H>>>0){if(!Qk(b,d+208|0)){Cb(d+208|0,0,130)}m=y[d+352>>1];i:{if(m>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<m>>>0){break i}}w[b+8>>2]=m}f=x[d+209|0];e=128;Ze(w[a+484360>>2]+(x[a+484376|0]<<5)|0,d+208|2,128,65535,65535);g=!f&g;h=g?h:0;f=x[d+208|0];j:{if(f>>>0>128){break j}e=f;if(e){break j}q=w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2];f=128;while(1){if(y[(q+((f&65535)<<1)|0)-2>>1]){e=f;break j}e=1;f=f-1|0;if((f&65535)>>>0>1){continue}break}}r=wp(b,w[a+484360>>2]+(x[a+484376|0]<<5)|0,e&65535,j,n,h,0);I=1;k:{if(!(g&y[a+480188>>1]==8)){I=(s|0)!=0;break k}w[d+344>>2]=7102}g=x[a+484376|0];l:{if(!A){j=w[a+484360>>2];break l}j=w[a+484360>>2];h=j+(g<<5)|0;f=w[h>>2];h=w[h+4>>2];if((f|0)==(h|0)){break l}while(1){v[f>>1]=y[f>>1]>>>1;f=f+2|0;if((h|0)!=(f|0)){continue}break}}j=(g<<5)+j|0;v[j+28>>1]=x[d+209|0];V=e-1&65535;e=x[d+209|0];m:{n:{if(V>>>0<e>>>0){e=y[n>>1];break n}f=y[n>>1];if((e|0)!=120){break m}e=4;if((f&65535)!=4){break m}}v[j+28>>1]=0;f=e}w[a+480260>>2]=56;w[a+480264>>2]=13696;w[a+480196>>2]=6;w[a+480204>>2]=125e4;w[a+480208>>2]=0;e=f&65535;f=256/(e>>>0)|0;w[a+480228>>2]=e>>>0>8?32:f>>>0>=128?128:f;s=0;Ce(a,0);q=1;f=0;W=1;if(!(l&1)){o:{if(!r){p=0;l=0;break o}h=0;l=0;p=0;while(1){e=0;j=0;while(1){v[d+196>>1]=0;w[d+192>>2]=0;Of(b,d+176|0);w[d+60>>2]=w[d+176>>2];Kf(d+60|0,d+192|0);f=x[d+192|0];o=(f-121&255)>>>0<136|(f-49&255)>>>0<36;p:{q:{r:{s:{f=x[d+195|0];if((f-7&255)>>>0<3){i=0;break s}g=x[d+197|0];if(!((f|0)!=14|g>>>0<=1)){i=0;break r}if(!((f|0)==15&(g&255)>>>0>31)){i=o?i:0;if((f|0)!=13){break s}j=j+1|0;if((j&65535)>>>0<2){break p}}i=0;break p}if((f|0)==8){break q}if((f|0)!=14){break p}g=x[d+197|0]}if((g&240)!=128){break p}f=s&255;g=g<<4&240;s=f>>>0>g>>>0?f:g;break p}g=s&255;f=x[d+197|0];s=f>>>0<g>>>0?g:f;if(f<<24>>24>=0){p=1;break p}l=(f|0)!=164&f>>>0>143|l}q=o&q;e=e+1|0;if((e|0)!=256){continue}break}h=h+1|0;if(r>>>0>(h&65535)>>>0){continue}break}}W=i&1;f=(l^-1)&p&(s&255)>>>0>47}t:{if(m>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<m>>>0){break t}}w[b+8>>2]=m}e=y[a+480188>>1];p=a+484344|0;E=r+A&65535;td(p,E);X=A?4:e;u:{v:{w:{x:{y:{if(!E){l=0;r=0;o=0;break y}Y=X&65535;$=f^1;aa=c&1;h=0;o=0;r=0;l=0;while(1){f=!aa;z:{if(A){e=(h&65534)>>>1|0;i=h&1;if(!i){if(!ie(p,e,64)){break y}}e=w[p>>2]+C(e,52)|0;ld(e);j=w[e>>2]+C(i,24)|0;break z}if(!ie(p,h&65535,64)){break y}e=w[p>>2]+C(h,52)|0;ld(e);j=w[e>>2]}if(f|!j){break y}e=y[n>>1];u[d+112|0]=0;f=e;e=d+112|0;F=Mi(d+192|0,f,e);f=y[n>>1];w[114256]=0;u[d+112|0]=0;G=S(304,d+176|0,f|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break x}J=0;while(1){i=0;Z=0;g=0;if(Y){while(1){w[114256]=0;Q(328,b|0,d+112|0)|0;e=w[114256];w[114256]=0;A:{B:{C:{D:{if((e|0)!=1){w[d+56>>2]=w[d+112>>2];f=C(g,6)+j|0;Kf(d+56|0,f);e=x[f+3|0];if(!e){if(x[f+5|0]){break C}break B}if(!L){break C}E:{switch(e-14|0){case 1:break D;case 0:break E;default:break C}}u[f+3|0]=0;u[f+5|0]=0;break C}g=P()|0;a=w[G>>2];if(!a){break w}w[d+180>>2]=a;zb(a);break w}if(x[f+5|0]<32){break C}u[f+5|0]=31}We(f);e=1;F:{G:{H:{k=x[f+3|0];switch(k-14|0){case 2:break A;case 0:break G;case 3:break H;default:break F}}l=x[f+5|0]<100|l;Z=1;break B}if(!W){break B}u[f+5|0]=0;break B}if(!((k|0)!=9|$)){e=x[f+5|0];if((e|0)==164){u[f+3|0]=20;u[f+5|0]=145;break B}e=e<<1;u[f+5|0]=(e|0)>=255?255:e;break B}if((k|0)!=19){break B}e=x[f+5|0];if(e>>>0>15){break B}k=e&1;e=!k;ba=!k;k=_&1;_=(k|0)==(e|0)?_:ba;o=((e|0)!=(k|0))+o|0}e=i}I:{if(!x[f|0]){i=x[f+1|0];if(!i|A){break I}k=x[w[F>>2]+g|0];if(!k|(i|0)==(k|0)){break I}k=w[G>>2]+g|0;i=x[k|0]+1|0;u[k|0]=i;if((i&255)>>>0<4){break I}w[a+1074320>>2]=w[a+1074320>>2]|2097152;break I}u[w[G>>2]+g|0]=0}f=x[f+1|0];if(f){u[w[F>>2]+g|0]=f}i=e;g=g+1|0;if((Y|0)!=(g|0)){continue}break}}r=i&Z|r;j=C(y[n>>1],6)+j|0;J=J+1|0;if((J|0)!=64){continue}break}e=w[G>>2];if(e){w[d+180>>2]=e;zb(e)}e=w[F>>2];if(e){w[d+196>>2]=e;zb(e)}h=h+1|0;if((h&65535)!=(E|0)){continue}break}}J:{if((q^-1|N)&1){break J}e=w[d+364>>2];if(!((e|0)==558571853|(e|0)==1414807888)&(e|0)!=776678989){break J}w[a+480208>>2]=w[a+480208>>2]|2162688;f=a+1074320|0;e=w[f>>2];w[f>>2]=e|404750336;K:{if((s&255)>>>0>47){break K}w[a+1074320>>2]=e|405798912;if(x[d+209|0]==127){break K}w[a+1074320>>2]=e|406323200}if(!q){break u}break v}if(q){break v}e=x[d+209|0];if((e|0)!=127|(t|0)!=776678989|e+1>>>0<V>>>0){break u}w[d+344>>2]=4537;break u}g=P()|0}a=w[F>>2];if(!a){break e}w[d+196>>2]=a;zb(a);break e}if((o|0)>6|I){break u}w[a+480208>>2]=w[a+480208>>2]|8388608}if(!(!I&(t|0)!=776678989)){e=a+1074320|0;w[e>>2]=w[e>>2]|33554432}if(!((D|0)!=77&(D|0)!=56)){e=a+1074320|0;w[e>>2]=w[e>>2]|1048576}if(c&2){c=m+(C(X&65535,E)<<8)|0;L:{if(c>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<c>>>0){break L}}w[b+8>>2]=c}i=(D|0)==56;j=(q^1|(t|0)!=776678989|O)&1;h=(D|0)==77;f=1;while(1){n=C(f,104)+a|0;c=n+484380|0;e=w[c>>2];M:{if(!e){break M}g=2;if(!(h|i)){g=gd(b,9584,5)?11:0;e=w[c>>2]}u[d+195|0]=g;u[d+194|0]=0;v[d+192>>1]=264;e=w[b+8>>2]+Tp(d+192|0,e)|0;if(!j){g=w[c>>2];n=w[n+484388>>2];w[c>>2]=g>>>0>n>>>0?g:n}Fd(d+192|0,c,b);if(e>>>0>z[b+8>>2]){c=w[b>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<e>>>0){break M}}w[b+8>>2]=e}f=f+1|0;if((f|0)!=32){continue}break}}N:{if((l^-1|(t|0)!=776678989|r)&1){break N}w[d+168>>2]=0;b=w[d+164>>2];w[d+40>>2]=w[d+160>>2];w[d+44>>2]=b;b=w[d+172>>2];w[d+48>>2]=w[d+168>>2];w[d+52>>2]=b;u[d+158|0]=255;v[d+156>>1]=0;w[d+152>>2]=0;b=w[d+156>>2];w[d+32>>2]=w[d+152>>2];w[d+36>>2]=b;ri(d+192|0,a,0,d+32|0);b=w[d+192>>2];K=B[b>>3];w[d+196>>2]=b;zb(b);if(K<480){break N}w[a+1074312>>2]=w[a+1074312>>2]|32;w[d+144>>2]=0;u[d+134|0]=255;v[d+132>>1]=0;w[d+128>>2]=0;if(!(K<0)){B[d+136>>3]=K;w[d+144>>2]=3}b=w[d+148>>2];w[d+24>>2]=w[d+144>>2];w[d+28>>2]=b;b=w[d+140>>2];w[d+16>>2]=w[d+136>>2];w[d+20>>2]=b;b=w[d+132>>2];w[d+8>>2]=w[d+128>>2];w[d+12>>2]=b;ri(d+192|0,a,0,d+8|0);b=w[d+192>>2];c=x[b+26|0];w[d+196>>2]=b;zb(b);if(c){w[a+1074312>>2]=w[a+1074312>>2]&-33;break N}w[d+344>>2]=12842}f=0;g=d+364|0;while(1){b=x[(d+364|0)+f|0];u[g|0]=b>>>0<=32?32:b;g=g+1|0;f=f+1|0;if((f|0)!=4){continue}break}b=Hb(d+96|0,13030);e=w[b>>2];w[d+116>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+119|0]=c;u[d+120|0]=c>>>8;u[d+121|0]=c>>>16;u[d+122|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+123|0]=c;w[d+112>>2]=e;u[d+75|0]=4;u[d+68|0]=0;w[d+64>>2]=w[d+364>>2];U(6,d+80|0,1,d- -64|0);c=w[114256];w[114256]=0;if((c|0)==1){break h}w[114256]=0;U(124,d+192|0,d+112|0,d+80|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}c=a+1304436|0;if(u[a+1304447|0]<0){zb(w[c>>2])}e=w[d+196>>2];w[c>>2]=w[d+192>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+200>>2];u[d+203|0]=0;u[d+192|0]=0;if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[b+11|0]<0){zb(w[b>>2])}b=a+1304448|0;c=Hb(d+192|0,8092);if(u[a+1304459|0]<0){zb(w[b>>2])}e=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=e;w[b+8>>2]=w[c+8>>2];b=w[d+344>>2];if(b){Jf(a+1304460|0,b,ec(b))}w[a+1304496>>2]=2}f=H>>>0<=T>>>0;break a}g=P()|0;break f}g=P()|0;if(u[d+91|0]>=0){break f}zb(w[d+80>>2])}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[b+11|0]>=0){break e}zb(w[b>>2])}R(g|0);M()}jb=d+368|0;return f|0}function zB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0;f=jb-272|0;jb=f;w[b+8>>2]=0;a:{if(!Ei(b,f+168|0)){break a}if(!lp(f+168|0)){break a}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(x[f+172|0]+(x[f+260|0]+(x[f+261|0]+y[f+262>>1]|0)<<2)|0)-96|0)|0)){break a}b:{if(!c){break b}d=x[f+172|0];if(d>>>0>z[b+8>>2]){g=w[b>>2];if(ob[w[w[g>>2]+24>>2]](g)>>>0<d>>>0){break a}}w[b+8>>2]=d;tc(a,268435456);je(a);w[a+480208>>2]=4;e=a+1304436|0;d=Hb(f+48|0,11068);if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+8>>2];e=a+1304448|0;d=Hb(f+48|0,6222);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=g;w[e+8>>2]=w[d+8>>2];w[a+1304496>>2]=4;Vb(f+48|0,3,f+168|6,48);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}d=w[f+52>>2];w[e>>2]=w[f+48>>2];w[e+4>>2]=d;w[e+8>>2]=w[f+56>>2];d=x[f+222|0];v[a+480188>>1]=d+1;w[a+480228>>2]=x[f+225|0];w[a+480204>>2]=C(x[f+226|0],1e4);w[a+480196>>2]=x[f+227|0];if(d){e=0;while(1){v[((e<<5)+a|0)+480284>>1]=C(x[(f+e|0)+228|0],17);e=e+1|0;if((d|0)!=(e|0)){continue}break}}v[a+480190>>1]=x[f+260|0];l=Tk(f+152|0,y[f+262>>1]);w[114256]=0;S(530,b|0,l|0,y[f+262>>1])|0;e=w[114256];w[114256]=0;c:{d:{e:{if((e|0)!=1){w[114256]=0;w[f+144>>2]=0;w[f+136>>2]=0;w[f+140>>2]=0;w[f+128>>2]=0;w[f+120>>2]=0;w[f+124>>2]=0;S(350,b|0,f+136|0,x[f+261|0])|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}w[114256]=0;S(350,b|0,f+120|0,x[f+260|0])|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}if(x[f+260|0]){n=c&2;m=f+86|0;o=f+48|6;e=0;while(1){w[114256]=0;d=e;e=d+1|0;g=C(e,104)+a|0;h=g+484380|0;T(266,h|0,0);i=w[114256];w[114256]=0;f:{g:{h:{if((i|0)!=1){p=d<<2;d=p+w[f+120>>2]|0;d=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);if(!d){break f}if(d>>>0>z[b+8>>2]){i=w[b>>2];k=w[w[i>>2]+24>>2];w[114256]=0;i=V(k|0,i|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break g}if(d>>>0>i>>>0){break f}}w[b+8>>2]=d;w[114256]=0;d=Q(531,b|0,f+48|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break g}if(d){break h}break f}e=P()|0;break d}w[114256]=0;Y(209,f+16|0,2,o|0,32);d=w[114256];w[114256]=0;i:{j:{k:{if((d|0)!=1){w[114256]=0;w[f+268>>2]=32;w[f+264>>2]=((e<<5)+a|0)+946304;Q(200,f+264|0,f+16|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break k}if(u[f+27|0]<0){zb(w[f+16>>2])}w[114256]=0;Y(209,f+16|0,2,m|0,12);d=w[114256];w[114256]=0;if((d|0)==1){break j}w[114256]=0;w[f+268>>2]=22;w[f+264>>2]=g+484423;Q(200,f+264|0,f+16|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}if(u[f+27|0]<0){zb(w[f+16>>2])}d=x[f+98|0];if(d>>>0<=15){v[g+484408>>1]=C(d,17);d=g+484414|0;v[d>>1]=y[d>>1]|32}d=x[f+99|0];v[g+484412>>1]=d>>>0>=64?64:d;w[g+484404>>2]=x[f+101|0]|x[f+102|0]<<8;k=g+484384|0;d=x[f+107|0]|x[f+108|0]<<8|(x[f+109|0]<<16|x[f+110|0]<<24);w[k>>2]=d;q=g+484388|0;i=x[f+111|0]|x[f+112|0]<<8|(x[f+113|0]<<16|x[f+114|0]<<24);w[q>>2]=i;s=x[f+115|0]|x[f+116|0]<<8|(x[f+117|0]<<16|x[f+118|0]<<24);w[h>>2]=s;t=x[f+100|0];if(t&1){d=d>>>1|0;w[k>>2]=d;i=i>>>1|0;w[q>>2]=i;w[h>>2]=s>>>1}l:{if(d>>>0>=i>>>0){break l}d=g+484414|0;g=y[d>>1];v[d>>1]=g|2;if(!(t&2)){break l}v[d>>1]=g|6}w[114256]=0;X(532,h|0);d=w[114256];w[114256]=0;if((d|0)==1){break g}if(!n){break f}d=p+w[f+120>>2]|0;d=x[f+52|0]+(x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24))|0;m:{if(d>>>0>z[b+8>>2]){g=w[b>>2];i=w[w[g>>2]+24>>2];w[114256]=0;g=V(i|0,g|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break g}if(d>>>0>g>>>0){break m}}w[b+8>>2]=d}w[114256]=0;u[f+19|0]=1;u[f+17|0]=1;u[f+18|0]=0;u[f+16|0]=u[f+100|0]&1?16:8;S(214,f+16|0,h|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break f}e=P()|0;break d}e=P()|0;break d}e=P()|0;if(u[f+27|0]>=0){break d}zb(w[f+16>>2]);break d}e=P()|0;break d}e=P()|0;if(u[f+27|0]>=0){break d}zb(w[f+16>>2]);break d}e=P()|0;break d}if(x[f+260|0]>e>>>0){continue}break}}n:{o:{p:{q:{r:{if(!(c&1)){break r}c=w[a+484360>>2]+(x[a+484376|0]<<5)|0;w[c+4>>2]=w[c>>2];s:{c=w[l>>2];q=w[l+4>>2];if((c|0)==(q|0)){break s}s=a+484344|0;i=0;while(1){e=x[c+3|0];t:{if(x[c+2|0]>x[f+222|0]|e>>>0>=x[f+261|0]){break t}e=w[f+136>>2]+(e<<2)|0;e=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);if(e>>>0>z[b+8>>2]){d=w[b>>2];g=w[w[d>>2]+24>>2];w[114256]=0;d=V(g|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break q}if(d>>>0<e>>>0){break t}}w[b+8>>2]=e;w[114256]=0;e=Q(533,b|0,f+48|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break p}if(!e){break t}g=x[f+52|0];if(!g){break t}h=x[c+2|0];e=x[c|0]|x[c+1|0]<<8;d=x[f+53|0];n=x[f+222|0];w[f+40>>2]=0;w[f+44>>2]=0;w[f+32>>2]=0;w[f+36>>2]=0;w[f+24>>2]=0;w[f+28>>2]=0;w[f+16>>2]=0;w[f+20>>2]=0;g=e+g|0;i=g>>>0<i>>>0?i:g;h=n-h&255;n=d>>>0>h>>>0?h:d;o=e>>>6|0;d=e&63;t=g&63;A=g>>>6|0;p=0;while(1){e=w[a+484360>>2]+(x[a+484376|0]<<5)|0;g=w[e>>2];m=d>>>0>63;o=m+o|0;h=o&65535;u:{if(h>>>0<w[e+4>>2]-g>>1>>>0){e=y[g+(h<<1)>>1];break u}w[114256]=0;v[f+264>>1]=65535;U(524,e|0,o+1&65535,f+264|0);e=w[114256];w[114256]=0;if((e|0)==1){break o}w[114256]=0;e=S(303,s|0,64,0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break o}v[w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]+(h<<1)>>1]=e}e=e&65535;g=w[a+484344>>2];if(e>>>0>=((w[a+484348>>2]-g|0)/52&65535)>>>0){break t}k=C(e,52);e=k+g|0;if(w[e>>2]==w[e+4>>2]){break t}g=x[c+2|0];w[114256]=0;h=V(218,e|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break n}m=m?0:d;if(n){e=w[e>>2]+C(g+C(h,m)|0,6)|0;h=0;while(1){w[114256]=0;Q(534,b|0,f+264|0)|0;d=w[114256];w[114256]=0;v:{w:{if((d|0)!=1){d=x[f+264|0];j=d-1&255;if(j>>>0>142){break w}d=(C((d&240)>>>4|0,12)+(d&15)|0)+13|0;u[e|0]=d;u[(f+16|0)+h|0]=d;break v}e=P()|0;break d}u[e|0]=0}d=x[f+265|0];u[e+2|0]=1;u[e+1|0]=d;d=x[f+266|0];x:{if((d|0)!=255){u[e+4|0]=d;break x}u[e+2|0]=0}d=x[f+267|0];y:{if(d>>>0>22){break y}u[e+3|0]=x[d+23824|0];g=x[f+268|0];u[e+5|0]=g;d=e+5|0;z:{switch(x[f+267|0]-4|0){case 3:u[d|0]=g&3|64;break y;case 4:u[d|0]=g&3|48;break y;case 7:j=w[l>>2];if(g>>>0>=w[l+4>>2]-j>>2>>>0){break y}r=d;d=j+(g<<2)|0;d=x[d|0]|x[d+1|0]<<8;u[r|0]=d>>>6;g=y[a+480188>>1];j=w[a+484344>>2];w[114256]=0;j=j+k|0;r=V(218,j|0)|0;B=w[114256];w[114256]=0;if((B|0)!=1){g=w[j>>2]+C(C(m,r)+(g-1&65535)|0,6)|0;u[g+5|0]=d&63;u[g+3|0]=14;break y}e=P()|0;break d;case 8:u[d|0]=A;d=y[a+480188>>1];g=w[a+484344>>2];w[114256]=0;g=g+k|0;j=V(218,g|0)|0;r=w[114256];w[114256]=0;if((r|0)!=1){d=w[g>>2]+C(C(j,m)+(d-1&65535)|0,6)|0;u[d+5|0]=t;u[d+3|0]=14;break y}e=P()|0;break d;case 10:u[d|0]=g&15|128;break y;case 12:u[f+15|0]=15;u[d|0]=x[(g>>>0>15?f+15|0:d)|0]|208;break y;case 13:u[f+15|0]=15;u[d|0]=x[(g>>>0>15?f+15|0:d)|0]|192;break y;case 14:u[f+15|0]=15;u[d|0]=x[(g>>>0>15?f+15|0:d)|0]|224;break y;case 0:case 16:case 17:if(!(g&15)){break y}j=g&240;if(!j|(j|0)==240){break y}u[d|0]=g|15;break y;case 9:case 18:break z;default:break y}}if(j>>>0<143){break y}u[e|0]=x[(f+16|0)+h|0]}e=e+6|0;h=h+1|0;if((n|0)!=(h|0)){continue}break}}e=x[f+53|0];if(e>>>0>n>>>0){d=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;e=C(e-n|0,5);d=S(h|0,g|0,d|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break n}A:{if(d){e=e+w[b+8>>2]|0;break A}e=w[b>>2];d=w[w[e>>2]+24>>2];w[114256]=0;e=V(d|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}}w[b+8>>2]=e}d=m+1|0;p=p+1|0;if(p>>>0<x[f+52|0]){continue}break}}c=c+4|0;if((q|0)!=(c|0)){continue}break}b=i&63;if(!b){break s}c=w[a+484360>>2];e=x[a+484376|0];w[114256]=0;d=c+(e<<5)|0;c=i>>>6|0;e=Q(305,d|0,c&65535)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(!e){break s}c=y[w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]+((c&65535)<<1)>>1];e=w[a+484344>>2];w[114256]=0;Z(535,e+C(c,52)|0,b|0,0,1)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break s}}e=P()|0;break d}b=w[a+484360>>2]+(x[a+484376|0]<<5)|0;e=w[b>>2];b=w[b+4>>2];if((e|0)==(b|0)){break r}a=a+484344|0;h=65535;while(1){if(y[e>>1]==65535){B:{if((h&65535)!=65535){break B}w[114256]=0;h=S(303,a|0,64,0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break B}e=P()|0;break d}v[e>>1]=h}e=e+2|0;if((b|0)!=(e|0)){continue}break}}a=w[f+120>>2];if(a){w[f+124>>2]=a;zb(a)}a=w[f+136>>2];if(a){w[f+140>>2]=a;zb(a)}a=w[l>>2];if(!a){break b}w[l+4>>2]=a;zb(a);break b}e=P()|0;break d}e=P()|0;break d}e=P()|0;break d}e=P()|0;break d}e=P()|0;break c}e=P()|0}a=w[f+120>>2];if(a){w[f+124>>2]=a;zb(a)}a=w[f+136>>2];if(!a){break c}w[f+140>>2]=a;zb(a)}a=w[l>>2];if(a){w[l+4>>2]=a;zb(a)}R(e|0);M()}e=1}jb=f+272|0;return e|0}function wJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,y=0,A=0,B=0,D=0,E=0;h=jb+-64|0;jb=h;w[b+8>>2]=0;d=w[a+4>>2];k=w[a>>2];if((d|0)!=(k|0)){while(1){d=d-32|0;Tg(d);if((d|0)!=(k|0)){continue}break}}w[a+4>>2]=k;a:{if(!Sl(b,h+24|0)){break a}if(!ns(h+24|0)){break a}b:{if(!c){break b}d=w[b>>2];c=w[h+28>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))-28|0)|0)){break a}c:{if(z[a+4>>2]<z[a+8>>2]){Jm(a);break c}Gm(a)}d=w[a+4>>2];c=Kb(12);w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[h+8>>2]=0;k=d-4|0;d=w[k>>2];w[k>>2]=c;if(d){kd(d)}c=w[h+8>>2];w[h+8>>2]=0;if(c){kd(c)}i=w[w[a+4>>2]-4>>2];c=w[b>>2];d=w[w[c>>2]+20>>2];w[114256]=0;d=V(d|0,c|0)|0;c=w[114256];w[114256]=0;d:{e:{f:{if((c|0)==1){break f}c=w[h+36>>2];s=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);if((s|0)<=0){break a}c=w[h+28>>2];b=w[b+8>>2];w[114256]=0;c=c<<8&16711680|c<<24|(c>>>8&65280|c>>>24);p=c-28|0;k=C(p>>>0>=214748364?214748364:p,20);T(190,i|0,(k>>>0<s>>>0?k:s)|0);k=w[114256];w[114256]=0;if((k|0)==1){break f}w[h+12>>2]=p;r=b+d|0;w[h+8>>2]=r;D=c-36|0;g:{h:{while(1){if(f>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}b=f+4|0;if(b>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}c=f+5|0;if(c>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}d=f+6|0;if(d>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}m=f+7|0;if(m>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}k=x[c+r|0]|x[b+r|0]<<8;B=f+8|0;i:{j:{k:{l:{m:{n:{switch(x[f+r|0]){case 0:o:{if(k>>>0<=s>>>0){if(k){break o}m=0;k=0;break j}break l}g=D-f|0;f=0;while(1){if((f|0)==(g|0)){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}m=x[(f+B|0)+r|0];b=w[i+4>>2];e=w[i+8>>2];p:{if(b>>>0<e>>>0){u[b|0]=m;w[i+4>>2]=b+1;break p}c=b;b=w[i>>2];d=c-b|0;c=d+1|0;if((c|0)<0){break k}e=e-b|0;j=e<<1;e=e>>>0>=1073741823?2147483647:c>>>0<j>>>0?j:c;q:{if(!e){c=0;break q}w[114256]=0;c=V(22,e|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break m}}j=c+d|0;u[j|0]=m;if((d|0)>0){Fb(c,b,d)}w[i+8>>2]=c+e;w[i+4>>2]=j+1;w[i>>2]=c;if(!b){break p}zb(b)}f=f+1|0;if((k|0)!=(f|0)){continue}break};m=k;break j;case 1:break n;default:break i}}b=f+10|0;if(b>>>0>=p>>>0){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}g=x[d+r|0];j=x[m+r|0];c=x[b+r|0];r:{b=w[i+4>>2];e=w[i+8>>2];s:{if(b>>>0<e>>>0){u[b|0]=c;w[i+4>>2]=b+1;break s}d=w[i>>2];m=b-d|0;b=m+1|0;if((b|0)<0){break k}e=e-d|0;n=e<<1;e=e>>>0>=1073741823?2147483647:b>>>0<n>>>0?n:b;t:{if(!e){b=0;break t}w[114256]=0;b=V(22,e|0)|0;n=w[114256];w[114256]=0;if((n|0)==1){break r}}n=b+m|0;u[n|0]=c;if((m|0)>0){Fb(b,d,m)}w[i+8>>2]=b+e;w[i+4>>2]=n+1;w[i>>2]=b;if(!d){break s}zb(d)}k=k+3&65532;b=j|g<<8;m=b>>>0<s>>>0?b:s;if(m>>>0<2){break j}j=f+11|0;f=m-1|0;n=0;A=0;t=0;d=0;while(1){w[114256]=0;e=Z(192,j|0,d|0,1,h+8|0)|0;b=w[114256];w[114256]=0;u:{v:{if((b|0)==1){break v}w:{x:{y:{z:{if((t|0)<=7){if(e){b=d;break w}b=d+1|0;n=8;break z}b=d+1|0;A:{B:{C:{if(!e){w[114256]=0;e=Z(192,j|0,b|0,1,h+8|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break v}if(!e){break w}w[114256]=0;g=d+2|0;b=Z(192,j|0,g|0,1,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}if(!b){e=2;break C}w[114256]=0;g=d+3|0;b=Z(192,j|0,g|0,1,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}if(!b){e=3;break C}w[114256]=0;e=Z(192,j|0,g|0,3,h+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break v}b=d+6|0;break B}e=4;if((n|0)==8){break A}break y}b=g+1|0}D:{d=(n<<3)+e|0;E:{if((d|0)<=16){a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;break E}d=d-17|0;if(d>>>0<56){break D}a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0}d=kb;ca(a|0);break d}e=d&31;if(((d&63)>>>0>=32?66624>>>e|0:((1<<e)-1&66624)<<32-e|1077952576>>>e)&1){break A}n=x[d+23104|0];e=4;break y}n=8;e=1;if((A|0)>19){break y}}e=0;break x}A=A+8|0}q=32-n|0;v=-2147483648>>>q|0;F:{G:{while(1){g=(b|0)/8|0;d=g+j|0;if(d>>>0>=p>>>0){break F}o=d+1|0;if(o>>>0>=p>>>0){break F}l=d+2|0;if(l>>>0>=p>>>0){break F}c=(v-(((x[l+r|0]|(x[o+r|0]<<8|x[d+r|0]<<16))<<(b-(g<<3)|0)+8^-2147483648)>>>q|0)|0)+c|0;d=w[i+4>>2];l=w[i+8>>2];H:{if(d>>>0<l>>>0){u[d|0]=c;w[i+4>>2]=d+1;break H}g=d;d=w[i>>2];o=g-d|0;g=o+1|0;if((g|0)<0){break k}l=l-d|0;y=l<<1;l=l>>>0>=1073741823?2147483647:g>>>0<y>>>0?y:g;I:{if(!l){g=0;break I}w[114256]=0;g=V(22,l|0)|0;y=w[114256];w[114256]=0;if((y|0)==1){break G}}y=g+o|0;u[y|0]=c;if((o|0)>0){Fb(g,d,o)}w[i+8>>2]=g+l;w[i+4>>2]=y+1;w[i>>2]=g;if(!d){break H}zb(d)}b=b+n|0;f=f-1|0;if((e|0)>0){e=e-1|0;if(f){continue}}break}t=(t|0)==31?31:t+1|0;d=b;break u}f=ja(74720,75856)|0;break e}a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}w[114256]=0;c=b+1|0;d=Z(192,j|0,c|0,1,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}J:{K:{L:{if(!d){e=2;break L}w[114256]=0;c=b+2|0;d=Z(192,j|0,c|0,1,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}if(!d){e=4;break L}w[114256]=0;c=b+3|0;d=Z(192,j|0,c|0,1,h+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}if(!d){e=6;break L}w[114256]=0;d=Z(192,j|0,b+4|0,1,h+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break v}c=b+5|0;if(!d){w[114256]=0;c=Z(192,j|0,c|0,3,h+8|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}g=c+8|0;c=b+8|0;break J}w[114256]=0;g=Z(192,j|0,c|0,5,h+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break v}e=16;c=b+10|0;break K}w[114256]=0;g=Z(192,j|0,c+1|0,1,h+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break v}c=c+2|0}g=e+g|0}w[114256]=0;b=Z(192,j|0,c|0,1,h+8|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}M:{if(b){e=-256;b=12;break M}w[114256]=0;c=c+1|0;b=Z(192,j|0,c|0,1,h+8|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}e=b?-4352:0;b=b?14:8}w[114256]=0;d=c+1|0;c=b;b=Z(192,j|0,d|0,b|0,h+8|0)|0;o=w[114256];w[114256]=0;if((o|0)==1){break v}if(g>>>0>=3){t=t-((g|0)!=3)|0;t=((t|0)<=1?1:t)-1|0}e=(b^-1)+e|0;b=e+(w[i+4>>2]-w[i>>2]|0)|0;if(b>>>0>=e>>>0){break l}d=c+d|0;while(1){N:{o=w[i>>2];c=x[o+b|0];e=w[i+4>>2];q=w[i+8>>2];O:{if(e>>>0<q>>>0){u[e|0]=c;w[i+4>>2]=e+1;break O}l=e-o|0;e=l+1|0;if((e|0)<0){break k}q=q-o|0;v=q<<1;q=q>>>0>=1073741823?2147483647:e>>>0<v>>>0?v:e;P:{if(!q){e=0;break P}w[114256]=0;e=V(22,q|0)|0;v=w[114256];w[114256]=0;if((v|0)==1){break N}}v=e+l|0;u[v|0]=c;if((l|0)>0){Fb(e,o,l)}w[i+8>>2]=e+q;w[i+4>>2]=v+1;w[i>>2]=e;zb(o)}f=f-1|0;if(g>>>0<2){break u}b=b+1|0;g=g-1|0;if(f){continue}break u}break}f=ja(74720,75856)|0;break e}f=ja(74720,75856)|0;break e}A=A-(A>>3)|0;if((f|0)>0){continue}break}break j}f=ja(74720,75856)|0;break e}f=ja(74720,75856)|0;break e}a=ba(8)|0;w[114256]=0;d=Q(191,a|0,9145)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}f=ja(74720,75856)|0;d=kb;ca(a|0);break d}w[114256]=0;X(193,i|0);a=w[114256];w[114256]=0;if((a|0)!=1){break g}break f}f=k+B|0;s=s-m|0;if((s|0)>0){continue}}break}c=w[i>>2];d=w[i+4>>2];if((c|0)==(d|0)){break a}b=Kb(24);w[b+4>>2]=0;w[b+8>>2]=0;w[b+20>>2]=d-c;w[b+16>>2]=c;w[b+12>>2]=75592;w[b>>2]=75552;w[h+16>>2]=0;w[h+20>>2]=0;w[h+12>>2]=b;w[h+8>>2]=b+12;a=w[a+4>>2];he(a-20|0,h+8|0);b=w[h+20>>2];a=a-12|0;w[a>>2]=w[h+16>>2];w[a+4>>2]=b;a=w[h+12>>2];if(!a){break b}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break b}ob[w[w[a>>2]+8>>2]](a);Ib(a);break b}w[d>>2]=75876;w[114256]=0;U(194,d|0,75856,133);a=w[114256];w[114256]=0;if((a|0)==1){break f}}M()}f=ja(74720,75856)|0}d=kb}Q:{if((fa(74720)|0)!=(d|0)){if((fa(75856)|0)!=(d|0)){break Q}}$(f|0)|0;aa();break a}R(f|0);M()}E=1}jb=h- -64|0;return E|0}function bD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-176|0;jb=e;w[e+132>>2]=0;w[e+136>>2]=0;n=e+128|4;w[e+128>>2]=n;a:{b:{c:{d:{e:{f:{g:{if(d){w[114256]=0;w[e+144>>2]=0;w[e+164>>2]=e+148;w[e+160>>2]=e+144;kc(a,e+160|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}j=w[e+144>>2];if(j-1>>>0>499){break g}k=e+114|0;h=e+113|0;l=e+116|0;h:{i:{while(1){w[e+168>>2]=0;w[114256]=0;w[e+160>>2]=0;w[e+164>>2]=0;u[e+160|0]=0;u[e+171|0]=0;v[e+80>>1]=0;w[e+112>>2]=0;w[e+148>>2]=l;w[e+144>>2]=e+112;d=kc(a,e+144|0);f=nb;g=w[114256];w[114256]=0;j:{if((g|0)!=1){if((d|0)!=4|f){break h}d=w[e+112>>2];if(d>>>0>255){break h}f=0;if(d){while(1){w[114256]=0;u[e+112|0]=0;w[e+148>>2]=h;w[e+144>>2]=e+112;g=kc(a,e+144|0);i=nb;o=w[114256];w[114256]=0;if((o|0)==1){break e}if((g|0)!=1|i){break h}g=u[e+112|0];w[114256]=0;T(71,e+160|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break e}f=f+1|0;if((d|0)!=(f|0)){continue}break}}w[114256]=0;v[e+112>>1]=0;w[e+148>>2]=k;w[e+144>>2]=e+112;kc(a,e+144|0);d=w[114256];w[114256]=0;if((d|0)!=1){break j}}d=P()|0;break b}w[114256]=0;v[e+80>>1]=y[e+112>>1];U(6,e+144|0,c|0,e+160|0);d=w[114256];w[114256]=0;if((d|0)!=1){w[114256]=0;d=e+80|0;w[e+96>>2]=d;ia(410,e+112|0,e+128|0,d|0,23586,e+96|0,e- -64|0);d=w[114256];w[114256]=0;if((d|0)==1){break i}d=w[e+112>>2];if(u[d+31|0]<0){zb(w[d+20>>2])}f=w[e+148>>2];w[d+20>>2]=w[e+144>>2];w[d+24>>2]=f;w[d+28>>2]=w[e+152>>2];if(u[e+171|0]<0){zb(w[e+160>>2])}m=m+1|0;if((j|0)!=(m|0)){continue}break g}break}d=P()|0;break b}d=P()|0;if(u[e+155|0]>=0){break b}zb(w[e+144>>2]);break b}if(u[e+171|0]>=0){break g}zb(w[e+160>>2]);break g}w[114256]=0;v[e+144>>1]=0;w[e+164>>2]=e+146;w[e+160>>2]=e+144;kc(a,e+160|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}j=y[e+144>>1];if(j>>>0>500|!j){break g}l=e+114|0;k=e+113|0;k:{l:{while(1){w[e+168>>2]=0;w[114256]=0;w[e+160>>2]=0;w[e+164>>2]=0;u[e+160|0]=0;u[e+171|0]=0;v[e+80>>1]=0;u[e+112|0]=0;w[e+148>>2]=k;w[e+144>>2]=e+112;d=kc(a,e+144|0);f=nb;g=w[114256];w[114256]=0;m:{if((g|0)!=1){if((d|0)!=1|f){break k}f=0;d=x[e+112|0];if(d){while(1){w[114256]=0;u[e+112|0]=0;w[e+148>>2]=k;w[e+144>>2]=e+112;g=kc(a,e+144|0);i=nb;o=w[114256];w[114256]=0;if((o|0)==1){break f}if((g|0)!=1|i){break k}g=u[e+112|0];w[114256]=0;T(71,e+160|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break f}f=f+1|0;if((d|0)!=(f&255)){continue}break}}w[114256]=0;v[e+112>>1]=0;w[e+148>>2]=l;w[e+144>>2]=e+112;kc(a,e+144|0);d=w[114256];w[114256]=0;if((d|0)!=1){break m}}d=P()|0;break d}w[114256]=0;v[e+80>>1]=y[e+112>>1];U(6,e+144|0,c|0,e+160|0);d=w[114256];w[114256]=0;if((d|0)!=1){w[114256]=0;d=e+80|0;w[e+96>>2]=d;ia(410,e+112|0,e+128|0,d|0,23586,e+96|0,e- -64|0);d=w[114256];w[114256]=0;if((d|0)==1){break l}d=w[e+112>>2];if(u[d+31|0]<0){zb(w[d+20>>2])}f=w[e+148>>2];w[d+20>>2]=w[e+144>>2];w[d+24>>2]=f;w[d+28>>2]=w[e+152>>2];if(u[e+171|0]<0){zb(w[e+160>>2])}h=h+1|0;if((j|0)!=(h|0)){continue}break g}break}d=P()|0;break d}d=P()|0;if(u[e+155|0]>=0){break d}zb(w[e+144>>2]);break d}if(u[e+171|0]>=0){break g}zb(w[e+160>>2])}w[e+168>>2]=0;w[e+160>>2]=0;w[e+164>>2]=0;if(y[b+480192>>1]){o=e+66|0;k=e- -64|4;h=1;l=1;while(1){w[114256]=0;v[e+64>>1]=0;w[e+148>>2]=o;w[e+144>>2]=e- -64;kc(a,e+144|0);c=w[114256];w[114256]=0;n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((c|0)!=1){d=w[e+132>>2];D:{E:{if(!d){break E}g=y[e+64>>1];f=n;while(1){c=d;j=f;i=g>>>0>y[d+16>>1];f=i?f:d;d=w[(i?d+4|0:d)>>2];if(d){continue}break}if((f|0)==(n|0)){break E}if(g>>>0>=y[(i?j:c)+16>>1]){break D}}f=n}j=((h<<2)+b|0)+900380|0;c=w[j>>2];if(!c){break n}if((f|0)!=(n|0)){F:{G:{H:{I:{if(u[f+31|0]>=0){w[e+152>>2]=w[f+28>>2];c=w[f+24>>2];w[e+144>>2]=w[f+20>>2];w[e+148>>2]=c;break I}c=w[f+24>>2];d=w[f+20>>2];w[114256]=0;U(3,e+144|0,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break H}}w[114256]=0;d=Q(1,e+112|0,12610)|0;c=w[114256];w[114256]=0;if((c|0)==1){break F}g=x[e+155|0];h=g<<24>>24;i=x[e+123|0];f=i<<24>>24;g=(h|0)<0?w[e+148>>2]:g;c=0;J:{if((g|0)!=(((f|0)<0?w[e+116>>2]:i)|0)){break J}c=1;if(!g){break J}c=!Jb((h|0)<0?w[e+144>>2]:e+144|0,(f|0)<0?w[d>>2]:d,g)}if((f|0)<0){zb(w[d>>2])}if(c){break A}c=w[b+4>>2];w[114256]=0;c=Q(411,c|0,e+144|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}w[w[j>>2]+44>>2]=c;if(!w[w[j>>2]+44>>2]){break G}break o}d=P()|0;break p}w[114256]=0;c=Q(1,e+96|0,9225)|0;d=w[114256];w[114256]=0;K:{L:{M:{N:{O:{if((d|0)!=1){f=x[e+155|0];h=f<<24>>24<0;i=x[e+107|0];d=i<<24>>24;g=(d|0)<0;m=g?w[e+100>>2]:i;i=h?w[e+148>>2]:f;P:{if((m|0)==(i|0)){f=1;if(!i){break P}if(!Jb(h?w[e+144>>2]:e+144|0,g?w[c>>2]:c,i)){break P}}w[114256]=0;d=Q(1,e+80|0,9426)|0;f=w[114256];w[114256]=0;if((f|0)==1){break O}i=x[e+155|0];g=i<<24>>24;m=x[e+91|0];h=m<<24>>24;i=(g|0)<0?w[e+148>>2]:i;f=0;Q:{if((i|0)!=(((h|0)<0?w[e+84>>2]:m)|0)){break Q}f=1;if(!i){break Q}f=!Jb((g|0)<0?w[e+144>>2]:e+144|0,(h|0)<0?w[d>>2]:d,i)}if((h|0)<0){zb(w[d>>2])}d=x[e+107|0]}if(d<<24>>24<0){zb(w[c>>2])}if(f){w[114256]=0;c=V(412,e+144|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break N}d=w[b+4>>2];w[114256]=0;w[e+64>>2]=0;d=Q(413,d|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break M}c=w[e+64>>2];w[e+64>>2]=0;if(c){od(c)}if(d){break o}}d=w[e+160>>2];c=w[e+164>>2];if((d|0)==(c|0)){break L}f=x[e+155|0];h=f<<24>>24<0;f=h?w[e+148>>2]:f;g=h?w[e+144>>2]:e+144|0;while(1){i=x[d+11|0];h=i<<24>>24<0;if((f|0)==((h?w[d+4>>2]:i)|0)){if(!f){break L}if(!Jb(h?w[d>>2]:d,g,f)){break L}}d=d+12|0;if((c|0)!=(d|0)){continue}break}break K}d=P()|0;break q}d=P()|0;if(u[e+107|0]>=0){break q}zb(w[c>>2]);break q}d=P()|0;break q}d=P()|0;a=w[e+64>>2];w[e+64>>2]=0;if(!a){break q}od(a);break q}if((c|0)!=(d|0)){break A}}if((c|0)!=w[e+168>>2]){if(u[e+155|0]>=0){d=w[e+148>>2];w[c>>2]=w[e+144>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+152>>2];break C}w[114256]=0;U(3,c|0,w[e+144>>2],w[e+148>>2]);d=w[114256];w[114256]=0;if((d|0)!=1){break C}d=P()|0;w[e+164>>2]=c;break q}w[114256]=0;T(414,e+160|0,e+144|0);c=w[114256];w[114256]=0;if((c|0)==1){break r}break B}d=P()|0;break q}w[c+44>>2]=0;break n}d=P()|0;break p}w[e+164>>2]=c+12}w[114256]=0;h=Q(1,e+24|0,13114)|0;c=w[114256];w[114256]=0;if((c|0)==1){break z}w[114256]=0;c=x[e+155|0];d=c<<24>>24<0;c=S(2,h|0,(d?w[e+144>>2]:e+144|0)|0,(d?w[e+148>>2]:c)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break y}w[e+48>>2]=w[c+8>>2];d=w[c+4>>2];w[e+40>>2]=w[c>>2];w[e+44>>2]=d;w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;w[114256]=0;f=Q(1,e+8|0,12118)|0;c=w[114256];w[114256]=0;if((c|0)==1){break x}c=w[f>>2];w[114256]=0;g=c;c=x[e+19|0];d=c<<24>>24<0;c=S(2,e+40|0,(d?g:f)|0,(d?w[e+12>>2]:c)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}g=w[c>>2];w[e+56>>2]=w[c+4>>2];d=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[e+59|0]=d;u[e+60|0]=d>>>8;u[e+61|0]=d>>>16;u[e+62|0]=d>>>24;w[c>>2]=0;w[c+4>>2]=0;d=x[c+11|0];w[c+8>>2]=0;w[e+64>>2]=g;c=x[e+59|0]|x[e+60|0]<<8|(x[e+61|0]<<16|x[e+62|0]<<24);u[k+3|0]=c;u[k+4|0]=c>>>8;u[k+5|0]=c>>>16;u[k+6|0]=c>>>24;w[k>>2]=w[e+56>>2];w[114256]=0;u[e+75|0]=d;T(348,b|0,e- -64|0);c=w[114256];w[114256]=0;if((c|0)==1){break v}if(u[e+75|0]<0){zb(w[e+64>>2])}if(u[e+19|0]<0){zb(w[f>>2])}if(u[e+51|0]<0){zb(w[e+40>>2])}if(u[e+35|0]>=0){break A}zb(w[h>>2])}w[w[j>>2]+44>>2]=0;break o}d=P()|0;break q}d=P()|0;break s}d=P()|0;break t}d=P()|0;break u}d=P()|0;if(u[e+75|0]>=0){break u}zb(w[e+64>>2])}if(u[e+19|0]>=0){break t}zb(w[f>>2])}if(u[e+51|0]>=0){break s}zb(w[e+40>>2])}if(u[e+35|0]>=0){break q}zb(w[h>>2]);break q}d=P()|0}if(u[e+155|0]>=0){break p}zb(w[e+144>>2])}bc(e+160|0);break a}if(u[e+155|0]>=0){break n}zb(w[e+144>>2])}l=l+1|0;h=l&65535;if(h>>>0<=y[b+480192>>1]){continue}break}}bc(e+160|0);Hi(e+128|0,w[e+132>>2]);jb=e+176|0;return}d=P()|0;break d}d=P()|0;break b}if(u[e+171|0]>=0){break a}zb(w[e+160>>2]);break a}d=P()|0;break a}if(u[e+171|0]>=0){break a}zb(w[e+160>>2])}Hi(e+128|0,w[e+132>>2]);R(d|0);M()}function hB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-256|0;jb=d;w[b+8>>2]=0;f=jb-16|0;jb=f;g=w[b+8>>2];e=w[b>>2];h=d+96|0;w[f+8>>2]=h;w[f+12>>2]=h+146;g=ob[w[w[e>>2]+32>>2]](e,g,f+8|0)|0;if((g|0)==146){e=w[b>>2];a:{if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],146)|0){e=w[b+8>>2]+146|0;break a}e=w[b>>2];e=ob[w[w[e>>2]+24>>2]](e)|0}w[b+8>>2]=e}jb=f+16|0;b:{c:{d:{e:{f:{if((g|0)!=146){break f}if(!cp(d+96|0)){break f}if(!c){j=1;break f}tc(a,4194304);f=a+1304436|0;e=Hb(d+16|0,12801);if(u[a+1304447|0]<0){zb(w[f>>2])}g=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+8>>2];f=a+1304448|0;e=Hb(d+16|0,6077);if(u[a+1304459|0]<0){zb(w[f>>2])}g=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+8>>2];w[a+1304496>>2]=4;e=y[d+176>>1];f=y[d+174>>1];v[a+480188>>1]=e>>>0>f>>>0?e:f>>>0>=127?127:f;f=x[d+165|0];w[a+480228>>2]=(f|0)==255?48:f;w[a+480196>>2]=x[d+163|0];w[a+480204>>2]=C(x[d+164|0],1e4);Vb(d+16|0,3,d+96|4,59);f=a+1304400|0;if(u[a+1304411|0]<0){zb(w[f>>2])}e=w[d+20>>2];w[f>>2]=w[d+16>>2];w[f+4>>2]=e;w[f+8>>2]=w[d+24>>2];f=y[d+178>>1]|y[d+180>>1]<<16;g:{if(f>>>0<5){break g}f=f-4|0;if(f>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<f>>>0){break g}}w[b+8>>2]=f;if(!gd(b,9877,4)){break g}wh(w[a+484360>>2]+(x[a+484376|0]<<5)|0,b,y[d+168>>1],65535,65535)}f=y[d+182>>1]|y[d+184>>1]<<16;h:{if(f>>>0<5){break h}f=f-4|0;if(f>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<f>>>0){break h}}w[b+8>>2]=f;if(!gd(b,9543,4)){break h}f=0;while(1){e=(f<<5)+a|0;Qd(e+480280|0);g=Xb(b,d+16|0);v[e+480284>>1]=g?((((x[d+16|0]^-1)&15)<<8|8)>>>0)/15|0:256;f=f+1|0;if((f|0)!=32){continue}break}}f=y[d+190>>1]|y[d+192>>1]<<16;i:{if(f>>>0<5){break i}f=f-4|0;if(f>>>0>z[b+8>>2]){e=w[b>>2];if(ob[w[w[e>>2]+24>>2]](e)>>>0<f>>>0){break i}}w[b+8>>2]=f;if(!gd(b,9814,4)){break i}oc(d+80|0,b,y[d+172>>1]<<6);j:{if(!y[d+172>>1]){break j}h=c&2;l=d+29|0;f=0;while(1){w[114256]=0;e=Q(558,d+80|0,d+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!e){break j}k:{e=x[d+61|0]|x[d+62|0]<<8;if((e-1&65535)>>>0>3998){break k}j=C(e,104)+a|0;g=j+484380|0;if(w[g>>2]?w[j+484400>>2]:0){break k}j=y[a+480190>>1];v[a+480190>>1]=e>>>0<j>>>0?j:e;w[114256]=0;T(559,d+16|0,g|0);j=w[114256];w[114256]=0;l:{m:{n:{if((j|0)==1){break n}w[114256]=0;Y(209,d|0,1,l|0,24);j=w[114256];w[114256]=0;if((j|0)==1){break m}w[114256]=0;w[d+252>>2]=32;w[d+248>>2]=((e<<5)+a|0)+946304;Q(200,d+248|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[d+11|0]<0){zb(w[d>>2])}if(!h){break k}e=x[d+53|0]|x[d+54|0]<<8|(x[d+55|0]<<16|x[d+56|0]<<24);o:{if(e>>>0>z[b+8>>2]){j=w[b>>2];m=w[w[j>>2]+24>>2];w[114256]=0;j=V(m|0,j|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break n}if(e>>>0>j>>>0){break o}}w[b+8>>2]=e}u[d+3|0]=0;j=1;u[d+1|0]=1;u[d+2|0]=0;e=x[d+63|0];u[d|0]=e&4?16:8;p:{q:{if(e&8){break q}j=2;if(e&16){break q}if(e&127){break p}}u[d+3|0]=j}w[114256]=0;S(214,d|0,g|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break k}a=P()|0;break c}a=P()|0;break c}a=P()|0;break c}a=P()|0;if(u[d+11|0]>=0){break c}zb(w[d>>2]);break c}f=f+1|0;if(y[d+172>>1]>(f&65535)>>>0){continue}break}}Bb(d+80|0)}j=1;if(!(c&1)){break f}c=y[d+186>>1]|y[d+188>>1]<<16;r:{if(c>>>0<5){break r}c=c-4|0;if(c>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<c>>>0){break r}}w[b+8>>2]=c;if(!gd(b,9432,4)){break r}m=a+484344|0;td(m,y[d+170>>1]);if(!y[d+170>>1]){break r}n=d+248|2;l=0;while(1){if(!Nc(b,d)){break r}c=y[d>>1];s:{if(c>>>0<=3){break s}oc(d+16|0,b,(c+15&131056)-4|0);w[114256]=0;e=S(216,m|0,l&65535,x[d+2|0])|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}f=10;c=0;t:{if(!e){break t}while(1){u:{f=w[d+16>>2];e=w[w[f>>2]+36>>2];w[114256]=0;f=S(e|0,f|0,w[d+24>>2],1)|0;e=w[114256];w[114256]=0;v:{if((e|0)!=1){e=x[d+2|0];if(!(f&e>>>0>c>>>0)){break u}w[114256]=0;f=Q(241,d+16|0,d+80|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}f=f?x[d+80|0]:0;e=f&255;if(e){break v}c=c+1|0;continue}break e}g=y[a+480188>>1];h=w[a+484344>>2];w[114256]=0;h=h+C(l,52)|0;i=V(218,h|0)|0;k=w[114256];w[114256]=0;w:{x:{if((k|0)!=1){h=w[h>>2];k=C(c,i);g=g-1&65535;i=f<<24>>24;f=i&31;g=k+(f>>>0>g>>>0?g:f)|0;f=h+C(g,6)|0;if((i|0)<0){i=w[d+16>>2];k=w[w[i>>2]+36>>2];w[114256]=0;i=S(k|0,i|0,w[d+24>>2],2)|0;k=w[114256];w[114256]=0;if((k|0)==1){break e}y:{if(i){w[d+84>>2]=n;w[d+80>>2]=d+248;i=w[d+16>>2];k=w[w[i>>2]+32>>2];w[114256]=0;i=S(k|0,i|0,w[d+24>>2],d+80|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break e}w[d+24>>2]=i+w[d+24>>2];i=x[d+248|0];break y}v[d+248>>1]=0;i=0}u[f|0]=i+36;u[f+1|0]=x[d+249|0]}if(e&64){u[f+2|0]=1;w[114256]=0;i=Q(241,d+16|0,d+80|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break e}k=x[d+80|0];u[f+4|0]=i?k>>>0>=64?64:k:0}if(!(e&32)){continue}e=w[d+16>>2];i=w[w[e>>2]+36>>2];w[114256]=0;e=S(i|0,e|0,w[d+24>>2],2)|0;i=w[114256];w[114256]=0;if((i|0)==1){break e}if(!e){break x}w[d+84>>2]=n;w[d+80>>2]=d+248;e=w[d+16>>2];i=w[w[e>>2]+32>>2];w[114256]=0;e=S(i|0,e|0,w[d+24>>2],d+80|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break e}w[d+24>>2]=e+w[d+24>>2];e=x[d+249|0];break w}break e}v[d+248>>1]=0;e=0}u[f+5|0]=e;z:{switch(x[d+248|0]-1|0){case 0:u[(h+C(g,6)|0)+3|0]=11;u[f+5|0]=e<<4|15;continue;case 1:u[(h+C(g,6)|0)+3|0]=11;u[f+5|0]=e<<4;continue;case 2:u[(h+C(g,6)|0)+3|0]=11;u[f+5|0]=e|240;continue;case 3:u[(h+C(g,6)|0)+3|0]=11;u[f+5|0]=e&15;continue;case 9:u[(h+C(g,6)|0)+3|0]=2;u[f+5|0]=e|240;continue;case 10:u[(h+C(g,6)|0)+3|0]=2;continue;case 11:u[(h+C(g,6)|0)+3|0]=3;u[f+5|0]=e|240;continue;case 12:u[(h+C(g,6)|0)+3|0]=3;continue;case 13:u[(h+C(g,6)|0)+3|0]=4;continue;case 14:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|16;continue;case 15:u[(h+C(g,6)|0)+3|0]=6;u[f+5|0]=e<<4;continue;case 16:u[(h+C(g,6)|0)+3|0]=6;u[f+5|0]=e&15;continue;case 19:u[(h+C(g,6)|0)+3|0]=5;continue;case 20:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|48;continue;case 21:u[(h+C(g,6)|0)+3|0]=7;u[f+5|0]=e<<4;continue;case 22:u[(h+C(g,6)|0)+3|0]=7;u[f+5|0]=e&15;continue;case 29:u[(h+C(g,6)|0)+3|0]=8;continue;case 30:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|64;continue;case 39:u[(h+C(g,6)|0)+3|0]=10;w[114256]=0;e=Q(241,d+16|0,d+80|0)|0;g=w[114256];w[114256]=0;A:{if((g|0)==1){break A}u[f+5|0]=e?x[d+80|0]:0;f=w[d+16>>2];e=w[w[f>>2]+36>>2];w[114256]=0;f=S(e|0,f|0,w[d+24>>2],1)|0;e=w[114256];w[114256]=0;if((e|0)==1){break A}B:{if(f){f=w[d+24>>2]+1|0;break B}f=w[d+16>>2];e=w[w[f>>2]+24>>2];w[114256]=0;f=V(e|0,f|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break A}}w[d+24>>2]=f;continue}break e;case 40:u[(h+C(g,6)|0)+3|0]=15;u[f+5|0]=e&15;continue;case 41:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|192;continue;case 42:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|208;continue;case 49:u[(h+C(g,6)|0)+3|0]=12;continue;case 50:u[(h+C(g,6)|0)+3|0]=14;continue;case 51:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|176;continue;case 52:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e|224;continue;case 59:u[(h+C(g,6)|0)+3|0]=16;continue;case 60:u[(h+C(g,6)|0)+3|0]=17;continue;case 69:u[(h+C(g,6)|0)+3|0]=1;continue;case 70:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e&15|32;continue;case 71:u[(h+C(g,6)|0)+3|0]=20;u[f+5|0]=e&15|128;continue;default:break z}}u[(h+C(g,6)|0)+3|0]=0;continue}break}f=0;if((e|0)==64){break t}c=w[m>>2];w[114256]=0;w[d+88>>2]=983039;w[d+84>>2]=e-1;e=x[d+92|0];w[d+80>>2]=1;u[d+92|0]=e&248|1;Q(271,c+C(l,52)|0,d+80|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break t}break e}c=w[d+20>>2];C:{if(!c){break C}e=w[c+4>>2];w[c+4>>2]=e-1;if(e){break C}ob[w[w[c>>2]+8>>2]](c);Ib(c)}if((f|0)==10){break s}if(f){break r}}l=l+1|0;if(l>>>0<y[d+170>>1]){continue}break}}c=y[d+194>>1]|y[d+196>>1]<<16;if(!c){break f}D:{if(c>>>0>z[b+8>>2]){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<c>>>0){break D}}w[b+8>>2]=c}c=cd(b,d+16|0);Jk(a+1304424|0,b,c?y[d+16>>1]:0,4)}jb=d+256|0;return j|0}a=P()|0;Bb(d+16|0);break b}a=P()|0}Bb(d+80|0)}R(a|0);M()}function gO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,A=0;e=jb-1408|0;jb=e;w[b+8>>2]=0;d=w[a+4>>2];f=w[a>>2];if((d|0)!=(f|0)){while(1){d=d-32|0;Tg(d);if((d|0)!=(f|0)){continue}break}}w[a+4>>2]=f;a:{if(!Vu(b,e+1392|0)|(w[e+1392>>2]!=1129474426|w[e+1396>>2]!=1634291279)|y[e+1400>>1]!=14){break a}if(!Qu(b,e+1376|0)|!y[e+1378>>1]|(w[e+1380>>2]-1|0)<0){break a}if(c){c=w[b>>2];if(z[e+1384>>2]>ob[w[w[c>>2]+24>>2]](c)>>>0){break a}c=w[b>>2];if(w[e+1384>>2]+(y[e+1378>>1]<<2)>>>0>ob[w[w[c>>2]+24>>2]](c)>>>0){break a}b:{if(z[a+4>>2]<z[a+8>>2]){Jm(a);break b}Gm(a)}l=Kb(12);w[l+8>>2]=0;w[l>>2]=0;w[l+4>>2]=0;c=w[a+4>>2];w[e+24>>2]=0;c=c-4|0;d=w[c>>2];w[c>>2]=l;if(d){kd(d)}c=w[e+24>>2];w[e+24>>2]=0;if(c){kd(c)}m=w[w[a+4>>2]-4>>2];$e(m,w[e+1380>>2]);Cb(e+1120|0,0,256);c:{if(!y[e+1378>>1]){break c}t=e+40|0;while(1){d:{d=w[e+1384>>2]+(s<<2)|0;if(d>>>0>z[b+8>>2]){c=w[b>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<d>>>0){break d}}w[b+8>>2]=d;j=0;c=w[b>>2];if(!(ob[w[w[c>>2]+36>>2]](c,d,4)|0)){break a}c=Nc(b,e+24|0);h=c?w[e+24>>2]:0;if(h>>>0>z[b+8>>2]){c=w[b>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<h>>>0){break a}}w[b+8>>2]=h;if(!Nm(b,e+1096|0)){break a}d=0;c=y[e+1108>>1];l=e+1080|0;w[l+8>>2]=0;w[l>>2]=0;w[l+4>>2]=0;if(c){lu(l,c);c=c<<3;v=l,A=Cb(w[l+4>>2],0,c)+c|0,w[v+4>>2]=A}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!y[e+1108>>1]){break A}c=0;B:{while(1){d=w[l>>2];w[114256]=0;g=d+(c<<3)|0;f=Q(129,b|0,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break y}if(f){c=c+1|0;d=y[e+1108>>1];if(c>>>0>=d>>>0){break B}continue}break}u[g|0]=0;u[g+1|0]=0;u[g+2|0]=0;u[g+3|0]=0;u[g+4|0]=0;u[g+5|0]=0;u[g+6|0]=0;u[g+7|0]=0;break g}if(!d){break A}c=w[l>>2];break z}c=0}g=w[b>>2];f=w[w[g>>2]+24>>2];w[114256]=0;g=V(f|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break x}n=0;f=(d&65535)<<3;d=h+20|0;if(f+d>>>0>=g>>>0){break e}f=y[e+1108>>1];r=d+(f<<3)|0;d=y[e+1110>>1];if(!(d&1)){k=0;if(!f){break f}while(1){if(!c){break g}j=w[m>>2];g=w[m+4>>2]-j|0;f=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);if(g>>>0<=f>>>0){break g}d=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);if(d>>>0>g>>>0|d-1>>>0>=g-f>>>0){break g}if(r>>>0>z[b+8>>2]){f=w[b>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}if(f>>>0<r>>>0){break g}j=w[m>>2]}w[b+8>>2]=r;h=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);g=w[b>>2];f=w[w[g>>2]+28>>2];d=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);w[114256]=0;f=Z(f|0,g|0,d+j|0,r|0,h|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}w[b+8>>2]=f+w[b+8>>2];if((f|0)!=(x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24))){break g}c=c+8|0;n=1;k=k+1|0;if(k>>>0<y[e+1108>>1]){continue}break}break e}if(d&4){if(!c){break e}g=w[m>>2];f=w[m+4>>2]-g|0;h=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);if(f>>>0<=h>>>0){break e}d=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);if(d>>>0>f>>>0|d-1>>>0>=f-h>>>0){break e}p=d&-2;if(!p){break e}j=y[e+1114>>1];o=y[e+1112>>1];i=r+o|0;if(i>>>0>z[b+8>>2]){f=w[b>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}if(f>>>0<i>>>0){break e}o=y[e+1112>>1]}w[b+8>>2]=i;f=w[b>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,i|0,w[e+1100>>2]-o|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}if(!f){break e}d=w[b+8>>2];w[114256]=0;Y(130,e+8|0,b|0,d|0,w[e+1100>>2]-y[e+1112>>1]|0);d=w[114256];w[114256]=0;if((d|0)==1){break i}w[e+24>>2]=w[e+8>>2];d=w[e+12>>2];w[e+28>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+20>>2];w[e+32>>2]=w[e+16>>2];w[e+36>>2]=d;q=0;Cb(t,0,1040);Bb(e+8|0);if(!y[e+1108>>1]){break l}o=g+h|0;k=0;C:{while(1){D:{w[114256]=0;d=Q(131,e+24|0,j+1|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}f=j&15;i=y[(f<<1)+22640>>1];E:{F:{if(i>>>0<=d>>>0){w[114256]=0;h=x[f+22688|0];g=Q(131,e+24|0,h|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}d=g+(d-i<<h)|0;if((d|0)!=(j|0)){j=d&15;break E}w[114256]=0;f=Q(131,e+24|0,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}if((f|0)==15){w[114256]=0;f=Q(131,e+24|0,1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=65535;if(!f){break F}break l}d=f+65520|0}if(d>>>0>65535){break E}}g=d&1?0-(d+1>>>1|0)|0:d>>>1|0;f=o+k|0;d=y[e+1110>>1];G:{if(d&2){q=g+q|0;d=q;break G}d=d&512?g:g^32768}u[f|0]=d;u[f+1|0]=d>>>8;k=k+2|0}H:{if(k>>>0<p>>>0){d=y[e+1108>>1];break H}d=y[e+1108>>1];n=n+1|0;if(d>>>0<=n>>>0){break l}f=w[m>>2];i=w[m+4>>2]-f|0;g=(n<<3)+c|0;h=x[g|0]|x[g+1|0]<<8|(x[g+2|0]<<16|x[g+3|0]<<24);if(i>>>0<=h>>>0){break C}g=x[g+4|0]|x[g+5|0]<<8|(x[g+6|0]<<16|x[g+7|0]<<24);if(g>>>0>i>>>0|g-1>>>0>=i-h>>>0){break C}p=g&-2;if(!p){break C}o=f+h|0;k=0}if(d>>>0>n>>>0){continue}break l}break}d=W(75512)|0;break m}Bb(e+24|0);break g}if(!c){break e}i=w[m>>2];d=w[m+4>>2]-i|0;q=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);if(d>>>0<=q>>>0){break e}k=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);if(d>>>0<k>>>0|k-1>>>0>=d-q>>>0){break e}o=y[e+1112>>1];if(o>>>0>256){break e}j=y[e+1114>>1];if(r>>>0>z[b+8>>2]){f=w[b>>2];d=w[w[f>>2]+24>>2];w[114256]=0;f=V(d|0,f|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}if(f>>>0<r>>>0){break e}o=y[e+1112>>1]}w[b+8>>2]=r;f=w[b>>2];d=w[w[f>>2]+28>>2];w[114256]=0;f=Z(d|0,f|0,e+1120|0,r|0,o|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}h=f+w[b+8>>2]|0;w[b+8>>2]=h;g=y[e+1112>>1];if(g>>>0>f>>>0){break e}f=w[b>>2];d=w[w[f>>2]+36>>2];w[114256]=0;f=S(d|0,f|0,h|0,w[e+1100>>2]-g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}if(!f){break e}d=w[b+8>>2];w[114256]=0;Y(130,e+8|0,b|0,d|0,w[e+1100>>2]-y[e+1112>>1]|0);d=w[114256];w[114256]=0;if((d|0)==1){break o}w[e+24>>2]=w[e+8>>2];d=w[e+12>>2];w[e+28>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+20>>2];w[e+32>>2]=w[e+16>>2];w[e+36>>2]=d;o=0;Cb(t,0,1040);Bb(e+8|0);if(!y[e+1108>>1]){break r}q=i+q|0;p=0;I:{while(1){J:{w[114256]=0;d=Q(131,e+24|0,j+1|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break J}f=j&7;i=x[f+22672|0];K:{L:{if(i>>>0<=d>>>0){w[114256]=0;h=x[f+22680|0];g=Q(131,e+24|0,h|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break t}d=g+(d-i<<h)|0;if((d|0)!=(j|0)){j=d&7;break K}w[114256]=0;f=Q(131,e+24|0,3)|0;d=w[114256];w[114256]=0;if((d|0)==1){break t}if((f|0)==7){w[114256]=0;f=Q(131,e+24|0,1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break t}d=255;if(!f){break L}break r}d=f+248|0}if(d>>>0>255){break K}}d=x[(e+1120|0)+d|0];f=d+o|0;g=d;d=y[e+1110>>1]&2;u[n+q|0]=d?f:g;o=d?f:o;n=n+1|0}M:{if(n>>>0<k>>>0){d=y[e+1108>>1];break M}d=y[e+1108>>1];p=p+1|0;if(d>>>0<=p>>>0){break r}f=w[m>>2];h=w[m+4>>2]-f|0;i=(p<<3)+c|0;g=x[i|0]|x[i+1|0]<<8|(x[i+2|0]<<16|x[i+3|0]<<24);if(h>>>0<=g>>>0){break I}k=x[i+4|0]|x[i+5|0]<<8|(x[i+6|0]<<16|x[i+7|0]<<24);if(h>>>0<k>>>0|k-1>>>0>=h-g>>>0){break I}q=f+g|0;n=0}if(d>>>0>p>>>0){continue}break r}break}d=W(75512)|0;break s}Bb(e+24|0);break g}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=P()|0;break h}d=W(75512)|0}if((kb|0)!=(fa(75512)|0)){break p}$(d|0)|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)==1){break q}}Bb(e+24|0);break f}d=P()|0}Bb(e+24|0);break h}d=P()|0;break h}d=W(75512)|0}if((kb|0)!=(fa(75512)|0)){break j}$(d|0)|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)==1){break k}}Bb(e+24|0);break f}d=P()|0}Bb(e+24|0);break h}d=P()|0}a=w[l>>2];if(a){w[e+1084>>2]=a;zb(a)}R(d|0);M()}n=0;break e}n=1}c=w[l>>2];if(c){w[e+1084>>2]=c;zb(c)}if(!n){break d}s=s+1|0;if(s>>>0<y[e+1378>>1]){continue}break c}break}j=0;break a}b=w[m+4>>2];c=w[m>>2];d=Kb(24);w[d+12>>2]=75592;w[d>>2]=75552;w[d+4>>2]=0;w[d+8>>2]=0;w[d+20>>2]=b-c;w[d+16>>2]=c;w[e+32>>2]=0;w[e+36>>2]=0;w[e+28>>2]=d;w[e+24>>2]=d+12;a=w[a+4>>2];c=e+24|0;he(a-20|0,c);b=a-12|0;a=w[e+36>>2];w[b>>2]=w[e+32>>2];w[b+4>>2]=a;Bb(c)}j=1}jb=e+1408|0;return j|0}function dS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=0,h=0,i=D(0),j=D(0),k=D(0),l=D(0),m=D(0),n=0,o=0,p=0,q=0,r=D(0),s=0,t=0,v=0,y=0,z=D(0),B=0,C=D(0),E=D(0),F=D(0),G=0,H=0,I=0,J=0,K=0,L=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=D(0),_=0,$=D(0);a:{if(!x[a+5046|0]){break a}l=A[a+4268>>2];yv(a);if(l==A[a+4268>>2]){break a}_m(a)}b:{if(!x[a+5045|0]){break b}o=w[a+56>>2];q=w[a+44>>2];if((0-(w[a+60>>2]-o>>11)|0)==w[a+48>>2]-q>>11){break b}s=o+2048|0;B=q+2048|0;c:{if(!(!x[a+5044|0]|(!d|x[a+4264|0]&2))){A[o>>2]=A[a+5036>>2];A[o+2048>>2]=A[a+5040>>2];u[a+5044|0]=0;B=q+2052|0;q=q+4|0;s=o+2052|0;o=o+4|0;e=d-1|0;break c}e=d}t=e;d:{if(!t){break d}I=a+4648|0;J=a+4672|0;K=a+4936|0;L=a+4696|0;N=a+4720|0;O=a+4744|0;P=a+4768|0;Q=a+4840|0;R=a+4528|0;S=a+4912|0;T=a+4552|0;U=a+4576|0;V=a+4600|0;W=a+4624|0;X=a+4816|0;v=a+4888|0;y=a+4864|0;G=a+4504|0;Y=a+4960|0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{while(1){w:{l=A[q>>2];l=D(D(D(A[a+5008>>2]-l)*A[a+4276>>2])+l);A[a+5008>>2]=l;e=w[a+4880>>2];g=w[a+4864>>2];if(e>>>0>=w[a+4868>>2]-g>>2>>>0){break w}A[g+(e<<2)>>2]=l;l=A[B>>2];l=D(D(D(A[a+5012>>2]-l)*A[a+4276>>2])+l);A[a+5012>>2]=l;e=w[a+4904>>2];g=w[a+4888>>2];if(e>>>0>=w[a+4892>>2]-g>>2>>>0){break v}A[g+(e<<2)>>2]=l;l=Zd(y,w[a+4356>>2]);f=Zd(y,w[a+4360>>2]);i=Zd(y,w[a+4364>>2]);j=Zd(y,w[a+4368>>2]);l=D(D(D(l*D(.6800000071525574))+D(D(i+Zd(y,w[a+4372>>2]))*D(-.6200000047683716)))+D(D(j+f)*D(-.5)));if(u[a+4264|0]&1){g=w[a+4816>>2];e=w[a+4820>>2]-g>>2;h=w[a+4836>>2];if(e>>>0<=h>>>0){break u}p=e;e=w[a+4832>>2];if(p>>>0<=e>>>0){break u}z=l;l=D(A[g+(h<<2)>>2]+D(l*D(.6180340051651001)));A[g+(e<<2)>>2]=z-D(l*D(.6180340051651001))}Z=A[a+4280>>2];_=a,$=D(Zd(y,w[a+4352>>2])+A[a+5020>>2]),A[_+5020>>2]=$;f=D(Zd(v,w[a+4376>>2])+A[a+5024>>2]);A[a+5024>>2]=f;g=w[a+4624>>2];e=w[a+4628>>2]-g>>2;h=w[a+4644>>2];if(e>>>0<=h>>>0){break t}i=A[a+5020>>2];j=A[g+(h<<2)>>2];j=D(D(D(A[a+4980>>2]-j)*A[a+4444>>2])+j);A[a+4980>>2]=j;h=e;e=w[a+4640>>2];if(h>>>0<=e>>>0){break t}m=D(i*D(-.7070000171661377));r=D(f*D(.7070000171661377));f=D(m+r);C=A[a+4272>>2];i=D(D(f*C)+D(j*A[a+4440>>2]));A[g+(e<<2)>>2]=f-D(i*C);g=w[a+4600>>2];e=w[a+4604>>2]-g>>2;h=w[a+4620>>2];if(e>>>0<=h>>>0){break s}f=A[g+(h<<2)>>2];f=D(D(D(A[a+4976>>2]-f)*A[a+4436>>2])+f);A[a+4976>>2]=f;h=e;e=w[a+4616>>2];if(h>>>0<=e>>>0){break s}j=A[a+4272>>2];f=D(D(j*i)+D(f*A[a+4432>>2]));A[g+(e<<2)>>2]=i-D(f*j);C=D(D(i*D(-.15000000596046448))+D(f*D(-.20000000298023224)));if(u[a+4264|0]&1){g=w[a+4576>>2];e=w[a+4580>>2]-g>>2;h=w[a+4596>>2];if(e>>>0<=h>>>0){break r}i=A[g+(h<<2)>>2];i=D(D(D(A[a+4972>>2]-i)*A[a+4428>>2])+i);A[a+4972>>2]=i;h=e;e=w[a+4592>>2];if(h>>>0<=e>>>0){break r}j=A[a+4272>>2];i=D(D(j*f)+D(i*A[a+4424>>2]));A[g+(e<<2)>>2]=f-D(i*j);g=w[a+4552>>2];e=w[a+4556>>2]-g>>2;h=w[a+4572>>2];if(e>>>0<=h>>>0){break q}f=A[g+(h<<2)>>2];f=D(D(D(A[a+4968>>2]-f)*A[a+4420>>2])+f);A[a+4968>>2]=f;h=e;e=w[a+4568>>2];if(h>>>0<=e>>>0){break q}j=A[a+4272>>2];f=D(D(j*i)+D(A[a+4416>>2]*f));A[g+(e<<2)>>2]=i-D(f*j);C=D(D(D(i*D(.3499999940395355))+C)+D(f*D(-.3799999952316284)))}g=w[a+4912>>2];e=w[a+4916>>2]-g>>2;h=w[a+4928>>2];if(e>>>0<=h>>>0){break p}A[g+(h<<2)>>2]=f;h=e;e=w[a+4932>>2];if(h>>>0<=e>>>0){break p}f=D(A[a+4496>>2]*A[g+(e<<2)>>2]);f=D(D(D(A[a+5028>>2]-f)*A[a+4500>>2])+f);A[a+5028>>2]=f;g=w[a+4528>>2];e=w[a+4532>>2]-g>>2;h=w[a+4548>>2];if(e>>>0<=h>>>0){break o}i=A[g+(h<<2)>>2];i=D(D(D(A[a+4964>>2]-i)*A[a+4412>>2])+i);A[a+4964>>2]=i;h=e;e=w[a+4544>>2];if(h>>>0<=e>>>0){break o}z=D(A[a+4408>>2]*i);i=A[a+4272>>2];k=D(z+D(i*f));A[g+(e<<2)>>2]=f-D(k*i);g=w[a+4504>>2];e=w[a+4508>>2]-g>>2;h=w[a+4524>>2];if(e>>>0<=h>>>0){break n}f=A[g+(h<<2)>>2];f=D(D(D(A[a+4960>>2]-f)*A[a+4404>>2])+f);A[a+4960>>2]=f;h=e;e=w[a+4520>>2];if(h>>>0<=e>>>0){break n}i=A[a+4272>>2];F=D(D(i*k)+D(A[a+4400>>2]*f));A[g+(e<<2)>>2]=k-D(F*i);A[a+5020>>2]=F;f=Zd(v,w[a+4380>>2]);i=Zd(v,w[a+4384>>2]);j=Zd(v,w[a+4388>>2]);E=Zd(v,w[a+4392>>2]);i=D(D(D(f*D(.7070000171661377))+D(D(j+Zd(v,w[a+4396>>2]))*D(-.5)))+D(D(E+i)*D(-.6000000238418579)));H=w[a+4264>>2];e=H&1;if(e){g=w[a+4840>>2];h=w[a+4844>>2]-g>>2;n=w[a+4860>>2];if(h>>>0<=n>>>0){break m}p=h;h=w[a+4856>>2];if(p>>>0<=h>>>0){break m}z=i;i=D(A[g+(n<<2)>>2]+D(i*D(.6180340051651001)));A[g+(h<<2)>>2]=z-D(i*D(.6180340051651001))}g=w[a+4768>>2];h=w[a+4772>>2]-g>>2;n=w[a+4788>>2];if(h>>>0<=n>>>0){break l}E=A[a+4280>>2];f=A[g+(n<<2)>>2];f=D(D(D(A[a+5004>>2]-f)*A[a+4492>>2])+f);A[a+5004>>2]=f;p=h;h=w[a+4784>>2];if(p>>>0<=h>>>0){break l}m=D(m-r);r=A[a+4272>>2];j=D(D(m*r)+D(f*A[a+4488>>2]));A[g+(h<<2)>>2]=m-D(j*r);g=w[a+4744>>2];h=w[a+4748>>2]-g>>2;n=w[a+4764>>2];if(h>>>0<=n>>>0){break k}f=A[g+(n<<2)>>2];f=D(D(D(A[a+5e3>>2]-f)*A[a+4484>>2])+f);A[a+5e3>>2]=f;p=h;h=w[a+4760>>2];if(p>>>0<=h>>>0){break k}m=A[a+4272>>2];f=D(D(m*j)+D(f*A[a+4480>>2]));A[g+(h<<2)>>2]=j-D(f*m);j=D(D(f*D(-.20000000298023224))+D(D(k*D(.3799999952316284))+D(j*D(-.15000000596046448))));if(e){g=w[a+4720>>2];e=w[a+4724>>2]-g>>2;h=w[a+4740>>2];if(e>>>0<=h>>>0){break j}k=A[g+(h<<2)>>2];k=D(D(D(A[a+4996>>2]-k)*A[a+4476>>2])+k);A[a+4996>>2]=k;h=e;e=w[a+4736>>2];if(h>>>0<=e>>>0){break j}m=A[a+4272>>2];k=D(D(m*f)+D(k*A[a+4472>>2]));A[g+(e<<2)>>2]=f-D(k*m);g=w[a+4696>>2];e=w[a+4700>>2]-g>>2;h=w[a+4716>>2];if(e>>>0<=h>>>0){break i}f=A[g+(h<<2)>>2];f=D(D(D(A[a+4992>>2]-f)*A[a+4468>>2])+f);A[a+4992>>2]=f;h=e;e=w[a+4712>>2];if(h>>>0<=e>>>0){break i}m=A[a+4272>>2];f=D(D(m*k)+D(A[a+4464>>2]*f));A[g+(e<<2)>>2]=k-D(f*m);j=D(D(D(k*D(.3499999940395355))+j)+D(f*D(-.3799999952316284)))}g=w[a+4936>>2];e=w[a+4940>>2]-g>>2;h=w[a+4952>>2];if(e>>>0<=h>>>0){break h}A[g+(h<<2)>>2]=f;h=e;e=w[a+4956>>2];if(h>>>0<=e>>>0){break h}f=D(A[a+4496>>2]*A[g+(e<<2)>>2]);f=D(D(D(A[a+5032>>2]-f)*A[a+4500>>2])+f);A[a+5032>>2]=f;g=w[a+4672>>2];e=w[a+4676>>2]-g>>2;h=w[a+4692>>2];if(e>>>0<=h>>>0){break g}k=A[g+(h<<2)>>2];k=D(D(D(A[a+4988>>2]-k)*A[a+4460>>2])+k);A[a+4988>>2]=k;h=e;e=w[a+4688>>2];if(h>>>0<=e>>>0){break g}z=f;r=D(A[a+4456>>2]*k);k=A[a+4272>>2];f=D(r+D(k*f));A[g+(e<<2)>>2]=z-D(f*k);g=w[a+4648>>2];e=w[a+4652>>2]-g>>2;h=w[a+4668>>2];if(e>>>0<=h>>>0){break f}k=A[a+4284>>2];m=A[g+(h<<2)>>2];m=D(D(D(A[a+4984>>2]-m)*A[a+4452>>2])+m);A[a+4984>>2]=m;n=w[a+4664>>2];if(n>>>0>=e>>>0){break f}e=q+4|0;h=B+4|0;r=D(E*i);E=A[a+4272>>2];i=D(D(E*f)+D(A[a+4448>>2]*m));A[g+(n<<2)>>2]=f-D(i*E);A[a+5024>>2]=i;i=D(i*D(.3799999952316284));l=D(D(k*D(D(D(f-F)*D(.3799999952316284))+C))+D(Z*l));f=A[a+4288>>2];g=G;while(1){n=w[g+16>>2];p=n-1|0;w[g+16>>2]=p;if((n|0)<=0){w[g+16>>2]=p+w[g+12>>2]}n=w[g+20>>2];p=n-1|0;w[g+20>>2]=p;if((n|0)<=0){w[g+20>>2]=p+w[g+12>>2]}g=g+24|0;if((Y|0)!=(g|0)){continue}break}f=D(D(D(j-i)*f)+r);x:{if(H&2){B=h;break x}A[o>>2]=D(A[a+5036>>2]+l)*D(.5);A[s>>2]=D(A[a+5040>>2]+f)*D(.5);A[a+5040>>2]=f;A[a+5036>>2]=l;if((t|0)==1){break e}t=t-1|0;B=B+8|0;s=s+4|0;o=o+4|0;e=q+8|0}q=e;A[o>>2]=l;A[s>>2]=f;s=s+4|0;o=o+4|0;t=t-1|0;if(t){continue}break d}break}Bc(y);M()}Bc(v);M()}Bc(X);M()}Bc(W);M()}Bc(V);M()}Bc(U);M()}Bc(T);M()}Bc(S);M()}Bc(R);M()}Bc(G);M()}Bc(Q);M()}Bc(P);M()}Bc(O);M()}Bc(N);M()}Bc(L);M()}Bc(K);M()}Bc(J);M()}Bc(I);M()}u[a+5044|0]=1}e=a;a=w[a+56>>2];ye(e,b,c,a,a+2048|0,d)}}function Ks(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=jb-336|0;jb=k;n=h;p=i&65535;o=d;m=e&65535;r=(e^i)&-2147483648;t=i>>>16&32767;u=e>>>16&32767;a:{b:{if(t-32767>>>0>4294934529&u-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){y=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){y=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));y=b?0:y;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|o);h=d<<6;j=F(d?b:o)+32|0;b=F(d?c:m);b=h+((b|0)==32?j:b)|0;$c(k+320|0,i,c,o,m,b-15|0);l=16-b|0;o=w[k+328>>2];m=w[k+332>>2];c=w[k+324>>2];b=w[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);e=d<<6;h=F(d?f:n)+32|0;d=F(d?g:p);d=e+((d|0)==32?h:d)|0;$c(k+304|0,f,g,n,p,d-15|0);l=(d+l|0)-16|0;n=w[k+312>>2];p=w[k+316>>2];f=w[k+304>>2];g=w[k+308>>2]}e=p|65536;E=e;G=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;Rc(k+288|0,e,j,0,0,d,i,0,0);j=w[k+296>>2];Rc(k+272|0,0-j|0,0-(w[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=w[k+280>>2];i=d<<1|w[k+276>>2]>>>31;d=w[k+284>>2]<<1|d>>>31;Rc(k+256|0,i,d,0,0,e,h,0,0);j=d;d=w[k+264>>2];Rc(k+240|0,i,j,0,0,0-d|0,0-(w[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=w[k+248>>2];j=i<<1|w[k+244>>2]>>>31;d=w[k+252>>2]<<1|i>>>31;Rc(k+224|0,j,d,0,0,e,h,0,0);i=d;d=w[k+232>>2];Rc(k+208|0,j,i,0,0,0-d|0,0-(w[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=w[k+216>>2];i=d<<1|w[k+212>>2]>>>31;d=w[k+220>>2]<<1|d>>>31;Rc(k+192|0,i,d,0,0,e,h,0,0);j=d;d=w[k+200>>2];Rc(k+176|0,i,j,0,0,0-d|0,0-(w[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=w[k+184>>2];e=i<<1|w[k+180>>2]>>>31;s=e-1|0;i=(w[k+188>>2]<<1|i>>>31)-!e|0;Rc(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;Rc(k+144|0,d<<15,j,0,0,s,i,0,0);h=w[k+172>>2];p=w[k+160>>2];e=w[k+152>>2];d=p+e|0;n=w[k+164>>2];j=n+w[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<p>>>0|d>>>0<n>>>0;j=n+w[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;p=!d&e>>>0>1|(d|0)!=0;n=p+j|0;j=h;h=n;Rc(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<p>>>0?j+1|0:j)|0)|0,0,0);Rc(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);L=(u-t|0)+l|0;e=w[k+116>>2];B=e;d=w[k+112>>2];j=e<<1|d>>>31;C=d<<1;q=j;d=j;h=w[k+140>>2];A=h;e=w[k+136>>2];j=h<<1|e>>>31;i=e<<1|w[k+132>>2]>>>31;h=i+C|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;n=d;l=0;j=m|65536;M=j;N=o;d=o;j=j<<1|d>>>31;Q=d<<1;R=j;H=j;x=BV(n,l,j,0);d=nb;v=d;j=b;d=c<<1|j>>>31;t=j<<1;s=d;p=d;j=0;u=j;i=h-13927|0;l=(e|0)==(n|0)&i>>>0<h>>>0|e>>>0>n>>>0;m=(e|0)==(q|0)&h>>>0<C>>>0|e>>>0<q>>>0;d=w[k+120>>2];h=w[k+124>>2]<<1|d>>>31;e=A>>>31|0;d=e+(d<<1|B>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;I=l-!e|0;C=0;j=BV(p,u,I,C);e=j+x|0;h=nb+v|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(v|0)&e>>>0<x>>>0|h>>>0<v>>>0;j=0;x=l;q=d;d=o;O=c>>>31|0;v=O|d<<1;A=0;l=BV(q,j,v,A);d=l+e|0;j=nb+h|0;j=d>>>0<l>>>0?j+1|0:j;o=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=x+e|0;l=0;l=d>>>0<e>>>0?1:l;e=BV(H,u,I,C);d=e+d|0;j=nb+l|0;x=d;d=d>>>0<e>>>0?j+1|0:j;l=BV(H,u,q,A);h=nb;D=BV(v,A,I,C);e=D+l|0;j=nb+h|0;j=e>>>0<D>>>0?j+1|0:j;D=e;e=j;j=(h|0)==(j|0)&l>>>0>D>>>0|h>>>0>j>>>0;l=x+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+o|0;j=m+D|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<o>>>0|j>>>0<m>>>0;h=m+h|0;j=l;x=h;l=h>>>0<m>>>0?j+1|0:j;o=d;m=e;D=i;h=BV(i,0,v,A);e=nb;i=BV(n,u,p,u);d=i+h|0;j=nb+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;J=x;B=e;K=t&-2;i=BV(q,A,K,0);e=i+d|0;j=nb+j|0;j=e>>>0<i>>>0?j+1|0:j;x=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=B+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+o|0;d=h+m|0;B=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<o>>>0|d>>>0<m>>>0;d=J+h|0;j=l;J=d;o=d>>>0<h>>>0?j+1|0:j;P=BV(H,u,D,y);H=nb;h=BV(I,C,K,y);d=h+P|0;j=nb+H|0;I=d;m=BV(n,u,v,A);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+nb|0;d=l>>>0<m>>>0?d+1|0:d;v=l;m=BV(p,u,q,A);j=l+m|0;l=nb+d|0;C=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&v>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&v>>>0<I>>>0|d>>>0<h>>>0;d=j+((h|0)==(H|0)&I>>>0<P>>>0|h>>>0<H>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+B|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<B>>>0|i>>>0>j>>>0;d=h+J|0;j=o;v=d;i=d>>>0<h>>>0?j+1|0:j;B=BV(n,u,K,y);n=nb;h=BV(p,u,D,y);d=h+B|0;j=nb+n|0;j=d>>>0<h>>>0?j+1|0:j;o=0;h=(j|0)==(n|0)&d>>>0<B>>>0|j>>>0<n>>>0;n=j;d=j+x|0;j=(h|o)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<x>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=C+d|0;l=e>>>0<o>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+v|0;l=i;l=h>>>0<j>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){N=Q|O;M=A|R;Rc(k+80|0,d,e,h,i,f,g,G,E);j=b<<17;b=0;c=w[k+88>>2];m=b-c|0;l=w[k+80>>2];p=w[k+84>>2];n=(l|p)!=0;o=m-n|0;m=(j-(w[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+p|0)|0;b=L+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Rc(k+96|0,d,e,h,i,f,g,G,E);m=0;n=w[k+104>>2];p=m-n|0;l=w[k+96>>2];s=w[k+100>>2];t=(l|s)!=0;o=p-t|0;m=((b<<16)-(w[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(p>>>0<t>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;t=b;s=c;b=L+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=o;l=m<<1|c>>>31;o=c<<1|p>>>31;m=l;t=h;s=i&65535|b<<16;b=n;l=p<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}fg(k- -64|0,d,e,h,i,1-b|0);$c(k+48|0,t,s,N,M,b+112|0);d=w[k+64>>2];e=w[k+68>>2];t=w[k+72>>2];s=w[k+76>>2];Rc(k+32|0,f,g,G,E,d,e,t,s);c=w[k+40>>2];i=c<<1;c=w[k+44>>2]<<1|c>>>31;b=w[k+56>>2];h=w[k+36>>2];o=h>>>31|i;i=b-o|0;l=w[k+60>>2]-((b>>>0<o>>>0)+c|0)|0;c=w[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=w[k+52>>2];b=w[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;o=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=b-c|0;l=j-((c>>>0>i>>>0)+h|0)|0}Rc(k+16|0,f,g,G,E,3,0,0,0);Rc(k,f,g,G,E,5,0,0,0);j=0;h=l+j|0;n=d&1;c=b+n|0;h=c>>>0<b>>>0?h+1|0:h;i=c;b=i;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(h|0)==(j|0)&b>>>0<n>>>0|h>>>0<j>>>0;b=c+o|0;l=m;l=b>>>0<c>>>0?l+1|0:l;f=b;c=(l|0)==(E|0);c=c&(b|0)==(G|0)?g:c&b>>>0>G>>>0|l>>>0>E>>>0;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;c=b;b=j;e=(j|0)==(e|0)&c>>>0<d>>>0|e>>>0>j>>>0;d=e+t|0;j=s;j=d>>>0<e>>>0?j+1|0:j;o=d;d=w[k+20>>2];g=(d|0)==(h|0)&z[k+16>>2]<i>>>0|d>>>0<h>>>0;d=w[k+28>>2];e=w[k+24>>2];g=j>>>0<2147418112&((e|0)==(f|0)&(d|0)==(l|0)?g:(d|0)==(l|0)&e>>>0<f>>>0|d>>>0<l>>>0);e=g+c|0;d=b;d=e>>>0<g>>>0?d+1|0:d;c=(b|0)==(d|0)&c>>>0>e>>>0|b>>>0>d>>>0;b=o+c|0;j=b>>>0<c>>>0?j+1|0:j;g=b;b=w[k+4>>2];h=(b|0)==(h|0)&z[k>>2]<i>>>0|b>>>0<h>>>0;b=w[k+12>>2];c=w[k+8>>2];c=j>>>0<2147418112&((c|0)==(f|0)&(b|0)==(l|0)?h:(b|0)==(l|0)&c>>>0<f>>>0|b>>>0<l>>>0);b=c+e|0;l=b>>>0<c>>>0?d+1|0:d;c=l;f=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;e=g+f|0;d=j;y=e|y;r=r|(e>>>0<f>>>0?d+1|0:d)}w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=y;w[a+12>>2]=r;jb=k+336|0}function Pw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-224|0;jb=g;v[a+480212>>1]=0;w[a+480240>>2]=65536;w[a+480244>>2]=65536;Cb(a+900380|0,0,1024);Cb(a+946304|0,0,128e3);Cb(g+72|0,0,148);d=a+906300|0;f=g+76|0;e=250;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{while(1){w[d>>2]=0;w[114256]=0;U(818,d+4|0,0,0);h=w[114256];w[114256]=0;if((h|0)==1){break q}Fb(d+16|0,f,144);d=d+160|0;h=e>>>0>1;e=e-1|0;if(h){continue}break}d=w[b>>2];e=w[w[d>>2]+8>>2];w[114256]=0;d=V(e|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}if(!d){break l}e=0;w[g+80>>2]=0;w[g+72>>2]=0;w[g+76>>2]=0;f=0;if(c&16){break o}w[114256]=0;h=(c|0)!=0;f=S(819,g+72|0,b|0,h|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=4;r:{if(f){break r}w[114256]=0;f=S(820,g+72|0,b|0,h|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=5;if(f){break r}w[114256]=0;f=S(821,g+72|0,b|0,h|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=6;if(f){break r}f=0;w[114256]=0;h=S(822,g+72|0,b|0,h|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}d=3;if(!h){break o}}if(c){break p}e=1;break b}a=P()|0;break c}f=w[g+72>>2];if((f|0)!=w[g+76>>2]){sp(b,f+12|0);h=w[f+24>>2];w[b+8>>2]=w[f+20>>2];w[b+12>>2]=h}f=d}if(c&32){break b}d=76368;s:{t:{while(1){i=w[d+8>>2];h=(i>>1)+a|0;e=w[d+4>>2];e=i&1?w[w[h>>2]+e>>2]:e;w[114256]=0;e=S(e|0,h|0,b|0,c|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){if(e){break s}d=d+12|0;if((d|0)==76824){break t}continue}break}a=W(74672)|0;break m}w[a+480180>>2]=0;w[a+480184>>2]=0}if(!c){break b}if(!(w[a+480184>>2]|!f)){w[a+480184>>2]=f}gk(g+72|0);break k}a=W(74672)|0}c=kb;gk(g+72|0);if((fa(74672)|0)!=(c|0)){break c}$(a|0)|0;w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)==1){a=P()|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)!=1){break c}W(0)|0;Eb()}M()}w[114256]=0;T(236,a|0,0);d=w[114256];w[114256]=0;if((d|0)==1){break j}w[a+1074304>>2]=19469585}d=0;while(1){e=(d<<5)+a|0;f=e+480286|0;if(y[f>>1]>=65){v[f>>1]=64}f=e+480284|0;if(y[f>>1]>=257){v[f>>1]=128}e=e+480288|0;if(x[e|0]>=251){u[e|0]=0}w[114256]=0;ga(823,(C(d,896)+a|0)+1074984|0,7,a|0,d&65535,1024);e=w[114256];w[114256]=0;if((e|0)==1){break e}d=d+1|0;if((d|0)!=127){continue}break}if(y[a+480190>>1]){e=1;while(1){f=C(e&65535,104)+a|0;d=f+484380|0;u:{if(!(!w[f+484400>>2]|!w[d>>2])){w[114256]=0;U(739,d|0,a|0,0);d=w[114256];w[114256]=0;if((d|0)!=1){break u}break d}h=f+484414|0;i=y[h>>1];if(i&16384){break u}w[d>>2]=0;w[d+4>>2]=0;w[d+16>>2]=0;w[d+8>>2]=0;w[d+12>>2]=0;v[h>>1]=i&65505}d=f+484412|0;if(y[d>>1]>=65){v[d>>1]=64}if(!(w[a+1304392>>2]|!(x[f+484415|0]&2))){w[114256]=0;X(824,a|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}e=e+1|0;if(y[a+480190>>1]>=(e&65535)>>>0){continue}break}}d=0;e=0;while(1){v:{f=w[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break v}e=w[a+480180>>2];w[114256]=0;T(825,f|0,e|0);f=w[114256];w[114256]=0;e=d;if((f|0)!=1){break v}a=P()|0;break c}d=d+1|0;if(y[a+480192>>1]>=(d&65535)>>>0){continue}break}v[a+480192>>1]=e;d=125e4;i=w[a+480204>>2];w:{if(i>>>0>=1e4){d=65535e4;if(i>>>0<655350001){break w}}w[a+480204>>2]=d;i=d}f=w[a+480196>>2];if(!f){w[a+480196>>2]=6;f=6}d=w[a+480216>>2];h=w[a+480220>>2];if(d>>>0>h>>>0){w[a+480220>>2]=d;h=d}if(d>>>0>=65537){w[a+480216>>2]=65536;d=65536}if(h>>>0>=65537){w[a+480220>>2]=65536;h=65536}e=w[a+480200>>2];if(e>>>0>=257){w[a+480200>>2]=256;e=256}if(w[a+480248>>2]!=w[a+480252>>2]){w[114256]=0;w[g+72>>2]=16777216;e=a+480248|0;U(826,e|0,d|0,g+72|0);d=w[114256];w[114256]=0;if((d|0)==1){break i}w[114256]=0;X(827,e|0);d=w[114256];w[114256]=0;if((d|0)==1){break i}e=w[a+480200>>2];h=w[a+480220>>2];i=w[a+480204>>2];f=w[a+480196>>2];d=w[a+480216>>2]}v[a+480276>>1]=0;w[a+1074420>>2]=i;w[a+1074416>>2]=f;w[a+1074460>>2]=e<<12;w[a+1074444>>2]=e;w[a+1074412>>2]=h;w[a+1074408>>2]=d;w[a+1074456>>2]=e;d=a+1074448|0;w[d>>2]=0;w[d+4>>2]=0;w[a+1074392>>2]=-2;d=a+1074384|0;w[d>>2]=0;w[d+4>>2]=0;w[a+1074380>>2]=0;d=a+1074424|0;w[d>>2]=0;w[d+4>>2]=0;w[a+1074440>>2]=-65536;d=a+1074432|0;w[d>>2]=0;w[d+4>>2]=0;d=a+1074396|0;w[d>>2]=0;w[d+4>>2]=0;_g(a);w[114256]=0;T(732,a+1304360|0,1);d=w[114256];w[114256]=0;if((d|0)==1){break i}d=w[a+484360>>2];e=w[a+484364>>2];if((d|0)!=(e|0)){while(1){w[114256]=0;f=V(828,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break h}w[114256]=0;v[g+72>>1]=65535;U(524,d|0,f|0,g+72|0);f=w[114256];w[114256]=0;if((f|0)==1){break h}if(y[d+28>>1]>=w[d+4>>2]-w[d>>2]>>1>>>0){v[d+28>>1]=0}d=d+32|0;if((e|0)!=(d|0)){continue}break}}w[g+64>>2]=0;w[g+56>>2]=0;w[g+60>>2]=0;x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{if((c&12)==12){c=0;while(1){h=C(c,160)+a|0;e=h+906320|0;i=h+906316|0;L:{if(!(w[e>>2]|w[i>>2])){break L}w[114256]=0;d=h+906300|0;Q(829,d|0,a|0)|0;f=w[114256];w[114256]=0;M:{if((f|0)!=1){d=w[d>>2];if(!d){break M}e=w[h+906448>>2];f=w[w[d>>2]+56>>2];w[114256]=0;T(f|0,d|0,e|0);d=w[114256];w[114256]=0;if((d|0)!=1){break L}}a=P()|0;break f}N:{O:{d=w[g+56>>2];f=w[g+60>>2];if((d|0)==(f|0)){break O}j=w[e>>2];while(1){e=w[d>>2];if((j|0)==(x[e+4|0]|x[e+5|0]<<8|(x[e+6|0]<<16|x[e+7|0]<<24))&w[i>>2]==(x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24))){break O}d=d+4|0;if((f|0)!=(d|0)){continue}break}break N}if((d|0)!=(f|0)){break L}}w[g+40>>2]=i;P:{if(f>>>0<z[g+64>>2]){w[f>>2]=i;w[g+60>>2]=f+4;break P}w[114256]=0;T(830,g+56|0,g+40|0);d=w[114256];w[114256]=0;if((d|0)==1){break x}}w[114256]=0;e=Q(1,g+24|0,13431)|0;d=w[114256];w[114256]=0;if((d|0)==1){break J}w[114256]=0;d=Q(5,g+72|0,h+906380|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break I}w[114256]=0;U(6,g+8|0,0,d|0);f=w[114256];w[114256]=0;if((f|0)==1){break K}if(u[g+83|0]<0){zb(w[d>>2])}w[114256]=0;d=x[g+19|0];f=d<<24>>24<0;d=S(2,e|0,(f?w[g+8>>2]:g+8|0)|0,(f?w[g+12>>2]:d)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break H}w[g+48>>2]=w[d+8>>2];f=w[d+4>>2];w[g+40>>2]=w[d>>2];w[g+44>>2]=f;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;w[114256]=0;U(367,a|0,2,g+40|0);d=w[114256];w[114256]=0;if((d|0)==1){break G}if(u[g+51|0]<0){zb(w[g+40>>2])}if(u[g+19|0]<0){zb(w[g+8>>2])}if(u[g+35|0]>=0){break L}zb(w[e>>2])}c=c+1|0;if((c|0)!=250){continue}break}}c=w[a+1074372>>2];w[114256]=0;T(831,a|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}d=w[a+480180>>2];if(!d){break y}e=77868;c=$g(a);switch(c-2|0){case 1:break A;case 0:break B;case 2:break C;default:break D}}a=P()|0;if(u[g+83|0]>=0){break E}zb(w[d>>2]);break E}a=P()|0;break f}a=P()|0;break E}a=P()|0;break F}a=P()|0;if(u[g+51|0]>=0){break F}zb(w[g+40>>2])}if(u[g+19|0]>=0){break E}zb(w[g+8>>2])}if(u[g+35|0]>=0){break f}zb(w[e>>2]);break f}if((c|0)==16777216){break z}if((c|0)!=32){break A}e=77884;break z}e=77880;break z}e=77876;break z}e=77872}w[a+8>>2]=w[e>>2];if(!w[a+1074308>>2]){break y}w[114256]=0;X(832,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break g}}a=w[g+56>>2];if(a){w[g+60>>2]=a;zb(a)}e=(d|0)!=0;break a}a=P()|0;break f}a=P()|0;break c}a=P()|0;break c}a=P()|0;break c}a=P()|0}c=w[g+56>>2];if(!c){break c}w[g+60>>2]=c;zb(c);break c}a=P()|0;break c}a=P()|0}Bb(b);R(a|0);M()}gk(g+72|0)}Bb(b);jb=g+224|0;return e|0}function jU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-384|0;jb=f;rd(f+248|0,b);e=jb-32|0;jb=e;w[e>>2]=0;g=e+4|0;w[e+20>>2]=g;w[e+16>>2]=e;Ob(b,e+16|0);a:{if(w[e>>2]!=1413698376){break a}w[e>>2]=0;w[e+20>>2]=g;w[e+16>>2]=e;Ob(b,e+16|0);j=-1;g=w[e>>2];if(g-3>>>0<4294967294){break a}b:{c:{d:{e:{if(g>>>0<=1){w[e+24>>2]=0;w[114256]=0;w[e+16>>2]=0;w[e+20>>2]=0;w[e+28>>2]=0;w[e+4>>2]=e+32;w[e>>2]=e+28;k=kc(b,e);i=nb;g=w[114256];w[114256]=0;if((g|0)!=1){f:{if((k|0)!=4|i){break a}h=w[e+28>>2];if(h>>>0>256){break a}g:{if(h){m=e+29|0;while(1){w[114256]=0;u[e+28|0]=0;w[e+4>>2]=m;w[e>>2]=e+28;k=kc(b,e);i=nb;g=w[114256];w[114256]=0;if((g|0)==1){break g}if((k|0)!=1|i){break e}g=u[e+28|0];w[114256]=0;T(71,e+16|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break g}l=l+1|0;if((h|0)!=(l|0)){continue}break}}w[114256]=0;U(6,e|0,d|0,e+16|0);g=w[114256];w[114256]=0;if((g|0)==1){break f}if(u[c+11|0]<0){zb(w[c>>2])}g=w[e+4>>2];w[c>>2]=w[e>>2];w[c+4>>2]=g;w[c+8>>2]=w[e+8>>2];if(u[e+27|0]>=0){break b}zb(w[e+16>>2]);break b}}}a=P()|0;if(u[e+27|0]>=0){break c}zb(w[e+16>>2]);break c}w[e+24>>2]=0;w[114256]=0;w[e+16>>2]=0;w[e+20>>2]=0;u[e+28|0]=0;w[e+4>>2]=e+29;w[e>>2]=e+28;k=kc(b,e);i=nb;g=w[114256];w[114256]=0;if((g|0)!=1){h:{if((k|0)!=1|i){break a}i:{h=x[e+28|0];if(h){m=e+29|0;while(1){w[114256]=0;u[e+28|0]=0;w[e+4>>2]=m;w[e>>2]=e+28;k=kc(b,e);i=nb;g=w[114256];w[114256]=0;if((g|0)==1){break i}if((k|0)!=1|i){break d}g=u[e+28|0];w[114256]=0;T(71,e+16|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break i}l=l+1|0;if((h|0)!=(l&255)){continue}break}}w[114256]=0;U(6,e|0,d|0,e+16|0);g=w[114256];w[114256]=0;if((g|0)==1){break h}if(u[c+11|0]<0){zb(w[c>>2])}g=w[e+4>>2];w[c>>2]=w[e>>2];w[c+4>>2]=g;w[c+8>>2]=w[e+8>>2];if(u[e+27|0]>=0){break b}zb(w[e+16>>2]);break b}}}a=P()|0;if(u[e+27|0]>=0){break c}zb(w[e+16>>2]);break c}if(u[e+27|0]>=0){break a}zb(w[e+16>>2]);break a}if(u[e+27|0]>=0){break a}zb(w[e+16>>2]);break a}R(a|0);M()}l=0;v[e>>1]=0;w[e+20>>2]=e+2;w[e+16>>2]=e;Ob(b,e+16|0);w[e>>2]=0;w[e+20>>2]=e+4;w[e+16>>2]=e;Ob(b,e+16|0);g=w[e>>2];if(g>>>0>50){break a}if(g){while(1){if(!Zv(a,b,d)){break a}l=l+1|0;if((g|0)!=(l|0)){continue}break}}w[e>>2]=0;w[e+20>>2]=e+4;w[e+16>>2]=e;Ob(b,e+16|0);j=w[e>>2]==1413698374?1:-1}jb=e+32|0;j:{k:{l:{m:{n:{o:{p:{if(!j){Jg(w[w[b>>2]-12>>2]+b|0,0);g=w[f+260>>2];w[f+48>>2]=w[f+256>>2];w[f+52>>2]=g;g=w[f+252>>2];w[f+40>>2]=w[f+248>>2];w[f+44>>2]=g;rf(b,f+40|0);h=mg(f+144|0,b);w[114256]=0;g=Q(5,f+128|0,9906)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}w[114256]=0;w[f+368>>2]=3;w[f+372>>2]=0;U(397,h|0,g|0,f+368|0);b=w[114256];w[114256]=0;if((b|0)==1){break l}if(u[g+11|0]<0){zb(w[g>>2])}w[114256]=0;u[f+127|0]=0;g=Q(5,f+112|0,10255)|0;b=w[114256];w[114256]=0;if((b|0)==1){break m}w[114256]=0;S(398,h|0,f+127|0,g|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}if(u[g+11|0]<0){zb(w[g>>2])}g=x[f+127|0];j=w[h+24>>2];if(!(j&16)){w[114256]=0;X(974,h|0);b=w[114256];w[114256]=0;if((b|0)==1){break o}j=w[h+24>>2]}i=w[h+44>>2];if(!(j&16)){w[114256]=0;X(974,h|0);b=w[114256];w[114256]=0;if((b|0)==1){break p}}m=w[h+48>>2];w[f+104>>2]=i;if((i|0)!=(m|0)){k=g?0:d;while(1){w[114256]=0;v[f+102>>1]=65535;i=Q(5,f+88|0,11706)|0;b=w[114256];w[114256]=0;q:{r:{s:{t:{if((b|0)!=1){j=1;b=w[f+104>>2];d=w[b>>2];g=w[h+32>>2];if(d>>>0<w[h+36>>2]-g>>>0){b=y[b+12>>1];w[114256]=0;d=S(975,f+264|0,d+g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break t}b=Yd(i,d);if(u[f+275|0]<0){zb(w[d>>2])}j=b^1}if(u[f+99|0]<0){zb(w[i>>2])}if(j){break s}d=w[h+28>>2];b=w[w[d>>2]-12>>2];w[114256]=0;T(16,b+d|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break r}b=w[w[f+104>>2]+4>>2];if(b){i=w[h+28>>2];g=w[h+8>>2];d=w[h+12>>2];w[114256]=0;g=b+g|0;d=g>>>0<b>>>0?d+1|0:d;b=g;w[f+376>>2]=b;w[f+380>>2]=d;w[f+16>>2]=b;w[f+20>>2]=d;w[f+368>>2]=0;w[f+372>>2]=0;w[f+8>>2]=0;w[f+12>>2]=0;Q(976,i|0,f+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}}b=w[h+28>>2];w[114256]=0;T(400,f+344|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break r}b=w[f+356>>2];w[f+360>>2]=w[f+352>>2];w[f+364>>2]=b;d=w[w[f+104>>2]+8>>2];b=w[h+28>>2];w[114256]=0;Y(960,b|0,c|0,d|0,k|0);b=w[114256];w[114256]=0;if((b|0)==1){break r}i=w[f+104>>2];g=y[i+12>>1];d=w[h+32>>2];b=w[i>>2];w[114256]=0;g=S(975,f+280|0,b+d|0,g|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}w[114256]=0;Z(402,h|0,i|0,g|0,f+360|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(u[f+291|0]>=0){break q}zb(w[g>>2]);break q}d=P()|0;if(u[f+291|0]>=0){break j}zb(w[g>>2]);break j}d=P()|0;break j}d=P()|0;if(u[f+99|0]>=0){break j}zb(w[i>>2]);break j}w[114256]=0;i=Q(5,f+72|0,11460)|0;b=w[114256];w[114256]=0;u:{v:{if((b|0)!=1){j=1;b=w[f+104>>2];d=w[b>>2];g=w[h+32>>2];if(d>>>0<w[h+36>>2]-g>>>0){b=y[b+12>>1];w[114256]=0;d=S(975,f+296|0,d+g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break v}b=Yd(i,d);if(u[f+307|0]<0){zb(w[d>>2])}j=b^1}if(u[f+83|0]<0){zb(w[i>>2])}if(j){break u}w[114256]=0;Z(977,h|0,f+104|0,f+102|0,978)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break q}break r}d=P()|0;break j}d=P()|0;if(u[f+83|0]>=0){break j}zb(w[i>>2]);break j}w[114256]=0;i=Q(5,f+56|0,11102)|0;b=w[114256];w[114256]=0;w:{if((b|0)!=1){j=1;b=w[f+104>>2];d=w[b>>2];g=w[h+32>>2];if(d>>>0<w[h+36>>2]-g>>>0){b=y[b+12>>1];w[114256]=0;d=S(975,f+312|0,d+g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break w}b=Yd(i,d);if(u[f+323|0]<0){zb(w[d>>2])}j=b^1}if(u[f+67|0]<0){zb(w[i>>2])}if(j){break q}d=w[h+28>>2];b=w[w[d>>2]-12>>2];w[114256]=0;T(16,b+d|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break r}b=w[w[f+104>>2]+4>>2];if(b){i=w[h+28>>2];g=w[h+8>>2];d=w[h+12>>2];w[114256]=0;g=b+g|0;d=g>>>0<b>>>0?d+1|0:d;b=g;w[f+376>>2]=b;w[f+380>>2]=d;w[f+32>>2]=b;w[f+36>>2]=d;w[f+368>>2]=0;w[f+372>>2]=0;w[f+24>>2]=0;w[f+28>>2]=0;Q(976,i|0,f+24|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}}b=w[h+28>>2];w[114256]=0;T(400,f+344|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break r}b=w[f+356>>2];w[f+360>>2]=w[f+352>>2];w[f+364>>2]=b;b=w[h+28>>2];w[114256]=0;S(979,a|0,b|0,k|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}i=w[f+104>>2];g=y[i+12>>1];d=w[h+32>>2];b=w[i>>2];w[114256]=0;g=S(975,f+328|0,b+d|0,g|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}w[114256]=0;Z(402,h|0,i|0,g|0,f+360|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(u[f+339|0]>=0){break q}zb(w[g>>2]);break q}d=P()|0;if(u[f+339|0]>=0){break j}zb(w[g>>2]);break j}d=P()|0;break j}d=P()|0;if(u[f+67|0]>=0){break j}zb(w[i>>2]);break j}d=P()|0;break j}b=w[f+104>>2]+16|0;w[f+104>>2]=b;if((b|0)!=(m|0)){continue}break}}a=w[h>>2];b=w[h+44>>2];if(b){w[h+48>>2]=b;zb(b)}b=w[h+32>>2];if(b){w[h+36>>2]=b;zb(b)}j=a&1073741824?-1:1}jb=f+384|0;return j|0}d=P()|0;break j}d=P()|0;break j}d=P()|0;if(u[g+11|0]>=0){break j}zb(w[g>>2]);break j}d=P()|0;break j}d=P()|0;if(u[g+11|0]>=0){break j}zb(w[g>>2]);break j}d=P()|0}Mf(h);R(d|0);M()}function nD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=jb-192|0;jb=f;a:{b:{if(!gd(b,9574,4)){break b}if(d){u[d|0]=1}w[114256]=0;w[f+4>>2]=0;k=a+1074312|0;w[f>>2]=k;T(388,f|0,110);d=w[114256];w[114256]=0;if((d|0)==1){break a}d=w[b>>2];c:{if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],7)|0)){break c}i=a+1304412|0;n=a+480248|0;l=w[15045];o=l-12|0;p=f+144|2;q=f+60|0;r=f+8|0;s=w[15048];while(1){d=f+176|0;e=Nc(b,d);g=w[f+176>>2];h=cd(b,d);d=e?g:0;if((d|0)==70791730){d=b;b=w[b+8>>2];c=b-6|0;w[d+8>>2]=b>>>0>=c>>>0?c:0;break c}if(!(d&1616928864)|d&-2139062144){break c}g=w[b>>2];h=h?y[f+176>>1]:0;e=h&65535;if(!(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],e)|0)){break c}oc(f+176|0,b,e);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break w}if((d|0)!=1129797166){break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break t}w[a+1074304>>2]=d;break d}if((d|0)==1130917459){break o}if((d|0)!=1145525806){break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480200>>2]=d;break d}if((d|0)<=1213486400){if((d|0)==1146367534){break z}if((d|0)!=1196316499|e>>>0<3){break d}w[114256]=0;T(390,f+160|0,f+176|0);d=w[114256];w[114256]=0;if((d|0)==1){break m}w[114256]=0;d=S(391,f|0,f+160|0,8)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[f+171|0]<0){zb(w[f+160>>2])}e=w[f+176>>2];g=w[w[e>>2]+24>>2];w[114256]=0;e=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}w[114256]=0;U(392,d|0,n|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break k}w[d>>2]=l;w[d+w[o>>2]>>2]=s;w[f+8>>2]=59272;if(u[f+51|0]<0){zb(w[f+40>>2])}wc(r);pc(q);break d}if((d|0)==1213486401){break p}if((d|0)==1280530262){break s}if((d|0)==1297303086){break j}break d}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break u}if((d|0)!=1347244882){break d}w[114256]=0;d=Q(393,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}u[a+480268|0]=(d&255)>>>0>=5?5:d;break d}if((d|0)==1380340804){break y}if((d|0)==1380986414){break q}if((d|0)!=1380991534){break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480216>>2]=d;break d}if((d|0)<=1397768493){if((d|0)==1380994350){break x}if((d|0)!=1397052739|e>>>0<3){break d}w[114256]=0;d=Q(197,f+176|0,f+160|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}e=(d?y[f+160>>1]:0)&65535;if(!e|e>>>0>y[a+480190>>1]){break d}d=0;g=(C(e,104)+a|0)+484448|0;e=g;while(1){w[114256]=0;h=Q(232,f+176|0,f+160|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break n}w[e>>2]=h?w[f+160>>2]:0;d=d+1|0;e=g+(d<<2)|0;if((d|0)!=9){continue}break}break d}if((d|0)==1397768494){break r}if((d|0)==1414344238){break v}if((d|0)!=1448301654){break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480232>>2]=d;break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break i}w[a+480204>>2]=C(d,1e4)+(z[a+480204>>2]%1e4|0);break d}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){g=(d>>>0)%1e4|0;d=w[a+480204>>2];w[a+480204>>2]=g+d-(d>>>0)%1e4;break d}e=P()|0;break e}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480220>>2]=d;break d}if(c){break d}w[114256]=0;d=Q(394,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){e=y[a+480188>>1];v[a+480188>>1]=d>>>0<e>>>0?e:d>>>0>=127?127:d;break d}e=P()|0;break e}w[114256]=0;d=Q(393,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480224>>2]=d;break d}w[114256]=0;d=Q(393,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+1074372>>2]=d;break d}e=P()|0;break e}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(!d){break d}w[a+1074308>>2]=d;break d}e=P()|0;break e}w[114256]=0;d=Q(389,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[a+480228>>2]=d;break d}if(w[a+480180>>2]==4){break d}w[114256]=0;d=Q(394,f+176|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=d;break d}e=P()|0;break e}w[f+168>>2]=0;w[f+160>>2]=0;w[f+164>>2]=0;d=w[f+176>>2];e=w[w[d>>2]+24>>2];w[114256]=0;d=V(e|0,d|0)|0;e=w[114256];w[114256]=0;A:{if((e|0)==1){break A}w[114256]=0;S(395,f+176|0,f+160|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break A}w[114256]=0;U(6,f+144|0,0,f+160|0);d=w[114256];w[114256]=0;if((d|0)==1){break A}if(u[a+1304423|0]<0){zb(w[i>>2])}d=w[f+148>>2];w[i>>2]=w[f+144>>2];w[i+4>>2]=d;w[i+8>>2]=w[f+152>>2];if(u[f+171|0]>=0){break d}zb(w[f+160>>2]);break d}e=P()|0;if(u[f+171|0]>=0){break e}zb(w[f+160>>2]);break e}if(e&1|e>>>0>126){break d}j=(h&65406)>>>1|64;if((j|0)==64){break d}e=64;while(1){d=w[f+176>>2];g=w[w[d>>2]+36>>2];w[114256]=0;h=S(g|0,d|0,w[f+184>>2],2)|0;d=w[114256];w[114256]=0;if((d|0)==1){break h}g=0;d=0;B:{if(h){w[f+164>>2]=p;w[f+160>>2]=f+144;d=w[f+176>>2];g=w[w[d>>2]+32>>2];w[114256]=0;d=S(g|0,d|0,w[f+184>>2],f+160|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break h}w[f+184>>2]=d+w[f+184>>2];d=x[f+144|0];if((d|0)==255){break B}g=x[f+145|0]}h=(e<<5)+a|0;m=h+480284|0;v[m>>1]=128;v[h+480286>>1]=g;g=h+480280|0;h=(d&128)<<3;w[g>>2]=h;d=d&127;if(d>>>0<65){v[m>>1]=d<<2;break B}if((d|0)!=100){break B}w[g>>2]=h|256}e=e+1|0;if((j|0)!=(e|0)){continue}break}break d}e=P()|0;break e}e=P()|0;break e}e=P()|0;if(u[f+171|0]>=0){break e}zb(w[f+160>>2]);break e}e=P()|0;Se(d);break e}w[114256]=0;w[f+164>>2]=0;w[f+160>>2]=k;T(388,f+160|0,110);d=w[114256];w[114256]=0;if((d|0)==1){break a}d=0;C:{while(1){D:{e=w[f+176>>2];g=w[w[e>>2]+36>>2];w[114256]=0;e=S(g|0,e|0,w[f+184>>2],1)|0;g=w[114256];w[114256]=0;if((g|0)==1){break D}if(!(e&d>>>0<110)){break d}w[114256]=0;g=Q(241,f+176|0,f+160|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break C}e=0;g=g?x[f+160|0]:0;while(1){if(!(!(g>>>e&1)|d>>>0>109)){h=(d>>>3&536870908)+k|0;w[h>>2]=w[h>>2]|1<<d}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}break}continue}break}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0;break e}e=P()|0}Bb(f+176|0);R(e|0);M()}d=w[f+180>>2];E:{if(!d){break E}e=w[d+4>>2];w[d+4>>2]=e-1;if(e){break E}ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[b>>2];if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],7)|0){continue}break}}b=w[a+8>>2];d=C(w[b+20>>2],1e4);b=C(w[b+24>>2],1e4);F:{if(d>>>0>b>>>0){break F}c=w[a+480204>>2];if(c>>>0>=d>>>0){d=b;if(c>>>0<=d>>>0){break F}}w[a+480204>>2]=d}if(w[a+480224>>2]>=3){w[a+480224>>2]=0}if(w[a+1074372>>2]>=6){w[a+1074372>>2]=0}if(z[a+480200>>2]>=257){w[a+480200>>2]=256}if(z[a+480216>>2]>=65537){w[a+480216>>2]=65536}if(z[a+480220>>2]<65537){break b}w[a+480220>>2]=65536}jb=f+192|0;return}W(0)|0;Eb();M()}function GB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=jb-256|0;jb=e;w[b+8>>2]=0;a:{if(!cl(b,e+184|0)){break a}if(!pp(e+184|0)){break a}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(y[e+212>>1]+((C(x[e+214|0],37)+C(y[e+208>>1],192)|0)+(x[e+210|0]<<6)|0)|0)+192|0)|0)){break a}b:{if(!c){break b}tc(a,16);Vb(e+32|0,2,e+184|4,20);f=a+1304400|0;if(u[a+1304411|0]<0){zb(w[f>>2])}d=w[e+36>>2];w[f>>2]=w[e+32>>2];w[f+4>>2]=d;w[f+8>>2]=w[e+40>>2];v[a+480190>>1]=x[e+214|0];v[a+480188>>1]=x[e+217|0];g=a+1304436|0;f=Hb(e+32|0,4564);if(u[a+1304447|0]<0){zb(w[g>>2])}d=w[f+4>>2];w[g>>2]=w[f>>2];w[g+4>>2]=d;w[g+8>>2]=w[f+8>>2];g=a+1304448|0;f=Hb(e+32|0,6069);if(u[a+1304459|0]<0){zb(w[g>>2])}d=w[f+4>>2];w[g>>2]=w[f>>2];w[g+4>>2]=d;w[g+8>>2]=w[f+8>>2];g=Hb(e+168|0,10824);f=w[g>>2];w[e+20>>2]=w[g+4>>2];d=x[g+7|0]|x[g+8|0]<<8|(x[g+9|0]<<16|x[g+10|0]<<24);u[e+23|0]=d;u[e+24|0]=d>>>8;u[e+25|0]=d>>>16;u[e+26|0]=d>>>24;w[g>>2]=0;w[g+4>>2]=0;d=x[g+11|0];w[g+8>>2]=0;w[114256]=0;w[e+16>>2]=f;u[e+27|0]=d;d=x[e+187|0];w[e>>2]=d>>>4;w[e+164>>2]=d&15;Y(292,e+32|0,e+16|0,e|0,e+164|0);d=w[114256];w[114256]=0;c:{d:{e:{f:{if((d|0)!=1){f=a+1304460|0;if(u[a+1304471|0]<0){zb(w[f>>2])}d=w[e+36>>2];w[f>>2]=w[e+32>>2];w[f+4>>2]=d;w[f+8>>2]=w[e+40>>2];u[e+43|0]=0;u[e+32|0]=0;if(u[e+27|0]<0){zb(w[e+16>>2])}if(u[g+11|0]<0){zb(w[g>>2])}w[a+1304496>>2]=4;if(y[a+480190>>1]){h=1;while(1){if(!Aq(b,e+32|0)){Cb(e+32|0,0,37)}g=h&65535;j=(C(g,104)+a|0)+484380|0;lc(j,0);i=e+32|0;d=x[i+35|0]<<2;v[j+30>>1]=d>>>0>=256?256:d;k=x[i+22|0]|x[i+23|0]<<8|(x[i+24|0]<<16|x[i+25|0]<<24);g:{if(k>>>0<3){break g}w[j>>2]=k;f=x[i+26|0]|x[i+27|0]<<8|(x[i+28|0]<<16|x[i+29|0]<<24);w[j+4>>2]=f;d=x[i+30|0]|x[i+31|0]<<8|(x[i+32|0]<<16|x[i+33|0]<<24);d=d?d-1|0:0;d=d>>>0<k>>>0?d:k;w[j+8>>2]=d;h:{if(d>>>0<=f+4>>>0){w[j+4>>2]=0;w[j+8>>2]=0;break h}if(d>>>0<3){break h}v[j+34>>1]=y[j+34>>1]|2}u[j+37|0]=x[i+34|0];s=j,t=Bk(0,u[i+34|0]<<4),w[s+24>>2]=t;if(!(u[i+36|0]&1)){break g}v[j+34>>1]=y[j+34>>1]|1;w[j>>2]=w[j>>2]>>>1;w[j+4>>2]=w[j+4>>2]>>>1;w[j+8>>2]=w[j+8>>2]>>>1}d=e+16|0;Vb(d,2,i,22);w[114256]=0;w[e+4>>2]=32;w[e>>2]=((g<<5)+a|0)+946304;Q(200,e|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(u[e+27|0]<0){zb(w[e+16>>2])}h=h+1|0;if(y[a+480190>>1]>=(h&65535)>>>0){continue}break}}if(y[a+480188>>1]){h=0;while(1){d=(h<<5)+a|0;Qd(d+480280|0);v[d+480284>>1]=(x[(e+h|0)+218|0]<<4|8)&248;h=h+1|0;if(h>>>0<y[a+480188>>1]){continue}break}}k=e+32|0;g=jb-16|0;jb=g;d=w[b>>2];i:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],128)|0){d=w[b+8>>2];f=w[b>>2];w[g+8>>2]=k;w[g+12>>2]=k+128;s=b,t=(ob[w[w[f>>2]+32>>2]](f,d,g+8|0)|0)+w[b+8>>2]|0,w[s+8>>2]=t;break i}Cb(k,0,128)}jb=g+16|0;Ze(w[a+484360>>2]+(x[a+484376|0]<<5)|0,k,x[e+211|0]+1|0,255,254);f=x[e+216|0];oc(e+16|0,b,C(y[e+208>>1],192));n=c&1;if(!n){break e}w[114256]=0;T(215,a+484344|0,x[e+210|0]+1|0);d=w[114256];w[114256]=0;if((d|0)!=1){break e}break d}d=P()|0;if(u[e+27|0]<0){zb(w[e+16>>2])}if(u[g+11|0]>=0){break c}zb(w[g>>2]);break c}d=P()|0;if(u[e+27|0]>=0){break c}zb(w[e+16>>2]);break c}q=f?f:64;r=a+484344|0;d=0;j:{while(1){k:{l:{if(n){w[114256]=0;g=S(216,r|0,p&65535,q|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}o=0;if(g){break l}}k=w[b+8>>2];g=w[b>>2];f=w[w[g>>2]+36>>2];w[114256]=0;g=S(f|0,g|0,k|0,64)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}m:{if(g){h=w[b+8>>2]- -64|0;break m}g=w[b>>2];f=w[w[g>>2]+24>>2];w[114256]=0;h=V(f|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}}w[b+8>>2]=h;break k}while(1){w[114256]=0;g=Q(197,b|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}f=(g?y[e>>1]:0)&65535;if(!(!f|f>>>0>y[e+208>>1]|y[a+480188>>1]<=o>>>0)){k=C(f,192)-192|0;n:{if(k>>>0>z[e+24>>2]){g=w[e+16>>2];f=w[w[g>>2]+24>>2];w[114256]=0;g=V(f|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}if(g>>>0<k>>>0){break n}}w[e+24>>2]=k}f=w[r>>2];w[114256]=0;g=f+C(p,52)|0;V(218,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}h=w[g>>2]+C(o,6)|0;l=0;while(1){w[114256]=0;Q(217,e+16|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}g=d;d=h;f=x[e|0];if(f>>>0>=4){u[h|0]=(f>>>2|0)+37;f=x[e|0]}u[d+1|0]=f<<4&48|x[e+1|0]>>>4;k=0;d=x[e+2|0];f=0;o:{p:{q:{r:{s:{t:{u:{i=x[e+1|0]&15;switch(i-8|0){case 2:break r;case 0:break s;case 6:break u;default:break t}}i=14;j=((d&240)+16&240)>>>4|0;if(j>>>0>8){break q}if(1<<j&435){break s}break q}k=i;f=d}d=f;i=k;if((d|i)&255){break q}break p}d=(d&240?-16:15)&d;i=10}u[h+5|0]=d;u[h+3|0]=i;w[114256]=0;X(312,h|0);d=w[114256];w[114256]=0;v:{if((d|0)!=1){d=1;switch(x[h+3|0]-16|0){case 0:break o;case 1:break v;default:break p}}break d}m=1}d=g}h=C(y[a+480188>>1],6)+h|0;l=l+1|0;if((q|0)!=(l|0)){continue}break}}o=o+1|0;if((o|0)!=32){continue}break}}f=x[e+210|0]>p>>>0;p=p+1|0;if(f){continue}break}w:{if(!(d&m)){break w}m=w[a+484344>>2];j=w[a+484348>>2];if((m|0)==(j|0)){break w}while(1){n=0;x:{if(!w[m+12>>2]){break x}while(1){y:{w[114256]=0;f=V(218,m|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break y}k=y[a+480188>>1];if(k){g=w[m>>2]+C(C(f,n),6)|0;h=0;i=0;f=0;while(1){d=1;z:{switch(x[(g+C(h,6)|0)+3|0]-16|0){case 1:i=1;default:d=f;break;case 0:break z}}f=d;h=h+1|0;if((k|0)!=(h|0)){continue}break}if(d&i&1){break w}}n=n+1|0;if(n>>>0<z[m+12>>2]){continue}break x}break}break d}m=m+52|0;if((j|0)!=(m|0)){continue}break}l=w[a+484344>>2];k=w[a+484348>>2];if((l|0)==(k|0)){break w}while(1){i=0;A:{if(!w[l+12>>2]){break A}while(1){B:{w[114256]=0;f=V(218,l|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break B}g=y[a+480188>>1];C:{if(!g){break C}f=w[l>>2]+C(C(f,i),6)|0;h=0;while(1){d=x[(f+C(h,6)|0)+3|0];if((d&254)==16){w[114256]=0;v[e+8>>1]=65535;w[e>>2]=0;w[e+4>>2]=i;d=(d|0)==16;u[e+11|0]=d?125:6;u[e+10|0]=d?17:16;u[e+12|0]=x[e+12|0]&248|1;Q(271,l|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break C}break d}h=h+1|0;if((g|0)!=(h|0)){continue}break}}i=i+1|0;if(i>>>0<z[l+12>>2]){continue}break A}break}break d}l=l+52|0;if((k|0)!=(l|0)){continue}break}}D:{d=y[e+212>>1];if(!d){break D}w[114256]=0;da(306,a+1304424|0,b|0,d|0,39,1)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break D}break d}E:{if(!(!(c&2)|!y[a+480190>>1])){h=1;while(1){d=C(h&65535,104)+a|0;c=y[d+484414>>1];w[114256]=0;u[e+3|0]=1;u[e+1|0]=1;u[e+2|0]=0;u[e|0]=c&1?16:8;S(214,e|0,d+484380|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break E}h=h+1|0;if(y[a+480190>>1]>=(h&65535)>>>0){continue}break}}w[a+480260>>2]=64;w[a+480264>>2]=32767;b=w[e+20>>2];if(!b){break b}a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break b}ob[w[w[b>>2]+8>>2]](b);Ib(b);break b}}}d=P()|0;Bb(e+16|0)}R(d|0);M()}h=1}jb=e+256|0;return h|0}function _A(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-368|0;jb=e;a:{if(z[b+8>>2]<=59){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<60){break a}}w[b+8>>2]=60}g=15;b:{if(!gd(b,9837,4)){c:{if(z[b+8>>2]<=123){f=w[b>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<124){break c}}w[b+8>>2]=124}f=0;g=31;if(!gd(b,11109,4)){break b}}tc(a,536870912);v[a+480190>>1]=g;w[b+8>>2]=0;f=0;d:{while(1){e:{if(!Nc(b,e+88|0)){w[(e+240|0)+(f<<2)>>2]=0;break e}d=w[e+88>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);w[(e+240|0)+(f<<2)>>2]=d;if(d>>>0>131072){break d}}f=f+1|0;if(f>>>0<y[a+480190>>1]){continue}break}w[a+480260>>2]=56;w[a+480264>>2]=13696;w[a+480196>>2]=6;v[a+480192>>1]=0;v[a+480188>>1]=4;w[a+480228>>2]=64;Ce(a,1);f=w[b>>2];f:{if(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],4)|0){d=w[b+8>>2]+4|0;break f}f=w[b>>2];d=ob[w[w[f>>2]+24>>2]](f)|0}w[b+8>>2]=d;if(!cd(b,e+88|0)){break d}f=0;d=y[e+88>>1];d=(d<<8|d>>>8)&65535;if(d>>>0<178){break b}o=Tb(177693e5/+(d>>>0));d=-1;g:{if(o>=4294967295){break g}d=0;if(o<=0){break g}d=~~o>>>0;if(o<4294967296&o>=0){break g}d=0}w[a+480204>>2]=d;f=w[b>>2];h:{if(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],14)|0){d=w[b+8>>2]+14|0;break h}f=w[b>>2];d=ob[w[w[f>>2]+24>>2]](f)|0}w[b+8>>2]=d;i:{j:{k:{l:{m:{n:{o:{p:{if(y[a+480190>>1]){l=1;m=1;while(1){if(!vp(b,e+88|0)){v[e+110>>1]=0;v[e+112>>1]=0;v[e+114>>1]=0;v[e+116>>1]=0;w[e+104>>2]=0;w[e+108>>2]=0;w[e+96>>2]=0;w[e+100>>2]=0;w[e+88>>2]=0;w[e+92>>2]=0}f=w[((l<<2)+e|0)+236>>2];i=(C(l,104)+a|0)+484380|0;lc(i,1);w[i>>2]=f;g=e+88|0;d=g;u[i+37|0]=x[d+24|0]<<4;j=x[d+25|0];v[i+30>>1]=(j>>>0>=64?64:j)<<2;q:{if(!f){break q}p=x[d+28|0]|x[d+29|0]<<8;d=x[d+26|0]|x[d+27|0]<<8;j=(d<<8|d>>>8)&65535;w[i+4>>2]=j;d=(((p<<8|p>>>8)&65535)<<1)+j|0;w[i+8>>2]=d;if(f>>>0<=j>>>0){j=f-1|0;w[i+4>>2]=j}if(f>>>0<d>>>0){w[i+8>>2]=f;d=f}if(!(!(d>>>0<4|d>>>0<j>>>0)&d-j>>>0>3)){w[i+4>>2]=0;w[i+8>>2]=0;break q}if(d>>>0<=j>>>0){break q}v[i+34>>1]=y[i+34>>1]|2}f=0;while(1){if((x[g|0]-1&255)>>>0<=30){u[g|0]=32;h=h+1|0}f=f+1|0;g=f+(e+88|0)|0;if((f|0)!=22){continue}break}if(h>>>0>127){break d}f=e+224|0;Vb(f,3,e+88|0,22);w[114256]=0;w[e+52>>2]=32;w[e+48>>2]=((l<<5)+a|0)+946304;Q(200,e+48|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break p}if(u[e+235|0]<0){zb(w[e+224>>2])}m=m+1|0;l=m&65535;if(l>>>0<=y[a+480190>>1]){continue}break}}f=Hb(e+88|0,9727);w[114256]=0;h=a+946336|0;d=Q(569,h|0,f|0)|0;g=w[114256];w[114256]=0;i=1;if((g|0)==1){break o}r:{if(d){break r}w[114256]=0;d=Q(5,e+224|0,9738)|0;g=w[114256];w[114256]=0;if((g|0)==1){break n}w[114256]=0;i=Q(569,h|0,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break m}if(u[d+11|0]>=0){break r}zb(w[d>>2])}if(u[f+11|0]<0){zb(w[f>>2])}f=0;if(!Qk(b,e+88|0)){break b}d=x[e+88|0];if(d>>>0>128){break b}if(c){break k}break i}h=P()|0;if(u[e+235|0]>=0){break j}zb(w[e+224>>2]);break j}h=P()|0;break l}h=P()|0;break l}h=P()|0;if(u[d+11|0]>=0){break l}zb(w[d>>2])}if(u[f+11|0]>=0){break j}zb(w[f>>2]);break j}h=0;if(d){while(1){h=h&65535;g=x[(e+f|0)+90|0]+1|0;h=g>>>0<h>>>0?h:g;f=f+1|0;if((d|0)!=(f|0)){continue}break}}f=w[a+484360>>2]+(x[a+484376|0]<<5)|0;g=x[e+89|0];v[f+28>>1]=d>>>0>g>>>0?g:0;Ze(f,e+88|2,x[e+88|0],65535,65535);if(y[a+480190>>1]==31){vq(b,4)}w[e+84>>2]=0;w[e+80>>2]=0;w[e+76>>2]=0;u[e+75|0]=0;p=c&1;if(p){td(a+484344|0,h)}if(h){j=a+484344|0;l=0;while(1){s:{t:{if(!p){break t}m=0;if(!ie(j,l&65535,64)){break t}while(1){f=w[j>>2]+C(l,52)|0;d=ld(f);q=w[f>>2]+C(C(d,m),6)|0;f=0;while(1){Of(b,e+48|0);d=C(f,6)+q|0;u:{v:{if(x[e+48|0]!=255){break v}u[(e+84|0)+f|0]=0;u[(e+76|0)+f|0]=0;w:{g=x[e+49|0];if((g|0)==252&i){u[e+49|0]=254;break w}x:{switch(g-252|0){case 1:break u;case 2:break w;case 0:break x;default:break v}}u[d+3|0]=14;u[e+75|0]=9;break u}u[d+3|0]=13;break u}g=w[e+48>>2];w[e+64>>2]=g;w[e+12>>2]=g;Kf(e+12|0,d);g=x[d|0];y:{if(!g){break y}u[(e+76|0)+f|0]=0;u[(e+84|0)+f|0]=g;if(g>>>0>48){break y}g=x[e+75|0];u[e+75|0]=g>>>0<=8?8:g}z:{A:{B:{C:{switch(x[d+3|0]){case 0:if(x[d+5|0]){break A}break z;case 1:u[d+3|0]=1;break u;case 2:g=x[d+5|0];if(g>>>0>=16){u[d+3|0]=3;u[d+5|0]=g>>>4;break u}if(g){u[d+3|0]=2;u[d+5|0]=g;break u}u[d+5|0]=0;break A;case 3:if(x[(e+76|0)+f|0]){break B}u[d+3|0]=19;u[d+5|0]=0;break u;case 4:if(x[(e+76|0)+f|0]){break B}u[d+3|0]=19;u[d+5|0]=1;break u;case 5:g=x[d+1|0];if(!g){break B}u[d+3|0]=13;g=x[d+5|0]+(y[(C(g,104)+a|0)+484410>>1]>>>2|0)&255;g=g>>>0>=63?63:g;u[d+5|0]=g;if(!x[(e+76|0)+f|0]){break u}u[d+4|0]=g;u[d+2|0]=1;u[d+5|0]=0;break A;case 6:g=x[d+1|0];if(!g){break B}u[d+3|0]=13;g=y[(C(g,104)+a|0)+484410>>1]>>>2|0;k=x[d+5|0];g=g>>>0>=k>>>0?g-k|0:0;u[d+5|0]=g;if(!x[(e+76|0)+f|0]){break u}u[d+4|0]=g;u[d+2|0]=1;u[d+5|0]=0;break A;case 7:g=x[(e+84|0)+f|0];k=x[d+5|0];n=g-(k>>>4|0)|0;u[(e+80|0)+f|0]=n;u[d+3|0]=3;k=k&15;u[(e+76|0)+f|0]=k;r=d,s=Zo(k,n&255,g),u[r+5|0]=s;break u;case 8:k=x[(e+84|0)+f|0];g=x[d+5|0];n=k+(g>>>4|0)|0;u[(e+80|0)+f|0]=n;u[d+3|0]=2;g=g&15;u[(e+76|0)+f|0]=g;r=d,s=Zo(g,k,n&255),u[r+5|0]=s;break u;case 9:break C;default:break A}}g=x[e+75|0];u[e+75|0]=g>>>0<=8?8:g;break A}u[d+5|0]=0}u[d+3|0]=0}k=x[(e+76|0)+f|0];if(!k){break u}n=(e+80|0)+f|0;g=x[n|0];if(g){u[(e+84|0)+f|0]=g;u[d|0]=g;u[d+5|0]=k;u[n|0]=0}u[d+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}break s}f=w[b>>2];D:{if(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],1024)|0){d=w[b+8>>2]+1024|0;break D}f=w[b>>2];d=ob[w[w[f>>2]+24>>2]](f)|0}w[b+8>>2]=d}l=l+1|0;if((l|0)!=(h|0)){continue}break}}g=y[a+480190>>1];E:{F:{G:{if(c&2){if(!(g&65535)){break G}f=1;while(1){c=(C(f&65535,104)+a|0)+484380|0;if(w[c>>2]){w[e+48>>2]=264;Fd(e+48|0,c,b);g=y[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(g&65535)>>>0){continue}break}}if((g&65535)!=15){break G}b=Hb(e+16|0,11368);f=w[b>>2];w[e+36>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[e+39|0]=c;u[e+40|0]=c>>>8;u[e+41|0]=c>>>16;u[e+42|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[e+43|0]=c;w[e+32>>2]=f;U(295,e+48|0,e+32|0,e+75|0);c=w[114256];w[114256]=0;g=1;if((c|0)!=1){break F}h=P()|0;if(u[e+43|0]<0){zb(w[e+32>>2])}if(u[b+11|0]>=0){break j}zb(w[b>>2]);break j}g=0;w[114256]=0;Q(1,e+48|0,8096)|0;b=w[114256];w[114256]=0;if((b|0)==1){break E}}b=a+1304436|0;if(u[a+1304447|0]<0){zb(w[b>>2])}c=w[e+52>>2];w[b>>2]=w[e+48>>2];w[b+4>>2]=c;w[b+8>>2]=w[e+56>>2];u[e+59|0]=0;u[e+48|0]=0;H:{if(!g){break H}if(u[e+43|0]<0){zb(w[e+32>>2])}if(u[e+27|0]>=0){break H}zb(w[e+16>>2])}b=y[a+480190>>1]==15;Jf(a+1304448|0,b?1768:10672,b?3:4);w[a+1304496>>2]=2;break i}h=P()|0}R(h|0);M()}f=1;break b}f=0}jb=e+368|0;return f|0}function tn(a,b){var c=0,d=0,e=0,f=0,g=0,h=D(0),i=0,j=0,k=0,l=0,m=0,n=0,o=D(0),p=0,q=0,r=0,s=0,t=D(0),z=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=D(0);a:{if(y[a+480188>>1]<=b>>>0){break a}b:{c:{c=C(b,896)+a|0;e=x[c+1075797|0];switch(e-31|0){case 1:break b;case 0:break c;default:break a}}if(!(x[a+480209|0]&16)){break a}}f=a;j=b;q=(e|0)==32;c=u[c+1075799|0];if((c|0)>=0){r=((x[(C(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0}else{r=(((c&127)<<5)+a|0)+902204|0}g=c&255;b=0;l=jb-32|0;jb=l;k=y[f+480192>>1]?w[(C(j,896)+f|0)+1075640>>2]:k;a=C(j,896)+f|0;z=a+1075805|0;B=a+1075672|0;E=a+1075772|0;p=a+1075748|0;s=a+1075744|0;F=a+1075704|0;G=a+1075676|0;H=a+1075668|0;I=a+1075648|0;J=a+1075792|0;K=a+1075072|0;o=D(g>>>0);i=a+1075855|0;t=D(x[i|0]);L=D(o-t);m=255;a=1;while(1){e=x[b+r|0];if(e){c=e-48|0;d:{e:{f:{if((c&255)>>>0<10){break f}if((e-65&255)>>>0<=5){c=e-55|0;break f}g:{h:{i:{switch(e-97|0){case 2:j:{e=Ef(f,j,3,0);if((e-1&255)>>>0>249){break j}c=w[(C(e,160)+f|0)+906140>>2];if(!c){break j}c=tl(c,78488,78496);if(!c){break j}c=ob[w[w[c>>2]+184>>2]](c,j)|0;e=(c|0)!=255;c=e?c:0;if(e|!k){break f}break g}if(k){break g}c=0;break f;case 21:c=C(w[p>>2],w[s>>2]);e=c;n=c>>31;c=C(w[f+1074444>>2],w[B>>2]+(w[f+1074312>>2]&268435458?v[E>>1]:0)|0);e=CV(BV(e,n,c,c>>31),nb,1048576,0);n=e;c=nb;e=(c|0)>=0&e>>>0>=2147483647|(c|0)>0;n=e?2147483647:n;c=e?0:c;c=(((c|0)<0&n>>>0<=2147483648|(c|0)<-1?-2147483648:n)|0)/2|0;c=(c|0)>=127?127:c;c=(c|0)<=1?1:c;break h;case 20:c=C(w[p>>2],w[s>>2]);e=c;n=c>>31;c=C(w[f+1074444>>2],w[F>>2]);e=CV(BV(e,n,c,c>>31),nb,67108864,0);n=e;c=nb;e=(c|0)>=0&e>>>0>=2147483647|(c|0)>0;n=e?2147483647:n;c=e?0:c;c=(((c|0)<0&n>>>0<=2147483648|(c|0)<-1?-2147483648:n)|0)/2|0;c=(c|0)>=127?127:c;c=(c|0)<=1?1:c;break h;case 23:c=w[G>>2]/2|0;c=(c|0)>=127?127:c;break h;case 24:c=w[H>>2]/2|0;c=(c|0)>=127?127:c;break h;case 0:c=0;if(!k){break h}e=y[k+28>>1];if(!e){break h}c=e-1>>>7&127;break h;case 1:c=0;if(!k){break h}e=y[k+28>>1];if(!e){break h}c=e-1&127;break h;case 14:c=w[I>>2]>>>8|0;break h;case 7:c=(y[f+480188>>1]<=j>>>0?x[J|0]-1|0:j)&127;break h;case 12:c=x[K|0]>>>7|0;break h;case 15:c=0;if(!k){break h}e=x[k+30|0];if(!e){break h}c=e-1&127;break h;case 25:k:{if(!q|u[i|0]<0){break k}l:{if(d>>>0<3){break l}c=d+l|0;if(x[c-3|0]!=240){break l}if(x[c-2|0]>239){break k}}h=o;c=w[f+1074396>>2];c=C(w[f+1074400>>2]+w[f+1074416>>2]|0,c?c:1)-w[f+1074392>>2]|0;if(c>>>0>=2){h=D(D(L/D(c>>>0))+t)}m:{if(h<D(4294967296)&h>=D(0)){c=~~h>>>0;break m}c=0}u[i|0]=c;m=128;break h}m=(m&255)==255?g:m;c=g;break h;case 18:e=d;n:{if(!d){e=0;break n}while(1){e=e-1|0;if(x[l+e|0]==240){break n}if(e){continue}break}}if(x[e+l|0]!=240|d-e>>>0<5){break d}c=0;e=e+5|0;if((e|0)!=(d|0)){while(1){c=x[e+l|0]+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}c=0-c&127;break h;case 13:break i;default:break d}}c=x[z|0]-1|0;c=(c&255)>>>0<120?c:0}a=((a^-1)&1)+d|0;u[a+l|0]=c;d=a+1|0;a=1;break e}c=0;o:{if(j>>>0>255){break o}e=x[k+31|0];if((e|0)==17){c=y[(C(j,896)+f|0)+1075792>>1];c=(c?c-1|0:j)&15;break o}e=e-1|0;if((e&255)>>>0>16){break o}c=e&15}}e=d+l|0;p:{if(a&1){u[e|0]=c;break p}u[e|0]=x[e|0]<<4|c;d=d+1|0}a=(a^-1)&1}}b=b+1|0;if((b|0)!=31){continue}}break}e=((a^-1)&1)+d|0;if(m<<24>>24>=0){u[i|0]=m}q:{if(!e){break q}c=0;a=0;while(1){g=a+l|0;b=u[g|0];r:{s:{t:{if((b|0)==-16){if(e-a>>>0>=4){b=4;if((x[(a+l|0)+1|0]&254)==240){break s}}b=a;u:{while(1){b=b+1|0;if(e>>>0<=b>>>0){break u}if(x[b+l|0]!=247){continue}break}b=(b-a|0)+1|0;if(b){break s}}u[e+l|0]=247;e=e+1|0;b=e-a|0;break t}if((b|0)>=0){if(c&255){a=a-1|0;u[l+a|0]=c;break r}a=a+1|0;c=0;break r}d=e-a|0;b=So(b&255);b=b>>>0>d>>>0?d:b}if(!b){break q}d=x[g|0];c=d>>>0<240?d:c}r=a;a=0;k=jb-16|0;jb=k;v:{if(!b){break v}w:{x:{d=x[g|0];i=d-250|0;if(!(i>>>0>5|!(1<<i&37))){i=y[f+480188>>1];if(!i){break x}d=0;while(1){m=(C(d,896)+f|0)+1075841|0;u[m|0]=127;u[m+1|0]=0;d=d+1|0;if((i|0)!=(d|0)){continue}break}d=x[g|0]}if((d&255)!=240){break x}i=x[g+1|0];if((i&254)!=240){break x}if(b>>>0<4){break v}m=(C(j,896)+f|0)+1074984|0;d=u[g+3|0];y:{z:{A:{B:{C:{D:{p=x[g+2|0];switch(p|0){case 3:break A;case 2:break B;case 1:break C;case 0:break D;default:break z}}if((i|0)==241|(d|0)<0){break z}g=C(j,896)+f|0;i=g+1075841|0;E:{if(!q){a=d;break E}a=255;h=D((d&255)>>>0);d=w[f+1074396>>2];d=C(w[f+1074400>>2]+w[f+1074416>>2]|0,d?d:1)-w[f+1074392>>2]|0;if(d>>>0>=2){o=h;h=D(x[i|0]);h=D(D(D(o-h)/D(d>>>0))+h)}h=_b(h);if(h>=D(255)){break E}a=0;if(h<=D(0)){break E}a=h<D(4294967296)&h>=D(0)?~~h>>>0:a}u[i|0]=a;u[g+1075802|0]=0;a=4;d=g+1075072|0;g=hh(f,m,!(w[d>>2]&32768),256);if((g|0)<0|!(x[d+1|0]&2)){break v}d=w[f+1304392>>2];if(!d){break v}lh(d,j,g>>>2&255,1);break v}if((i|0)==241|(d|0)<0){break z}a=C(j,896)+f|0;g=a+1075842|0;F:{if(!q){break F}h=D((d&255)>>>0);d=w[f+1074396>>2];d=C(w[f+1074400>>2]+w[f+1074416>>2]|0,d?d:1)-w[f+1074392>>2]|0;if(d>>>0>=2){o=h;h=D(x[g|0]);h=D(D(D(o-h)/D(d>>>0))+h)}if(h<D(4294967296)&h>=D(0)){d=~~h>>>0;break F}d=0}u[g|0]=d;u[a+1075801|0]=0;hh(f,m,!(w[a+1075072>>2]&32768),256);a=4;break v}if((i|0)==241){break y}a=4;if(d>>>0>31){break v}g=C(j,896)+f|0;u[g+1075849|0]=(d&240)>>>4;hh(f,m,!(w[g+1075072>>2]&32768),256);break v}if((i|0)==241){break y}a=4;g=Ef(f,j,3,0);if((d|0)<0|(g-1&255)>>>0>249){break v}g=(C(g,160)+f|0)+906284|0;h=D(D(((d^127)&255)>>>0)*D(.007874015718698502));if(!q){break w}d=w[f+1074396>>2];d=C(w[f+1074400>>2]+w[f+1074416>>2]|0,d?d:1)-w[f+1074392>>2]|0;if(d>>>0<2){break w}o=h;h=A[g>>2];h=D(D(D(o-h)/D(d>>>0))+h);break w}if(p<<24>>24<0){break y}if((i|0)!=241){break v}}a=4;g=Ef(f,j,3,0);if((g-1&255)>>>0>249){break v}g=w[(C(g,160)+f|0)+906140>>2];if(!g|(d|0)<0){break v}i=(i|0)==241?p+128|0:p&127;h=D(D((d&255)>>>0)*D(.007874015718698502));d=w[g>>2];if(!q){ob[w[d+44>>2]](g,i,h);break v}o=D(ob[w[d+48>>2]](g,i));d=w[f+1074396>>2];d=C(w[f+1074400>>2]+w[f+1074416>>2]|0,d?d:1)-w[f+1074392>>2]|0;if(d>>>0>=2){h=D(D(D(h-o)/D(d>>>0))+o)}ob[w[w[g>>2]+44>>2]](g,i,h);break v}a=y[f+480188>>1];G:{H:{if(a>>>0>j>>>0){d=j+1|0;break H}d=y[(C(j,896)+f|0)+1075792>>1];if(!d){break G}}if(x[(C(j,896)+f|0)+1075075|0]&4|a>>>0<(d&65535)>>>0){break G}a=Ef(f,j,3,0);if((a-1&255)>>>0>249){break G}a=w[(C(a,160)+f|0)+906140>>2];if(!a){break G}d=x[g|0];if((d|0)==240){w[k+8>>2]=g;w[k+12>>2]=b+g;ob[w[w[a>>2]+72>>2]](a,k+8|0)|0;break G}d=So(d);w[k+4>>2]=0;Fb(k+4|0,g,b>>>0>d>>>0?d:b);ob[w[w[a>>2]+68>>2]](a,w[k+4>>2])|0}a=b;break v}A[g>>2]=h}jb=k+16|0;a=(a?a:b)+r|0}if(a>>>0<e>>>0){continue}break}}jb=l+32|0}}function gD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-384|0;jb=d;k=d+112|0;h=k;j=jb-32|0;jb=j;g=Wk(j+8|0,b);e=w[g+4>>2];a:{if(e){f=w[g>>2]+e|0;break a}e=w[g+8>>2];f=w[g+12>>2];if((e|0)!=(f|0)){break a}f=0;e=0}b:{c:{i=f-e|0;if(i>>>0>=4294967280){w[114256]=0;X(408,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}M()}d:{if(i>>>0<=10){u[h+11|0]=i;break d}w[114256]=0;l=(i|15)+1|0;b=V(22,l|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break c}w[h>>2]=b;w[h+4>>2]=i;w[h+8>>2]=l|-2147483648;h=b}if((e|0)!=(f|0)){while(1){u[h|0]=x[e|0];h=h+1|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}u[h|0]=0;b=w[g+8>>2];if(b){w[g+12>>2]=b;zb(b)}jb=j+32|0;break b}b=P()|0;a=w[g+8>>2];if(a){w[g+12>>2]=a;zb(a)}R(b|0);M()}w[114256]=0;h=S(391,d+216|0,k|0,8)|0;b=w[114256];w[114256]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((b|0)!=1){if(u[d+123|0]<0){zb(w[d+112>>2])}if(c>>>0<2189){break i}w[114256]=0;b=Q(396,d+112|0,h|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break h}w[114256]=0;c=Q(5,d+96|0,6064)|0;e=w[114256];w[114256]=0;if((e|0)==1){break A}w[114256]=0;w[d+360>>2]=19469585;w[d+364>>2]=0;U(397,b|0,c|0,d+360|0);e=w[114256];w[114256]=0;if((e|0)==1){break z}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;u[d+95|0]=0;c=Q(5,d+80|0,6946)|0;e=w[114256];w[114256]=0;if((e|0)==1){break y}w[114256]=0;S(398,b|0,d+95|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break x}if(u[c+11|0]<0){zb(w[c>>2])}g=w[a+1304496>>2];f=w[a+4>>2];w[114256]=0;i=x[d+95|0];c=Q(5,d- -64|0,11706)|0;e=w[114256];w[114256]=0;if((e|0)==1){break w}w[114256]=0;e=Q(399,b|0,c|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break v}j=w[b+28>>2];w[114256]=0;T(400,d+360|0,j|0);j=w[114256];w[114256]=0;if((j|0)==1){break v}g=i?0:g;i=w[d+372>>2];w[d+48>>2]=w[d+368>>2];w[d+52>>2]=i;B:{C:{D:{E:{F:{if(!(x[b+24|0]&32?e:1)){break F}i=w[b+28>>2];w[114256]=0;w[d+368>>2]=0;w[d+360>>2]=0;w[d+364>>2]=0;Z(401,f|0,i|0,d+360|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break E}if(u[d+371|0]>=0){break F}zb(w[d+360>>2])}w[114256]=0;Z(402,b|0,e|0,c|0,d+48|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break v}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,d+48|0,11460)|0;e=w[114256];w[114256]=0;if((e|0)==1){break t}w[114256]=0;e=Q(399,b|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}f=w[b+28>>2];w[114256]=0;T(400,d+360|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break s}f=w[d+372>>2];w[d+32>>2]=w[d+368>>2];w[d+36>>2]=f;if(x[b+24|0]&32?e:1){f=w[b+28>>2];w[114256]=0;Y(403,f|0,a|0,g|0,0);g=w[114256];w[114256]=0;if((g|0)==1){break s}}w[114256]=0;Z(402,b|0,e|0,c|0,d+32|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break s}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,d+32|0,11102)|0;e=w[114256];w[114256]=0;if((e|0)==1){break r}w[114256]=0;e=Q(399,b|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break q}g=w[b+28>>2];w[114256]=0;T(400,d+360|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break q}g=a+484360|0;f=w[d+372>>2];w[d+16>>2]=w[d+368>>2];w[d+20>>2]=f;if(e){break D}f=-1;if(!(x[b+24|0]&32)){break C}break B}a=P()|0;if(u[d+371|0]>=0){break u}zb(w[d+360>>2]);break u}f=w[e+8>>2]}i=w[b+28>>2];w[114256]=0;U(404,i|0,g|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break q}}w[114256]=0;Z(402,b|0,e|0,c|0,d+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break q}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,d+16|0,23572)|0;e=w[114256];w[114256]=0;if((e|0)==1){break p}w[114256]=0;e=Q(399,b|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break o}f=w[b+28>>2];w[114256]=0;T(400,d+360|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break o}f=w[d+372>>2];w[d>>2]=w[d+368>>2];w[d+4>>2]=f;G:{H:{if(!e){f=-1;if(!(x[b+24|0]&32)){break H}break G}f=w[e+8>>2]}i=w[b+28>>2];w[114256]=0;U(405,i|0,a+484344|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break o}}w[114256]=0;Z(402,b|0,e|0,c|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break o}if(u[c+11|0]<0){zb(w[c>>2])}i=w[a+1304496>>2];w[114256]=0;c=Q(5,d|0,23578)|0;e=w[114256];w[114256]=0;if((e|0)==1){break n}w[114256]=0;e=Q(399,b|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break m}f=w[b+28>>2];w[114256]=0;T(400,d+360|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break m}f=w[d+372>>2];w[d+376>>2]=w[d+368>>2];w[d+380>>2]=f;I:{J:{if(!e){f=-1;if(!(x[b+24|0]&32)){break J}break I}f=w[e+8>>2]}j=w[b+28>>2];w[114256]=0;Y(406,j|0,g|0,f|0,i|0);g=w[114256];w[114256]=0;if((g|0)==1){break m}}w[114256]=0;Z(402,b|0,e|0,c|0,d+376|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}if(u[c+11|0]<0){zb(w[c>>2])}K:{if(!(x[b+3|0]&64)){break K}w[114256]=0;c=Q(1,d+360|0,12069)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}w[114256]=0;U(367,a|0,1,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break k}if(u[c+11|0]>=0){break K}zb(w[c>>2])}a=w[b+44>>2];if(a){w[b+48>>2]=a;zb(a)}a=w[b+32>>2];if(!a){break e}w[b+36>>2]=a;zb(a);break e}a=P()|0;if(u[d+123|0]>=0){break f}zb(w[d+112>>2]);break f}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0}if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2]);break j}a=P()|0;break j}a=P()|0;if(u[c+11|0]>=0){break j}zb(w[c>>2])}Mf(b);break g}w[d+120>>2]=0;w[d+112>>2]=0;w[d+116>>2]=0;b=w[a+1304496>>2];e=w[a+4>>2];w[114256]=0;b=Z(401,e|0,h|0,d+112|0,b|0)|0;e=w[114256];w[114256]=0;L:{M:{if((e|0)==1){break M}N:{if((b|0)!=1){w[114256]=0;b=Q(1,d+360|0,12375)|0;c=w[114256];w[114256]=0;O:{if((c|0)!=1){w[114256]=0;U(367,a|0,1,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break O}if(u[b+11|0]>=0){break N}zb(w[b>>2]);break N}a=P()|0;break L}a=P()|0;if(u[b+11|0]>=0){break L}zb(w[b>>2]);break L}b=w[a+1304496>>2];w[114256]=0;Y(403,h|0,a|0,b|0,c>>>0<2188|0);a=w[114256];w[114256]=0;if((a|0)==1){break M}}if(u[d+123|0]>=0){break e}zb(w[d+112>>2]);break e}a=P()|0}if(u[d+123|0]>=0){break g}zb(w[d+112>>2]);break g}a=P()|0}Se(h)}R(a|0);M()}a=w[15045];w[h>>2]=a;w[h+w[a-12>>2]>>2]=w[15048];w[h+8>>2]=59272;if(u[h+51|0]<0){zb(w[h+40>>2])}wc(h+8|0);pc(h+60|0);jb=d+384|0}function aF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-112|0;jb=d;w[b+8>>2]=0;a:{if(!gd(b,7577,7)){break a}if(!hl(b,d+96|0)|x[d+97|0]!=1){break a}g=w[b>>2];if(!(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],(((C(x[d+99|0],18)+(x[d+105|0]|x[d+106|0]<<8)|0)+(y[d+102>>1]<<1)|0)+(y[d+100>>1]<<2)|0)+3|0)|0)){break a}g=w[b>>2];f=x[d+105|0]|x[d+106|0]<<8;if(!(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],f)|0)){a=w[b>>2];k=b,l=ob[w[w[a>>2]+24>>2]](a)|0,w[k+8>>2]=l;break a}w[b+8>>2]=f+w[b+8>>2];b:{if(!c){break b}tc(a,4096);w[a+480208>>2]=12;v[a+480188>>1]=(x[d+98|0]&31)+1;v[a+480190>>1]=x[d+99|0];Ce(a,1);g=a+1304436|0;e=Hb(d+40|0,4675);if(u[a+1304447|0]<0){zb(w[g>>2])}f=w[e+4>>2];w[g>>2]=w[e>>2];w[g+4>>2]=f;w[g+8>>2]=w[e+8>>2];g=a+1304448|0;e=Hb(d+40|0,3356);if(u[a+1304459|0]<0){zb(w[g>>2])}f=w[e+4>>2];w[g>>2]=w[e>>2];w[g+4>>2]=f;w[g+8>>2]=w[e+8>>2];g=Hb(d- -64|0,10860);f=w[g>>2];w[d+84>>2]=w[g+4>>2];e=x[g+7|0]|x[g+8|0]<<8|(x[g+9|0]<<16|x[g+10|0]<<24);u[d+87|0]=e;u[d+88|0]=e>>>8;u[d+89|0]=e>>>16;u[d+90|0]=e>>>24;w[g>>2]=0;w[g+4>>2]=0;e=x[g+11|0];w[g+8>>2]=0;w[114256]=0;u[d+91|0]=e;w[d+80>>2]=f;e=d+96|0;Y(219,d+40|0,d+80|0,e|1,e|0);e=w[114256];w[114256]=0;c:{d:{e:{if((e|0)!=1){e=a+1304460|0;if(u[a+1304471|0]<0){zb(w[e>>2])}f=w[d+44>>2];w[e>>2]=w[d+40>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+48>>2];u[d+51|0]=0;u[d+40|0]=0;if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[g+11|0]<0){zb(w[g>>2])}w[a+1304496>>2]=4;e=x[d+99|0];f=jb-16|0;jb=f;g=d+80|0;w[g+8>>2]=0;w[g>>2]=0;w[g+4>>2]=0;if(e){$i(g,e);h=w[g+4>>2];i=h+e|0;w[g+4>>2]=i;f:{g:{if(!h){j=i-1|0;break g}j=i-1|0;if((j^h-1)>>>0<32){break f}}w[w[g>>2]+((i>>>0>=33?j>>>5|0:0)<<2)>>2]=0}i=w[g>>2];w[f+12>>2]=h&31;w[f+8>>2]=i+(h>>>3&536870908);Jh(f+8|0,e)}jb=f+16|0;if(!y[a+480190>>1]){break e}e=1;f=1;while(1){w[114256]=0;h=Q(220,b|0,d+40|0)|0;i=w[114256];w[114256]=0;h:{if((i|0)!=1){if(!h){u[d+56|0]=0;w[d+48>>2]=0;w[d+52>>2]=0;w[d+40>>2]=0;w[d+44>>2]=0}w[114256]=0;T(221,d+40|0,(C(e,104)+a|0)+484380|0);h=w[114256];w[114256]=0;if((h|0)!=1){break h}}b=P()|0;break d}h=e-1|0;e=1<<h;h=w[g>>2]+(h>>>3&536870908)|0;if(x[d+56|0]&3){e=e|w[h>>2]}else{e=w[h>>2]&(e^-1)}w[h>>2]=e;f=f+1|0;e=f&65535;if(e>>>0<=y[a+480190>>1]){continue}break}break e}b=P()|0;if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[g+11|0]>=0){break c}zb(w[g>>2]);break c}w[114256]=0;S(222,b|0,a+1304400|0,-1)|0;f=w[114256];w[114256]=0;e=1;i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)==1){break p}if(y[a+480190>>1]){while(1){w[114256]=0;S(223,b|0,(((e&65535)<<5)+a|0)+946304|0,-1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}e=e+1|0;if(y[a+480190>>1]>=(e&65535)>>>0){continue}break}}if(y[a+480188>>1]){e=0;while(1){w[114256]=0;f=(e<<5)+a|0;X(224,f+480280|0);h=w[114256];w[114256]=0;if((h|0)==1){break j}w[114256]=0;S(225,b|0,f+480289|0,-1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}e=e+1|0;if(e>>>0<y[a+480188>>1]){continue}break}}e=0;w[114256]=0;f=a+484344|0;T(215,f|0,y[d+100>>1]);h=w[114256];w[114256]=0;if((h|0)==1){break p}if(y[d+100>>1]){while(1){w[114256]=0;h=S(226,b|0,d+40|0,-1)|0;i=w[114256];w[114256]=0;q:{r:{if((i|0)==1){break r}w[114256]=0;i=S(216,f|0,e&65535,64)|0;j=w[114256];w[114256]=0;if((j|0)==1){break r}if((h&i)!=1){break q}h=w[f>>2];w[114256]=0;S(227,h+C(e,52)|0,d+40|0,11)|0;h=w[114256];w[114256]=0;if((h|0)!=1){break q}}b=P()|0;break d}e=e+1|0;if(e>>>0<y[d+100>>1]){continue}break}}w[114256]=0;e=Q(197,b|0,d+40|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break k}s:{if(!e){break s}e=y[d+40>>1];if(!e){break s}f=w[b+8>>2];h=w[b>>2];i=w[w[h>>2]+36>>2];w[114256]=0;f=S(i|0,h|0,f|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}if(!f){break s}w[114256]=0;w[d+48>>2]=0;w[d+40>>2]=0;w[d+44>>2]=0;S(228,b|0,d+40|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break m}w[114256]=0;w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;T(72,d+24|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break n}e=w[d+40>>2];h=w[d+44>>2];if((e|0)!=(h|0)){while(1){t:{f=u[e|0];if((f|0)<0){w[114256]=0;i=x[d+35|0];Z(93,d+24|0,(i<<24>>24<0?w[d+28>>2]:i)|0,f&127,32)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break t}break n}w[114256]=0;T(71,d+24|0,f|0);f=w[114256];w[114256]=0;if((f|0)!=1){break t}break n}e=e+1|0;if((h|0)!=(e|0)){continue}break}}w[114256]=0;Y(229,d+8|0,4,5,d+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break n}if(u[d+35|0]<0){zb(w[d+24>>2])}w[d+32>>2]=w[d+16>>2];w[114256]=0;e=w[d+12>>2];f=w[d+8>>2];w[d+24>>2]=f;w[d+28>>2]=e;h=f;e=u[d+35|0];f=(e|0)<0;da(230,a+1304424|0,(f?h:d+24|0)|0,(f?w[d+28>>2]:e&255)|0,76,0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break n}if(u[d+35|0]<0){zb(w[d+24>>2])}e=w[d+40>>2];if(!e){break s}w[d+44>>2]=e;zb(e)}e=x[a+484376|0];f=w[a+484360>>2];w[114256]=0;da(231,f+(e<<5)|0,b|0,y[d+102>>1],65535,65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}if(!y[d+100>>1]){break o}h=c&1;e=0;while(1){f=w[b+8>>2];i=w[b>>2];j=w[w[i>>2]+36>>2];w[114256]=0;f=S(j|0,i|0,f|0,4)|0;i=w[114256];w[114256]=0;u:{if((i|0)!=1){if(f){break u}break o}b=P()|0;break d}w[114256]=0;f=Q(232,b|0,d+40|0)|0;i=w[114256];w[114256]=0;v:{w:{if((i|0)!=1){w[114256]=0;U(188,d+40|0,b|0,(f?w[d+40>>2]:0)|0);f=w[114256];w[114256]=0;if((f|0)==1){break w}if(!h){break v}f=w[a+484344>>2];if(((w[a+484348>>2]-f|0)/52&65535)>>>0<=e>>>0){break v}f=f+C(e,52)|0;if(w[f>>2]==w[f+4>>2]){break v}w[114256]=0;U(233,f|0,0,d+40|0);f=w[114256];w[114256]=0;if((f|0)!=1){break v}b=P()|0;Bb(d+40|0);break d}b=P()|0;break d}b=P()|0;break d}f=w[d+44>>2];x:{if(!f){break x}i=w[f+4>>2];w[f+4>>2]=i-1;if(i){break x}ob[w[w[f>>2]+8>>2]](f);Ib(f)}e=e+1|0;if(e>>>0<y[d+100>>1]){continue}break}break o}b=P()|0;break d}y:{if(!(!(c&2)|!y[a+480190>>1])){e=1;while(1){c=e&65535;f=c-1|0;h=w[w[g>>2]+(f>>>3&536870908)>>2];c=C(c,104)+a|0;i=y[c+484414>>1];w[114256]=0;u[d+41|0]=1;u[d+42|0]=0;u[d+40|0]=i&1?16:8;u[d+43|0]=0-(h>>>f&1)&6;S(214,d+40|0,c+484380|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break y}e=e+1|0;if(y[a+480190>>1]>=(e&65535)>>>0){continue}break}}a=w[g>>2];if(!a){break b}zb(a);break b}b=P()|0;break d}b=P()|0;if(u[d+35|0]>=0){break l}zb(w[d+24>>2]);break l}b=P()|0}a=w[d+40>>2];if(!a){break d}w[d+44>>2]=a;zb(a);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0}a=w[g>>2];if(!a){break c}zb(a)}R(b|0);M()}e=1}jb=d+112|0;return e|0}function XI(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,y=0,z=0;l=jb-560|0;jb=l;w[l+548>>2]=k;w[l+552>>2]=b;a:{b:{if(Le(a,l+552|0)){w[f>>2]=w[f>>2]|4;a=0;break b}w[l+96>>2]=1769;b=l+96|0;p=vc(l+136|0,l+144|0,b);k=w[p>>2];w[l+132>>2]=k;w[l+128>>2]=k+400;r=Wb(b);m=Wb(l+80|0);o=Wb(l- -64|0);n=Wb(l+48|0);q=Wb(l+32|0);w[114256]=0;oa(1780,c|0,d|0,l+120|0,l+116|0,l+112|0,r|0,m|0,o|0,n|0,l+28|0);b=w[114256];w[114256]=0;if((b|0)!=1){w[j>>2]=w[i>>2];t=e&512;v=t>>>9|0;e=0;k=0;while(1){c=k;c:{d:{e:{f:{if((e|0)==4){break f}w[114256]=0;b=Q(1740,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!b){break f}b=0;g:{h:{i:{j:{k:{switch(u[(l+120|0)+e|0]){case 1:if((e|0)==3){break d}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w[114256]=0;b=S(1781,h|0,1,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(b){w[114256]=0;U(1782,l+16|0,a|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[l+16>>2];w[114256]=0;T(69,q|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break j}}break a}w[f>>2]=w[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break d}}while(1){w[114256]=0;b=Q(1740,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!b){break d}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w[114256]=0;b=S(1781,h|0,1,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!b){break d}w[114256]=0;U(1782,l+16|0,a|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[l+16>>2];w[114256]=0;T(69,q|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Db(o)){break l}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if((b|0)!=w[Qb(o)>>2]){break l}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}u[g|0]=0;k=Db(o)>>>0>1?o:c;break c}m:{if(!Db(n)){break m}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if((b|0)!=w[Qb(n)>>2]){break m}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}u[g|0]=1;k=Db(n)>>>0>1?n:c;break c}n:{if(!Db(o)){break n}if(!Db(n)){break n}w[f>>2]=w[f>>2]|4;a=0;break e}if(!Db(o)){if(!Db(n)){break d}}y=g,z=!Db(n),u[y|0]=z;break d}if(!(c|e>>>0<2)){k=0;if(!((e|0)==2&x[l+123|0]!=0|v)){break c}}y=l,z=zd(m),w[y+8>>2]=z;b=Zf(l+16|0,l+8|0);o:{if(!e|x[(e+l|0)+119|0]>1){break o}p:{while(1){y=l,z=ff(m),w[y+8>>2]=z;if(!qe(b,l+8|0)){break p}d=w[w[b>>2]>>2];w[114256]=0;d=S(1781,h|0,1,d|0)|0;k=w[114256];w[114256]=0;if((k|0)!=1){if(!d){break p}Oh(b);continue}break}break a}y=l,z=zd(m),w[y+8>>2]=z;d=w[b>>2]-w[l+8>>2]>>2;if(Db(q)>>>0>=d>>>0){y=l,z=ff(q),w[y+8>>2]=z;d=Pr(l+8|0,0-d|0);k=ff(q);s=zd(m);w[114256]=0;d=Tr(d,k,s);k=w[114256];w[114256]=0;if((k|0)==1){break a}if(d){break o}}y=l,z=zd(m),w[y>>2]=z;y=b,z=w[Zf(l+8|0,l)>>2],w[y>>2]=z}w[l+8>>2]=w[b>>2];q:{while(1){y=l,z=ff(m),w[y>>2]=z;if(!qe(l+8|0,l)){break q}w[114256]=0;b=Q(1740,a|0,l+552|0)|0;d=w[114256];w[114256]=0;r:{if((d|0)==1){break r}if(!b){break q}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}if((b|0)!=w[w[l+8>>2]>>2]){break q}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}Oh(l+8|0);continue}break}break a}if(!t){break d}y=l,z=ff(m),w[y>>2]=z;if(!qe(l+8|0,l)){break d}w[f>>2]=w[f>>2]|4;a=0;break e}s:{while(1){t:{w[114256]=0;d=Q(1740,a|0,l+552|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break t}if(!d){break s}w[114256]=0;k=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w[114256]=0;d=S(1781,h|0,64,k|0)|0;s=w[114256];w[114256]=0;if((s|0)==1){break a}u:{if(d){d=w[j>>2];if((d|0)==w[l+548>>2]){w[114256]=0;U(1784,i|0,j|0,l+548|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}d=w[j>>2]}w[j>>2]=d+4;w[d>>2]=k;b=b+1|0;break u}if(!Db(r)|!b|(k|0)!=w[l+112>>2]){break s}k=w[l+132>>2];if((k|0)==w[l+128>>2]){w[114256]=0;U(1776,p|0,l+132|0,l+128|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}k=w[l+132>>2]}w[l+132>>2]=k+4;w[k>>2]=b;b=0}w[114256]=0;V(1744,a|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){continue}}break}break a}k=w[l+132>>2];if(!(!b|(k|0)==w[p>>2])){if(w[l+128>>2]==(k|0)){w[114256]=0;U(1776,p|0,l+132|0,l+128|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}k=w[l+132>>2]}w[l+132>>2]=k+4;w[k>>2]=b}v:{if(w[l+28>>2]<=0){break v}w[114256]=0;b=Q(1741,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w:{if(!b){w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if((b|0)==w[l+116>>2]){break w}}w[f>>2]=w[f>>2]|4;a=0;break e}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}while(1){if(w[l+28>>2]<=0){break v}w[114256]=0;b=Q(1741,a|0,l+552|0)|0;d=w[114256];w[114256]=0;x:{if((d|0)==1){break x}y:{if(!b){w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}w[114256]=0;b=S(1781,h|0,64,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}if(b){break y}}w[f>>2]=w[f>>2]|4;a=0;break e}if(w[j>>2]==w[l+548>>2]){w[114256]=0;U(1784,i|0,j|0,l+548|0);b=w[114256];w[114256]=0;if((b|0)==1){break x}}w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}d=w[j>>2];w[j>>2]=d+4;w[d>>2]=b;w[114256]=0;w[l+28>>2]=w[l+28>>2]-1;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break a}k=c;if(w[i>>2]!=w[j>>2]){break c}w[f>>2]=w[f>>2]|4;a=0;break e}z:{if(!c){break z}k=1;while(1){if(Db(c)>>>0<=k>>>0){break z}w[114256]=0;b=Q(1741,a|0,l+552|0)|0;d=w[114256];w[114256]=0;A:{if((d|0)==1){break A}B:{if(!b){w[114256]=0;b=V(1742,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break A}if((b|0)==w[kj(c,k)>>2]){break B}}w[f>>2]=w[f>>2]|4;a=0;break e}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(w[p>>2]==w[l+132>>2]){break C}w[l+16>>2]=0;a=w[p>>2];w[114256]=0;Jc(r,a,w[l+132>>2],l+16|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(!w[l+16>>2]){break C}w[f>>2]=w[f>>2]|4;a=0;break e}break a}a=1}$b(q);$b(n);$b(o);$b(m);Gb(r);Ub(p);break b}k=c}e=e+1|0;continue}}break a}jb=l+560|0;return a|0}a=P()|0;$b(q);$b(n);$b(o);$b(m);Gb(r);Ub(p);R(a|0);M()}function qi(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{if((c|0)<=0){break a}j=w[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{k=w[b+656>>2];i=w[a+480180>>2];j:{if(!(!k|(i|0)!=16777216)){m=w[k+44>>2]!=0;break j}if(!k){break i}}if(c>>>0>128){break h}h=c-1|0;l=y[((h<<1)+k|0)+236>>1];k:{if((l-1&65535)>>>0<=3998){j=(C(l,104)+a|0)+484380|0;break k}if(!(x[a+1074317|0]&8)){break k}if((x[k+31|0]-1&255)>>>0>16){break a}}h=x[(h+k|0)+108|0];if(h>>>0<=120){break g}c=h;break h}h=c;l=0;if(c>>>0<121){break f}}l:{if(!(i&16777248?(c|0)!=255:0)){pg(a,b);if(!(x[a+1074324|0]&16)|d|(!(x[a+480208|0]&4)|!x[b+811|0])){break l}w[b+88>>2]=w[b+88>>2]&-6145;break l}if(!y[a+480192>>1]){break l}w[b+88>>2]=w[b+88>>2]|4096}m:{if((c|0)!=254){break m}c=w[b+88>>2];if(!(!(c&512)|w[a+480180>>2]!=2)){w[b+88>>2]=c|2048;break m}w[b+88>>2]=c|2101248;if(!(!y[a+480192>>1]|x[a+1074318|0]&4?w[a+480180>>2]&16777248:0)){w[b+688>>2]=0}if(x[a+1074318|0]&4){w[b+8>>2]=0;w[b+12>>2]=0}w[b+696>>2]=0}if(!(x[a+1074314|0]&16)){break a}u[b+819|0]=0;u[b+824|0]=0;return}l=0;if(!m){break f}if(d){l=x[b+819|0];if(l){break e}}w[b+708>>2]=0;l=1}if(d){break d}if(!(!(w[a+480180>>2]&1048588)|!j)){w[b+772>>2]=u[j+36|0];w[b+768>>2]=u[j+37|0];break c}if(j){break c}j=0;m=0;break b}l=C(v[w[k+44>>2]+36>>1]+1|0,h-l|0)-w[b+876>>2]|0;w[b+708>>2]=l;w[b+876>>2]=0-l;l=1}m=(j|0)!=0;n=1;if(w[b+8>>2]|w[b+12>>2]){break b}i=w[a+1074316>>2];if(i&4194304){w[b+700>>2]=0;return}n=!(i&128)&d;break b}m=1;if(!(u[a+1074315|0]&1)){break b}w[b+704>>2]=w[j+24>>2]}n:{if(w[a+480180>>2]&740327453){i=12;d=w[b+772>>2]+h|0;if((d|0)>=12){i=131;if(d>>>0<132){break n}}d=i;break n}d=h?h:1}h=w[a+1074316>>2];u[b+872|0]=x[b+872|0]|16;u[b+819|0]=h&4?(c|0)>=120?120:c:d;if(!(!(w[a+480180>>2]&16777250)&n)){u[b+825|0]=0}c=md(a,d,w[b+768>>2],w[b+704>>2]);u[b+851|0]=0;if(u[a+1074318|0]&1){Yn(a,b,k,j)}o:{if(e^1|n){break o}w[b+788>>2]=0;w[b+792>>2]=0;if(!k){break o}d=w[a+1074312>>2];if(d&536870912){u[b+820|0]=x[k+16|0]}if(!(x[k+60|0]&8)){w[b+728>>2]=0;w[b+732>>2]=-1}if(!(x[k+80|0]&8)){w[b+740>>2]=0;w[b+744>>2]=-1}if(!(x[k+100|0]&8)){w[b+752>>2]=0;w[b+756>>2]=-1}h=x[k+20|0];if(h){i=w[a+1074328>>2];w[a+1074328>>2]=C(i,214013)+2531011;i=((C(h,i<<8>>24)<<16>>16)/64<<16)+65536>>16;if(d&268435456){h=w[b+764>>2]}else{h=(w[b+688>>2]+1|0)/2|0}v[b+788>>1]=(C(h,i)|0)/199}h=x[k+19|0];p:{if(!h){break p}i=w[a+1074328>>2];w[a+1074328>>2]=C(i,214013)+2531011;v[b+790>>1]=(C(h,i<<8>>24)<<16>>16)/32;if(y[b+796>>1]|d&268435456){break p}v[b+796>>1]=y[b+692>>1]+1}d=x[k+23|0];if(d){h=w[a+1074328>>2];w[a+1074328>>2]=C(h,214013)+2531011;i=x[b+857|0];u[b+818|0]=i+1;v[b+792>>1]=(C(i,(C(d,(h<<8>>24)+1|0)<<16>>16)/128<<16>>16)+1|0)/128}d=x[k+24|0];if(!d){break o}h=w[a+1074328>>2];w[a+1074328>>2]=C(h,214013)+2531011;i=x[b+858|0];u[b+817|0]=i+1;v[b+794>>1]=(C(i,(C(d,(h<<8>>24)+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}q:{r:{if(!c){c=0;break r}if(!(w[b+700>>2]?n:0)){w[b+700>>2]=c}s:{t:{u:{v:{w:{x:{if(!l){if(!n){if(x[a+1074320|0]&32|x[a+1074317|0]&64|w[a+480180>>2]==1){break x}}w[b+708>>2]=c}if(!n){break x}c=w[b+76>>2];if(c){break w}if(!(x[a+480180|0]&2)){break x}c=w[b>>2];break v}w[b+104>>2]=j;c=w[j>>2];w[b+84>>2]=c;w[b+76>>2]=c;w[b+80>>2]=0;w[b>>2]=0;w[b+4>>2]=0;i=w[a+480208>>2];y:{if(!(i&2097152)){if(!(u[a+1074324|0]&1)){break u}if(!x[b+811|0]){break y}break u}if(x[b+811|0]){break u}}d=c-1|0;h=w[b+660>>2];d=d>>>0<h>>>0?d:h;w[b>>2]=0;w[b+4>>2]=d;break t}d=c;c=w[b>>2];if(d>>>0>z[b+4>>2]){break s}}d=c;c=w[b+80>>2];w[b>>2]=d;w[b+4>>2]=c;break s}w[b+660>>2]=0}h=y[j+34>>1];d=h&1023;m=d|w[b+88>>2]&-525056;w[b+88>>2]=m;z:{A:{if(h&8){l=w[j+12>>2];w[b+80>>2]=l;j=w[j+16>>2];m=(d&16?m|4:m&-524295)|2;w[b+88>>2]=m;w[b+84>>2]=j;d=c;if(j>>>0<d>>>0){break A}break z}l=0;if(!(d&2)){d=c;break z}l=w[j+4>>2];w[b+80>>2]=l;j=w[j+8>>2];w[b+84>>2]=j;d=c;if(j>>>0>=d>>>0){break z}}w[b+76>>2]=j;d=j}if(!(!(x[a+1074322|0]&8)|l)){w[b+84>>2]=c;w[b+76>>2]=c;d=c}if(!(!(m&128)|!d)){w[b+88>>2]=m|128;w[b>>2]=0;w[b+4>>2]=d-1}c=w[a+1074312>>2];B:{if(x[b+842|0]>3){break B}h=w[a+480180>>2];C:{D:{if(!(!(h&16777248)|c&2097152)){m=16;if(i&4){break D}break C}m=32;if((h|0)==16){break C}}if(h&67633152){break B}m=0}u[b+839|0]=m}if(!(c&2097152|x[b+845|0]>3)){u[b+840|0]=0}c=d;d=w[b>>2];if(c>>>0<=z[b+4>>2]){c=d;d=w[b+80>>2];w[b>>2]=c;w[b+4>>2]=d}c=0;if(!n){break r}}c=1;if(!(w[a+480180>>2]&17301536)|(w[b+696>>2]?0:x[b+89|0]&16)){break r}d=x[b+811|0];if(!(x[a+480208|0]&8)|!d){break q}}E:{if(!(w[a+480180>>2]&17301536)){break E}d=w[b+88>>2];if(w[b+696>>2]|!(d&4096)){break E}w[b+752>>2]=0;w[b+756>>2]=-1;w[b+740>>2]=0;w[b+744>>2]=-1;w[b+728>>2]=0;w[b+732>>2]=-1;if(!(x[a+1074314|0]&32)){u[b+838|0]=0;w[b+780>>2]=0}w[b+696>>2]=65536;w[b+88>>2]=d&-4097}F:{G:{if(!c){d=x[b+811|0];break G}d=x[b+811|0];if(d|!(x[a+480208|0]&8)){break G}c=1;break F}if(d&255?0:w[a+480180>>2]&1048580){break F}w[b+696>>2]=65536;w[b+88>>2]=w[b+88>>2]&-4097;break q}d=0}h=w[a+1074316>>2];if(!c|!(h&256)|(d&255?x[a+480208|0]&8:0)){d=w[b+88>>2]&-4196353}else{d=w[b+88>>2]&-4194305}w[b+88>>2]=d;H:{if(c){break H}v[b+862>>1]=65535;w[b+88>>2]=d&-6324225|2097152;if(!(x[a+1074320|0]&128|(w[a+1074312>>2]&12582912|h&1048576))){u[b+859|0]=0;v[b+798>>1]=0}if(e){u[b+838|0]=0;w[b+780>>2]=0}w[b+20>>2]=0;w[b+24>>2]=0;d=w[a+480208>>2]&8192;I:{if(k){e=u[k+22|0];J:{K:{if((e|0)>=0){e=u[k+21|0];if((e|0)<0){break K}d=!(d>>>13|0);if(d){break J}break I}u[b+858|0]=e&127;e=u[k+21|0];if((e|0)>=0){break J}}u[b+857|0]=e&127}d=1;e=x[k+25|0];if((e|0)==255){break I}u[b+865|0]=e;break I}w[b+788>>2]=0;w[b+792>>2]=0;d=!d}L:{if(x[b+857|0]>=127){if(!(h&16)){break H}if(!(d^1)){break L}break H}if(!d){break H}}if((hh(a,b,1,256)|0)<0|(!(x[b+89|0]&2)|(g|0)==65535)){break H}d=w[a+1304392>>2];if(!d){break H}lh(d,g,x[b+857|0]>>>1|0,1)}d=w[b+88>>2];if(f){d=d&-1025;w[b+88>>2]=d}M:{N:{if(x[a+24618|0]&16?d&1024:0){break N}a=w[b+104>>2];if(!(!a|!(x[a+35|0]&4)|f)){break N}a=w[b+656>>2];if(!a|!(x[a+15|0]&2)){break M}}if(f){break M}w[b+700>>2]=0}if(c){break a}v[b+136>>1]=0;w[b+132>>2]=4194304;w[b+112>>2]=0;w[b+116>>2]=0}}function yu(a,b,c,d,e,f){var g=0,h=D(0),i=0,j=0,k=D(0),l=D(0),m=0,n=D(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=D(0),B=D(0),F=D(0),G=D(0),H=0,I=D(0),J=D(0),K=D(0),L=D(0),M=D(0),N=D(0),O=0,P=0,Q=0,R=0;m=jb-144|0;jb=m;if((d|0)>0){x=(c|0)<=0;while(1){if(!x){y=C(w,2304)+b|0;j=0;while(1){p=y+(j<<2)|0;q=0;g=0;i=m;t=i;while(1){h=A[C(31-g|0,72)+p>>2];u=C(g,72)+p|0;k=A[u>>2];n=D(h+k);l=A[u+1152>>2];z=A[C(15-g|0,72)+p>>2];B=D(l+z);A[t>>2]=n+B;u=C(g,12)+45792|0;h=D(A[u+4>>2]*D(k-h));k=D(A[u>>2]*D(z-l));A[t+64>>2]=h+k;l=A[u+8>>2];A[t+32>>2]=l*D(n-B);A[t+96>>2]=l*D(h-k);t=t+4|0;g=g+1|0;if((g|0)!=8){continue}break}while(1){n=A[i+28>>2];l=A[i>>2];h=D(n+l);z=A[i+16>>2];B=A[i+12>>2];k=D(z+B);F=D(h+k);G=A[i+24>>2];I=A[i+4>>2];J=D(G+I);K=A[i+20>>2];L=A[i+8>>2];M=D(K+L);N=D(J+M);A[i>>2]=F+N;A[i+16>>2]=D(F-N)*D(.7071067690849304);h=D(h-k);k=D(D(h+D(J-M))*D(.7071067690849304));A[i+24>>2]=D(h-k)*D(1.3065630197525024);A[i+8>>2]=D(k+h)*D(.5411961078643799);k=D(I-G);F=D(L-K);G=D(D(k+F)*D(.7071067690849304));h=D(l-n);n=D(G+h);k=D(h+k);l=D(D(D(B-z)+F)+D(k*D(-.1989123672246933)));k=D(D(l*D(.3826834261417389))+k);A[i+28>>2]=D(n-k)*D(2.562915563583374);A[i+4>>2]=D(k+n)*D(.509795606136322);k=D(l+D(k*D(-.1989123672246933)));h=D(h-G);A[i+20>>2]=D(k+h)*D(.8999761939048767);A[i+12>>2]=D(h-k)*D(.601344883441925);i=i+32|0;q=q+1|0;if((q|0)!=4){continue}break}g=0;h=A[m+32>>2];k=A[m+96>>2];l=A[m+64>>2];while(1){i=p;A[i>>2]=A[(g<<2)+m>>2];g=g+1|0;p=(g<<2)+m|0;n=A[p+96>>2];z=D(n+k);A[i+72>>2]=z+l;k=A[p+32>>2];A[i+144>>2]=k+h;l=A[p- -64>>2];A[i+216>>2]=l+z;p=i+288|0;h=k;k=n;if((g|0)!=7){continue}break}A[i+288>>2]=A[m+28>>2];h=A[m+124>>2];A[i+360>>2]=h+A[m+92>>2];k=A[m+60>>2];A[i+504>>2]=h;A[i+432>>2]=k;j=j+1|0;if((j|0)!=(c|0)){continue}break}}w=w+1|0;if((w|0)!=(d|0)){continue}break}}H=Fb(f,a,3840);if((c|0)>0){O=d<<5;x=0;P=d-1|0;R=C(P,2304);while(1){p=(x<<8)+H|0;t=(x<<2)+b|0;A[p+4080>>2]=A[t+1152>>2];w=t+R|0;A[p+4084>>2]=A[w+1152>>2];A[p+4088>>2]=A[t>>2];A[p+4092>>2]=A[w>>2];A[p+4336>>2]=A[t+1156>>2];A[p+4340>>2]=A[w+1156>>2];A[p+4344>>2]=A[t+4>>2];A[p+4348>>2]=A[w+4>>2];u=(C(x,O)<<1)+e|0;y=u+(P<<1)|0;Qj(y,d,p+244|0);f=O<<1;Qj(f+y|0,d,p+500|0);Qj(u,d,p+240|0);Qj(f+u|0,d,p+496|0);q=45888;Q=p+3840|0;i=14;while(1){f=i;o=i<<4;j=o+Q|0;g=C(31-i|0,72);A[j>>2]=A[g+t>>2];A[j+4>>2]=A[g+w>>2];g=g|4;A[j+8>>2]=A[g+t>>2];A[j+12>>2]=A[g+w>>2];g=C(i,72);r=g+76|0;A[j+256>>2]=A[r+t>>2];A[j+260>>2]=A[r+w>>2];g=g+72|0;A[j-248>>2]=A[g+t>>2];A[j-244>>2]=A[g+w>>2];r=i<<2;o=p+o|0;h=A[q+4>>2];k=A[q>>2];g=0;while(1){i=g<<2;n=A[i+j>>2];l=A[i+o>>2];A[i+m>>2]=D(n*k)-D(l*h);A[i+(m+128|0)>>2]=D(l*k)+D(n*h);g=g+1|0;if((g|0)!=4){continue}break}i=(r<<2)+Q|0;o=i-3584|0;r=i-256|0;h=A[q+12>>2];k=A[q+8>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(n*h)-D(l*k))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}o=i-3328|0;r=i-512|0;h=A[q+20>>2];k=A[q+16>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(l*k)-D(n*h))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}o=i-3072|0;r=i-768|0;h=A[q+28>>2];k=A[q+24>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(n*h)-D(l*k))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}o=i-2816|0;r=i-1024|0;h=A[q+36>>2];k=A[q+32>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(l*k)-D(n*h))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}o=i-2560|0;r=i-1280|0;h=A[q+44>>2];k=A[q+40>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(n*h)-D(l*k))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}o=i-2304|0;r=i-1536|0;h=A[q+52>>2];k=A[q+48>>2];g=0;while(1){j=g<<2;s=j+(m+128|0)|0;n=A[j+o>>2];l=A[j+r>>2];A[s>>2]=D(D(n*k)+D(l*h))+A[s>>2];j=j+m|0;A[j>>2]=D(D(l*k)-D(n*h))+A[j>>2];g=g+1|0;if((g|0)!=4){continue}break}j=i-2048|0;o=i-1792|0;h=A[q+60>>2];k=A[q+56>>2];g=0;while(1){i=g<<2;r=i+(m+128|0)|0;n=A[i+j>>2];l=A[i+o>>2];A[r>>2]=D(D(n*k)+D(l*h))+A[r>>2];i=i+m|0;A[i>>2]=D(D(n*h)-D(l*k))+A[i>>2];g=g+1|0;if((g|0)!=4){continue}break}i=32767;j=C(15-f|0,d)<<1;o=j+y|0;h=A[m+4>>2];g=32767;a:{if(h>=D(32766.5)){break a}g=32768;if(h<=D(-32767.5)){break a}h=D(h+D(.5));b:{if(D(E(h))<D(2147483648)){g=~~h;break b}g=-2147483648}g=(g>>15)+g|0}v[o>>1]=g;h=A[m+132>>2];c:{if(h>=D(32766.5)){break c}i=32768;if(h<=D(-32767.5)){break c}h=D(h+D(.5));d:{if(D(E(h))<D(2147483648)){i=~~h;break d}i=-2147483648}i=(i>>15)+i|0}o=C(f+17|0,d)<<1;v[o+y>>1]=i;i=32767;j=j+u|0;h=A[m>>2];g=32767;e:{if(h>=D(32766.5)){break e}g=32768;if(h<=D(-32767.5)){break e}h=D(h+D(.5));f:{if(D(E(h))<D(2147483648)){g=~~h;break f}g=-2147483648}g=(g>>15)+g|0}v[j>>1]=g;h=A[m+128>>2];g:{if(h>=D(32766.5)){break g}i=32768;if(h<=D(-32767.5)){break g}h=D(h+D(.5));h:{if(D(E(h))<D(2147483648)){i=~~h;break h}i=-2147483648}i=(i>>15)+i|0}v[o+u>>1]=i;i=32767;j=C(47-f|0,d)<<1;o=j+y|0;h=A[m+12>>2];g=32767;i:{if(h>=D(32766.5)){break i}g=32768;if(h<=D(-32767.5)){break i}h=D(h+D(.5));j:{if(D(E(h))<D(2147483648)){g=~~h;break j}g=-2147483648}g=(g>>15)+g|0}v[o>>1]=g;h=A[m+140>>2];k:{if(h>=D(32766.5)){break k}i=32768;if(h<=D(-32767.5)){break k}h=D(h+D(.5));l:{if(D(E(h))<D(2147483648)){i=~~h;break l}i=-2147483648}i=(i>>15)+i|0}o=C(f+49|0,d)<<1;v[o+y>>1]=i;i=32767;j=j+u|0;h=A[m+8>>2];g=32767;m:{if(h>=D(32766.5)){break m}g=32768;if(h<=D(-32767.5)){break m}h=D(h+D(.5));n:{if(D(E(h))<D(2147483648)){g=~~h;break n}g=-2147483648}g=(g>>15)+g|0}v[j>>1]=g;h=A[m+136>>2];o:{if(h>=D(32766.5)){break o}i=32768;if(h<=D(-32767.5)){break o}h=D(h+D(.5));p:{if(D(E(h))<D(2147483648)){i=~~h;break p}i=-2147483648}i=(i>>15)+i|0}q=q- -64|0;v[o+u>>1]=i;i=f-1|0;if(f){continue}break}x=x+2|0;if((x|0)<(c|0)){continue}break}}b=c<<6;q:{if((d|0)==1){i=0;while(1){A[(i<<2)+a>>2]=A[(b+i<<2)+H>>2];c=i>>>0<958;i=i+2|0;if(c){continue}break}break q}Fb(a,(b<<2)+H|0,3840)}jb=m+144|0}function oU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-112|0;jb=d;e=-1;a:{b:{c:{d:{e:{if(w[(w[w[b>>2]-12>>2]+b|0)+16>>2]){break e}rd(d+80|0,b);g=w[d+88>>2];f=w[d+92>>2];w[d+72>>2]=0;w[d+76>>2]=0;sf(b,d+72|0,8);if(w[d+72>>2]!=1414681667|w[d+76>>2]!=776101705){a=d- -64|0;w[a>>2]=g;w[a+4>>2]=f;w[d+8>>2]=g;w[d+12>>2]=f;w[d+56>>2]=0;w[d+60>>2]=0;w[d>>2]=0;w[d+4>>2]=0;rf(b,d);break e}v[d+32>>1]=0;w[d+84>>2]=d+34;w[d+80>>2]=d+32;Ob(b,d+80|0);l=v[d+32>>1];if((l-4&65535)>>>0<65534){break e}w[d+48>>2]=0;w[d+52>>2]=0;sf(b,d+48|0,8);if(w[d+48>>2]!=1933333571|w[d+52>>2]!=1111389030){break e}v[d+32>>1]=0;w[d+84>>2]=d+34;w[d+80>>2]=d+32;Ob(b,d+80|0);g=y[d+32>>1];if((g-5&65535)>>>0<65534){break e}f:{g:{h:{i:{j:{if(g>>>0<=3){w[114256]=0;w[d+88>>2]=0;w[d+80>>2]=0;w[d+84>>2]=0;f=S(971,b|0,d+80|0,65535)|0;h=w[114256];w[114256]=0;if((h|0)==1){break g}if(!f){break j}w[114256]=0;U(6,d+32|0,c|0,d+80|0);f=w[114256];w[114256]=0;if((f|0)!=1){if(u[a+51|0]<0){zb(w[a+40>>2])}f=w[d+36>>2];w[a+40>>2]=w[d+32>>2];w[a+44>>2]=f;w[a+48>>2]=w[d+40>>2];if(u[d+91|0]>=0){break f}zb(w[d+80>>2]);break f}break g}w[114256]=0;w[d+88>>2]=0;w[d+80>>2]=0;w[d+84>>2]=0;f=S(972,b|0,d+80|0,255)|0;h=w[114256];w[114256]=0;if((h|0)==1){break h}if(!f){break i}w[114256]=0;U(6,d+32|0,c|0,d+80|0);f=w[114256];w[114256]=0;if((f|0)!=1){if(u[a+51|0]<0){zb(w[a+40>>2])}f=w[d+36>>2];w[a+40>>2]=w[d+32>>2];w[a+44>>2]=f;w[a+48>>2]=w[d+40>>2];if(u[d+91|0]>=0){break f}zb(w[d+80>>2]);break f}break h}if(u[d+91|0]>=0){break e}zb(w[d+80>>2]);break e}if(u[d+91|0]>=0){break e}zb(w[d+80>>2]);break e}b=P()|0;if(u[d+91|0]>=0){break a}zb(w[d+80>>2]);break a}b=P()|0;if(u[d+91|0]>=0){break a}zb(w[d+80>>2]);break a}v[d+32>>1]=0;f=d+34|0;w[d+84>>2]=f;h=d+32|0;w[d+80>>2]=h;Ob(b,d+80|0);v[d+32>>1]=0;w[d+84>>2]=f;w[d+80>>2]=h;Ob(b,d+80|0);v[a>>1]=y[d+32>>1];k:{if(g>>>0<=3){w[d+32>>2]=0;w[d+84>>2]=d+36;w[d+80>>2]=d+32;Ob(b,d+80|0);f=w[d+32>>2];if(f>>>0<=65535){break k}break e}v[d+32>>1]=0;w[d+84>>2]=f;w[d+80>>2]=d+32;Ob(b,d+80|0);f=y[d+32>>1]}l:{m:{n:{o:{p:{m=f&65535;if(m){n=a+52|0;f=d+105|0;o=d+108|0;p=d+106|0;q=g>>>0>3;g=0;while(1){w[d+88>>2]=0;w[114256]=0;w[d+80>>2]=0;w[d+84>>2]=0;v[d+24>>1]=0;v[d+104>>1]=0;w[d+36>>2]=p;w[d+32>>2]=d+104;kc(b,d+32|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}v[d+24>>1]=y[d+104>>1];e=u[d+91|0];q:{if(!q){r:{if((e|0)<0){u[w[d+80>>2]]=0;w[d+84>>2]=0;break r}u[d+91|0]=0;u[d+80|0]=0}w[114256]=0;w[d+104>>2]=0;w[d+36>>2]=o;w[d+32>>2]=d+104;e=kc(b,d+32|0);h=nb;i=w[114256];w[114256]=0;if((i|0)==1){break d}if((e|0)!=4|h){break p}h=w[d+104>>2];if(h>>>0>65535){break p}e=0;if(!h){break q}while(1){s:{w[114256]=0;u[d+104|0]=0;w[d+36>>2]=f;w[d+32>>2]=d+104;i=kc(b,d+32|0);j=nb;k=w[114256];w[114256]=0;if((k|0)==1){break s}if((i|0)!=1|j){break p}i=u[d+104|0];w[114256]=0;T(71,d+80|0,i|0);i=w[114256];w[114256]=0;if((i|0)==1){break s}e=e+1|0;if((h|0)!=(e|0)){continue}break q}break}b=P()|0;break b}t:{if((e|0)<0){u[w[d+80>>2]]=0;w[d+84>>2]=0;break t}u[d+91|0]=0;u[d+80|0]=0}w[114256]=0;u[d+104|0]=0;w[d+36>>2]=f;w[d+32>>2]=d+104;e=kc(b,d+32|0);h=nb;i=w[114256];w[114256]=0;if((i|0)==1){break d}if((e|0)!=1|h){break p}e=0;h=x[d+104|0];if(!h){break q}while(1){w[114256]=0;u[d+104|0]=0;w[d+36>>2]=f;w[d+32>>2]=d+104;i=kc(b,d+32|0);j=nb;k=w[114256];w[114256]=0;if((k|0)==1){break c}if((i|0)!=1|j){break p}i=u[d+104|0];w[114256]=0;T(71,d+80|0,i|0);i=w[114256];w[114256]=0;if((i|0)==1){break c}e=e+1|0;if((h|0)!=(e&255)){continue}break}}w[114256]=0;U(6,d+32|0,c|0,d+80|0);e=w[114256];w[114256]=0;if((e|0)==1){break o}w[114256]=0;e=d+24|0;w[d+96>>2]=e;ia(970,d+104|0,n|0,e|0,35814,d+96|0,d+16|0);e=w[114256];w[114256]=0;if((e|0)==1){break n}e=w[d+104>>2];if(u[e+31|0]<0){zb(w[e+20>>2])}h=w[d+36>>2];w[e+20>>2]=w[d+32>>2];w[e+24>>2]=h;w[e+28>>2]=w[d+40>>2];if(u[d+91|0]<0){zb(w[d+80>>2])}g=g+1|0;if((g&65535)>>>0<m>>>0){continue}break}}w[d+32>>2]=0;w[d+36>>2]=0;sf(b,d+32|0,8);e=-1;if(w[d+32>>2]!=1933333571|w[d+36>>2]!=1161720678){break e}c=y[a>>1];if(c>>>0>3|(c|0)==2){break e}c=a+4|0;if((l|0)>2){break m}if(!aw(b,c)){break e}if(aw(b,a+16|0)){break l}break e}e=-1;if(u[d+91|0]>=0){break e}zb(w[d+80>>2]);break e}b=P()|0;break b}b=P()|0;if(u[d+43|0]>=0){break b}zb(w[d+32>>2]);break b}if(!$v(b,c)){break e}if(!$v(b,a+16|0)){break e}}w[a+36>>2]=w[a+20>>2]-w[a+16>>2]>>2;v[d+104>>1]=0;c=d+106|0;w[d+84>>2]=c;w[d+80>>2]=d+104;Ob(b,d+80|0);g=y[d+104>>1];v[a+28>>1]=g;if((g-201&65535)>>>0<65135){break e}v[d+104>>1]=0;w[d+84>>2]=c;w[d+80>>2]=d+104;Ob(b,d+80|0);c=v[d+104>>1];v[a+30>>1]=c;if((c|0)<0){break e}w[d+96>>2]=0;c=d+96|0;w[d+84>>2]=c|4;w[d+80>>2]=c;Ob(b,d+80|0);A[a+32>>2]=H(D(G(D(E(A[d+96>>2])),D(1e7))),D(10000000036274937e-31));w[d+104>>2]=0;w[d+108>>2]=0;sf(b,d+104|0,8);if(w[d+104>>2]!=1414681667|w[d+108>>2]!=776298313){break e}b=w[a+8>>2]-w[a+4>>2]|0;if(b>>>0>131068){break e}c=v[a+30>>1];g=y[a>>1];if(!(g?(c|0)>0&A[a+32>>2]>D(0):1)){break e}u:{switch(g-1|0){case 0:case 2:if(c>>>0>b>>2>>>0){break e}break;default:break u}}b=w[a+36>>2];v:{if(!b){b=0;break v}b=b-1|0;w[a+36>>2]=b}w[a+36>>2]=b>>>0>=65535?65535:b;ii(a);e=1;if(y[a>>1]!=3){break e}g=v[a+30>>1];c=v[a+28>>1];f=w[a+8>>2]-w[a+4>>2]|0;b=f>>2;if((g-c|0)>((b>>>0>=32767?32767:b)|0)){break e}b=0;w[d+88>>2]=0;w[d+80>>2]=0;w[d+84>>2]=0;w:{if((g|0)>0){x:{while(1){y:{c=w[a+4>>2]+(b-v[a+28>>1]<<2)|0;e=w[d+84>>2];z:{if((e|0)!=w[d+88>>2]){A[e>>2]=A[c>>2];w[d+84>>2]=e+4;break z}w[114256]=0;T(973,d+80|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break y}g=y[a+30>>1]}b=b+1|0;if((b|0)<g<<16>>16){continue}break x}break}break w}f=w[a+8>>2]-w[a+4>>2]|0;c=y[a+28>>1]}w[114256]=0;v[d+24>>1]=c;v[d+26>>1]=((f>>>2|0)+c|0)-1;v[d+16>>1]=0;da(967,a|0,d+80|0,a+32|0,d+24|0,d+16|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=w[d+80>>2];if(a){w[d+84>>2]=a;zb(a)}e=1;break e}}b=P()|0;a=w[d+80>>2];if(!a){break a}w[d+84>>2]=a;zb(a);break a}jb=d+112|0;return e|0}b=P()|0;break b}b=P()|0}if(u[d+91|0]>=0){break a}zb(w[d+80>>2])}R(b|0);M()}function yn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=jb-16|0;jb=i;a:{b:{if(!d|(c-1&255)>>>0>119|w[b+480180>>2]!=16777216|y[b+480192>>1]<d>>>0){break b}d=w[((d<<2)+b|0)+900380>>2];if(!d){break b}g=w[d+44>>2];if(!g){break b}v[i+14>>1]=c-61;b=a;e=jb-80|0;jb=e;a=v[g+28>>1];j=i+14|0;d=v[j>>1];c:{if(!((a|0)<=(d|0)&(d|0)<=(a+(w[g+8>>2]-w[g+4>>2]>>>2|0)<<16)-65536>>16)){w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;break c}d:{h=v[g+30>>1];if(!h){e:{c=g+56|0;f=w[c>>2];if(!f){break e}a=c;while(1){g=(d|0)>v[f+16>>1];a=g?a:f;f=w[(g?f+4|0:f)>>2];if(f){continue}break}if((a|0)==(c|0)|(d|0)<v[a+16>>1]){break e}if(u[a+31|0]<0){break d}c=w[a+24>>2];w[b>>2]=w[a+20>>2];w[b+4>>2]=c;w[b+8>>2]=w[a+28>>2];break c}d=jb-16|0;jb=d;c=jb-160|0;jb=c;a=Od(c+8|0);g=w[w[a>>2]-12>>2];w[114256]=0;f=ea(79)|0;h=w[114256];w[114256]=0;f:{g:{h:{i:{if((h|0)==1){break i}w[114256]=0;g=a+g|0;T(10,c|0,g|0);h=w[114256];w[114256]=0;if((h|0)==1){break i}w[114256]=0;U(80,c+152|0,g|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break h}Ab(c+152|0);g=w[g+24>>2];if(g){h=w[w[g>>2]+8>>2];w[114256]=0;T(h|0,g|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break h}g=g+4|0;h=Ic(c+144|0,g);Wc(g,f);Ab(h)}Ab(c);f=v[j>>1];w[114256]=0;Q(86,a|0,f|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}w[114256]=0;f=a+4|0;T(82,d|0,f|0);g=w[114256];w[114256]=0;if((g|0)==1){break i}g=w[15e3];w[a>>2]=g;w[a+w[g-12>>2]>>2]=w[15003];w[a+4>>2]=59272;if(u[a+47|0]<0){zb(w[a+36>>2])}wc(f);pc(a+56|0);jb=c+160|0;break f}b=P()|0;break g}b=P()|0;Ab(c)}nd(a);R(b|0);M()}w[114256]=0;U(6,b|0,0,d|0);a=w[114256];w[114256]=0;j:{if((a|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}jb=d+16|0;break j}a=P()|0;if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}break c}if((d|0)>=0){c=(d|0)%(h|0)|0}else{c=h+((d^-1)%(h|0)^-1)|0}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{d=g+56|0;f=w[d>>2];if(!f){break z}a=d;while(1){k=v[f+16>>1]<c<<16>>16;a=k?a:f;f=w[(k?f+4|0:f)>>2];if(f){continue}break}if((a|0)==(d|0)|v[a+16>>1]>c<<16>>16){break z}w[114256]=0;Q(117,b|0,a+20|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break y}a=v[g+30>>1];c=v[j>>1];A:{if((c|0)>=0){a=(c|0)/(a|0)|0;break A}a=((c+1|0)/(a|0)|0)-1|0}w[114256]=0;w[e+40>>2]=a+5;T(116,e+56|0,e+40|0);a=w[114256];w[114256]=0;B:{if((a|0)!=1){w[114256]=0;a=x[e+67|0];c=a<<24>>24<0;S(2,b|0,(c?w[e+56>>2]:e+56|0)|0,(c?w[e+60>>2]:a)|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break B}if(u[e+67|0]>=0){break c}zb(w[e+56>>2]);break c}f=P()|0;break k}f=P()|0;if(u[e+67|0]>=0){break k}zb(w[e+56>>2]);break k}if((h|0)>26){break w}w[114256]=0;u[e+41|0]=0;u[e+40|0]=c+65;u[e+51|0]=1;U(6,e+56|0,0,e+40|0);a=w[114256];w[114256]=0;if((a|0)==1){break x}if(u[b+11|0]<0){zb(w[b>>2])}a=w[e+60>>2];w[b>>2]=w[e+56>>2];w[b+4>>2]=a;w[b+8>>2]=w[e- -64>>2];u[e+67|0]=0;u[e+56|0]=0;if(u[e+51|0]<0){zb(w[e+40>>2])}w[114256]=0;S(2,b|0,10095,1)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break v}}f=P()|0;break k}f=P()|0;if(u[e+51|0]>=0){break k}zb(w[e+40>>2]);break k}w[114256]=0;a=(c<<16>>16)/16|0;w[e+28>>2]=c-(a<<4)<<16>>16;u[e+72|0]=44;w[e+64>>2]=-1;w[e+68>>2]=0;w[e+56>>2]=1058;w[e+60>>2]=1;U(101,e+40|0,e+28|0,e+56|0);d=w[114256];w[114256]=0;if((d|0)==1){break u}w[114256]=0;w[e+12>>2]=(a<<16>>16)%16;u[e+72|0]=44;w[e+64>>2]=-1;w[e+68>>2]=0;w[e+56>>2]=1058;w[e+60>>2]=1;U(101,e+16|0,e+12|0,e+56|0);a=w[114256];w[114256]=0;if((a|0)==1){break t}w[114256]=0;a=u[e+27|0];d=(a|0)<0;a=S(2,e+40|0,(d?w[e+16>>2]:e+16|0)|0,(d?w[e+20>>2]:a&255)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break s}f=w[a>>2];w[e+32>>2]=w[a+4>>2];d=x[a+7|0]|x[a+8|0]<<8|(x[a+9|0]<<16|x[a+10|0]<<24);u[e+35|0]=d;u[e+36|0]=d>>>8;u[e+37|0]=d>>>16;u[e+38|0]=d>>>24;w[a>>2]=0;w[a+4>>2]=0;d=x[a+11|0];w[a+8>>2]=0;if(u[b+11|0]<0){zb(w[b>>2])}w[b>>2]=f;w[b+4>>2]=w[e+32>>2];a=x[e+35|0]|x[e+36|0]<<8|(x[e+37|0]<<16|x[e+38|0]<<24);u[b+7|0]=a;u[b+8|0]=a>>>8;u[b+9|0]=a>>>16;u[b+10|0]=a>>>24;u[b+11|0]=d;if(u[e+27|0]<0){zb(w[e+16>>2])}if(u[e+51|0]<0){zb(w[e+40>>2])}if(c<<16>>16<256){break v}w[114256]=0;U(9,e|0,0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break q}w[114256]=0;T(959,e+40|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break p}w[114256]=0;U(6,e+56|0,0,e+40|0);a=w[114256];w[114256]=0;if((a|0)==1){break o}if(u[b+11|0]<0){zb(w[b>>2])}a=w[e+60>>2];w[b>>2]=w[e+56>>2];w[b+4>>2]=a;w[b+8>>2]=w[e- -64>>2];u[e+67|0]=0;u[e+56|0]=0;if(u[e+51|0]<0){zb(w[e+40>>2])}if(u[e+11|0]>=0){break v}zb(w[e>>2])}a=v[g+30>>1];c=v[j>>1];if((c|0)<0){break m}a=(c|0)/(a|0)|0;break l}f=P()|0;break k}f=P()|0;break r}f=P()|0;if(u[e+27|0]>=0){break r}zb(w[e+16>>2])}if(u[e+51|0]>=0){break k}zb(w[e+40>>2]);break k}f=P()|0;break k}f=P()|0;break n}f=P()|0;if(u[e+51|0]>=0){break n}zb(w[e+40>>2])}if(u[e+11|0]>=0){break k}zb(w[e>>2]);break k}a=((c+1|0)/(a|0)|0)-1|0}w[114256]=0;w[e+40>>2]=a+5;T(116,e+56|0,e+40|0);a=w[114256];w[114256]=0;C:{if((a|0)!=1){w[114256]=0;a=x[e+67|0];c=a<<24>>24<0;S(2,b|0,(c?w[e+56>>2]:e+56|0)|0,(c?w[e+60>>2]:a)|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break C}if(u[e+67|0]>=0){break c}zb(w[e+56>>2]);break c}f=P()|0;break k}f=P()|0;if(u[e+67|0]>=0){break k}zb(w[e+56>>2])}if(u[b+11|0]<0){zb(w[b>>2])}R(f|0);M()}me(b,w[a+20>>2],w[a+24>>2])}jb=e+80|0;break a}d=w[b>>2];b=jb-32|0;jb=b;D:{if(c>>>0>=251){w[b+16>>2]=w[6416];d=w[6413];w[b>>2]=w[6412];w[b+4>>2]=d;d=w[6415];w[b+8>>2]=w[6414];w[b+12>>2]=d;Hb(a,(b+(c<<2)|0)-1004|0);break D}e=c-1|0;f=e&255;if(f>>>0<=119){w[b+8>>2]=0;w[b>>2]=0;w[b+4>>2]=0;c=(f>>>0)/12|0;d=d+((e-C(c,12)&255)<<2)|0;e=ec(d);w[114256]=0;d=S(2,b|0,d|0,e|0)|0;e=w[114256];w[114256]=0;E:{if((e|0)==1){break E}w[114256]=0;c=S(53,d|0,1,c+48|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break E}F:{if(u[c+11|0]>=0){d=w[c+4>>2];w[a>>2]=w[c>>2];w[a+4>>2]=d;w[a+8>>2]=w[c+8>>2];break F}d=w[c+4>>2];c=w[c>>2];w[114256]=0;U(3,a|0,c|0,d|0);a=w[114256];w[114256]=0;if((a|0)==1){break E}}if(u[b+11|0]>=0){break D}zb(w[b>>2]);break D}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}if(!c){Hb(a,12594);break D}Hb(a,10066)}jb=b+32|0}jb=i+16|0}function WB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-208|0;jb=d;w[b+8>>2]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!Ii(b,d+192|0)){break l}if(!tp(d+192|0)){break l}f=Kb(16);w[f+4>>2]=0;w[f+8>>2]=0;w[f+12>>2]=75696;w[f>>2]=75656;w[d+184>>2]=0;w[d+188>>2]=0;w[d+180>>2]=f;w[d+176>>2]=f+12;f=0;w[d+168>>2]=0;w[d+160>>2]=0;w[d+164>>2]=0;Cb(d+96|0,0,64);w[114256]=0;e=Q(494,b|0,d+88|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break h}m:{if(!e){break m}f=w[d+92>>2];f=(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))-4|0;w[d+92>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);f=0;g=0;n:{while(1){e=w[d+92>>2];e=(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-8|0;w[d+92>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(w[d+88>>2]!=1413764176|c)){f=1;break m}w[114256]=0;U(188,d+24|0,b|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}e=w[d+24>>2];i=w[w[e>>2]+8>>2];w[114256]=0;i=V(i|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{q:{e=w[d+88>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break q}if((e|0)!=1229866575){break o}w[114256]=0;e=Q(495,d+24|0,d+96|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}g=1;if(e){break o}g=0;Cb(d+96|0,0,64);break o}if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}e=w[d+24>>2];h=w[w[e>>2]+36>>2];w[114256]=0;e=S(h|0,e|0,w[d+32>>2],4)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}r:{if(e){e=w[d+32>>2]+4|0;break r}e=w[d+24>>2];h=w[w[e>>2]+24>>2];w[114256]=0;e=V(h|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}}w[114256]=0;w[d+32>>2]=e;e=S(343,d+24|0,9419,2)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}if(!e){break o}e=w[d+92>>2];e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(e>>>0<7){break o}w[114256]=0;Z(496,d+24|0,d+160|0,2,e-6|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break o}break b}sp(d+176|0,d+24|0);e=w[d+36>>2];w[d+184>>2]=w[d+32>>2];w[d+188>>2]=e;break o}w[114256]=0;f=S(497,a|0,d+24|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}}e=w[d+28>>2];s:{if(!e){break s}h=w[e+4>>2];w[e+4>>2]=h-1;if(h){break s}ob[w[w[e>>2]+8>>2]](e);Ib(e)}if(!i){break n}w[114256]=0;e=Q(494,b|0,d+88|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break i}if(e){continue}break}w[d+88>>2]=0;w[d+92>>2]=0}b=x[d+171|0];if(!(b<<24>>24<0?w[d+164>>2]:b)){w[114256]=0;b=Q(1,d+72|0,10373)|0;c=w[114256];w[114256]=0;if((c|0)==1){break g}if(u[d+171|0]<0){zb(w[d+160>>2])}w[d+168>>2]=w[b+8>>2];c=w[b+4>>2];w[d+160>>2]=w[b>>2];w[d+164>>2]=c}t:{if(!(f&g)){break t}c=v[d+138>>1]&1;w[a+1074312>>2]=w[a+1074312>>2]&-33|c<<5^32;b=y[d+134>>1];if(b){b=(b<<8|b>>>8)&65535;w[a+480228>>2]=b>>>0>=64?64:b}u:{if(!c){break u}b=y[d+136>>1];if(!b){break u}w[a+480204>>2]=C((b<<8|(b&65280)>>>8)&65535,1e4)}if(x[d+96|0]){w[114256]=0;Y(209,d+24|0,2,d+96|0,32);b=w[114256];w[114256]=0;if((b|0)==1){break f}b=a+1304400|0;if(u[a+1304411|0]<0){zb(w[b>>2])}c=w[d+28>>2];w[b>>2]=w[d+24>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+32>>2]}b=y[d+142>>1];if(!b){break t}c=(b<<8|b>>>8)&65535;if(c>>>0>12){break t}b=y[d+140>>1];if(!b){break t}b=(b<<8|b>>>8)&65535;if(b>>>0>31){break t}e=y[d+146>>1];e=(e<<8|e>>>8)&65535;if(e>>>0>23){break t}g=y[d+148>>1];g=(g<<8|g>>>8)&65535;if(g>>>0>59){break t}i=y[d+150>>1];i=(i<<8|i>>>8)&65535;if(i>>>0>59){break t}w[114256]=0;h=d- -64|0;w[h>>2]=0;w[h+4>>2]=0;w[d+56>>2]=0;w[d+60>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0;w[d+36>>2]=b;w[d+32>>2]=e;w[d+28>>2]=g;w[d+40>>2]=c-1;w[d+24>>2]=i;b=y[d+144>>1];w[d+44>>2]=(b<<8|b>>>8)&65535;T(384,a+1304500|0,d+24|0);b=w[114256];w[114256]=0;if((b|0)!=1){break t}a=P()|0;break a}v:{if(!(f&1)){break v}b=w[d+176>>2];c=w[w[b>>2]+8>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break h}w:{if(!b){break w}w[114256]=0;w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;S(258,d+176|0,d+24|0,32)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=x[d+35|0];x:{if(((b<<24>>24<0?w[d+28>>2]:b)|0)==14){w[114256]=0;b=da(186,d+24|0,0,-1,9511,14)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}if(!b){break x}}w[114256]=0;U(6,d+8|0,2,d+24|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=a+1304412|0;if(u[a+1304423|0]<0){zb(w[b>>2])}c=w[d+12>>2];w[b>>2]=w[d+8>>2];w[b+4>>2]=c;w[b+8>>2]=w[d+16>>2]}b=w[d+176>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[d+184>>2],1)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}if(b){b=w[d+176>>2];c=w[w[b>>2]+24>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}w[114256]=0;da(306,a+1304424|0,d+176|0,b-w[d+184>>2]|0,40,0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}}if(u[d+35|0]>=0){break w}zb(w[d+24>>2])}w[114256]=0;c=Q(1,d+24|0,13180)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}w[114256]=0;b=x[d+171|0];e=b<<24>>24<0;b=S(2,c|0,(e?w[d+160>>2]:d+160|0)|0,(e?w[d+164>>2]:b)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}g=w[b>>2];w[d+8>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+11|0]=e;u[d+12|0]=e>>>8;u[d+13|0]=e>>>16;u[d+14|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;i=x[b+11|0];w[b+8>>2]=0;if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}w[a+1304460>>2]=g;w[a+1304464>>2]=w[d+8>>2];b=a+1304467|0;e=x[d+11|0]|x[d+12|0]<<8|(x[d+13|0]<<16|x[d+14|0]<<24);u[b|0]=e;u[b+1|0]=e>>>8;u[b+2|0]=e>>>16;u[b+3|0]=e>>>24;u[a+1304471|0]=i;if(u[c+11|0]>=0){break v}zb(w[c>>2])}w[a+480208>>2]=w[a+480208>>2]|2097152;a=a+1074320|0;w[a>>2]=w[a>>2]&-3670017|1572864}if(u[d+171|0]<0){zb(w[d+160>>2])}a=w[d+180>>2];if(!a){break l}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break l}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+208|0;return f&1}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}W(0)|0;Eb();M()}a=P()|0;break a}a=P()|0;if(u[d+35|0]>=0){break a}zb(w[d+24>>2]);break a}a=P()|0;Bb(d+24|0)}if(u[d+171|0]<0){zb(w[d+160>>2])}Bb(d+176|0);R(a|0);M()}function dJ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,y=0,z=0;l=jb-560|0;jb=l;w[l+548>>2]=k;w[l+552>>2]=b;a:{b:{if(ue(a,l+552|0)){w[f>>2]=w[f>>2]|4;a=0;break b}w[l+104>>2]=1769;b=l+104|0;p=vc(l+136|0,l+144|0,b);k=w[p>>2];w[l+132>>2]=k;w[l+128>>2]=k+400;r=Wb(b);m=Wb(l+88|0);o=Wb(l+72|0);n=Wb(l+56|0);q=Wb(l+40|0);w[114256]=0;oa(1772,c|0,d|0,l+120|0,l+119|0,l+118|0,r|0,m|0,o|0,n|0,l+36|0);b=w[114256];w[114256]=0;if((b|0)!=1){w[j>>2]=w[i>>2];s=e&512;t=s>>>9|0;c=0;k=0;while(1){e=k;c:{d:{e:{f:{if((c|0)==4){break f}w[114256]=0;b=Q(1710,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!b){break f}b=0;g:{h:{i:{j:{k:{switch(u[(l+120|0)+c|0]){case 1:if((c|0)==3){break d}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(Ld(h,1,b)){w[114256]=0;U(1773,l+24|0,a|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){b=u[l+24|0];w[114256]=0;T(71,q|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break j}}break a}w[f>>2]=w[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((c|0)==3){break d}}while(1){w[114256]=0;b=Q(1710,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!b){break d}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(!Ld(h,1,b)){break d}w[114256]=0;U(1773,l+24|0,a|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){b=u[l+24|0];w[114256]=0;T(71,q|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Db(o)){break l}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(x[Rb(o,0)|0]!=(b&255)){break l}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}u[g|0]=0;k=Db(o)>>>0>1?o:e;break c}m:{if(!Db(n)){break m}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(x[Rb(n,0)|0]!=(b&255)){break m}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}u[g|0]=1;k=Db(n)>>>0>1?n:e;break c}n:{if(!Db(o)){break n}if(!Db(n)){break n}w[f>>2]=w[f>>2]|4;a=0;break e}if(!Db(o)){if(!Db(n)){break d}}y=g,z=!Db(n),u[y|0]=z;break d}if(!(e|c>>>0<2)){k=0;if(!((c|0)==2&x[l+123|0]!=0|t)){break c}}y=l,z=zd(m),w[y+16>>2]=z;b=Zf(l+24|0,l+16|0);o:{if(!c|x[(c+l|0)+119|0]>1){break o}while(1){p:{y=l,z=hf(m),w[y+16>>2]=z;if(!qe(b,l+16|0)){break p}if(!Ld(h,1,u[w[b>>2]])){break p}Ph(b);continue}break}y=l,z=zd(m),w[y+16>>2]=z;d=w[b>>2]-w[l+16>>2]|0;if(Db(q)>>>0>=d>>>0){y=l,z=hf(q),w[y+16>>2]=z;d=Vr(l+16|0,0-d|0);k=hf(q);v=zd(m);w[114256]=0;d=Zr(d,k,v);k=w[114256];w[114256]=0;if((k|0)==1){break a}if(d){break o}}y=l,z=zd(m),w[y+8>>2]=z;y=b,z=w[Zf(l+16|0,l+8|0)>>2],w[y>>2]=z}w[l+16>>2]=w[b>>2];q:{while(1){y=l,z=hf(m),w[y+8>>2]=z;if(!qe(l+16|0,l+8|0)){break q}w[114256]=0;b=Q(1710,a|0,l+552|0)|0;d=w[114256];w[114256]=0;r:{if((d|0)==1){break r}if(!b){break q}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}if(x[w[l+16>>2]]!=(b&255)){break q}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}Ph(l+16|0);continue}break}break a}if(!s){break d}y=l,z=hf(m),w[y+8>>2]=z;if(!qe(l+16|0,l+8|0)){break d}w[f>>2]=w[f>>2]|4;a=0;break e}s:{while(1){t:{w[114256]=0;d=Q(1710,a|0,l+552|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break t}if(!d){break s}w[114256]=0;k=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}u:{if(Ld(h,64,k)){d=w[j>>2];if((d|0)==w[l+548>>2]){w[114256]=0;U(1775,i|0,j|0,l+548|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}d=w[j>>2]}w[j>>2]=d+1;u[d|0]=k;b=b+1|0;break u}if(!Db(r)|!b|x[l+118|0]!=(k&255)){break s}k=w[l+132>>2];if((k|0)==w[l+128>>2]){w[114256]=0;U(1776,p|0,l+132|0,l+128|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}k=w[l+132>>2]}w[l+132>>2]=k+4;w[k>>2]=b;b=0}w[114256]=0;V(1714,a|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){continue}}break}break a}k=w[l+132>>2];if(!(!b|(k|0)==w[p>>2])){if(w[l+128>>2]==(k|0)){w[114256]=0;U(1776,p|0,l+132|0,l+128|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}k=w[l+132>>2]}w[l+132>>2]=k+4;w[k>>2]=b}v:{if(w[l+36>>2]<=0){break v}w[114256]=0;b=Q(1711,a|0,l+552|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w:{if(!b){w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}if(x[l+119|0]==(b&255)){break w}}w[f>>2]=w[f>>2]|4;a=0;break e}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}while(1){if(w[l+36>>2]<=0){break v}w[114256]=0;b=Q(1711,a|0,l+552|0)|0;d=w[114256];w[114256]=0;x:{if((d|0)==1){break x}y:{if(!b){w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}if(Ld(h,64,b)){break y}}w[f>>2]=w[f>>2]|4;a=0;break e}if(w[j>>2]==w[l+548>>2]){w[114256]=0;U(1775,i|0,j|0,l+548|0);b=w[114256];w[114256]=0;if((b|0)==1){break x}}w[114256]=0;b=V(1712,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}d=w[j>>2];w[j>>2]=d+1;u[d|0]=b;w[114256]=0;w[l+36>>2]=w[l+36>>2]-1;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break a}k=e;if(w[i>>2]!=w[j>>2]){break c}w[f>>2]=w[f>>2]|4;a=0;break e}z:{if(!e){break z}k=1;while(1){if(Db(e)>>>0<=k>>>0){break z}w[114256]=0;b=Q(1711,a|0,l+552|0)|0;c=w[114256];w[114256]=0;A:{if((c|0)==1){break A}B:{if(!b){w[114256]=0;b=V(1712,a|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break A}if(x[Rb(e,k)|0]==(b&255)){break B}}w[f>>2]=w[f>>2]|4;a=0;break e}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(w[p>>2]==w[l+132>>2]){break C}w[l+24>>2]=0;a=w[p>>2];w[114256]=0;Jc(r,a,w[l+132>>2],l+24|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(!w[l+24>>2]){break C}w[f>>2]=w[f>>2]|4;a=0;break e}break a}a=1}Gb(q);Gb(n);Gb(o);Gb(m);Gb(r);Ub(p);break b}k=e}c=c+1|0;continue}}break a}jb=l+560|0;return a|0}a=P()|0;Gb(q);Gb(n);Gb(o);Gb(m);Gb(r);Ub(p);R(a|0);M()}function Aw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-224|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(w[18800]<(c|0)){break B}d=f+176|0;a=c-1|0;if(a>>>0>4){a=5613}else{a=w[(a<<2)+75204>>2]}j=Hb(d,a);w[114256]=0;h=Q(1,f+128|0,13499)|0;a=w[114256];w[114256]=0;C:{D:{if((a|0)!=1){c=w[h>>2];d=w[h+4>>2];a=x[h+11|0];w[114256]=0;g=c;c=a<<24>>24<0;a=S(2,j|0,(c?g:h)|0,(c?d:a)|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[f+200>>2]=w[a+8>>2];c=w[a+4>>2];w[f+192>>2]=w[a>>2];w[f+196>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;E:{F:{if(u[e+11|0]>=0){w[f+120>>2]=w[e+8>>2];a=w[e+4>>2];w[f+112>>2]=w[e>>2];w[f+116>>2]=a;break F}a=w[e+4>>2];c=w[e>>2];w[114256]=0;U(3,f+112|0,c|0,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break E}}w[114256]=0;i=Q(1,f+96|0,15241)|0;a=w[114256];w[114256]=0;if((a|0)!=1){c=x[i+11|0];a=c<<24>>24<0;d=a?w[i+4>>2]:c;e=a?w[i>>2]:i;c=x[f+123|0];g=c<<24>>24<0;a=g?w[f+112>>2]:f+112|0;k=g?w[f+116>>2]:c;g=a+k|0;c=g;G:{while(1){if((a|0)==(c|0)){break G}c=c-1|0;if(d){if(uc(e,x[c|0],d)){continue}}break}c=c-a|0;if((c|0)==-1){break G}w[114256]=0;c=(a+c|0)+1|0;S(4,f+112|0,c-a|0,g-c|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break D}e=P()|0;break z}if(!k|!d){break D}k=d+e|0;d=a;while(1){l=x[d|0];c=e;H:{while(1){if(x[c|0]!=(l|0)){c=c+1|0;if((k|0)!=(c|0)){continue}break H}break}if((d|0)==(g|0)){break D}c=f+160|0;if((a|0)==(d|0)){break C}break D}d=d+1|0;if((g|0)!=(d|0)){continue}break}break D}e=P()|0;break y}e=P()|0;break x}e=P()|0;break w}e=P()|0;break v}w[f+168>>2]=w[f+120>>2];a=w[f+116>>2];w[f+160>>2]=w[f+112>>2];w[f+164>>2]=a;c=f+112|0}w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;w[114256]=0;a=x[f+171|0];c=a<<24>>24<0;a=S(2,f+192|0,(c?w[f+160>>2]:f+160|0)|0,(c?w[f+164>>2]:a)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break A}w[f+152>>2]=w[a+8>>2];c=w[a+4>>2];w[f+144>>2]=w[a>>2];w[f+148>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;if(u[f+171|0]<0){zb(w[f+160>>2])}if(u[i+11|0]<0){zb(w[i>>2])}if(u[f+123|0]<0){zb(w[f+112>>2])}if(u[f+203|0]<0){zb(w[f+192>>2])}if(u[h+11|0]<0){zb(w[h>>2])}if(u[j+11|0]<0){zb(w[j>>2])}a=w[b>>2];w[114256]=0;a=Q(5,f+160|0,(a?a:17256)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break u}w[114256]=0;U(6,f+80|0,1,a|0);c=w[114256];w[114256]=0;I:{J:{if((c|0)!=1){if(u[a+11|0]<0){zb(w[a>>2])}a=w[b+4>>2];w[114256]=0;a=Q(5,f+176|0,(a?a:17256)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break t}w[114256]=0;U(6,f- -64|0,1,a|0);c=w[114256];w[114256]=0;if((c|0)==1){break J}if(u[a+11|0]<0){zb(w[a>>2])}a=w[b+8>>2];w[114256]=0;w[f+32>>2]=a;u[f+208|0]=44;w[f+200>>2]=-1;w[f+204>>2]=0;w[f+192>>2]=257;w[f+196>>2]=0;U(7,f+48|0,f+32|0,f+192|0);a=w[114256];w[114256]=0;if((a|0)==1){break s}w[114256]=0;a=S(8,459624,13378,12)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}w[114256]=0;U(9,f+192|0,0,f+80|0);b=w[114256];w[114256]=0;if((b|0)==1){break q}w[114256]=0;c=a;a=x[f+203|0];b=a<<24>>24<0;a=S(8,c|0,(b?w[f+192>>2]:f+192|0)|0,(b?w[f+196>>2]:a)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;a=S(8,a|0,13112,1)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(9,f+32|0,0,f+48|0);b=w[114256];w[114256]=0;if((b|0)==1){break o}w[114256]=0;c=a;a=x[f+43|0];b=a<<24>>24<0;a=S(8,c|0,(b?w[f+32>>2]:f+32|0)|0,(b?w[f+36>>2]:a)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}w[114256]=0;a=S(8,a|0,13109,1)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}w[114256]=0;a=S(8,a|0,13499,2)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}w[114256]=0;U(9,f+16|0,0,f+144|0);b=w[114256];w[114256]=0;if((b|0)==1){break m}w[114256]=0;c=a;a=x[f+27|0];b=a<<24>>24<0;a=S(8,c|0,(b?w[f+16>>2]:f+16|0)|0,(b?w[f+20>>2]:a)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break l}w[114256]=0;a=S(8,a|0,9251,2)|0;b=w[114256];w[114256]=0;if((b|0)==1){break l}w[114256]=0;U(9,f|0,0,f- -64|0);b=w[114256];w[114256]=0;if((b|0)==1){break k}w[114256]=0;c=a;a=x[f+11|0];b=a<<24>>24<0;a=S(8,c|0,(b?w[f>>2]:f)|0,(b?w[f+4>>2]:a)|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break j}w[114256]=0;a=S(8,a|0,9249,1)|0;b=w[114256];w[114256]=0;if((b|0)==1){break j}b=w[w[a>>2]-12>>2];w[114256]=0;T(10,f+216|0,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break j}w[114256]=0;b=Q(11,f+216|0,460428)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[w[b>>2]+28>>2];w[114256]=0;b=Q(c|0,b|0,10)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break I}}e=P()|0;Ab(f+216|0);break i}e=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}e=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}Ab(f+216|0);w[114256]=0;Q(12,a|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break j}w[114256]=0;V(13,a|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break j}if(u[f+11|0]<0){zb(w[f>>2])}if(u[f+27|0]<0){zb(w[f+16>>2])}if(u[f+43|0]<0){zb(w[f+32>>2])}if(u[f+203|0]<0){zb(w[f+192>>2])}if(u[f+59|0]<0){zb(w[f+48>>2])}if(u[f+75|0]<0){zb(w[f+64>>2])}if(u[f+91|0]<0){zb(w[f+80>>2])}if(u[f+155|0]>=0){break B}zb(w[f+144>>2])}jb=f+224|0;return}e=P()|0;if(u[f+171|0]>=0){break z}zb(w[f+160>>2])}if(u[i+11|0]>=0){break y}zb(w[i>>2])}if(u[f+123|0]>=0){break x}zb(w[f+112>>2])}if(u[f+203|0]>=0){break w}zb(w[f+192>>2])}if(u[h+11|0]>=0){break v}zb(w[h>>2])}if(u[j+11|0]>=0){break a}zb(w[j>>2]);break a}e=P()|0;break b}e=P()|0;break c}e=P()|0;break d}e=P()|0;break e}e=P()|0;break e}e=P()|0;break f}e=P()|0;break f}e=P()|0;break g}e=P()|0;break g}e=P()|0;break h}e=P()|0;break h}e=P()|0}if(u[f+11|0]>=0){break h}zb(w[f>>2])}if(u[f+27|0]>=0){break g}zb(w[f+16>>2])}if(u[f+43|0]>=0){break f}zb(w[f+32>>2])}if(u[f+203|0]>=0){break e}zb(w[f+192>>2])}if(u[f+59|0]>=0){break d}zb(w[f+48>>2])}if(u[f+75|0]>=0){break c}zb(w[f+64>>2])}if(u[f+91|0]>=0){break b}zb(w[f+80>>2])}if(u[f+155|0]>=0){break a}zb(w[f+144>>2])}R(e|0);M()}function KA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-208|0;jb=e;w[b+8>>2]=0;a:{if(!Zk(b,e+144|0)|(x[e+158|0]-53&255)>>>0<252){break a}if(Jb(e+144|0,11506,14)){break a}if(!c){i=1;break a}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(x[e+191|0]<<5)+259|0)|0)){break a}tc(a,128);Vb(e+72|0,2,e+159|0,32);d=a+1304400|0;if(u[a+1304411|0]<0){zb(w[d>>2])}f=w[e+76>>2];w[d>>2]=w[e+72>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+80>>2];d=a+1304436|0;f=Hb(e+72|0,4652);if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=a+1304448|0;f=Hb(e+72|0,2476);if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];f=Hb(e+72|0,13192);d=w[(x[e+158|0]<<2)+75772>>2];g=ec(d);w[114256]=0;d=S(2,f|0,d|0,g|0)|0;g=w[114256];w[114256]=0;b:{if((g|0)!=1){i=w[d>>2];w[e+56>>2]=w[d+4>>2];g=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[e+59|0]=g;u[e+60|0]=g>>>8;u[e+61|0]=g>>>16;u[e+62|0]=g>>>24;w[d>>2]=0;w[d+4>>2]=0;h=x[d+11|0];w[d+8>>2]=0;if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}w[a+1304460>>2]=i;w[a+1304464>>2]=w[e+56>>2];d=a+1304467|0;g=x[e+59|0]|x[e+60|0]<<8|(x[e+61|0]<<16|x[e+62|0]<<24);u[d|0]=g;u[d+1|0]=g>>>8;u[d+2|0]=g>>>16;u[d+3|0]=g>>>24;u[a+1304471|0]=h;if(u[f+11|0]<0){zb(w[f>>2])}w[a+480208>>2]=12;w[a+1304496>>2]=4;i=0;Ik(a+1304424|0,b,x[e+191|0]<<5,32,0);d=Xb(b,e+72|0);d=d?x[e+72|0]:0;v[a+480190>>1]=d;c:{if(d){g=1;l=1;while(1){d:{if(x[e+158|0]>=52){if(cl(b,e+72|0)){break d}Cb(e+72|0,0,66);break d}d=e+72|0;f=64;h=w[b>>2];e:{if(ob[w[w[h>>2]+36>>2]](h,w[b+8>>2],64)|0){h=w[b+8>>2];break e}f=w[b>>2];f=ob[w[w[f>>2]+24>>2]](f)|0;h=w[b+8>>2];f=f-h|0}j=w[b>>2];ob[w[w[j>>2]+28>>2]](j,d,h,f)|0;Cb(d+f|0,0,66-f|0);d=w[b>>2];f:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],64)|0){d=w[b+8>>2]- -64|0;break f}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d;v[e+136>>1]=y[e+134>>1];v[e+134>>1]=8363}j=jb-32|0;jb=j;h=(C(g,104)+a|0)+484380|0;lc(h,0);d=j+8|0;f=e+72|0;Vb(d,2,f+32|0,12);w[114256]=0;w[j+28>>2]=22;w[j+24>>2]=h+43;Q(200,j+24|0,d|0)|0;d=w[114256];w[114256]=0;g:{if((d|0)!=1){if(u[j+19|0]<0){zb(w[j+8>>2])}d=x[f+56|0]|x[f+57|0]<<8|(x[f+58|0]<<16|x[f+59|0]<<24);k=x[f+52|0]|x[f+53|0]<<8|(x[f+54|0]<<16|x[f+55|0]<<24);h:{if(d>>>0<=k>>>0){break h}d=d-k|0;w[h>>2]=d;w[h+12>>2]=x[f+44|0]|x[f+45|0]<<8|(x[f+46|0]<<16|x[f+47|0]<<24);k=x[f+48|0]|x[f+49|0]<<8|(x[f+50|0]<<16|x[f+51|0]<<24);w[h+16>>2]=d>>>0<k>>>0?d:k;v[h+30>>1]=x[f+60|0];w[h+24>>2]=x[f+62|0]|x[f+63|0]<<8;d=x[f+64|0]|x[f+65|0]<<8;if(d){yi(h,+(d<<16>>16)*25431315104166665e-22)}d=x[f+61|0];if(d&8){v[h+34>>1]=y[h+34>>1]|8;d=x[f+61|0]}if(d&16){v[h+34>>1]=y[h+34>>1]|16;d=x[f+61|0]}if(!(d&4)){break h}v[h+34>>1]=y[h+34>>1]|1;w[h+12>>2]=w[h+12>>2]>>>1;w[h+16>>2]=w[h+16>>2]>>>1}jb=j+32|0;break g}a=P()|0;if(u[j+19|0]<0){zb(w[j+8>>2])}R(a|0);M()}d=e+56|0;Vb(d,2,f,32);w[114256]=0;w[e+196>>2]=32;w[e+192>>2]=((g<<5)+a|0)+946304;Q(200,e+192|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(u[e+67|0]<0){zb(w[e+56>>2])}l=l+1|0;g=l&65535;if(g>>>0<=y[a+480190>>1]){continue}break}}wh(w[a+484360>>2]+(x[a+484376|0]<<5)|0,b,256,255,254);d=Xb(b,e+72|0);d=(d?x[e+72|0]:0)&255;if(d>>>0>=127){break a}v[a+480188>>1]=d+1;d=Xb(b,e+72|0);f=d?x[e+72|0]:0;p=f+1|0;if(y[a+480188>>1]){while(1){d=(i<<5)+a|0;Qd(d+480280|0);g=d+480284|0;i:{if(x[e+158|0]>=51){d=Xb(b,e+72|0);d=d?(x[e+72|0]<<4|8)&248:8;break i}d=i&1?192:64}v[g>>1]=d;i=i+1|0;if(i>>>0<y[a+480188>>1]){continue}break}}j=a+484344|0;td(j,p);i=0;g=0;while(1){d=g&65535;if(!ie(j,d,64)){break a}g=g+1|0;if(d>>>0<f>>>0){continue}break}if(y[a+480188>>1]){while(1){h=0;while(1){d=w[b>>2];if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],5)|0){d=w[j>>2]+C(h,52)|0;ld(d);i=w[d>>2]+C(o,6)|0;d=0;while(1){f=x[e+158|0];l=Xb(b,e+72|0);g=1;l=l?x[e+72|0]:0;if((l&255)==252){g=Xb(b,e+72|0);g=g?x[e+72|0]:0;l=Xb(b,e+72|0);l=l?x[e+72|0]:0}Of(b,e+72|0);q=x[e+72|0];k=x[e+73|0];u[e+192|0]=k&15;u[e+207|0]=k>>>4;u[e+206|0]=x[e+74|0];u[e+205|0]=x[e+75|0];To(e+192|0,e+206|0,f);To(e+207|0,e+205|0,f);k=x[e+192|0];m=(k|0)!=10;f=x[e+207|0];j:{if(!(m|(f|0)!=10)){u[e+192|0]=0;f=(x[e+205|0]|x[e+206|0]<<8)>>>6|0;u[e+206|0]=f>>>0>=255?255:f;break j}k:{l:{m:{if(!m){m=x[e+206|0]<<2;u[e+206|0]=m>>>0>=255?255:m;break m}if((f|0)==10){f=x[e+205|0]<<2;u[e+205|0]=f>>>0>=255?255:f;break j}if((f|0)!=(k|0)){break m}f=0;u[e+207|0]=0;break l}m=13;if((f|0)==13){break k}}if(f){break j}m=0;if((k|0)==13){break j}}u[e+207|0]=k;u[e+192|0]=m;f=x[e+206|0];u[e+206|0]=x[e+205|0];u[e+205|0]=f}f=e+207|0;k=e+205|0;m=e+192|0;n=e+206|0;en(f,k,m,n);nw(e+56|0,m,n,f,k);f=d+g|0;g=f>>>0>64?64-d|0:g;if(g){d=(l-1&255)>>>0<60?l+36|0:0;l=x[e+192|0];k=x[e+206|0];m=x[e+207|0];n=x[e+205|0];while(1){u[i+5|0]=n;u[i+4|0]=k;u[i+3|0]=m;u[i+2|0]=l;u[i+1|0]=q;u[i|0]=d;i=C(y[a+480188>>1],6)+i|0;g=g-1|0;if(g){continue}break}d=f>>>0>=64?64:f;if(f>>>0<=63){continue}}break}h=h+1|0;if((p|0)!=(h|0)){continue}}break}i=y[a+480188>>1];o=o+1|0;if(i>>>0>o>>>0){continue}break}}d=e+8|0;u[d+16|0]=0;v[d+14>>1]=0;v[d+12>>1]=i;w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;w[114256]=0;U(520,d|0,i|0,0);f=w[114256];w[114256]=0;if((f|0)==1){a=P()|0;b=w[d>>2];if(b){zb(b)}R(a|0);M()}w[114256]=0;U(582,e+32|0,j|0,d|0);f=w[114256];w[114256]=0;if((f|0)!=1){f=w[e+32>>2];if(f){zb(f)}d=w[d>>2];if(d){zb(d)}i=1;if(!(c&2)|!y[a+480190>>1]){break a}g=1;while(1){c=C(g&65535,104)+a|0;d=y[c+484414>>1];u[e+75|0]=0;u[e+73|0]=1;u[e+74|0]=0;u[e+72|0]=d&1?16:8;Fd(e+72|0,c+484380|0,b);g=g+1|0;if(y[a+480190>>1]>=(g&65535)>>>0){continue}break}break a}g=P()|0;a=w[d>>2];if(!a){break b}zb(a);break b}g=P()|0;if(u[e+67|0]>=0){break b}zb(w[e+56>>2]);break b}g=P()|0;if(u[f+11|0]>=0){break b}zb(w[f>>2])}R(g|0);M()}jb=e+208|0;return i|0}function cO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-176|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+24>>2];d=x[c+484376|0];c=w[c+484360>>2];w[114256]=0;k=V(828,c+(d<<5)|0)|0;c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)==1){break c}w[114256]=0;T(918,a|0,k|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}if(k){j=a+8|0;while(1){d=w[b+24>>2];c=y[w[w[d+484360>>2]+(x[d+484376|0]<<5)>>2]+(l<<1)>>1];d:{f=w[d+484344>>2];if(c>>>0<((w[d+484348>>2]-f|0)/52&65535)>>>0){e:{f:{g:{h:{c=f+C(c,52)|0;i:{if(u[c+47|0]>=0){w[e+56>>2]=w[c+44>>2];f=w[c+40>>2];w[e+48>>2]=w[c+36>>2];w[e+52>>2]=f;break i}d=w[c+40>>2];c=w[c+36>>2];w[114256]=0;U(76,e+48|0,c|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break h}d=w[b+24>>2]}c=w[d+1304496>>2];w[114256]=0;Y(229,e- -64|0,0,c|0,e+48|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}c=w[a+4>>2];d=w[a+8>>2];j:{if(c>>>0<d>>>0){d=w[e+68>>2];w[c>>2]=w[e+64>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+72>>2];w[e+72>>2]=0;w[e+64>>2]=0;w[e+68>>2]=0;w[a+4>>2]=c+12;break j}f=w[a>>2];h=(c-f|0)/12|0;c=h+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}break a}w[114256]=0;d=(d-f|0)/12|0;f=d<<1;g=Z(921,e+80|0,(d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,h|0,j|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}d=w[e+68>>2];c=w[e+88>>2];w[c>>2]=w[e+64>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+72>>2];w[e+72>>2]=0;w[e+64>>2]=0;w[e+68>>2]=0;h=w[e+88>>2]+12|0;w[e+88>>2]=h;f=w[e+84>>2];d=w[a+4>>2];c=w[a>>2];k:{if((d|0)==(c|0)){d=c;break k}while(1){d=d-12|0;h=w[d+4>>2];f=f-12|0;w[f>>2]=w[d>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+84>>2]-12|0;w[e+84>>2]=f;if((c|0)!=(d|0)){continue}break}c=w[a+4>>2];h=w[e+88>>2];d=w[a>>2]}w[a>>2]=f;w[e+84>>2]=d;w[a+4>>2]=h;w[e+88>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+92>>2];w[e+92>>2]=c;w[g>>2]=d;sc(g);if(u[e+75|0]>=0){break j}zb(w[e+64>>2])}if(u[e+59|0]>=0){break d}zb(w[e+48>>2]);break d}d=P()|0;break b}d=P()|0;break e}d=P()|0;if(u[e+75|0]>=0){break e}zb(w[e+64>>2])}if(u[e+59|0]>=0){break b}zb(w[e+48>>2]);break b}l:{switch(c-65534|0){case 0:w[114256]=0;g=Q(5,e+32|0,5170)|0;c=w[114256];w[114256]=0;m:{if((c|0)!=1){c=w[a+4>>2];d=w[a+8>>2];if(c>>>0<d>>>0){d=w[g+4>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[a+4>>2]=c+12;break d}f=w[a>>2];h=(c-f|0)/12|0;c=h+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}break m}w[114256]=0;d=(d-f|0)/12|0;f=d<<1;i=Z(921,e+104|0,(d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,h|0,j|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break m}d=w[g+4>>2];c=w[e+112>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[g>>2]=0;w[g+4>>2]=0;w[g+8>>2]=0;h=w[e+112>>2]+12|0;w[e+112>>2]=h;f=w[e+108>>2];d=w[a+4>>2];c=w[a>>2];n:{if((d|0)==(c|0)){d=c;break n}while(1){d=d-12|0;h=w[d+4>>2];f=f-12|0;w[f>>2]=w[d>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+108>>2]-12|0;w[e+108>>2]=f;if((c|0)!=(d|0)){continue}break}c=w[a+4>>2];h=w[e+112>>2];d=w[a>>2]}w[a>>2]=f;w[e+108>>2]=d;w[a+4>>2]=h;w[e+112>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+116>>2];w[e+116>>2]=c;w[i>>2]=d;sc(i);if(u[e+43|0]>=0){break d}zb(w[g>>2]);break d}d=P()|0;break b}d=P()|0;if(u[e+43|0]>=0){break b}zb(w[g>>2]);break b;case 1:w[114256]=0;g=Q(5,e+16|0,5132)|0;c=w[114256];w[114256]=0;o:{if((c|0)!=1){c=w[a+4>>2];d=w[a+8>>2];if(c>>>0<d>>>0){d=w[g+4>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[a+4>>2]=c+12;break d}f=w[a>>2];h=(c-f|0)/12|0;c=h+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}break o}w[114256]=0;d=(d-f|0)/12|0;f=d<<1;i=Z(921,e+128|0,(d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,h|0,j|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break o}d=w[g+4>>2];c=w[e+136>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[g>>2]=0;w[g+4>>2]=0;w[g+8>>2]=0;h=w[e+136>>2]+12|0;w[e+136>>2]=h;f=w[e+132>>2];d=w[a+4>>2];c=w[a>>2];p:{if((d|0)==(c|0)){d=c;break p}while(1){d=d-12|0;h=w[d+4>>2];f=f-12|0;w[f>>2]=w[d>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+132>>2]-12|0;w[e+132>>2]=f;if((c|0)!=(d|0)){continue}break}c=w[a+4>>2];h=w[e+136>>2];d=w[a>>2]}w[a>>2]=f;w[e+132>>2]=d;w[a+4>>2]=h;w[e+136>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+140>>2];w[e+140>>2]=c;w[i>>2]=d;sc(i);if(u[e+27|0]>=0){break d}zb(w[g>>2]);break d}d=P()|0;break b}d=P()|0;if(u[e+27|0]>=0){break b}zb(w[g>>2]);break b;default:break l}}w[114256]=0;g=Q(5,e|0,10066)|0;c=w[114256];w[114256]=0;q:{if((c|0)!=1){c=w[a+4>>2];d=w[a+8>>2];if(c>>>0<d>>>0){d=w[g+4>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[a+4>>2]=c+12;break d}f=w[a>>2];h=(c-f|0)/12|0;c=h+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}break q}w[114256]=0;d=(d-f|0)/12|0;f=d<<1;i=Z(921,e+152|0,(d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,h|0,j|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break q}d=w[g+4>>2];c=w[e+160>>2];w[c>>2]=w[g>>2];w[c+4>>2]=d;w[c+8>>2]=w[g+8>>2];w[g>>2]=0;w[g+4>>2]=0;w[g+8>>2]=0;h=w[e+160>>2]+12|0;w[e+160>>2]=h;f=w[e+156>>2];d=w[a+4>>2];c=w[a>>2];r:{if((d|0)==(c|0)){d=c;break r}while(1){d=d-12|0;h=w[d+4>>2];f=f-12|0;w[f>>2]=w[d>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+156>>2]-12|0;w[e+156>>2]=f;if((c|0)!=(d|0)){continue}break}c=w[a+4>>2];h=w[e+160>>2];d=w[a>>2]}w[a>>2]=f;w[e+156>>2]=d;w[a+4>>2]=h;w[e+160>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+164>>2];w[e+164>>2]=c;w[i>>2]=d;sc(i);if(u[e+11|0]>=0){break d}zb(w[g>>2]);break d}d=P()|0;break b}d=P()|0;if(u[e+11|0]>=0){break b}zb(w[g>>2]);break b}l=l+1|0;if((l|0)!=(k|0)){continue}break}}jb=e+176|0;return}d=P()|0}bc(a);R(d|0);M()}M()}function DM(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,v=0,y=0,z=0,A=0,B=0,D=0,F=0;m=jb-560|0;jb=m;w[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){v=1;A=1782;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){v=1;A=1785;break a}v=e&1;A=v?1788:1783;F=!v}b:{if((g&2146435072)==2146435072){d=v+3|0;ad(a,32,c,d,e&-65537);Tc(a,A,v);f=f&32;Tc(a,b!=b?f?5923:9548:f?6970:9847,3);ad(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=m+16|0;c:{d:{e:{b=Ut(b,m+44|0);b=b+b;if(b!=0){g=w[m+44>>2];w[m+44>>2]=g-1;t=f|32;if((t|0)!=97){break e}break c}t=f|32;if((t|0)==97){break c}l=w[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;w[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}r=(m+48|0)+((l|0)>=0?288:0)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}w[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)>=29?29:d;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=w[g>>2];p=d&31;B=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=B+q|0;i=i+D|0;i=p>>>0<q>>>0?i+1|0:i;i=EV(p,i,1e9,0);q=BV(i,nb,1e9,0);w[g>>2]=p-q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;w[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!w[h>>2]){continue}}break}d=w[m+44>>2]-d|0;w[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((n+25>>>0)/9|0)+1|0;p=(t|0)==102;while(1){d=0-d|0;i=(d|0)>=9?9:d;h:{if(g>>>0<=k>>>0){h=w[k>>2];break h}q=1e9>>>i|0;D=-1<<i^-1;d=0;h=k;while(1){B=d;d=w[h>>2];w[h>>2]=B+(d>>>i|0);d=C(q,d&D);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=w[k>>2];if(!d){break h}w[g>>2]=d;g=g+4|0}d=i+w[m+44>>2]|0;w[m+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=C(r-k>>2,9);h=10;i=w[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=C(h,10);if(i>>>0>=h>>>0){continue}break}}h=(n-((t|0)!=102?d:0)|0)-((t|0)==103&(n|0)!=0)|0;if((h|0)<(C(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+m|0)+(p<<2)|0)-4048|0;h=10;i=i-C(p,9)|0;if((i|0)<=7){while(1){h=C(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=w[l>>2];y=(p>>>0)/(h>>>0)|0;i=p-C(h,y)|0;q=l+4|0;j:{if(!i&(q|0)==(g|0)){break j}k:{if(!(y&1)){b=9007199254740992;if(!(u[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=i>>>0<q>>>0?.5:(q|0)==(i|0)?s:1.5;if(!(x[A|0]!=45|F)){s=-s;b=-b}i=p-i|0;w[l>>2]=i;if(b+s==b){break j}d=h+i|0;w[l>>2]=d;if(d>>>0>=1e9){while(1){w[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;w[k>>2]=0}d=w[l>>2]+1|0;w[l>>2]=d;if(d>>>0>999999999){continue}break}}d=C(r-k>>2,9);h=10;i=w[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=C(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!w[g>>2]){continue}}break}l:{if((t|0)!=103){l=e&8;break l}g=n?n:1;l=(g|0)>(d|0)&(d|0)>-5;n=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=w[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=C(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=C(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g}i=-1;t=l|n;if(((t?2147483645:2147483646)|0)<(n|0)){break b}p=(((t|0)!=0)+n|0)+1|0;q=f&-33;n:{if((q|0)==70){if((p^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Pg((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;u[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;u[y|0]=f;u[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(p^2147483647)){break b}}d=g+p|0;if((d|0)>(v^2147483647)){break b}f=d+v|0;ad(a,32,c,f,e);Tc(a,A,v);ad(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=m+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=Pg(w[k>>2],0,l);r:{if((i|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;u[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}u[m+24|0]=48;g=d}Tc(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(t){Tc(a,12600,1)}if((n|0)<=0|h>>>0<=k>>>0){break q}while(1){g=Pg(w[k>>2],0,l);if(g>>>0>m+16>>>0){while(1){g=g-1|0;u[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}Tc(a,g,(n|0)>=9?9:n);g=n-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=m+16|0;d=g|8;r=g|9;h=k;while(1){g=Pg(w[h>>2],0,r);if((r|0)==(g|0)){u[m+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;u[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}Tc(a,g,1);g=g+1|0;if(!(l|n)){break t}Tc(a,12600,1)}B=g;g=r-g|0;Tc(a,B,(g|0)>(n|0)?n:g);n=n-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((n|0)>=0){continue}break}}ad(a,48,n+18|0,18,0);Tc(a,y,z-y|0);break o}g=n}ad(a,48,g+9|0,9,0)}ad(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}n=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(x[n|0]==45){b=-(s+(-b-s));break u}b=b+s-s}h=w[m+44>>2];g=h>>31;g=Pg((g^h)-g|0,0,z);if((z|0)==(g|0)){u[m+15|0]=48;g=m+15|0}l=v|2;k=f&32;h=w[m+44>>2];r=g-2|0;u[r|0]=f+15;u[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;if(E(b)<2147483648){g=~~b}else{g=-2147483648}u[h|0]=k|x[g+58928|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(m+16|0)|0)!=1)){u[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(m+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(m+16|0)|0;g=k}d=g+f|0;ad(a,32,c,d,e);Tc(a,n,l);ad(a,48,c,d,e^65536);Tc(a,m+16|0,k);ad(a,48,g-k|0,0,0);Tc(a,r,p);ad(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}jb=m+560|0;return i|0}function _B(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-1808|0;jb=f;w[b+8>>2]=0;d=jb-16|0;jb=d;i=w[b+8>>2];h=w[b>>2];m=f+1208|0;w[d+8>>2]=m;w[d+12>>2]=m+600;i=ob[w[w[h>>2]+32>>2]](h,i,d+8|0)|0;if((i|0)==600){h=w[b>>2];a:{if(ob[w[w[h>>2]+36>>2]](h,w[b+8>>2],600)|0){p=w[b+8>>2]+600|0;break a}h=w[b>>2];p=ob[w[w[h>>2]+24>>2]](h)|0}w[b+8>>2]=p}jb=d+16|0;b:{if((i|0)!=600){break b}if(!up(f+1208|0)){break b}if(!Pk(b,16,0)){break b}w[f+1200>>2]=w[f+1224>>2];d=w[f+1212>>2];w[f+1184>>2]=w[f+1208>>2];w[f+1188>>2]=d;d=f+1216|0;e=w[d+4>>2];w[f+1192>>2]=w[d>>2];w[f+1196>>2]=e;tc(a,1);w[a+480188>>2]=983044;d=a+1074320|0;w[d>>2]=w[d>>2]&-3670017|3145728;c:{if(z[b+8>>2]<=19){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<20){break c}}w[b+8>>2]=20}e=1;h=1;while(1){i=C(e,104)+a|0;m=i+484380|0;d=((e<<5)+a|0)+946304|0;Rk(b,f+24|0,m,d,1);l=w[m>>2];d:{if(!x[d|0]){break d}e:{if(Jb(d,12602,3)){if(Jb(d,12606,3)){break e}}if(x[d+5|0]==58){break d}}h=0}d=y[f+52>>1];d=(d<<8|d>>>8)&65535;if(d>>>0>=2){k=y[f+50>>1];k=(k<<8|k>>>8)&65535;w[i+484384>>2]=k;w[i+484388>>2]=k+(d<<1);tg(m)}d=y[f+46>>1];f:{if(((d<<8|d>>>8)&65535)>>>0<=4999){d=y[f+50>>1];if(((d<<8|d>>>8)&65535)>>>0<1e4){break f}}g=5}j=j+l|0;e=e+1|0;if((e|0)!=16){continue}break}if(!Qk(b,f+1048|0)){Cb(f+1048|0,0,130)}d=a+484376|0;Ze(w[a+484360>>2]+(x[d|0]<<5)|0,f+1048|2,128,65535,65535);e=0;m=wp(b,w[a+484360>>2]+(x[d|0]<<5)|0,x[f+1048|0],j,a+480188|0,0,1);if(!(x[f+1049|0]|m>>>0>1|x[f+1048|0])){break b}d=w[b>>2];if(((ob[w[w[d>>2]+24>>2]](d)|0)-w[b+8>>2]|0)+65536>>>0<(m<<10)+j>>>0){break b}if(!c){e=1;break b}e=x[f+1049|0];if(!e){u[f+1049|0]=120;e=120}g:{if(!Jb(f+1184|0,10421,6)){u[f+1049|0]=120;w[a+480204>>2]=125e4;break g}w[a+480204>>2]=125e4;if((e|0)==120){break g}r=Tb(145364549.18032786/+(240-e|0));d=-1;h:{if(r>=4294967295){break h}d=0;if(r<=0){break h}d=~~r>>>0;if(r<4294967296&r>=0){break h}d=0}w[a+480204>>2]=d;if((g|0)>=2){d=h&1?4:5;g=d>>>0<g>>>0?g:d;break g}d=h&1?1:2;g=(d|0)<(g|0)?g:d}w[a+480228>>2]=64;w[a+480260>>2]=452;w[a+480264>>2]=3424;w[a+480208>>2]=w[a+480208>>2]|2097152;Vb(f+24|0,3,f+1184|0,20);d=a+1304400|0;if(u[a+1304411|0]<0){zb(w[d>>2])}e=w[f+28>>2];w[d>>2]=w[f+24>>2];w[d+4>>2]=e;w[d+8>>2]=w[f+32>>2];Ce(a,0);q=w[b+8>>2];i:{if(m){d=h&1;while(1){j:{k:{h=w[a+484360>>2]+(x[a+484376|0]<<5)|0;e=w[h>>2];l=w[h+4>>2];if((e|0)==(l|0)){break k}while(1){if(y[e>>1]==(n&65535)){break k}e=e+2|0;if((l|0)!=(e|0)){continue}break}Ok(b,f+24|0);break j}i=f+24|0;Ok(b,i);h=0;j=0;if((e|0)==(l|0)){break j}while(1){e=0;while(1){h=(x[(e<<2)+i|0]>15)+h|0;e=e+1|0;if((e|0)!=4){continue}break}j=j+1|0;i=(f+24|0)+(j<<4)|0;if((j|0)!=64){continue}break}t=h+t|0;if(t>>>0>512){break i}}h=0;j=0;i=0;while(1){p=(f+24|0)+(h<<4)|0;e=0;while(1){k=(e<<2)+p|0;s=x[k+2|0]&15;l=x[k+3|0];l:{if(!(!(j&255)|(x[k|0]|x[k+1|0]<<8|(x[k+2|0]<<16|x[k+3|0]<<24)))){j=j+1|0;g=(j&255)>>>0>32?6:g;break l}j=0}m:{n:{switch(s-1|0){case 0:case 1:if(!((g|0)!=1|l>>>0<32)){g=d;break m}k=(s|0)!=1;if(!(k|!l|l>>>0>2)){g=(g|0)<=2?2:g;break m}if(k){break m}k=(g|0)<3?d:g;g=(l|0)==55?k:(l|0)==71?k:g;break m;case 10:g=6;break m;case 11:case 12:case 13:g=(g|0)<=2?2:g;if((s|0)!=13){break m}i=((h|l)!=0)+i|0;j=1;break m;case 14:break n;default:break m}}g=(g|0)<=3?3:g}e=e+1|0;if((e|0)!=4){continue}break}h=h+1|0;if((h|0)!=64){continue}break}g=(i-1&255)>>>0<2?6:g;o=(i&255)+o|0;n=n+1|0;if(m>>>0>(n&65535)>>>0){continue}break}}o:{if(q>>>0>z[b+8>>2]){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<q>>>0){break o}}w[b+8>>2]=q}q=c&1;if(q){td(a+484344|0,m)}j=m+32>>>0<o>>>0?(g|0)==6?5:g:g;if(m){k=a+484344|0;o=0;while(1){Ok(b,f+24|0);p:{if(!q){break p}if(!ie(k,o&65535,64)){break p}n=0;w[f+20>>2]=0;while(1){g=w[k>>2]+C(o,52)|0;d=ld(g);s=w[g>>2]+C(C(d,n),6)|0;t=(f+24|0)+(n<<4)|0;g=0;while(1){d=t+(g<<2)|0;d=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);w[f+12>>2]=d;w[f+16>>2]=d;d=s+C(g,6)|0;Kf(f+12|0,d);q:{r:{s:{i=x[d+5|0];if(i){e=d+3|0;l=(f+20|0)+g|0;h=x[d+3|0];if((h|0)!=14){break s}u[l|0]=0;h=14;break r}u[(f+20|0)+g|0]=0;h=x[d+3|0];if(!h){break q}e=d+3|0;break r}l=x[l|0];if(!l){break r}if(l>>>0>=16){u[d+2|0]=3;u[d+4|0]=l>>>4;break r}u[d+2|0]=4;u[d+4|0]=l}t:{u:{v:{w:{switch(h-12|0){case 1:if((j|0)==6){break u}h=10;u[e|0]=10;break v;case 0:i=i&127;u[d+5|0]=i;h=12;break v;case 2:if(i>>>0<=1&(j|0)>3){break t}h=10;u[e|0]=10;u[(f+20|0)+g|0]=i;break v;case 3:break w;default:break v}}h=15;i=i&15;u[d+5|0]=i}if((j|0)>1){break t}x:{y:{z:{switch(h|0){case 0:if(i>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}u[e|0]=0;break q}u[e|0]=1;break q}h=i&15;if(h){u[e|0]=2;u[d+5|0]=h;break q}if(i>>>0<16){break q}u[e|0]=3;u[d+5|0]=i>>>4;break q}u[d+5|0]=0}We(d)}g=g+1|0;if((g|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}o=o+1|0;if((m|0)!=(o|0)){continue}break}}g=j>>>0>=7?17256:w[(j<<2)+75928>>2];d=a+1304436|0;e=Hb(f+24|0,4489);if(u[a+1304447|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];d=a+1304448|0;e=Hb(f+24|0,6688);if(u[a+1304459|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];Dp(a+1304460|0,g);w[a+1304496>>2]=2;e=1;if(!(c&2)){break b}g=1;while(1){d=C(g,104)+a|0;c=d+484380|0;i=w[b>>2];h=d+484384|0;j=w[h>>2];A:{if(ob[w[w[i>>2]+36>>2]](i,w[b+8>>2],j)|0){p=j+w[b+8>>2]|0;break A}i=w[b>>2];p=ob[w[w[i>>2]+24>>2]](i)|0}w[b+8>>2]=p;i=w[h>>2];w[c>>2]=w[c>>2]-i;d=d+484388|0;w[d>>2]=w[d>>2]-i;w[h>>2]=0;w[f+24>>2]=65800;Fd(f+24|0,c,b);g=g+1|0;if((g|0)!=16){continue}break}break b}e=0}jb=f+1808|0;return e|0}function eB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=jb-768|0;jb=d;w[b+8>>2]=0;f=jb-16|0;jb=f;i=w[b+8>>2];g=w[b>>2];h=d+160|0;w[f+8>>2]=h;w[f+12>>2]=h+608;i=ob[w[w[g>>2]+32>>2]](g,i,f+8|0)|0;if((i|0)==608){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],608)|0){g=w[b+8>>2]+608|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{if((i|0)!=608){break b}if(!ap(d+160|0)){break b}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],C(y[d+194>>1],80))|0)){break b}c:{if(!c){break c}tc(a,262144);Vb(d+8|0,2,d+160|0,28);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+12>>2];w[e>>2]=w[d+8>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+16>>2];e=a+1304436|0;f=Hb(d+8|0,4502);if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];e=a+1304448|0;f=Hb(d+8|0,6065);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];e=Hb(d+128|0,10806);g=w[e>>2];w[d+148>>2]=w[e+4>>2];f=x[e+7|0]|x[e+8|0]<<8|(x[e+9|0]<<16|x[e+10|0]<<24);u[d+151|0]=f;u[d+152|0]=f>>>8;u[d+153|0]=f>>>16;u[d+154|0]=f>>>24;w[e>>2]=0;w[e+4>>2]=0;f=x[e+11|0];w[e+8>>2]=0;w[114256]=0;w[d+144>>2]=g;u[d+155|0]=f;u[d+127|0]=x[d+190|0];u[d+111|0]=x[d+189|0];u[d+24|0]=44;w[d+16>>2]=-1;w[d+20>>2]=0;w[d+8>>2]=1042;w[d+12>>2]=2;U(239,d+112|0,d+111|0,d+8|0);f=w[114256];w[114256]=0;d:{e:{if((f|0)!=1){w[114256]=0;Y(240,d+88|0,d+144|0,d+127|0,d+112|0);f=w[114256];w[114256]=0;if((f|0)!=1){f=a+1304460|0;if(u[a+1304471|0]<0){zb(w[f>>2])}g=w[d+92>>2];w[f>>2]=w[d+88>>2];w[f+4>>2]=g;w[f+8>>2]=w[d+96>>2];u[d+99|0]=0;u[d+88|0]=0;if(u[d+123|0]<0){zb(w[d+112>>2])}if(u[d+155|0]<0){zb(w[d+144>>2])}if(u[e+11|0]<0){zb(w[e>>2])}w[a+480208>>2]=12;w[a+1304496>>2]=4;v[a+480188>>1]=y[d+198>>1];e=y[d+194>>1];v[a+480190>>1]=e>>>0>=3999?3999:e;Pf(w[a+484360>>2]+(x[a+484376|0]<<5)|0,d+256|0,y[d+192>>1],255,254);if(y[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;Qd(f+480280|0);v[f+480284>>1]=(x[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<y[a+480188>>1]){continue}break}}oc(d+88|0,b,C(y[d+194>>1],80));f:{g:{h:{i:{j:{k:{l:{if(y[a+480190>>1]){i=c&2;h=d+56|0;e=0;while(1){w[114256]=0;f=Q(560,d+88|0,d+8|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break l}if(!f){Cb(d+8|0,0,80)}w[114256]=0;Y(209,d+144|0,2,h|0,28);f=w[114256];w[114256]=0;m:{n:{if((f|0)!=1){w[114256]=0;w[d+116>>2]=32;e=e+1|0;w[d+112>>2]=((e<<5)+a|0)+946304;Q(200,d+112|0,d+144|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(u[d+155|0]<0){zb(w[d+144>>2])}w[114256]=0;f=(C(e,104)+a|0)+484380|0;U(561,d+144|0,d+8|0,f|0);g=w[114256];w[114256]=0;o:{if((g|0)==1){break o}if(!i|!w[f>>2]){break m}g=y[d+26>>1]|y[d+28>>1]<<16;if(g>>>0>z[b+8>>2]){j=w[b>>2];k=w[w[j>>2]+24>>2];w[114256]=0;j=V(k|0,j|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break o}if(g>>>0>j>>>0){break m}}w[b+8>>2]=g;w[114256]=0;S(214,d+144|0,f|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){break m}}b=P()|0;break f}b=P()|0;break f}b=P()|0;if(u[d+155|0]>=0){break f}zb(w[d+144>>2]);break f}if(y[a+480190>>1]>e>>>0){continue}break}}p:{if(!(c&1)){break p}w[114256]=0;m=a+484344|0;T(215,m|0,y[d+196>>1]);c=w[114256];w[114256]=0;if((c|0)==1){break k}if(!y[d+196>>1]){break p}c=d+8|0;o=c|4;p=c|2;q=c|5;r=c|3;s=c|1;f=0;while(1){w[114256]=0;c=S(216,m|0,f&65535,64)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}q:{if(!c){break q}c=(f<<1)+d|0;c=x[c+512|0]|x[c+513|0]<<8;if(!c){break q}c=c<<4;if(c>>>0>z[b+8>>2]){e=w[b>>2];g=w[w[e>>2]+24>>2];w[114256]=0;e=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}if(c>>>0>e>>>0){break q}}w[b+8>>2]=c;c=w[m>>2];w[114256]=0;c=c+C(f,52)|0;V(218,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}j=w[c>>2];k=0;while(1){c=w[b+8>>2];e=w[b>>2];g=w[w[e>>2]+36>>2];w[114256]=0;c=S(g|0,e|0,c|0,1)|0;e=w[114256];w[114256]=0;r:{s:{t:{if((e|0)!=1){if(!c){break q}w[114256]=0;c=Q(241,b|0,d+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break t}c=c?x[d+8|0]:0;h=c&255;if(h){break s}k=k+1|0;j=C(y[a+480188>>1],6)+j|0;break r}b=P()|0;break f}b=P()|0;break f}v[d+12>>1]=0;w[d+8>>2]=0;n=c<<24>>24;c=n&31;g=C(c,6)+j|0;i=c>>>0<y[a+480188>>1];e=i?g:d+8|0;u:{v:{w:{x:{y:{z:{if(!(h&32)){break z}w[114256]=0;Q(562,b|0,d+144|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break y}c=x[d+144|0];u[e|0]=c;u[(i?g+1|0:s)|0]=x[d+145|0];A:{if(c){if((c|0)==254){break A}if(c>>>0<121){break z}}c=0}u[e|0]=c}if(!(h&64)){break u}w[114256]=0;Q(562,b|0,d+144|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}c=i?g+3|0:r;l=x[d+144|0];u[c|0]=l;h=i?g+5|0:q;u[h|0]=x[d+145|0];if(l>>>0>15){break x}w[114256]=0;X(312,e|0);e=w[114256];w[114256]=0;if((e|0)!=1){break w}b=P()|0;break f}b=P()|0;break f}if(l>>>0<=23){e=x[l+23831|0];u[c|0]=e;break v}u[c|0]=0;break u}e=x[c|0]}e=e&255;if((e|0)!=23){if((e|0)!=9){break u}u[c|0]=20;c=x[h|0];u[h|0]=c>>>0<8?-128:(c>>>3|0)-1&15|128;break u}c=x[h|0];u[h|0]=(c>>>0>=64?64:c)<<1}if((n|0)>=0){break r}u[(i?g+2|0:p)|0]=1;w[114256]=0;c=Q(241,b|0,d+144|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}u[(i?g+4|0:o)|0]=c?x[d+144|0]:0}if(k>>>0<64){continue}break}}f=f+1|0;if(f>>>0<y[d+196>>1]){continue}break}}a=w[d+92>>2];if(!a){break c}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break c}ob[w[w[a>>2]+8>>2]](a);Ib(a);break c}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0}Bb(d+88|0);break d}b=P()|0;if(u[d+123|0]>=0){break e}zb(w[d+112>>2]);break e}b=P()|0}if(u[d+155|0]<0){zb(w[d+144>>2])}if(u[e+11|0]>=0){break d}zb(w[e>>2])}R(b|0);M()}e=1}jb=d+768|0;return e|0}function fh(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0;j=y[a+480192>>1];i=j>>>0>=c>>>0?w[((c<<2)+a|0)+900380>>2]:i;l=(C(c,104)+a|0)+484380|0;s=w[b+764>>2];a:{b:{g=x[b+824|0];c:{if(!g){if(x[a+1074313|0]&8){break a}p=(i|0)!=0;if(!j){break b}break c}p=(i|0)!=0;if(!(!i|(g-1&255)>>>0>119)){k=g-1|0;g=y[((k<<1)+i|0)+236>>1];if(!(g|!(x[a+1074317|0]&8)|(x[i+31|0]-1&255)>>>0<17)){w[b+656>>2]=i;return}if(x[(i+k|0)+108|0]>120){break a}l=(g-1&65535)>>>0<3999?(C(g,104)+a|0)+484380|0:0;break b}if(!j){break b}if(g>>>0>250){break a}}l=0;if(!(x[a+1074317|0]&8)|((x[i+31|0]-1&255)>>>0<17?i:0)){break b}u[b+825|0]=0;w[b+656>>2]=0;return}g=w[b+104>>2];o=(g|0)!=0&(g|0)!=(l|0);h=w[b+656>>2];k=w[a+480180>>2];d:{if(!((k|0)==16777216&p)){q=!o;break d}q=!o;m=w[i+44>>2];t=(m|0)!=0;if(!d|!m|(h|0)!=(i|0)){break d}if(!q){break a}}m=0;A=!(x[a+1074319|0]&32);e:{f:{if(!(d&o)){break f}l=!(u[a+1074316|0]&1)|!(x[a+480208|0]&8)?l:w[b+8>>2]|w[b+12>>2]?g:l;g:{h:{if((h|0)==(i|0)){if((k&1048580)!=0&p|(k|0)==268435456){break g}n=w[b+8>>2];r=w[b+12>>2];if((k|0)!=1){break h}if(n|r){break g}break h}if((k|0)!=1){if((k|0)==268435456){break g}n=w[b+8>>2];r=w[b+12>>2];break h}if(w[b+8>>2]|w[b+12>>2]){break g}n=b+8|0;j=1;break e}if(!(x[a+1074321|0]&128)|!(n|r)){break f}}m=1}if(!(!(x[a+1074322|0]&128)|(!w[b+16>>2]|(!j|(h|0)!=(i|0)|q)))){m=(x[b+810|0]-121&255)>>>0<136|m}n=b+8|0;j=(h|0)!=(i|0);if((x[i+31|0]-1&255)>>>0<17&p|(!(k&16777248)|(w[b+8>>2]|w[b+12>>2]))){break e}j=1}i:{if(!(A|(!j|!d))){k=0;if(g|h){break i}}w[b+656>>2]=i;g=l;h=i;k=j}j:{k:{l:{if(!e){break l}m:{if(x[a+480180|0]&3){if(!(w[g>>2]?!g|!w[g+20>>2]:1)){break m}if(!h|(x[h+31|0]-1&255)>>>0>16){break l}}if(!g){break k}}if(v[g+34>>1]<0){break l}w[b+688>>2]=y[g+30>>1]}i=(g|0)!=0;if(!(m&o)|!g){break j}if(x[a+1074322|0]&32){w[b+768>>2]=u[g+37|0]}i=1;if(!w[g>>2]|(!w[g+20>>2]|w[a+480180>>2]!=2)){break j}w[b+704>>2]=w[g+24>>2];break j}if(!(!h|!x[h+34|0])){w[b+688>>2]=w[h+4>>2]<<2;i=0;break j}i=0;w[b+688>>2]=0}if(m){break a}u[b+825|0]=0;if(!(!h|!(!(x[a+1074315|0]&32)&i)&(k|x[h+34|0]!=0)!=1)){u[b+820|0]=x[h+16|0]}l=64;w[b+764>>2]=64;if(g){l=y[g+32>>1];w[b+764>>2]=l}if(h){w[b+764>>2]=C(w[h+4>>2],l)>>>6}if(!(!(w[a+480180>>2]&1048580?e:1)|u[a+1074318|0]&1)){Yn(a,b,h,g)}l=d^1;n:{o:{p:{if(!f){break p}q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{e=w[a+1074312>>2];if(e&524288){if(w[b+76>>2]){if(!(l|!c)){j=(x[a+480208|0]&8)>>>3|0;if(j){break z}break A}j=0;if(c){break A}break z}c=1;if(k|!w[b+696>>2]){break x}c=(x[b+89|0]&8)>>>3|0;break x}c=w[a+480180>>2]&17301536;B:{j=1;C:{if(!d){break C}if(!c){c=1;break x}c=1;j=1;if(x[a+480208|0]&8){break C}j=1;if(!w[b+76>>2]){break C}if(!(x[b+89|0]&16)){break B}j=!w[b+696>>2]}if(!h|(k|!c)){break y}if(!j){break u}c=w[b+88>>2];w[b+88>>2]=c|2097152;if(c&6144){break w}break s}if((k|!h)!=1){break u}break v}if(d){break z}if(!(x[b+89|0]&24)){j=0;break z}j=(x[a+480208|0]&4)>>>2|0}if(k|!w[b+696>>2]){break y}if(!j){break v}c=(x[b+89|0]&8)>>>3|0;break x}c=1;if(!j){break v}}w[b+88>>2]=w[b+88>>2]|2097152;if(!h){break q}if(!c){break s}}w[b+740>>2]=0;w[b+744>>2]=-1;w[b+728>>2]=0;w[b+732>>2]=-1;break r}if(!h){break t}}if(u[h+60|0]&1){break p}c=w[a+1074316>>2];w[b+728>>2]=0;w[b+732>>2]=-1;if(c&1){break p}w[b+752>>2]=0;w[b+756>>2]=-1;w[b+740>>2]=0;w[b+744>>2]=-1;break p}c=0;if(!g){break o}break n}if(!(x[h+60|0]&8)){w[b+728>>2]=0;w[b+732>>2]=-1}if(!(x[h+80|0]&8)){w[b+740>>2]=0;w[b+744>>2]=-1}if(x[h+100|0]&8){break q}}w[b+752>>2]=0;w[b+756>>2]=-1}if(e&2097152){break p}u[b+838|0]=0;w[b+780>>2]=0}c=0;if(g){break n}if(!h){break o}c=1;if((x[h+31|0]-1&255)>>>0<17){break n}}w[b+764>>2]=0;w[b+104>>2]=0;return}D:{if(!(!d|(i^1|w[b+104>>2]!=(g|0)))){e=w[a+480180>>2];if(w[b+76>>2]?e&16777250:0){break a}E:{if(!(x[b+811|0]|(!(u[a+1074317|0]&1)|(e|0)!=4))){e=w[b+88>>2];break E}e=w[b+88>>2]&-6145}j=e&-640;w[b+88>>2]=j;e=g;break D}f=w[b+88>>2];w[b+88>>2]=f&-6145;F:{G:{if(!(x[a+1074314|0]&4)){i=-6784;e=g;m=w[b+104>>2];if(k|(w[a+480180>>2]&16777248|(m|0)!=(g|0))){break G}break F}i=-6784;e=g;m=w[b+104>>2];if((k|(m|0)!=(g|0))!=1){break F}}i=-6912;e=m}j=f&i;w[b+88>>2]=j;if(!h){break D}u[b+724|0]=x[h+60|0];u[b+736|0]=x[h+80|0];u[b+748|0]=x[h+100|0];if(!(x[b+857|0]|(x[a+1074316|0]&16|(x[h+100|0]&17)!=17))){u[b+857|0]=127}f=u[h+21|0];if((f|0)<0){u[b+857|0]=f&127}f=u[h+22|0];if((f|0)>=0){break D}u[b+858|0]=f&127}if(c){w[b+76>>2]=0;w[b+104>>2]=0;return}if(!(!(w[a+1074316>>2]&4194432)|(w[b+76>>2]|!d))){w[n>>2]=0;w[n+4>>2]=0}if(!(!(x[a+1074324|0]&16)|x[b+810|0]!=255|(!(x[a+480208|0]&4)|q))){if(e){w[b+88>>2]=y[e+34>>1]&1023|j}w[b+764>>2]=s;w[b+688>>2]=y[g+30>>1];if(!(x[g+34|0]&32)){break a}Bi(b,y[g+28>>1],a);return}w[b+104>>2]=g;i=w[g>>2];w[b+76>>2]=i;c=w[g+4>>2];w[b+80>>2]=c;d=w[g+8>>2];c=(w[a+1074320>>2]&524288)>>>19|0?c?d:i:d;w[b+84>>2]=c;d=y[g+34>>1]&1023;h=d|j;w[b+88>>2]=h;if(x[a+1074314|0]&32){u[b+838|0]=0;w[b+780>>2]=0}H:{I:{if(t){w[b+704>>2]=w[g+24>>2];u[b+872|0]=x[b+872|0]|16;e=0;break I}if(!(x[a+480180|0]&5?l|o:1)){break H}w[b+704>>2]=w[g+24>>2];e=u[g+37|0]}w[b+768>>2]=e}w[b+772>>2]=w[a+480180>>2]&740327453?u[g+36|0]:0;if(!(x[a+1074320|0]&32|w[a+480180>>2]==1)){w[b+708>>2]=0}w[b+876>>2]=0;if(d&8){w[b+80>>2]=w[g+12>>2];c=w[g+16>>2];w[b+84>>2]=c;h=d>>>2&4|h|2;w[b+88>>2]=h}if(!(h&2)|c>>>0>=i>>>0){c=i}else{w[b+76>>2]=c}if(c>>>0>z[b+4>>2]|!(w[a+480180>>2]&16777248)){break a}w[b>>2]=0;w[b+4>>2]=0}}function VA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,A=0,B=0;d=jb-192|0;jb=d;w[b+8>>2]=0;a:{b:{c:{if(!Zk(b,d+144|0)){break c}if(!Xo(d+144|0)){break c}e=w[b>>2];if(!(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],(x[d+177|0]<<8)+(x[d+175|0]?1120:1056)|0)|0)){break c}d:{if(c){tc(a,256);Vb(d+32|0,2,d+144|0,20);f=a+1304400|0;if(u[a+1304411|0]<0){zb(w[f>>2])}e=w[d+36>>2];w[f>>2]=w[d+32>>2];w[f+4>>2]=e;w[f+8>>2]=w[d+40>>2];g=a+1304436|0;f=Hb(d+32|0,11087);if(u[a+1304447|0]<0){zb(w[g>>2])}e=w[f+4>>2];w[g>>2]=w[f>>2];w[g+4>>2]=e;w[g+8>>2]=w[f+8>>2];g=a+1304448|0;f=Hb(d+32|0,6060);if(u[a+1304459|0]<0){zb(w[g>>2])}e=w[f+4>>2];w[g>>2]=w[f>>2];w[g+4>>2]=e;w[g+8>>2]=w[f+8>>2];g=Hb(d+112|0,10884);f=w[g>>2];w[d+132>>2]=w[g+4>>2];e=x[g+7|0]|x[g+8|0]<<8|(x[g+9|0]<<16|x[g+10|0]<<24);u[d+135|0]=e;u[d+136|0]=e>>>8;u[d+137|0]=e>>>16;u[d+138|0]=e>>>24;w[g>>2]=0;w[g+4>>2]=0;e=x[g+11|0];w[g+8>>2]=0;w[114256]=0;u[d+139|0]=e;w[d+128>>2]=f;u[d+48|0]=44;w[d+40>>2]=-1;w[d+44>>2]=0;w[d+32>>2]=1025;w[d+36>>2]=2;U(239,d+96|0,d+175|0,d+32|0);e=w[114256];w[114256]=0;e:{f:{g:{h:{if((e|0)!=1){w[114256]=0;Y(240,d|0,d+128|0,d+174|0,d+96|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}f=a+1304460|0;if(u[a+1304471|0]<0){zb(w[f>>2])}e=w[d+4>>2];w[f>>2]=w[d>>2];w[f+4>>2]=e;w[f+8>>2]=w[d+8>>2];u[d+11|0]=0;u[d|0]=0;if(u[d+107|0]<0){zb(w[d+96>>2])}if(u[d+139|0]<0){zb(w[d+128>>2])}if(u[g+11|0]<0){zb(w[g>>2])}w[a+1304496>>2]=4;w[a+480260>>2]=64;w[a+480264>>2]=32767;w[a+480188>>2]=2031620;e=a+1074324|0;w[e>>2]=w[e>>2]|2048;f=x[d+176|0];if(x[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-C(e,10)}f=(f&255?f:96)&255;e=50-(C(x[(f>>>4|0)+25616|0],f&15)>>>4|0)|0;e=e>>>0>23863?65536:23863/(e>>>0)|0;w[a+480196>>2]=f>>>4;w[a+480204>>2]=(e+119315e4>>>0)/(e<<1>>>0);if(x[d+175|0]>10){break f}break e}i=P()|0;break g}i=P()|0;if(u[d+107|0]>=0){break g}zb(w[d+96>>2])}if(u[d+139|0]<0){zb(w[d+128>>2])}if(u[g+11|0]>=0){break a}zb(w[g>>2]);break a}e=x[d+178|0];w[a+480200>>2]=(e>>>0>=64?64:e)<<2}f=0;while(1){e=(f<<5)+a|0;Qd(e+480280|0);v[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;while(1){i:{if(!Fi(b,d)){w[d+24>>2]=0;w[d+28>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;w[d+8>>2]=0;w[d+12>>2]=0;w[d>>2]=0;w[d+4>>2]=0;break i}e=x[d+12|0];if((e|0)==46){break i}if(e){break d}}j=jb-32|0;jb=j;h=(C(f,104)+a|0)+484380|0;lc(h,0);e=j+8|0;Vb(e,2,d,12);w[114256]=0;w[j+28>>2]=22;w[j+24>>2]=h+43;Q(200,j+24|0,e|0)|0;e=w[114256];w[114256]=0;j:{k:{if((e|0)!=1){if(u[j+19|0]<0){zb(w[j+8>>2])}w[h+24>>2]=x[d+24|0]|x[d+25|0]<<8;e=x[d+22|0];v[h+30>>1]=(e>>>0>=64?64:e)<<2;i=x[d+16|0]|x[d+17|0]<<8;w[h>>2]=i;e=x[d+18|0]|x[d+19|0]<<8;w[h+4>>2]=e;g=x[d+20|0]|x[d+21|0]<<8;w[h+8>>2]=g;if(i>>>0>1){break k}w[h>>2]=0;break j}a=P()|0;if(u[j+19|0]<0){zb(w[j+8>>2])}R(a|0);M()}if(e>>>0>=i>>>0|e>>>0>=g>>>0|(g|0)==65535){break j}v[h+34>>1]=2;w[h+8>>2]=g>>>0>i>>>0?i:g}jb=j+32|0;e=d+128|0;Vb(e,2,d,12);w[114256]=0;w[d+100>>2]=32;w[d+96>>2]=((f<<5)+a|0)+946304;Q(200,d+96|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}if(u[d+139|0]<0){zb(w[d+128>>2])}v[((f<<1)+d|0)+30>>1]=y[d+14>>1];f=f+1|0;if((f|0)!=32){continue}break}e=a+484376|0;wh(w[a+484360>>2]+(x[e|0]<<5)|0,b,x[d+175|0]?128:64,65535,65535);e=w[a+484360>>2]+(x[e|0]<<5)|0;f=w[e>>2];e=w[e+4>>2];if((f|0)!=(e|0)){while(1){g=y[f>>1];l:{if(!((g|0)!=255&(g|0)!=99)){v[f>>1]=65535;break l}if(g>>>0>63){break d}}f=f+2|0;if((e|0)!=(f|0)){continue}break}}s=c&1;if(s){td(a+484344|0,x[d+177|0])}if(x[d+177|0]){o=a+484344|0;while(1){m:{n:{if(s){if(ie(o,n&65535,64)){break n}}f=0;while(1){if(!(t=Xb(b,d),A=0,B=(x[d|0]+2&255)>>>0>252,B?t:A)){e=w[b>>2];o:{if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],3)|0){e=w[b+8>>2]+3|0;break o}e=w[b>>2];e=ob[w[w[e>>2]+24>>2]](e)|0}w[b+8>>2]=e}f=f+1|0;if((f|0)!=256){continue}break}break m}j=C(n,52);f=w[j+w[o>>2]>>2];l=63;k=65535;m=0;while(1){h=0;while(1){g=h;i=0;e=Xb(b,d);p=0;q=0;h=0;p:{q:{r:{s:{t:{u:{e=e?x[d|0]:0;r=e&255;switch(r-251|0){case 1:break p;case 0:break s;case 2:break u;default:break t}}u[f|0]=254;break p}nl(b,d);h=x[d+2|0];q=x[d+1|0];p=x[d|0];i=254;if((r|0)==254){break r}i=e;if(r>>>0>95){break q}}i=(C((i&240)>>>4|0,12)+(i&15)|0)+37|0}u[f|0]=i}u[f+1|0]=(p&248)>>>3;e=q>>>1&120|p&7;if(e>>>0<=64){u[f+4|0]=e;u[f+2|0]=1}u[f+5|0]=h;e=x[(q&15)+23856|0];u[f+3|0]=e;v:{w:{switch(e-11|0){case 0:e=h&15;if(e){u[f+5|0]=e;break p}u[f+5|0]=h&240;break p;case 3:e=C(h&-16,10)|h&15;u[f+5|0]=e;x:{if((k|0)!=65535){if(e&255){break x}u[f+5|0]=k;u[f+3|0]=12}k=65535}l=l>>>0<m>>>0?l:m;break p;case 1:u[f+3|0]=0;k=h&255;l=63;break p;case 5:if(x[d+175|0]<=20){e=((h&255)>>>0)/10|0;h=e<<4|h-C(e,10);u[f+5|0]=h}if(!(h&255)){break v}break p;case 7:break p;default:break w}}if(h&255){break p}}u[f+3|0]=0}f=f+6|0;h=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break m}e=w[o>>2];u[d+11|0]=k;u[d+10|0]=12;v[d+8>>1]=65535;w[d+4>>2]=l;w[d>>2]=2;u[d+12|0]=x[d+12|0]&248|1;ng(e+j|0,d)}n=n+1|0;if(n>>>0<x[d+177|0]){continue}break}}f=1;if(!(c&2)){break c}w[d>>2]=264;while(1){c=C(f,104)+a|0;e=c+484380|0;y:{if(!w[e>>2]|!y[c+484410>>1]){break y}c=y[((f<<1)+d|0)+30>>1];if(c>>>0<4){break y}g=c<<4;if(g>>>0>z[b+8>>2]){c=w[b>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<g>>>0){break y}}w[b+8>>2]=g;Fd(d,e,b)}f=f+1|0;if((f|0)!=32){continue}break}}f=1;break c}f=0}jb=d+192|0;return f|0}i=P()|0;if(u[d+139|0]>=0){break a}zb(w[d+128>>2])}R(i|0);M()}function FE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-3056|0;jb=e;w[b+8>>2]=0;f=jb-16|0;jb=f;i=w[b+8>>2];g=w[b>>2];j=e+1088|0;w[f+8>>2]=j;w[f+12>>2]=j+1954;i=ob[w[w[g>>2]+32>>2]](g,i,f+8|0)|0;if((i|0)==1954){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],1954)|0){h=w[b+8>>2]+1954|0;break a}g=w[b>>2];h=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=h}jb=f+16|0;b:{c:{d:{e:{if((i|0)!=1954){break e}if(!nq(e+1088|0)){break e}if(!c){d=1;break e}f=w[b>>2];if(!(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],1024)|0)){break e}dl(b,e+576|0);dl(b,e- -64|0);f=0;f:{while(1){d=f<<2;g=w[d+(e+576|0)>>2];if(g>>>0>16777215){break f}i=w[d+(e- -64|0)>>2];if(i-4097>>>0<4294963202){break f}d=0;j=w[b>>2];if(!(ob[w[w[j>>2]+36>>2]](j,0,(g+i|0)+2978|0)|0)){break e}f=f+1|0;if((f|0)!=128){continue}break}tc(a,2);je(a);d=a+1304436|0;f=Hb(e+32|0,9579);if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=a+1304448|0;f=Hb(e+32|0,10272);if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=a+1304460|0;f=Hb(e+32|0,11478);if(u[a+1304471|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];w[a+1304496>>2]=4;d=x[e+1088|0];w[a+480204>>2]=143e4;w[a+480196>>2]=d;v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=x[e+1089|0];w[a+480188>>2]=4194317;d=a+1074320|0;w[d>>2]=w[d>>2]|-2147483648;w[a+480208>>2]=w[a+480208>>2]|16777216;d=0;while(1){v[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;while(1){f=d+1|0;g=C(f,104)+a|0;i=g+484380|0;lc(i,2);j=e+32|0;Vb(j,1,(C(d,13)+e|0)+1090|0,13);w[114256]=0;w[e+3052>>2]=32;w[e+3048>>2]=((f<<5)+a|0)+946304;Q(200,e+3048|0,j|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break c}if(u[e+43|0]<0){zb(w[e+32>>2])}h=i;d=(e+1088|0)+(d<<4)|0;i=x[d+422|0]|x[d+423|0]<<8|(x[d+424|0]<<16|x[d+425|0]<<24);w[h>>2]=i;h=i;i=x[d+430|0]|x[d+431|0]<<8|(x[d+432|0]<<16|x[d+433|0]<<24);if(h>>>0>=i>>>0){d=x[d+426|0]|x[d+427|0]<<8|(x[d+428|0]<<16|x[d+429|0]<<24);v[g+484414>>1]=2;w[g+484388>>2]=i;w[g+484384>>2]=d}w[g+484404>>2]=8287;d=f;if((d|0)!=32){continue}break}f=0;while(1){d=f+33|0;g=(C(d,104)+a|0)+484380|0;lc(g,2);i=e+32|0;Vb(i,1,(C(f,13)+e|0)+2018|0,13);w[114256]=0;w[e+3052>>2]=32;w[e+3048>>2]=((d<<5)+a|0)+946304;Q(200,e+3048|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}if(u[e+43|0]<0){zb(w[e+32>>2])}d=(e+1088|0)+C(f,11)|0;i=x[d+1356|0];j=x[d+1346|0];h=x[d+1347|0];m=x[d+1352|0];n=x[d+1348|0];o=x[d+1353|0];l=x[d+1349|0];k=x[d+1354|0];p=x[d+1350|0];q=x[d+1355|0];u[e+56|0]=x[d+1351|0];u[e+55|0]=q;u[e+54|0]=p;u[e+53|0]=k;u[e+52|0]=l;u[e+51|0]=o;u[e+50|0]=n;u[e+49|0]=m;u[e+48|0]=h;u[e+59|0]=0;u[e+58|0]=j;u[e+57|0]=i;w[e+16>>2]=w[e+56>>2];d=w[e+52>>2];w[e+8>>2]=w[e+48>>2];w[e+12>>2]=d;Ai(g,1,e+8|0);f=f+1|0;if((f|0)!=32){continue}break}Pf(w[a+484360>>2]+(x[a+484376|0]<<5)|0,e+2786|0,256,255,65535);m=a+484344|0;td(m,128);n=c&1;o=e+24|2;j=0;while(1){f=j<<2;d=w[f+(e+576|0)>>2]+2978|0;g:{if(d>>>0>z[b+8>>2]){g=w[b>>2];if(ob[w[w[g>>2]+24>>2]](g)>>>0<d>>>0){break g}}w[b+8>>2]=d}oc(e+32|0,b,w[f+(e- -64|0)>>2]);h=16;h:{if(!n){break h}w[114256]=0;d=S(216,m|0,j&65535,64)|0;f=w[114256];w[114256]=0;i:{if((f|0)!=1){j:{if(!d){break h}i=w[m>>2]+C(j,52)|0;f=0;while(1){d=w[e+32>>2];g=w[w[d>>2]+36>>2];w[114256]=0;d=S(g|0,d|0,w[e+40>>2],1)|0;g=w[114256];w[114256]=0;k:{l:{if((g|0)!=1){if(!d){break i}w[114256]=0;d=Q(241,e+32|0,e+3048|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}d=d?x[e+3048|0]:0;g=d&255;if(g>>>0>12){break l}w[114256]=0;d=V(218,i|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break j}l=w[i>>2];h=w[e+32>>2];k=w[w[h>>2]+36>>2];w[114256]=0;h=S(k|0,h|0,w[e+40>>2],2)|0;k=w[114256];w[114256]=0;if((k|0)==1){break j}m:{if(h){w[e+3052>>2]=o;w[e+3048>>2]=e+24;h=w[e+32>>2];k=w[w[h>>2]+32>>2];w[114256]=0;h=S(k|0,h|0,w[e+40>>2],e+3048|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break j}w[e+40>>2]=h+w[e+40>>2];h=x[e+24|0];break m}v[e+24>>1]=0;h=0}d=l+C(g+C(d,f)|0,6)|0;l=g>>>0>3;u[d|0]=((h&15)+(l?13:37)|0)+C(h>>>4&7,12);u[d+1|0]=((x[e+25|0]>>>4|0)+(l?33:1)|0)+(x[e+24|0]>>>3&16);h=x[e+25|0];u[d+2|0]=1;h=h&15;if(g>>>0>=4){h=x[h+23280|0]}else{h=(h<<2)+4|0}u[d+4|0]=h;break k}break j}if((d-32&255)>>>0<=12){w[114256]=0;d=V(218,i|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break j}h=w[i>>2];w[114256]=0;l=Q(241,e+32|0,e+3048|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break j}k=x[e+3048|0];d=h+C(C(d,f)+(g+65504&65535)|0,6)|0;u[d+2|0]=1;h=l?k&15:0;if(g>>>0>=36){h=x[h+23280|0]}else{h=(h<<2)+4|0}u[d+4|0]=h;break k}if((g|0)!=64){h=1;if((g|0)!=96){break h}if(!f){break i}w[114256]=0;d=V(218,i|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}u[(w[i>>2]+C(C(d,f-1|0),6)|0)+3|0]=14;break i}w[114256]=0;d=Q(241,e+32|0,e+3048|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}f=(d?x[e+3048|0]:0)+f|0}h=0;if(f>>>0<64){continue}break}break h}}d=P()|0;Bb(e+32|0);break b}h=0}d=w[e+36>>2];n:{if(!d){break n}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break n}ob[w[w[d>>2]+8>>2]](d);Ib(d)}if((h|16)!=16){break f}j=j+1|0;if((j|0)!=128){continue}break}d=1;if(!(c&2)){break e}f=1;while(1){w[e+32>>2]=16777480;Fd(e+32|0,(C(f,104)+a|0)+484380|0,b);f=f+1|0;if((f|0)!=33){continue}break}break e}d=0}jb=e+3056|0;return d|0}d=P()|0;if(u[e+43|0]>=0){break b}zb(w[e+32>>2]);break b}d=P()|0;if(u[e+43|0]>=0){break b}zb(w[e+32>>2])}R(d|0);M()}function uU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=D(0),j=0,k=0,l=0,m=0;e=jb-320|0;jb=e;d=-1;a:{b:{c:{if(x[(w[w[b>>2]-12>>2]+b|0)+16|0]&5){break c}b=mg(e+200|0,b);w[114256]=0;d=Q(5,e+184|0,9692)|0;f=w[114256];w[114256]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){w[114256]=0;w[e+304>>2]=83886084;w[e+308>>2]=0;U(397,b|0,d|0,e+304|0);f=w[114256];w[114256]=0;if((f|0)==1){break E}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;u[e+183|0]=0;d=Q(5,e+168|0,10255)|0;f=w[114256];w[114256]=0;if((f|0)==1){break D}w[114256]=0;S(398,b|0,e+183|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break C}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;g=x[e+183|0];d=Q(5,e+152|0,11706)|0;f=w[114256];w[114256]=0;if((f|0)==1){break B}w[114256]=0;f=Q(399,b|0,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break A}h=w[b+28>>2];w[114256]=0;T(400,e+304|0,h|0);h=w[114256];w[114256]=0;if((h|0)==1){break A}g=g?0:c;c=w[e+316>>2];w[e+136>>2]=w[e+312>>2];w[e+140>>2]=c;if(x[b+24|0]&32?f:1){c=w[b+28>>2];w[114256]=0;Y(960,c|0,a+40|0,e|0,g|0);c=w[114256];w[114256]=0;if((c|0)==1){break A}}w[114256]=0;Z(402,b|0,f|0,d|0,e+136|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break A}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;v[e+150>>1]=65535;c=Q(5,e+136|0,11460)|0;d=w[114256];w[114256]=0;if((d|0)==1){break z}w[114256]=0;S(715,b|0,e+150|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break y}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;v[e+134>>1]=0;c=Q(5,e+120|0,11102)|0;d=w[114256];w[114256]=0;if((d|0)==1){break x}w[114256]=0;S(715,b|0,e+134|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break w}if(u[c+11|0]<0){zb(w[c>>2])}v[a>>1]=y[e+134>>1];w[114256]=0;c=Q(5,e+104|0,10603)|0;d=w[114256];w[114256]=0;if((d|0)==1){break v}w[114256]=0;d=Q(399,b|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break u}f=w[b+28>>2];w[114256]=0;T(400,e+304|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break u}f=w[e+316>>2];w[e+88>>2]=w[e+312>>2];w[e+92>>2]=f;if(x[b+24|0]&32?d:1){f=w[b+28>>2];w[114256]=0;Y(961,f|0,a+52|0,e|0,g|0);f=w[114256];w[114256]=0;if((f|0)==1){break u}}w[114256]=0;Z(402,b|0,d|0,c|0,e+88|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break u}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,e+304|0,10489)|0;d=w[114256];w[114256]=0;if((d|0)==1){break t}w[114256]=0;S(948,b|0,a+36|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break s}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,e+88|0,11462)|0;d=w[114256];w[114256]=0;if((d|0)==1){break r}w[114256]=0;h=a+4|0;Z(962,b|0,h|0,c|0,963)|0;d=w[114256];w[114256]=0;if((d|0)==1){break q}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,e+72|0,11104)|0;d=w[114256];w[114256]=0;if((d|0)==1){break p}w[114256]=0;f=a+28|0;S(964,b|0,f|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break o}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,e+56|0,10704)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}w[114256]=0;S(964,b|0,a+30|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break m}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;c=Q(5,e+40|0,10513)|0;d=w[114256];w[114256]=0;if((d|0)==1){break l}w[114256]=0;S(965,b|0,a+32|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break k}if(u[c+11|0]<0){zb(w[c>>2])}w[114256]=0;v[e+38>>1]=0;c=Q(5,e+24|0,10456)|0;d=w[114256];w[114256]=0;if((d|0)==1){break j}w[114256]=0;S(715,b|0,e+38|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}d=-1;if(u[c+11|0]<0){zb(w[c>>2])}i=D(H(D(G(D(E(A[a+32>>2])),D(1e7))),D(10000000036274937e-31)));A[a+32>>2]=i;if(x[b+3|0]&64){break d}c=y[f>>1];if((c+300&65535)>>>0>600){break d}g=y[a>>1];if(g>>>0>3|(g|0)==2){break d}j=v[a+30>>1];if((j|0)<0){break d}l=w[a+8>>2];m=w[a+4>>2];k=w[a+36>>2];w[a+36>>2]=k>>>0>=65535?65535:k;if(l-m>>>0>131068){break d}switch(g-1|0){case 0:break g;case 2:break h;default:break f}}a=P()|0;break a}a=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}a=P()|0;break a}a=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}a=P()|0;break a}a=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;break a}a=P()|0;if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}f=v[e+38>>1];if((f|0)<=0){break d}w[114256]=0;v[e+22>>1]=j;A[e+16>>2]=i;v[e+8>>1]=c;v[e+10>>1]=(c+f|0)-1;a=Z(966,a|0,e+22|0,e+16|0,e+8|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;break a}g=v[e+38>>1];if((g|0)<=0){break d}w[114256]=0;A[e+16>>2]=i;v[e+8>>1]=c;v[e+10>>1]=(c+g|0)-1;a=da(967,a|0,h|0,e+16|0,e+8|0,f|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;break a}w[114256]=0;X(968,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}}d=1}a=w[b+44>>2];if(a){w[b+48>>2]=a;zb(a)}a=w[b+32>>2];if(!a){break c}w[b+36>>2]=a;zb(a)}jb=e+320|0;return d|0}a=P()|0}Mf(b);R(a|0);M()}function St(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0;j=jb-80|0;jb=j;w[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=x[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(x[i+1|0]!=37){b=i;break j}h=h+1|0;m=x[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;D=p^2147483647;if((h|0)>(D|0)){break d}if(a){Tc(a,k,h)}if(h){continue e}w[j+76>>2]=b;h=b+1|0;q=-1;if(!(!Wd(u[b+1|0])|x[b+2|0]!=36)){q=u[b+1|0]-48|0;t=1;h=b+3|0}w[j+76>>2]=h;n=0;i=u[h|0];b=i-32|0;k:{if(b>>>0>31){m=h;break k}m=h;b=1<<b;if(!(b&75913)){break k}while(1){m=h+1|0;w[j+76>>2]=m;n=b|n;i=u[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=m;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){m:{if(!(!Wd(u[m+1|0])|x[m+2|0]!=36)){w[((u[m+1|0]<<2)+e|0)-192>>2]=10;i=m+3|0;t=1;b=w[((u[m+1|0]<<3)+d|0)-384>>2];break m}if(t){break h}i=m+1|0;if(!a){w[j+76>>2]=i;t=0;r=0;break l}b=w[c>>2];w[c>>2]=b+4;t=0;b=w[b>>2]}r=b;w[j+76>>2]=i;if((r|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=Qt(j+76|0);if((r|0)<0){break d}i=w[j+76>>2]}h=0;l=-1;n:{if(x[i|0]!=46){b=i;A=0;break n}if(x[i+1|0]==42){o:{if(!(!Wd(u[i+2|0])|x[i+3|0]!=36)){w[((u[i+2|0]<<2)+e|0)-192>>2]=10;b=i+4|0;l=w[((u[i+2|0]<<3)+d|0)-384>>2];break o}if(t){break h}b=i+2|0;l=0;if(!a){break o}i=w[c>>2];w[c>>2]=i+4;l=w[i>>2]}w[j+76>>2]=b;A=(l^-1)>>>31|0;break n}w[j+76>>2]=i+1;l=Qt(j+76|0);b=w[j+76>>2];A=1}while(1){o=h;m=28;y=b;h=u[b|0];if(h-123>>>0<4294967238){break c}b=y+1|0;h=x[(h+C(o,58)|0)+58399|0];if(h-1>>>0<8){continue}break}w[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){w[(q<<2)+e>>2]=h;h=(q<<3)+d|0;i=w[h+4>>2];w[j+64>>2]=w[h>>2];w[j+68>>2]=i;break q}if(!a){break f}Pt(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=1772;m=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=u[y|0];h=o?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}o=w[j+64>>2];i=w[j+68>>2];z=1772;break z}h=0;I:{switch(o&255){case 0:w[w[j+64>>2]>>2]=p;continue e;case 1:w[w[j+64>>2]>>2]=p;continue e;case 2:k=w[j+64>>2];w[k>>2]=p;w[k+4>>2]=p>>31;continue e;case 3:v[w[j+64>>2]>>1]=p;continue e;case 4:u[w[j+64>>2]]=p;continue e;case 6:w[w[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=w[j+64>>2];w[k>>2]=p;w[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;o=w[j+64>>2];i=w[j+68>>2];if(o|i){while(1){k=k-1|0;u[k|0]=F|x[(o&15)+58928|0];G=!i&o>>>0>15|(i|0)!=0;y=i;i=i>>>4|0;o=(y&15)<<28|o>>>4;if(G){continue}break}}if(!(n&8)|!(w[j+64>>2]|w[j+68>>2])){break y}z=(h>>>4|0)+1772|0;q=2;break y}h=s;k=w[j+68>>2];i=k;o=w[j+64>>2];if(i|o){while(1){h=h-1|0;u[h|0]=o&7|48;y=!i&o>>>0>7|(i|0)!=0;k=i;i=i>>>3|0;o=(k&7)<<29|o>>>3;if(y){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}h=w[j+68>>2];i=h;o=w[j+64>>2];if((h|0)<0){i=0-(i+((o|0)!=0)|0)|0;o=0-o|0;w[j+64>>2]=o;w[j+68>>2]=i;q=1;z=1772;break z}if(n&2048){q=1;z=1773;break z}q=n&1;z=q?1774:1772}k=Pg(o,i,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;i=w[j+64>>2];h=w[j+68>>2];if(!((i|h)!=0|l)){k=s;m=k;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=w[j+64>>2];k=h?h:12835;h=l>>>0>=2147483647?2147483647:l;m=uc(k,0,h);h=m?m-k|0:h;m=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(x[m|0]){break d}break g}if(l){i=w[j+64>>2];break u}h=0;ad(a,32,r,0,n);break t}w[j+12>>2]=0;w[j+8>>2]=w[j+64>>2];i=j+8|0;w[j+64>>2]=i;l=-1}h=0;J:{while(1){k=w[i>>2];if(!k){break J}k=Ot(j+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break J}break}if(m){break b}}m=61;if((h|0)<0){break c}ad(a,32,r,h,n);if(!h){h=0;break t}m=0;i=w[j+64>>2];while(1){k=w[i>>2];if(!k){break t}k=Ot(j+4|0,k);m=k+m|0;if(m>>>0>h>>>0){break t}Tc(a,j+4|0,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}ad(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}m=61;h=ob[f|0](a,B[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}u[j+55|0]=w[j+64>>2];l=1;k=E;n=i;break g}i=x[h+1|0];h=h+1|0;continue}}if(a){break a}if(!t){break f}h=1;while(1){a=w[(h<<2)+e>>2];if(a){Pt((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(w[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}o=m-k|0;l=(l|0)>(o|0)?l:o;if((l|0)>(q^2147483647)){break d}m=61;i=l+q|0;h=(i|0)<(r|0)?r:i;if((D|0)<(h|0)){break c}ad(a,32,h,i,n);Tc(a,z,q);ad(a,48,h,i,n^65536);ad(a,48,l,o,0);Tc(a,k,o);ad(a,32,h,i,n^8192);continue}break}p=0;break a}m=61}w[114084]=m}p=-1}jb=j+80|0;return p}function LD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-960|0;jb=e;w[b+8>>2]=0;d=jb-16|0;jb=d;f=w[b+8>>2];g=w[b>>2];i=e+848|0;w[d+8>>2]=i;w[d+12>>2]=i+98;f=ob[w[w[g>>2]+32>>2]](g,f,d+8|0)|0;if((f|0)==98){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],98)|0){h=w[b+8>>2]+98|0;break a}g=w[b>>2];h=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=h}jb=d+16|0;b:{if((f|0)!=98){break b}if(!Yp(e+848|0)){break b}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(x[e+895|0]|x[e+896|0]<<8)-98|0)|0)){break b}if(!c){k=1;break b}tc(a,512);w[a+480228>>2]=32;v[a+480188>>1]=16;w[a+480196>>2]=x[e+923|0];w[a+480200>>2]=256;w[a+480204>>2]=8e5;d=a+1304436|0;g=Hb(e+72|0,4409);if(u[a+1304447|0]<0){zb(w[d>>2])}f=w[g+4>>2];w[d>>2]=w[g>>2];w[d+4>>2]=f;w[d+8>>2]=w[g+8>>2];d=a+1304448|0;g=Hb(e+72|0,4997);if(u[a+1304459|0]<0){zb(w[d>>2])}f=w[g+4>>2];w[d>>2]=w[g>>2];w[d+4>>2]=f;w[d+8>>2]=w[g+8>>2];w[a+1304496>>2]=4;Vb(e+72|0,2,e+848|4,40);d=a+1304400|0;if(u[a+1304411|0]<0){zb(w[d>>2])}g=w[e+76>>2];w[d>>2]=w[e+72>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+80>>2];d=0;while(1){g=(d<<5)+a|0;f=g+480280|0;Qd(f);h=f;f=(e+848|0)+d|0;w[h>>2]=!x[f+50|0]<<10;v[g+480284>>1]=(x[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}d=y[e+944>>1];if(d){Ik(a+1304424|0,b,d,132,0)}d=jb-16|0;jb=d;f=w[b+8>>2];g=w[b>>2];i=e+72|0;w[d+8>>2]=i;w[d+12>>2]=i+771;f=ob[w[w[g>>2]+32>>2]](g,f,d+8|0)|0;if((f|0)==771){g=w[b>>2];c:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],771)|0){h=w[b+8>>2]+771|0;break c}g=w[b>>2];h=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=h}jb=d+16|0;k=(f|0)==771;if(!k){break b}d=a+484376|0;Pf(w[a+484360>>2]+(x[d|0]<<5)|0,e+72|0,x[e+329|0],255,254);v[(w[a+484360>>2]+(x[d|0]<<5)|0)+28>>1]=x[e+330|0];d=x[e+895|0]|x[e+896|0]<<8;d:{if(d>>>0>z[b+8>>2]){g=w[b>>2];if(ob[w[w[g>>2]+24>>2]](g)>>>0<d>>>0){break d}}w[b+8>>2]=d}l=a+484344|0;n=c&1;o=e+952|4;g=0;e:{f:{while(1){d=(g<<1)+e|0;f=x[d+331|0]|x[d+332|0]<<8;g:{if(!f){break g}oc(e,b,f);f=x[d+331|0]|x[d+332|0]<<8;i=(f-2|0)/64|0;h:{if(!n){break h}w[114256]=0;d=S(216,l|0,g&65535,i|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}if(!d){break h}w[114256]=0;p=Q(241,e|0,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}q=x[e+56|0];d=w[e>>2];h=w[w[d>>2]+36>>2];w[114256]=0;d=S(h|0,d|0,w[e+8>>2],1)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}i:{if(d){d=w[e+8>>2]+1|0;break i}d=w[e>>2];h=w[w[d>>2]+24>>2];w[114256]=0;d=V(h|0,d|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}}w[e+8>>2]=d;if(f>>>0>=66){r=i>>>0<=1?1:i;h=0;while(1){d=w[l>>2];w[114256]=0;d=d+C(g,52)|0;f=V(218,d|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break f}s=w[d>>2]+C(C(f,h),6)|0;j=0;while(1){d=w[e>>2];f=w[w[d>>2]+36>>2];w[114256]=0;f=S(f|0,d|0,w[e+8>>2],4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}d=C(j,6)+s|0;j:{k:{l:{if(!f){w[e+952>>2]=0;break l}w[e+60>>2]=o;w[e+56>>2]=e+952;f=w[e>>2];m=w[w[f>>2]+32>>2];w[114256]=0;f=S(m|0,f|0,w[e+8>>2],e+56|0)|0;m=w[114256];w[114256]=0;if((m|0)==1){break f}w[e+8>>2]=f+w[e+8>>2];f=x[e+952|0];if((f-1&255)>>>0>71){break l}u[d|0]=f+36;u[d+1|0]=x[e+953|0]+1;break k}if(!(x[d|0]|x[e+954|0])){break j}}u[d+2|0]=1;f=x[e+954|0];u[d+4|0]=f?((f>>>0>=16?16:f)<<2)-4|0:0}f=x[e+955|0]&15;u[d+5|0]=f;m:{n:{switch((x[e+955|0]>>>4|0)-3|0){case 0:u[d+5|0]=f<<2;break m;case 1:u[d+5|0]=(6/(f+1>>>0)|0)+1;break m;case 3:case 4:u[d+5|0]=f<<3;break m;case 7:u[d+4|0]=(f<<2)+4;u[d+2|0]=1;break m;case 8:u[d+5|0]=f|128;break m;case 9:break n;default:break m}}u[d+5|0]=(6/(f+1>>>0)|0)+1|13}u[d+3|0]=x[(x[e+955|0]>>>4|0)+23360|0];j=j+1|0;if((j|0)!=16){continue}break}h=h+1|0;if((r|0)!=(h|0)){continue}break}}f=w[l>>2];w[114256]=0;w[e+64>>2]=983039;d=(p?q:0)&255;w[e+60>>2]=d?d>>>0>=i-2>>>0?-1:d+1|0:-1;d=x[e+68|0];w[e+56>>2]=1;u[e+68|0]=d&248|1;Q(271,f+C(g,52)|0,e+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}}d=w[e+4>>2];if(!d){break g}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break g}ob[w[w[d>>2]+8>>2]](d);Ib(d)}g=g+1|0;if((g|0)!=256){continue}break}if(!(c&2)){break b}jq(b,e+48|0);d=0;while(1){o:{p:{if(!(x[e+48+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break p}if(!Zk(b,e)){break b}d=d+1|0;v[a+480190>>1]=d;c=e+56|0;Vb(c,1,e,32);g=y[a+480190>>1];w[114256]=0;w[e+956>>2]=32;w[e+952>>2]=((g<<5)+a|0)+946304;Q(200,e+952|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break o}if(u[e+67|0]<0){zb(w[e+56>>2])}c=(C(d,104)+a|0)+484380|0;lc(c,0);i=x[e+32|0]|x[e+33|0]<<8|(x[e+34|0]<<16|x[e+35|0]<<24);w[c>>2]=i;f=x[e+38|0]|x[e+39|0]<<8|(x[e+40|0]<<16|x[e+41|0]<<24);w[c+4>>2]=f;g=x[e+42|0]|x[e+43|0]<<8|(x[e+44|0]<<16|x[e+45|0]<<24);w[c+24>>2]=16726;w[c+8>>2]=g;v[c+30>>1]=x[e+37|0]<<4;if(u[e+46|0]&1){g=g>>>1|0;w[c+8>>2]=g;f=f>>>1|0;w[c+4>>2]=f;w[c>>2]=i>>>1}if(!(!(x[e+47|0]&8)|f>>>0>=g>>>0)){v[c+34>>1]=y[c+34>>1]|2}u[e+59|0]=0;u[e+57|0]=1;u[e+58|0]=0;u[e+56|0]=u[e+46|0]&1?16:8;Fd(e+56|0,c,b)}if((d|0)!=64){continue}break b}break}d=P()|0;if(u[e+67|0]>=0){break e}zb(w[e+56>>2]);break e}d=P()|0;Bb(e)}R(d|0);M()}jb=e+960|0;return k|0}function Wn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0;a:{if((d-1&255)>>>0>119){break a}i=(C(b,896)+a|0)+1074984|0;b:{c:{f=e;e=y[a+480192>>1];if(!(f|(!(w[a+480180>>2]&17825824)|!e))){break c}f=C(b,896)+a|0;g=w[f+1075640>>2];if((x[g+31|0]-1&255)>>>0<17?g:0){break c}d=f+1075060|0;if(!w[d>>2]){break b}c=C(b,896)+a|0;e=w[c+1075072>>2];if(e&1024){break b}f=c+1075004|0;g=c+1075008|0;if(!(w[f>>2]|w[g>>2])){break b}d:{if(!(e&512)){break d}c=w[a+1304392>>2];if(!c){break d}le(c,b,0);break a}c=pk(a,b);if((c|0)==65535){break b}e=a+1074984|0;c=e+C(c,896)|0;a=Fb(c,i,88);w[a+88>>2]=w[i+88>>2];Fb(a+92|0,i+92|0,576);w[a+668>>2]=w[i+668>>2];Fb(a+672|0,i+672|0,52);u[a+724|0]=x[i+724|0];h=w[i+732>>2];w[a+728>>2]=w[i+728>>2];w[a+732>>2]=h;u[a+736|0]=x[i+736|0];h=w[i+744>>2];w[a+740>>2]=w[i+740>>2];w[a+744>>2]=h;u[a+748|0]=x[i+748|0];h=w[i+756>>2];w[a+752>>2]=w[i+752>>2];w[a+756>>2]=h;Fb(a+760|0,i+760|0,135);u[c+851|0]=0;u[c+827|0]=0;v[c+808>>1]=b+1;v[c+810>>1]=0;v[c+812>>1]=0;v[c+814>>1]=0;w[c+696>>2]=0;w[c+88>>2]=w[c+88>>2]&-3019777|2101248;w[d>>2]=0;w[i>>2]=0;w[i+4>>2]=0;a=e+C(b,896)|0;w[a+92>>2]=0;w[a+96>>2]=0;w[f>>2]=0;w[g>>2]=0;return}j=C(b,896)+a|0;k=w[j+1075088>>2];c=c>>>0<=e>>>0?c:0;n=j+1075640|0;g=w[(c?((c<<2)+a|0)+900380|0:n)>>2];e:{if(!g){break e}e=d-1|0;c=y[((e<<1)+g|0)+236>>1];d=(x[a+1074316|0]&4?u[a+1074325|0]&1:0)?d:x[(e+g|0)+108|0];if((c-1&65535)>>>0<=3998){k=(C(c,104)+a|0)+484380|0;break e}if(!(x[a+1074317|0]&8)){break e}if((x[g+31|0]-1&255)>>>0>16){break b}}if(x[j+1075073|0]&4){break a}if(b>>>0<=255){q=b+1|0;o=a+1074325|0;c=b;while(1){f:{if((b|0)!=(c|0)&y[a+480188>>1]>c>>>0){break f}h=C(c,896)+a|0;if((q|0)!=y[h+1075792>>1]&(b|0)!=(c|0)){break f}p=h+1075640|0;f=w[p>>2];if(!f){break f}l=h+1074984|0;e=f;g:{h:{i:{j:{k:{l:{m:{n:{switch(x[f+17|0]-1|0){case 0:if(!d){break f}m=x[h+1075803|0]==(d|0)&(f|0)==(g|0);if(!g){break m}if(m){break j}break f;case 1:if(!k|w[h+1075088>>2]!=(k|0)){break f}e=g;if((f|0)==(g|0)){break g}e=f;if(!(u[o|0]&1)){break g}break f;case 3:break l;case 2:break n;default:break f}}if(g){break k}m=(f|0)==(g|0)}if(m){break g}break f}if(!g){break f}e=x[g+34|0];if(!e|(e|0)!=x[f+34|0]){break f}break i}if((f|0)!=(g|0)){break f}}if(!x[g+34|0]){break h}}if(!x[h+1075803|0]){break h}e=f;if(x[f+18|0]>2){break g}Ff(a,c&65535,Io(l,(w[a+1074316>>2]&4)>>>2|0)+255|0,0);u[h+1075806|0]=0;e=w[p>>2];break g}e=f}o:{p:{switch(x[e+18|0]){case 0:pg(a,l);w[h+1075672>>2]=0;if(!(x[h+1075073|0]&2)){break o}e=w[a+1304392>>2];if(!e){break o}le(e,c&65535,1);break o;case 1:pg(a,l);if(!(x[h+1075073|0]&2)){break o}e=w[a+1304392>>2];if(!e){break o}Ue(e,c&65535);break o;case 2:break p;default:break o}}f=h+1075072|0;e=w[f>>2];w[f>>2]=e|4096;if(!(e&512)){break o}e=w[a+1304392>>2];if(!e|x[o|0]&2){break o}Ue(e,c&65535)}if(w[h+1075672>>2]){break f}w[h+1075680>>2]=0;e=h+1075072|0;w[e>>2]=w[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}q:{r:{d=w[n>>2];if(!d){break r}e=0;c=0;if((x[d+31|0]-1&255)>>>0>=17){break q}c=0;if((x[(C(b,896)+a|0)+1075803|0]-1&255)>>>0>119){break q}d=Ef(a,b,2,1);c=0;if((d-1&255)>>>0>249){break q}e=w[(C(d,160)+a|0)+906140>>2];if(!e){break r}c=(s=e,t=Io(i,(w[a+1074316>>2]&4)>>>2|0),z=b,r=w[w[e>>2]+96>>2],ob[r](s|0,t|0,z|0)|0);break q}e=0;c=0}if(!c){d=(C(b,896)+a|0)+1074992|0;if(!(w[d>>2]|w[d+4>>2])){break b}}h=pk(a,b);if((h|0)==65535){break b}f=j+1075072|0;j=C(h,896);d=j+a|0;g=d+1075072|0;k=d+1074984|0;s:{if(!(x[d+1075073|0]&2)){break s}d=w[a+1304392>>2];if(!d){break s}le(d,h,1)}k=Fb(k,i,88);l=w[f>>2];f=a+1074984|0;d=f+j|0;f=f+C(b,896)|0;Fb(d+92|0,f+92|0,576);w[d+668>>2]=w[f+668>>2];Fb(d+672|0,f+672|0,52);u[d+724|0]=x[f+724|0];j=w[f+732>>2];w[d+728>>2]=w[f+728>>2];w[d+732>>2]=j;u[d+736|0]=x[f+736|0];j=w[f+744>>2];w[d+740>>2]=w[f+740>>2];w[d+744>>2]=j;u[d+748|0]=x[f+748|0];j=w[f+756>>2];w[d+752>>2]=w[f+752>>2];w[d+756>>2]=j;Fb(d+760|0,f+760|0,135);w[g>>2]=l&-917505;u[d+851|0]=0;j=y[a+480188>>1];u[d+827|0]=0;v[d+808>>1]=b>>>0<j>>>0?b+1|0:0;t:{if(!(c&(e|0)!=0)){break t}c=x[(C(b,896)+a|0)+1075804|0];if(c>>>0>3|(c|0)==1){break t}Ff(a,b,255,0);u[(C(b,896)+a|0)+1075806|0]=0}u:{v:{switch(x[(C(b,896)+a|0)+1075804|0]){case 2:pg(a,k);if(!(x[g+1|0]&2)){break u}c=w[a+1304392>>2];if(!c){break u}Ue(c,b);if(!(x[a+1074325|0]&2)){break u}xk(w[a+1304392>>2],b,h);break u;case 0:w[(C(h,896)+a|0)+1075680>>2]=0;c=w[g>>2];w[g>>2]=c|4096;if(!(c&512)){break u}c=w[a+1304392>>2];if(!c){break u}le(c,b,1);break u;case 3:c=w[g>>2];w[g>>2]=c|4096;if(!(c&512)){break u}c=w[a+1304392>>2];if(!c){break u}if(x[a+1074325|0]&2){xk(c,b,h);break u}Ue(c,b);break u;case 1:break v;default:break u}}if(!(x[g+1|0]&2)){break u}c=w[a+1304392>>2];if(!c){break u}xk(c,b,h)}if(!w[(C(h,896)+a|0)+1075672>>2]){w[(C(h,896)+a|0)+1075680>>2]=0;w[g>>2]=w[g>>2]|2101248}a=C(b,896)+a|0;w[a+1075060>>2]=0;w[i>>2]=0;w[i+4>>2]=0;w[a+1075080>>2]=0;w[f+92>>2]=0}}}function _D(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-320|0;jb=d;w[b+8>>2]=0;a:{if(!Ii(b,d+296|0)){break a}if(!aq(d+296|0)){break a}if(w[d+296>>2]==1179472708){e=w[b>>2];b:{if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],4)|0){e=w[b+8>>2]+4|0;break b}e=w[b>>2];e=ob[w[w[e>>2]+24>>2]](e)|0}w[b+8>>2]=e}e=0;if(!Mc(b,d+288|0)|w[d+288>>2]!=1196314451){break a}if(c){qq(b,d+96|0,w[d+292>>2]);if(y[d+132>>1]>128|y[d+138>>1]>16|(y[d+136>>1]>256|y[d+130>>1]>128)){break a}tc(a,8192);e=a+1304436|0;f=Hb(d+16|0,2868);if(u[a+1304447|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];e=a+1304448|0;f=Hb(d+16|0,6081);if(u[a+1304459|0]<0){zb(w[e>>2])}g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];w[a+1304496>>2]=4;Vb(d+16|0,2,d+96|0,28);e=a+1304400|0;if(u[a+1304411|0]<0){zb(w[e>>2])}f=w[d+20>>2];w[e>>2]=w[d+16>>2];w[e+4>>2]=f;w[e+8>>2]=w[d+24>>2];e=y[d+138>>1];e=e?e:1;v[a+480188>>1]=e;w[a+480196>>2]=x[d+142|0];w[a+480204>>2]=C(x[d+143|0],1e4);f=x[d+140|0];f=f>>>0>=64?64:f;w[a+480200>>2]=f?f<<2:256;f=x[d+141|0];c:{if((f|0)==128){e=256/(e>>>0)|0;e=e>>>0>=128?128:e;break c}e=f&127}w[a+480228>>2]=e;e=0;while(1){f=(e<<5)+a|0;Qd(f+480280|0);g=x[(d+e|0)+144|0];if(g>>>0<=128){v[f+480284>>1]=g<<1}e=e+1|0;if((e|0)!=16){continue}break}Ze(w[a+484360>>2]+(x[a+484376|0]<<5)|0,d+160|0,y[d+132>>1],255,254);e=y[d+130>>1];if(e>>>0<y[d+132>>1]){v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=e}e=1;if(!Mc(b,d+288|0)){break a}l=c&2;i=a+484344|0;m=c&1;n=d+52|0;o=d+312|2;while(1){oc(d+80|0,b,w[d+292>>2]);d:{c=w[d+288>>2];e:{if(!(!m|(c|0)!=1414807888)){w[114256]=0;k=j&65535;c=S(216,i|0,k|0,64)|0;e=w[114256];w[114256]=0;f:{if((e|0)==1){break f}if(!c){break d}c=w[d+80>>2];e=w[w[c>>2]+36>>2];w[114256]=0;c=S(e|0,c|0,w[d+88>>2],2)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}g:{if(c){f=w[d+88>>2]+2|0;break g}c=w[d+80>>2];e=w[w[c>>2]+24>>2];w[114256]=0;f=V(e|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}}w[d+88>>2]=f;c=0;v[d+4>>1]=0;w[d>>2]=0;while(1){e=w[d+80>>2];g=w[w[e>>2]+36>>2];w[114256]=0;e=S(g|0,e|0,f|0,1)|0;f=w[114256];w[114256]=0;h:{i:{j:{k:{l:{m:{n:{if((f|0)!=1){if(!(e&c>>>0<64)){break l}w[114256]=0;e=Q(241,d+80|0,d+16|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(e){f=x[d+16|0];g=f<<24>>24;if(g){break m}}c=c+1|0;break h}b=P()|0;break e}b=P()|0;break e}e=d;o:{p:{q:{h=g&15;r:{if(h>>>0<y[a+480188>>1]){e=w[i>>2];w[114256]=0;e=e+C(k,52)|0;p=V(218,e|0)|0;q=w[114256];w[114256]=0;if((q|0)==1){break r}e=w[e>>2]+C(C(c,p)+h|0,6)|0}s:{if((g|0)>=0){break s}w[114256]=0;g=Q(241,d+80|0,d+16|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break q}if(!g){break s}g=x[d+16|0];if(!g){break s}u[e|0]=g>>>0<109?g+12|0:g}if(!(f&64)){break o}w[114256]=0;g=Q(241,d+80|0,d+16|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){break p}}b=P()|0;break e}b=P()|0;break e}u[e+1|0]=g?x[d+16|0]:0}if(f&32){u[e+2|0]=1;w[114256]=0;g=Q(241,d+80|0,d+16|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}h=x[d+16|0];u[e+4|0]=g?h>>>0>=64?64:h:0}if(!(f&16)){break h}f=w[d+80>>2];g=w[w[f>>2]+36>>2];w[114256]=0;f=S(g|0,f|0,w[d+88>>2],2)|0;g=w[114256];w[114256]=0;t:{u:{v:{w:{x:{if((g|0)==1){break x}if(!f){break j}w[d+20>>2]=o;w[d+16>>2]=d+312;f=w[d+80>>2];g=w[w[f>>2]+32>>2];w[114256]=0;f=S(g|0,f|0,w[d+88>>2],d+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break x}w[d+88>>2]=f+w[d+88>>2];f=x[d+312|0];switch(f-17|0){case 2:break v;case 0:case 1:break w;default:break u}}b=P()|0;break e}f=f&15;break t}v[d+312>>1]=37153;f=33;break i}if(f>>>0<17){break i}f=(f&240)==32?9:-1}u[d+312|0]=f;break i}j=j+1|0;break d}b=P()|0;break e}f=0;v[d+312>>1]=0}u[e+3|0]=f;u[e+5|0]=x[d+313|0];w[114256]=0;X(312,e|0);e=w[114256];w[114256]=0;if((e|0)!=1){break h}b=P()|0;break e}f=w[d+88>>2];continue}}b=P()|0;break e}if((c|0)!=1414745673){break d}c=y[a+480190>>1];if(c>>>0>3998){break d}c=c+1|0;v[a+480190>>1]=c;w[114256]=0;e=Q(313,d+80|0,d+16|0)|0;f=w[114256];w[114256]=0;y:{z:{A:{if((f|0)==1){break A}if(!e){Cb(d+16|0,0,64)}w[114256]=0;e=(C(c&65535,104)+a|0)+484380|0;T(314,d+16|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break A}w[114256]=0;Y(209,d|0,2,n|0,28);c=w[114256];w[114256]=0;if((c|0)==1){break z}c=y[a+480190>>1];w[114256]=0;w[d+316>>2]=32;w[d+312>>2]=((c<<5)+a|0)+946304;Q(200,d+312|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break y}if(u[d+11|0]<0){zb(w[d>>2])}if(!l){break d}w[d>>2]=16777480;f=2;c=x[d+29|0]|x[d+30|0]<<8;B:{if(!(c&64)){f=0;if(!(c&2)){break B}}u[d+3|0]=f}if(c&4){u[d|0]=16}w[114256]=0;S(214,d|0,e|0,d+80|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break d}b=P()|0;break e}b=P()|0;break e}b=P()|0;break e}b=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2])}Bb(d+80|0);R(b|0);M()}c=w[d+84>>2];C:{if(!c){break C}e=w[c+4>>2];w[c+4>>2]=e-1;if(e){break C}ob[w[w[c>>2]+8>>2]](c);Ib(c)}if(Mc(b,d+288|0)){continue}break}}e=1}jb=d+320|0;return e|0}function GD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=jb-704|0;jb=k;a:{b:{if(d>>>0<=511){d=0;l=jb-16|0;jb=l;j=w[b+8>>2];g=w[b>>2];a=k+16|0;w[l+8>>2]=a;w[l+12>>2]=a+554;j=ob[w[w[g>>2]+32>>2]](g,j,l+8|0)|0;if((j|0)==554){a=w[b>>2];c:{if(ob[w[w[a>>2]+36>>2]](a,w[b+8>>2],554)|0){a=w[b+8>>2]+554|0;break c}a=w[b>>2];a=ob[w[w[a>>2]+24>>2]](a)|0}w[b+8>>2]=a}jb=l+16|0;if((j|0)!=554){break b}i=jb-32|0;jb=i;d:{e:{f:{g:{f=k+16|0;h:{if((x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24))!=1229999433){break h}a=i+8|0;Vb(a,3,f+32|0,26);w[114256]=0;w[i+28>>2]=32;w[i+24>>2]=c+492;Q(200,i+24|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break f}if(u[i+19|0]<0){zb(w[i+8>>2])}a=i+8|0;Vb(a,1,f+4|0,13);w[114256]=0;w[i+28>>2]=32;w[i+24>>2]=c+524;Q(200,i+24|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break g}if(u[i+19|0]<0){zb(w[i+8>>2])}a=x[f+24|0]|x[f+25|0]<<8;w[c+4>>2]=64;w[c+8>>2]=128;w[c>>2]=a<<6;u[c+16|0]=x[f+26|0];u[c+17|0]=x[f+27|0];j=c+108|0;d=c+236|0;while(1){b=h<<1;a=b+f|0;g=x[a- -64|0];v[b+d>>1]=x[a+65|0];u[h+j|0]=(g>>>0<120?g:h)+1;h=h+1|0;if((h|0)!=120){continue}break}a=x[c+60|0]&-2|u[f+17|0]&1;u[c+60|0]=a;a=a&-3|x[f+17|0]&2;u[c+60|0]=a;u[c+60|0]=a&251|x[f+17|0]&4;u[c+61|0]=x[f+18|0];u[c+62|0]=x[f+19|0];u[c+63|0]=x[f+20|0];u[c- -64|0]=x[f+21|0];j=c+48|0;Hd(j,25);l=w[c+48>>2];h=0;while(1){i:{d=(h<<2)+l|0;b=h<<1;a=x[(b+f|0)+504|0];v[d>>1]=a;if((a|0)==255){Hd(j,h);l=w[j>>2];break i}u[d+2|0]=x[(f+(b|1)|0)+504|0];h=h+1|0;if((h|0)!=25){continue}}break}d=w[c+52>>2]-l>>2;b=x[c+61|0];a=x[c+62|0];if(d>>>0<=(a>>>0<b>>>0?b:a)>>>0){u[c+60|0]=x[c+60|0]&253}b=x[c+63|0];a=x[c+64|0];if(d>>>0>(a>>>0<b>>>0?b:a)>>>0){break h}u[c+60|0]=x[c+60|0]&251}jb=i+32|0;break d}h=P()|0;if(u[i+19|0]>=0){break e}zb(w[i+8>>2]);break e}h=P()|0;if(u[i+19|0]>=0){break e}zb(w[i+8>>2])}R(h|0);M()}d=554;break b}j=w[b+8>>2];e=k+16|0;h=674;d=w[b>>2];j:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],674)|0){l=w[b+8>>2];break j}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;l=w[b+8>>2];h=d-l|0}d=w[b>>2];ob[w[w[d>>2]+28>>2]](d,e,l,h)|0;Cb(e+h|0,0,674-h|0);d=w[b>>2];k:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],674)|0){d=w[b+8>>2]+674|0;break k}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d;d=w[a+480180>>2];f=jb-32|0;jb=f;l:{m:{if((x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24))==1229999433){a=f+8|0;Vb(a,3,e+32|0,26);w[114256]=0;w[f+28>>2]=32;w[f+24>>2]=c+492;Q(200,f+24|0,a|0)|0;a=w[114256];w[114256]=0;n:{o:{p:{q:{r:{if((a|0)!=1){if(u[f+19|0]<0){zb(w[f+8>>2])}a=f+8|0;Vb(a,1,e+4|0,13);w[114256]=0;w[f+28>>2]=32;w[f+24>>2]=c+524;Q(200,f+24|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break r}if(u[f+19|0]<0){zb(w[f+8>>2])}w[c>>2]=(x[e+20|0]|x[e+21|0]<<8)<<5;a=x[e+24|0]>>>1|0;w[c+4>>2]=a>>>0>=64?64:a;a=x[e+25|0]&127;w[c+8>>2]=a>>>0>64?128:a<<2;u[c+15|0]=x[c+15|0]&254|((x[e+25|0]^-1)&128)>>>7;a=x[e+26|0];u[c+20|0]=a>>>0>=100?100:a;a=x[e+27|0];u[c+19|0]=a>>>0>=64?64:a;u[c+16|0]=x[e+17|0];u[c+17|0]=x[e+18|0];u[c+18|0]=x[e+19|0];u[c+26|0]=x[e+22|0];u[c+27|0]=x[e+23|0];u[c+21|0]=x[e+58|0];u[c+22|0]=x[e+59|0];s:{t:{a=x[e+28|0]|x[e+29|0]<<8;switch(a-529|0){case 1:case 2:break q;case 0:case 3:break s;default:break t}}if((a|0)==514){break s}if((a|0)!=544){break q}}a=x[e+61|0];if((a|0)==255){break p}if(a>>>0<=128){u[c+30|0]=a}g=x[e+62|0]|x[e+63|0]<<8;if(g>>>0<129){break o}break n}g=P()|0;if(u[f+19|0]>=0){break m}zb(w[f+8>>2]);break m}g=P()|0;if(u[f+19|0]>=0){break m}zb(w[f+8>>2]);break m}a=u[e+61|0];if((a|0)<0){break p}u[c+30|0]=a+1}a=u[e+63|0];g=(a|0)>=0?(a&255)<<7:0;a=x[e+62|0];g=g+(a<<24>>24>=0?a+1|0:0)|0}v[c+28>>1]=g}a=u[e+60|0];u[c+31|0]=a;if((a|0)<0){u[c+31|0]=0;u[c+34|0]=a^128}g=0;a=d&16777216?240:25;Nl(e+304|0,c+48|0,0,a);Nl(e+386|0,c+68|0,32,a);Nl(e+468|0,c+88|0,32,a);u[c+100|0]=x[c+100|0]&239|x[e+468|0]>>>3&16;i=c+108|0;l=c+236|0;while(1){d=g<<1;a=d+e|0;h=x[a- -64|0];v[d+l>>1]=x[a+65|0];u[g+i|0]=(h>>>0<120?h:g)+1;g=g+1|0;if((g|0)!=120){continue}break}g=554}jb=f+32|0;a=g;break l}R(g|0);M()}if(a){d=x[e+550|0]|x[e+551|0]<<8|(x[e+552|0]<<16|x[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){g=c+236|0;a=0;while(1){d=g+(a<<1)|0;v[d>>1]=y[d>>1]|x[(a+e|0)+554|0]<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;j=j+a|0;u:{if(j>>>0>z[b+8>>2]){a=w[b>>2];if(ob[w[w[a>>2]+24>>2]](a)>>>0<j>>>0){break u}}w[b+8>>2]=j}if(!gd(b,9722,4)){break b}a=Nc(b,k+696|0);oc(k,b,a?w[k+696>>2]:0);b=w[k>>2];a=w[w[b>>2]+24>>2];w[114256]=0;j=V(a|0,b|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}w[114256]=0;b=S(343,k|0,9526,4)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}if(b){w[114256]=0;b=Q(241,k|0,k+696|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}a=b?x[k+696|0]:0;u[c+34|0]=(a&255)>>>0<=250?a:0}b=d+j|0;c=w[k+4>>2];v:{if(!c){break v}a=w[c+4>>2];w[c+4>>2]=a-1;if(a){break v}ob[w[w[c>>2]+8>>2]](c);Ib(c)}d=b+8|0}jb=k+704|0;return d|0}a=P()|0;Bb(k);R(a|0);M()}function nE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-736|0;jb=e;w[b+8>>2]=0;f=jb-16|0;jb=f;h=w[b+8>>2];g=w[b>>2];i=e+120|0;w[f+8>>2]=i;w[f+12>>2]=i+610;h=ob[w[w[g>>2]+32>>2]](g,h,f+8|0)|0;if((h|0)==610){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],610)|0){g=w[b+8>>2]+610|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=f+16|0;b:{if((h|0)!=610){break b}if(!hq(e+120|0)){break b}c:{if(!c){break c}tc(a,67108864);je(a);d=x[e+145|0];v[a+480190>>1]=31;v[a+480188>>1]=d;w[a+480228>>2]=256/(d>>>0);d=a+1304436|0;f=Hb(e,4364);if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=a+1304448|0;f=Hb(e,6703);if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=Hb(e+104|0,10787);g=w[d>>2];w[e+76>>2]=w[d+4>>2];f=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[e+79|0]=f;u[e+80|0]=f>>>8;u[e+81|0]=f>>>16;u[e+82|0]=f>>>24;w[d>>2]=0;w[d+4>>2]=0;f=x[d+11|0];w[d+8>>2]=0;w[114256]=0;w[e+72>>2]=g;u[e+83|0]=f;f=x[e+144|0];w[e+96>>2]=f>>>4;w[e+92>>2]=f&15;Y(292,e|0,e+72|0,e+96|0,e+92|0);f=w[114256];w[114256]=0;d:{if((f|0)!=1){f=a+1304460|0;if(u[a+1304471|0]<0){zb(w[f>>2])}g=w[e+4>>2];w[f>>2]=w[e>>2];w[f+4>>2]=g;w[f+8>>2]=w[e+8>>2];u[e+11|0]=0;u[e|0]=0;if(u[e+83|0]<0){zb(w[e+72>>2])}if(u[d+11|0]<0){zb(w[d>>2])}w[a+1304496>>2]=2;Ze(w[a+484360>>2]+(x[a+484376|0]<<5)|0,e+168|0,x[e+167|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;h=C(d,104)+a|0;j=h+484380|0;lc(j,1);g=(e+120|0)+(f<<2)|0;i=x[g+176|0]|x[g+177|0]<<8|(x[g+178|0]<<16|x[g+179|0]<<24);w[j>>2]=i<<24|i<<8&16711680|(i>>>8&65280|i>>>24);i=x[g+300|0]|x[g+301|0]<<8|(x[g+302|0]<<16|x[g+303|0]<<24);i=i<<24|i<<8&16711680|(i>>>8&65280|i>>>24);w[h+484384>>2]=i;g=x[g+424|0]|x[g+425|0]<<8|(x[g+426|0]<<16|x[g+427|0]<<24);w[h+484388>>2]=i+(g<<24|g<<8&16711680|(g>>>8&65280|g>>>24));if(g){g=h+484414|0;v[g>>1]=y[g>>1]|2}tg(j);f=(e+120|0)+f|0;g=x[f+548|0];v[h+484410>>1]=(g>>>0>=64?64:g)<<2;u[h+484417|0]=x[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}Ki(b,a+1304400|0,32);d=1;while(1){gq(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}l=c&1;if(l){td(a+484344|0,x[e+166|0]+1|0)}j=a+484344|0;d=0;e:{while(1){g=d;d=Kb(16);w[d+4>>2]=0;w[d+8>>2]=0;w[d+12>>2]=75696;w[d>>2]=75656;w[e+80>>2]=0;w[e+84>>2]=0;w[e+76>>2]=d;w[e+72>>2]=d+12;f:{if(x[e+146|0]){w[114256]=0;d=Q(261,b|0,e+96|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}h=0;if(d){d=y[e+96>>1];h=d<<8|d>>>8}w[114256]=0;U(188,e|0,b|0,h&65535);d=w[114256];w[114256]=0;if((d|0)==1){break e}f=w[e>>2];h=w[e+4>>2];w[e>>2]=0;w[e+4>>2]=0;d=w[e+76>>2];w[e+72>>2]=f;w[e+76>>2]=h;if(!d){d=w[e+12>>2];w[e+80>>2]=w[e+8>>2];w[e+84>>2]=d;break f}f=w[d+4>>2];w[d+4>>2]=f-1;if(!f){ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[e+12>>2];w[e+80>>2]=w[e+8>>2];w[e+84>>2]=d;d=w[e+4>>2];if(!d){break f}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break f}ob[w[w[d>>2]+8>>2]](d);Ib(d);break f}d=y[a+480188>>1];w[114256]=0;U(188,e|0,b|0,d<<8);d=w[114256];w[114256]=0;if((d|0)==1){break e}f=w[e>>2];h=w[e+4>>2];w[e>>2]=0;w[e+4>>2]=0;d=w[e+76>>2];w[e+72>>2]=f;w[e+76>>2]=h;if(!d){d=w[e+12>>2];w[e+80>>2]=w[e+8>>2];w[e+84>>2]=d;break f}f=w[d+4>>2];w[d+4>>2]=f-1;if(!f){ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[e+12>>2];w[e+80>>2]=w[e+8>>2];w[e+84>>2]=d;d=w[e+4>>2];if(!d){break f}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break f}ob[w[w[d>>2]+8>>2]](d);Ib(d)}g:{if(!l){break g}w[114256]=0;d=S(216,j|0,g&65535,64)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}if(!d){break g}if(!x[e+146|0]){f=0;if(!y[a+480188>>1]){break g}while(1){d=0;while(1){h=w[j>>2];w[114256]=0;h=h+C(g,52)|0;i=V(218,h|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break e}h=w[h>>2];w[114256]=0;T(293,e+72|0,h+C(C(d,i)+f|0,6)|0);h=w[114256];w[114256]=0;if((h|0)==1){break e}d=d+1|0;if((d|0)!=64){continue}break}f=f+1|0;if(f>>>0<y[a+480188>>1]){continue}break}break g}i=0;w[114256]=0;Q(294,e+72|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}while(1){d=w[j>>2];w[114256]=0;d=d+C(g,52)|0;h=V(218,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}f=y[a+480188>>1];if(f){k=w[d>>2]+C(C(h,i),6)|0;m=e+i|0;d=128;h=0;while(1){if(x[m|0]&d){w[114256]=0;T(293,e+72|0,k+C(h,6)|0);f=w[114256];w[114256]=0;if((f|0)==1){break e}f=y[a+480188>>1]}d=d>>>1|0;h=h+1|0;if(h>>>0<(f&65535)>>>0){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}d=w[e+76>>2];h:{if(!d){break h}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break h}ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=g+1|0;if(g>>>0<x[e+166|0]){continue}break}d=1;if(!(c&2)){break b}w[e>>2]=65800;while(1){Fd(e,(C(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break c}h=P()|0;Bb(e+72|0);break d}h=P()|0;if(u[e+83|0]<0){zb(w[e+72>>2])}if(u[d+11|0]>=0){break d}zb(w[d>>2])}R(h|0);M()}d=1}jb=e+736|0;return d|0}function fP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-176|0;jb=d;w[d+148>>2]=0;w[d+140>>2]=0;w[d+144>>2]=0;w[d+136>>2]=82216;w[w[a+24>>2]+1304560>>2]=d+136;f=w[a+24>>2];h=x[a+62|0];j=x[a+61|0];k=x[a+60|0];w[d+120>>2]=w[b>>2];e=w[b+4>>2];w[d+124>>2]=e;k=k?13:15;j=j?k&14:k;h=h?j&3:j;if(e){w[e+4>>2]=w[e+4>>2]+1}l=d+136|4;e=w[b+12>>2];b=w[b+8>>2];w[114256]=0;w[d+128>>2]=b;w[d+132>>2]=e;w[d+8>>2]=b;w[d+12>>2]=e;b=w[d+124>>2];w[d>>2]=w[d+120>>2];w[d+4>>2]=b;b=S(1450,f|0,d|0,h|0)|0;e=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}if(!b){c=ba(8)|0;w[114256]=0;a=Q(5,d+152|0,7813)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=Pb(c,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break e}b=P()|0;if(u[a+11|0]>=0){break a}zb(w[a>>2]);break a}b=P()|0;ca(c|0);break a}if(!x[a+63|0]){w[114256]=0;T(1451,a|0,a+36|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}}u[a+28|0]=1;w[w[a+24>>2]+1304560>>2]=w[a+4>>2];w[114256]=0;j=Q(1452,d+104|0,l|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}h=w[j>>2];n=w[j+4>>2];if((h|0)==(n|0)){break c}q=a+76|0;o=a+68|0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{while(1){q:{b=w[h>>2];w[114256]=0;e=h+4|0;U(1453,a|0,b|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break q}b=w[h>>2]-1|0;if(b>>>0>4){b=5613}else{b=w[(b<<2)+82604>>2]}w[114256]=0;m=Q(1,d+48|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}w[114256]=0;U(9,d- -64|0,0,m|0);b=w[114256];w[114256]=0;if((b|0)==1){break o}w[114256]=0;k=Q(5,d+32|0,13499)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}b=w[k>>2];w[114256]=0;g=b;b=x[d+43|0];f=b<<24>>24<0;b=S(92,d- -64|0,(f?g:k)|0,(f?w[d+36>>2]:b)|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break m}w[d+88>>2]=w[b+8>>2];f=w[b+4>>2];w[d+80>>2]=w[b>>2];w[d+84>>2]=f;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;f=w[h+8>>2];i=w[h+4>>2];b=x[h+15|0];w[114256]=0;g=e;e=b<<24>>24<0;b=S(92,d+80|0,(e?i:g)|0,(e?f:b)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}e=w[b>>2];w[d+96>>2]=w[b+4>>2];f=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+99|0]=f;u[d+100|0]=f>>>8;u[d+101|0]=f>>>16;u[d+102|0]=f>>>24;w[b>>2]=0;w[b+4>>2]=0;f=u[b+11|0];w[b+8>>2]=0;b=w[a+72>>2];i=w[a+76>>2];r:{if(b>>>0<i>>>0){w[b>>2]=e;w[b+4>>2]=w[d+96>>2];e=x[d+99|0]|x[d+100|0]<<8|(x[d+101|0]<<16|x[d+102|0]<<24);u[b+7|0]=e;u[b+8|0]=e>>>8;u[b+9|0]=e>>>16;u[b+10|0]=e>>>24;u[b+11|0]=f;w[a+72>>2]=b+12;break r}g=w[o>>2];p=(b-g|0)/12|0;b=p+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,o|0);a=w[114256];w[114256]=0;if((a|0)==1){break k}break e}w[114256]=0;i=(i-g|0)/12|0;g=i<<1;i=Z(921,d+152|0,(i>>>0>=178956970?357913941:b>>>0<g>>>0?g:b)|0,p|0,q|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}b=w[d+160>>2];w[b>>2]=e;w[b+4>>2]=w[d+96>>2];e=x[d+99|0]|x[d+100|0]<<8|(x[d+101|0]<<16|x[d+102|0]<<24);u[b+7|0]=e;u[b+8|0]=e>>>8;u[b+9|0]=e>>>16;u[b+10|0]=e>>>24;u[b+11|0]=f;u[d+99|0]=0;u[d+100|0]=0;u[d+101|0]=0;u[d+102|0]=0;w[d+96>>2]=0;g=w[d+160>>2]+12|0;w[d+160>>2]=g;e=w[d+156>>2];b=w[a+72>>2];f=w[a+68>>2];s:{if((b|0)==(f|0)){b=f;break s}while(1){b=b-12|0;g=w[b+4>>2];e=e-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=g;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[d+156>>2]-12|0;w[d+156>>2]=e;if((b|0)!=(f|0)){continue}break}f=w[a+72>>2];g=w[d+160>>2];b=w[a+68>>2]}w[a+68>>2]=e;w[d+156>>2]=b;w[a+72>>2]=g;w[d+160>>2]=f;e=w[a+76>>2];w[a+76>>2]=w[d+164>>2];w[d+164>>2]=e;w[i>>2]=b;sc(i)}if(u[d+91|0]<0){zb(w[d+80>>2])}if(u[d+43|0]<0){zb(w[k>>2])}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+59|0]<0){zb(w[m>>2])}h=h+16|0;if((n|0)!=(h|0)){continue}break c}break}b=P()|0;break b}b=P()|0;break b}b=P()|0;break g}b=P()|0;break h}b=P()|0;break i}b=P()|0;break j}b=P()|0;if((f|0)>=0){break j}zb(e)}if(u[d+91|0]>=0){break i}zb(w[d+80>>2])}if(u[d+43|0]>=0){break h}zb(w[k>>2])}if(u[d+75|0]>=0){break g}zb(w[d+64>>2])}if(u[d+59|0]>=0){break b}zb(w[m>>2]);break b}b=P()|0;break a}M()}b=P()|0;break a}t:{u:{e=w[c>>2];c=c+4|0;if((e|0)!=(c|0)){while(1){v:{if(u[e+27|0]>=0){w[d+24>>2]=w[e+24>>2];b=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=b;break v}b=w[e+20>>2];f=w[e+16>>2];w[114256]=0;U(76,d+16|0,f|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break u}}w[114256]=0;Y(1400,a|0,d+16|0,e+28|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break t}if(u[d+27|0]<0){zb(w[d+16>>2])}f=w[e+4>>2];w:{if(f){while(1){b=f;f=w[b>>2];if(f){continue}break w}}while(1){b=w[e+8>>2];f=w[b>>2]!=(e|0);e=b;if(f){continue}break}}e=b;if((b|0)!=(c|0)){continue}break}}Ug(j);w[d+136>>2]=82216;Ug(l);jb=d+176|0;return}b=P()|0;break b}b=P()|0;if(u[d+27|0]>=0){break b}zb(w[d+16>>2])}Ug(j)}w[d+136>>2]=82216;Ug(l);R(b|0);M()}function dv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-96|0;jb=e;g=w[b+4>>2];a:{if(!g){break a}h=w[b>>2];f=g-1|0;i=x[h+f|0];if((i|0)==33){d=1}else{if((i|0)!=63){break a}d=0}w[b>>2]=h;w[b+4>>2]=f>>>0>g>>>0?g:f}f=82096;h=w[b+4>>2];i=h;g=w[b>>2];b:{c:{d:{e:{f:{g:{while(1){h:{j=w[f>>2];if((ec(j)|0)==(h|0)){if(!h){break h}if(!Jb(j,g,h)){break h}}f=f+8|0;if((f|0)!=82200){continue}break g}break}if((f|0)!=82200){break f}}if(!i){d=ba(8)|0;w[114256]=0;b=Q(1447,e+80|0,c|0)|0;a=w[114256];w[114256]=0;i:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}f=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[b+11|0]>=0){break e}zb(w[b>>2]);break e}f=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2]);break i}f=P()|0}ca(d|0);break e}if(!d){break b}h=ba(8)|0;w[114256]=0;g=Q(1447,e+48|0,b|0)|0;a=w[114256];w[114256]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){w[114256]=0;a=S(1436,g|0,0,13399)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}w[e+72>>2]=w[a+8>>2];b=w[a+4>>2];w[e+64>>2]=w[a>>2];w[e+68>>2]=b;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;a=Q(1315,e- -64|0,13373)|0;b=w[114256];w[114256]=0;d=1;if((b|0)==1){break q}w[e+88>>2]=w[a+8>>2];b=w[a+4>>2];w[e+80>>2]=w[a>>2];w[e+84>>2]=b;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;a=Q(1447,e+32|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break p}c=w[a>>2];d=w[a+4>>2];b=x[a+11|0];w[114256]=0;i=c;c=b<<24>>24<0;b=S(92,e+80|0,(c?i:a)|0,(c?d:b)|0)|0;c=w[114256];w[114256]=0;d=1;if((c|0)==1){break o}w[e+16>>2]=w[b+8>>2];c=w[b+4>>2];w[e+8>>2]=w[b>>2];w[e+12>>2]=c;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;b=Pb(h,e+8|0);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break d}f=P()|0;d=0;if(u[e+19|0]>=0){break n}zb(w[e+8>>2]);break n}f=P()|0;break j}f=P()|0;break l}f=P()|0;break m}f=P()|0}if(u[a+11|0]>=0){break m}zb(w[a>>2])}if(u[e+91|0]>=0){break l}zb(w[e+80>>2])}if(u[e+75|0]<0){zb(w[e+64>>2])}if(u[g+11|0]<0){zb(w[g>>2])}if(d){break j}break e}f=P()|0;if(u[g+11|0]>=0){break j}zb(w[g>>2])}ca(h|0);break e}r:{if((h|0)!=11){if((h|0)==35){break r}if(h){break b}d=ba(8)|0;w[114256]=0;b=Q(1447,e+80|0,c|0)|0;a=w[114256];w[114256]=0;s:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}f=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[b+11|0]>=0){break e}zb(w[b>>2]);break e}f=P()|0;if(u[b+11|0]>=0){break s}zb(w[b>>2]);break s}f=P()|0}ca(d|0);break e}if(Jb(g,8127,11)){break b}b=w[c>>2];t:{u:{v:{w:{d=w[c+4>>2];switch(d-4|0){case 0:break u;case 4:break v;case 3:break w;default:break t}}if(Jb(b,2087,7)){break t}w[a+52>>2]=0;break b}if(Jb(b,7124,d)){break t}w[a+52>>2]=1;break b}if(Jb(b,5136,d)){break t}w[a+52>>2]=2;break b}d=ba(8)|0;w[114256]=0;b=Q(1447,e+80|0,c|0)|0;a=w[114256];w[114256]=0;x:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,10072)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}f=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[b+11|0]>=0){break e}zb(w[b>>2]);break e}f=P()|0;if(u[b+11|0]>=0){break x}zb(w[b>>2]);break x}f=P()|0}ca(d|0);break e}if(Jb(g,7361,h)){break b}b=w[c>>2];y:{z:{A:{B:{C:{c=w[c+4>>2];switch(c-4|0){case 6:break A;case 1:break B;case 0:break C;default:break y}}if((x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24))!=808465761){break z}b=1;f=0;break c}if(Jb(b,11539,c)){break y}b=2;f=1;break c}if(Jb(b,8386,c)){break y}b=3;f=2;break c}if(Jb(b,5200,c)){break y}b=2;f=3;break c}b=ba(8)|0;w[114256]=0;a=Q(5,e+8|0,7397)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break d}f=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}f=P()|0;ca(b|0)}R(f|0)}M()}w[a+56>>2]=f;a=w[a+24>>2];c=w[a+24668>>2];if(!c){break b}d=a+24664|0;g=w[d+4>>2];w[e+24>>2]=w[d>>2];w[e+28>>2]=g;d=a+24656|0;g=w[d+4>>2];w[e+16>>2]=w[d>>2];w[e+20>>2]=g;g=w[a+24652>>2];f=w[a+24648>>2];w[e+8>>2]=f;w[e+12>>2]=g;w[e+28>>2]=b;if(!(x[a+24648|0]!=(f&255)|B[e+16>>3]!=B[d>>3]|x[e+24|0]!=x[a+24664|0])){if((b|0)==(c|0)){break b}}dk(a,e+8|0)}jb=e+96|0}function Yu(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb+-64|0;jb=g;a:{b:{c:{if(c>>>0>65535){break c}i=w[b+24>>2];h=w[i+484344>>2];if(((w[i+484348>>2]-h|0)/52&65535)>>>0<=(c&65535)>>>0){break c}j=h+C(c,52)|0;if(w[j>>2]!=w[j+4>>2]){break b}}w[a>>2]=0;w[a+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+8>>2]=0;w[a+20>>2]=0;break a}d:{if((d|0)>=0){h=h+C(c,52)|0;if(w[h+12>>2]>(d|0)){break d}}w[a>>2]=0;w[a+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+8>>2]=0;w[a+20>>2]=0;break a}if(!(y[i+480188>>1]>e>>>0&(e|0)>=0)){w[a>>2]=0;w[a+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+8>>2]=0;w[a+20>>2]=0;break a}if(f>>>0>=6){w[a>>2]=0;w[a+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+8>>2]=0;w[a+20>>2]=0;break a}c=C(ld(h),d)+(e&65535)|0;d=w[h>>2];e=C(c,6)+d|0;e:{f:{g:{switch(f|0){case 0:h:{i:{j:{f=x[e|0];h=f>>>0>250|(f-1&255)>>>0<120;k:{if(h){i=g+24|0;yn(i,w[b+24>>2],f,x[(d+C(c,6)|0)+1|0]);w[114256]=0;U(9,g+40|0,0,i|0);b=w[114256];w[114256]=0;if((b|0)!=1){break k}a=P()|0;break h}w[114256]=0;Q(5,g+40|0,12594)|0;b=w[114256];w[114256]=0;if((b|0)==1){break j}}b=x[e|0];w[114256]=0;b=Q(5,g+8|0,((b-1&255)>>>0<120?5913:b>>>0>250?6218:12594)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[g+44>>2];w[a>>2]=w[g+40>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+48>>2];w[g+48>>2]=0;w[g+40>>2]=0;w[g+44>>2]=0;w[a+20>>2]=w[b+8>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;if(!h|u[g+35|0]>=0){break a}zb(w[g+24>>2]);break a}a=P()|0;break f}a=P()|0;if(u[g+51|0]<0){zb(w[g+40>>2])}if(!h){break f}}if(u[g+35|0]>=0){break f}zb(w[g+24>>2]);break f;case 1:c=d+C(c,6)|0;b=c+1|0;l:{if(x[c+1|0]){u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=2;$j(g+24|0,b,g+40|0);break l}Hb(g+24|0,12599)}b=x[b|0];w[114256]=0;b=Q(5,g+40|0,(b?6700:12599)|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[g+28>>2];w[a>>2]=w[g+24>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+32>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;w[a+20>>2]=w[b+8>>2];break a}a=P()|0;if(u[g+35|0]>=0){break f}zb(w[g+24>>2]);break f;case 2:m:{if((x[e|0]+5&255)>>>0<=1){Hb(g+40|0,13546);break m}f=x[(d+C(c,6)|0)+2|0];if(f){b=qw(w[w[b+24>>2]+8>>2],f);u[g+41|0]=0;u[g+40|0]=b;u[g+51|0]=1;break m}Hb(g+40|0,13546)}b=(x[e|0]+5&255)>>>0<2?13546:x[(d+C(c,6)|0)+2|0]?1991:13546;w[114256]=0;b=Q(5,g+24|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[g+44>>2];w[a>>2]=w[g+40>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+48>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;w[a+20>>2]=w[b+8>>2];break a}a=P()|0;if(u[g+51|0]>=0){break f}zb(w[g+40>>2]);break f;case 4:n:{if((x[e|0]+5&255)>>>0<=1){w[g+8>>2]=x[(d+C(c,6)|0)+4|0];u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=2;ln(g+24|0,g+8|0,g+40|0);break n}b=d+C(c,6)|0;if(x[b+2|0]){u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=2;$j(g+24|0,b+4|0,g+40|0);break n}Hb(g+24|0,12599)}b=(x[e|0]+5&255)>>>0<2?1975:x[(d+C(c,6)|0)+2|0]?1975:12599;w[114256]=0;b=Q(5,g+40|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[g+28>>2];w[a>>2]=w[g+24>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+32>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;w[a+20>>2]=w[b+8>>2];break a}a=P()|0;if(u[g+35|0]>=0){break f}zb(w[g+24>>2]);break f;case 3:f=x[(d+C(c,6)|0)+3|0];o:{if((x[e|0]+5&255)>>>0<=1){u[g+8|0]=(f&15)!=0;u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=1;b=jb-16|0;jb=b;w[b+12>>2]=x[g+8|0];ek(g+24|0,b+12|0,g+40|0);jb=b+16|0;break o}if(f){b=pw(w[w[b+24>>2]+8>>2],f);u[g+25|0]=0;u[g+24|0]=b;u[g+35|0]=1;break o}Hb(g+24|0,12600)}b=(x[e|0]+5&255)>>>0<2?8090:x[(d+C(c,6)|0)+3|0]?8090:12600;w[114256]=0;b=Q(5,g+40|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[g+28>>2];w[a>>2]=w[g+24>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+32>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;w[a+20>>2]=w[b+8>>2];break a}a=P()|0;if(u[g+35|0]>=0){break f}zb(w[g+24>>2]);break f;case 5:break g;default:break e}}p:{if((x[e|0]+5&255)>>>0<=1){w[g+8>>2]=x[(d+C(c,6)|0)+5|0];u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=2;ln(g+24|0,g+8|0,g+40|0);break p}b=d+C(c,6)|0;if(x[b+3|0]){u[g+56|0]=44;w[g+48>>2]=-1;w[g+52>>2]=0;w[g+40>>2]=1058;w[g+44>>2]=2;$j(g+24|0,b+5|0,g+40|0);break p}Hb(g+24|0,12599)}b=(x[e|0]+5&255)>>>0<2?6987:x[(d+C(c,6)|0)+3|0]?6987:12599;w[114256]=0;b=Q(5,g+40|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){c=w[g+28>>2];w[a>>2]=w[g+24>>2];w[a+4>>2]=c;w[a+8>>2]=w[g+32>>2];c=w[b+4>>2];w[a+12>>2]=w[b>>2];w[a+16>>2]=c;w[a+20>>2]=w[b+8>>2];break a}a=P()|0;if(u[g+35|0]>=0){break f}zb(w[g+24>>2])}R(a|0);M()}w[a>>2]=0;w[a+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+8>>2]=0;w[a+20>>2]=0}jb=g- -64|0}function mS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=jb-288|0;jb=d;w[a>>2]=0;i=a+32|0;Vj(i,32);a:{e=w[a+36>>2];m=w[a+40>>2];if(e>>>0<m>>>0){u[e|0]=0;w[a+36>>2]=e+1;break a}f=w[i>>2];h=e-f|0;j=h+1|0;if((j|0)>=0){e=0;i=m-f|0;m=i<<1;i=i>>>0>=1073741823?2147483647:j>>>0<m>>>0?m:j;if(i){e=Kb(i)}j=e+h|0;u[j|0]=0;if((h|0)>0){Fb(e,f,h)}w[a+40>>2]=e+i;w[a+36>>2]=j+1;w[a+32>>2]=e;if(f){zb(f)}break a}Mb(i);M()}e=w[a+28>>2];b:{if(w[(w[w[e>>2]-12>>2]+e|0)+16>>2]){w[a>>2]=w[a>>2]|1073741825;break b}rd(d+16|0,e);e=w[d+28>>2];w[a+8>>2]=w[d+24>>2];w[a+12>>2]=e;w[d+16>>2]=3;f=w[a+28>>2];e=jb-16|0;jb=e;if(w[d+16>>2]){h=e+8|0;while(1){u[e+7|0]=0;w[e+12>>2]=h;w[e+8>>2]=e+7;Ob(f,e+8|0);u[d+l|0]=x[e+7|0];l=l+1|0;if(l>>>0<z[d+16>>2]){continue}break}}jb=e+16|0;if(Jb(d,22592,3)){w[a>>2]=w[a>>2]|1073741827;break b}e=w[a+28>>2];u[d|0]=0;w[d+20>>2]=d+1;w[d+16>>2]=d;f=d+16|0;Ob(e,f);e=x[d|0];Cb(f,0,256);if(e){sf(w[a+28>>2],d+16|0,e)}else{e=0}h=b;b=Uj(d,f,e);f=Yd(h,b);if(u[b+11|0]<0){zb(w[b>>2])}e=w[a>>2];if(!f){e=e|1073741830;w[a>>2]=e}if(e&1073741824){break b}b=w[a+28>>2];u[d+287|0]=0;e=d+288|0;w[d+4>>2]=e;w[d>>2]=d+287;Ob(b,d);i=x[d+287|0];b=i&3;v[a+16>>1]=(b|0)==3?4:b;if(i&64){w[a+24>>2]=w[a+24>>2]|512}f=w[a+28>>2];u[d+287|0]=0;w[d+4>>2]=e;w[d>>2]=d+287;Ob(f,d);e=x[d+287|0];b=e>>>2|0;h=e&3;if(h){j=d+288|0;e=0;while(1){u[d+287|0]=0;w[d+4>>2]=j;w[d>>2]=d+287;Ob(f,d);e=e+1|0;b=x[d+287|0]<<(e<<3)-2|b;if((e|0)!=(h|0)){continue}break}}j=0;if(b>>>0>=2){e=w[a+28>>2];u[d+287|0]=0;f=d+288|0;w[d+4>>2]=f;w[d>>2]=d+287;Ob(e,d);e=-1;if(!x[d+287|0]){e=w[a+28>>2];u[d+287|0]=0;w[d+4>>2]=f;w[d>>2]=d+287;Ob(e,d);j=x[d+287|0];e=-2}cg(w[a+28>>2],b+e|0,-1)}c:{if(!(i&16)){break c}m=w[a+28>>2];u[d+287|0]=0;n=d+288|0;w[d+4>>2]=n;w[d>>2]=d+287;Ob(m,d);b=x[d+287|0];e=(b&252)>>>2|0;h=0;b=b&3;if(b){b=-1<<b;o=(b>>>0>=4294967294?-2:b)^-1;while(1){u[d+287|0]=0;w[d+4>>2]=n;w[d>>2]=d+287;Ob(m,d);f=x[d+287|0];b=g;g=k+1|0;b=g?b:b+1|0;k=g;g=b;b=(k<<3)-2|0;l=b&31;if((b&63)>>>0>=32){b=f<<l;f=0}else{b=(1<<l)-1&f>>>32-l;f=f<<l}e=f|e;h=b|h;if((k|0)!=(o|0)|g){continue}break}}w[a+56>>2]=e;w[a+60>>2]=h;b=w[c+4>>2];if((b|0)==(h|0)&z[c>>2]>=e>>>0|b>>>0>h>>>0){break c}w[a>>2]=w[a>>2]|536871424}if(i&32){b=w[a+28>>2];u[d+287|0]=0;w[d+4>>2]=d+288;w[d>>2]=d+287;Ob(b,d);cg(w[a+28>>2],x[d+287|0],-1)}d:{if(!(j&1)){break d}b=w[a+28>>2];u[d+287|0]=0;w[d+4>>2]=d+288;w[d>>2]=d+287;Ob(b,d);b=x[d+287|0];b=b&1?-1:b>>>1|0;v[a+16>>1]=b;if(b){break d}w[a>>2]=w[a>>2]|536871168}w[a+4>>2]=0;e:{if(!(j&2)){break e}b=w[a+28>>2];u[d+287|0]=0;c=d+288|0;w[d+4>>2]=c;w[d>>2]=d+287;Ob(b,d);g=x[d+287|0];w[a+4>>2]=g>>>2;g=g&3;if(!g){break e}e=0;while(1){u[d+287|0]=0;w[d+4>>2]=c;w[d>>2]=d+287;Ob(b,d);e=e+1|0;w[a+4>>2]=w[a+4>>2]|x[d+287|0]<<(e<<3)-2;if((e|0)!=(g|0)){continue}break}}b=i<<4;c=b&128;g=y[a+16>>1];k=g?2048:c>>>7|0?2048:b&2048;b=b&64;w[a+24>>2]=c|(w[a+24>>2]&-2529|(i&128)<<1|((g|0)!=0)<<5|(b>>>6|0?2048:k))|b;if(j&4){b=w[a+28>>2];u[d+287|0]=0;w[d+4>>2]=d+288;w[d>>2]=d+287;Ob(b,d);c=x[d+287|0];e=c>>>1|0;if(c&1){u[d+287|0]=0;w[d+4>>2]=d+288;w[d>>2]=d+287;Ob(b,d);e=x[d+287|0]<<7|e}cg(w[a+28>>2],C(w[a+24>>2]&512?2:1,e),-1)}if(j&8){cg(w[a+28>>2],5,-1)}i=w[a+28>>2];u[d+287|0]=0;j=d+288|0;w[d+4>>2]=j;w[d>>2]=d+287;Ob(i,d);b=x[d+287|0];e=(b&252)>>>2|0;h=0;f:{b=b&3;if(!b){break f}b=-1<<b;l=(b>>>0>=4294967294?-2:b)^-1;k=0;g=0;while(1){u[d+287|0]=0;w[d+4>>2]=j;w[d>>2]=d+287;Ob(i,d);c=x[d+287|0];b=g;g=k+1|0;b=g?b:b+1|0;k=g;g=b;b=(k<<3)-2|0;f=b&31;if((b&63)>>>0>=32){b=c<<f;c=0}else{b=(1<<f)-1&c>>>32-f;c=c<<f}e=c|e;h=b|h;if((k|0)!=(l|0)|g){continue}break}if(!h&e>>>0<16001){break f}w[a>>2]=w[a>>2]|1073741831;break b}w[a+92>>2]=e;if(!e){w[a>>2]=w[a>>2]|536871040}g:{if(!(x[a+25|0]&8)){break g}i=w[a+28>>2];u[d+287|0]=0;j=d+288|0;w[d+4>>2]=j;w[d>>2]=d+287;Ob(i,d);b=x[d+287|0];e=(b&252)>>>2|0;h=0;b=b&3;if(!b){break g}b=-1<<b;l=(b>>>0>=4294967294?-2:b)^-1;k=0;g=0;while(1){u[d+287|0]=0;w[d+4>>2]=j;w[d>>2]=d+287;Ob(i,d);c=x[d+287|0];b=g;g=k+1|0;b=g?b:b+1|0;k=g;g=b;b=(k<<3)-2|0;f=b&31;if((b&63)>>>0>=32){b=c<<f;c=0}else{b=(1<<f)-1&c>>>32-f;c=c<<f}e=c|e;h=b|h;if((k|0)!=(l|0)|g){continue}break}if((h|0)>0|(h|0)>=0){break g}w[a>>2]=w[a>>2]|1073741829;break b}rd(d,w[a+28>>2]);g=w[d+12>>2];k=w[d+8>>2];b=k;f=w[a+8>>2];c=g-(w[a+12>>2]+(b>>>0<f>>>0)|0)|0;b=b-f|0;if((c|0)==1|c>>>0>1){w[a>>2]=w[a>>2]|1073741832;break b}w[a+88>>2]=b;h=b;b=w[a+24>>2];c=b&2048;w[a+64>>2]=c?e:h;if(!c){w[a+72>>2]=k;w[a+76>>2]=g}w[a+24>>2]=b|1024}jb=d+288|0}function zT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-112|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;h=x[c+11|0];d=h<<24>>24<0;f=d?w[c+4>>2]:h;i=d?w[c>>2]:c;h=x[b+11|0];d=h<<24>>24<0;g=d?w[b+4>>2]:h;m=d?w[b>>2]:b;n=a+8|0;d=0;a:{b:{c:{d:{e:{f:{g:{while(1){h=d;h:{if(f){l=g+m|0;j=h+m|0;k=l-j|0;if((k|0)<(f|0)){break d}o=x[i|0];d=k;g=j;while(1){d=(d-f|0)+1|0;if(!d){break d}d=uc(g,o,d);if(!d){break d}if(Jb(d,i,f)){g=d+1|0;d=l-g|0;if((f|0)>(d|0)){break d}continue}break}if((d|0)==(l|0)|(d-m|0)==-1){break d}i:{while(1){j:{d=(k-f|0)+1|0;if(!d){break j}d=uc(j,o,d);if(!d){break j}if(!Jb(d,i,f)){break i}j=d+1|0;k=l-j|0;if((k|0)>=(f|0)){continue}}break}d=l}d=(d|0)==(l|0)?-1:d-m|0;break h}d=-1;if((h|0)==-1){break c}d=h}w[114256]=0;j=da(104,e+48|0,b|0,h|0,d-h|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){k:{if(u[e+59|0]>=0){w[e+96>>2]=w[j+8>>2];d=w[j+4>>2];w[e+88>>2]=w[j>>2];w[e+92>>2]=d;break k}d=w[j>>2];w[114256]=0;U(3,e+88|0,d|0,w[e+52>>2]);d=w[114256];w[114256]=0;if((d|0)==1){break g}}d=w[a+4>>2];g=w[a+8>>2];l:{if(d>>>0<g>>>0){g=w[e+92>>2];w[d>>2]=w[e+88>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+96>>2];w[e+96>>2]=0;w[e+88>>2]=0;w[e+92>>2]=0;w[a+4>>2]=d+12;break l}i=w[a>>2];k=(d-i|0)/12|0;d=k+1|0;if(d>>>0>=357913942){w[114256]=0;X(105,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}break a}w[114256]=0;g=(g-i|0)/12|0;i=g<<1;l=Z(106,e- -64|0,(g>>>0>=178956970?357913941:d>>>0<i>>>0?i:d)|0,k|0,n|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}g=w[e+92>>2];d=w[e+72>>2];w[d>>2]=w[e+88>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+96>>2];w[e+96>>2]=0;w[e+88>>2]=0;w[e+92>>2]=0;k=w[e+72>>2]+12|0;w[e+72>>2]=k;d=w[e+68>>2];f=w[a+4>>2];g=w[a>>2];m:{if((f|0)==(g|0)){i=g;break m}while(1){f=f-12|0;i=w[f+4>>2];d=d-12|0;w[d>>2]=w[f>>2];w[d+4>>2]=i;w[d+8>>2]=w[f+8>>2];w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;d=w[e+68>>2]-12|0;w[e+68>>2]=d;if((f|0)!=(g|0)){continue}break}g=w[a+4>>2];k=w[e+72>>2];i=w[a>>2]}w[a>>2]=d;w[e+68>>2]=i;w[a+4>>2]=k;w[e+72>>2]=g;d=w[a+8>>2];w[a+8>>2]=w[e+76>>2];w[e+76>>2]=d;w[l>>2]=i;sc(l);if(u[e+99|0]>=0){break l}zb(w[e+88>>2])}if(u[e+59|0]<0){zb(w[j>>2])}g=x[c+11|0];d=g<<24>>24<0;f=d?w[c+4>>2]:g;i=d?w[c>>2]:c;g=x[b+11|0];j=g<<24>>24<0;m=j?w[b>>2]:b;g=j?w[b+4>>2]:g;d=-1;n:{if(h>>>0>g>>>0){break n}d=h;if(!f){break n}k=g+m|0;j=h+m|0;d=k-j|0;o:{p:{if((f|0)>(d|0)){break p}h=x[i|0];while(1){d=(d-f|0)+1|0;if(!d){break p}d=uc(j,h,d);if(!d){break p}if(!Jb(d,i,f)){break o}j=d+1|0;d=k-j|0;if((f|0)<=(d|0)){continue}break}}d=k}d=(d|0)==(k|0)?-1:d-m|0}d=d+f|0;if(d>>>0<=g>>>0){continue}break c}break}f=P()|0;break b}f=P()|0;break e}f=P()|0;if(u[e+99|0]>=0){break e}zb(w[e+88>>2])}if(u[e+59|0]>=0){break b}zb(w[j>>2]);break b}d=h}q:{r:{s:{t:{u:{v:{if(w[a>>2]==w[a+4>>2]){w[114256]=0;c=da(104,e+32|0,b|0,d|0,-1,b|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break u}g=x[c+11|0];h=g<<24>>24;h=(h|0)<0;g=h?w[c+4>>2]:g;if(h){zb(w[c>>2])}if(!g){break v}}w[114256]=0;d=da(104,e|0,b|0,d|0,-1,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break t}w:{if(u[d+11|0]>=0){w[e+24>>2]=w[d+8>>2];b=w[d+4>>2];w[e+16>>2]=w[d>>2];w[e+20>>2]=b;break w}b=w[d+4>>2];c=w[d>>2];w[114256]=0;U(3,e+16|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break s}}b=w[a+4>>2];c=w[a+8>>2];x:{if(b>>>0<c>>>0){c=w[e+20>>2];w[b>>2]=w[e+16>>2];w[b+4>>2]=c;w[b+8>>2]=w[e+24>>2];w[e+24>>2]=0;w[e+16>>2]=0;w[e+20>>2]=0;w[a+4>>2]=b+12;break x}h=w[a>>2];g=(b-h|0)/12|0;b=g+1|0;if(b>>>0>=357913942){w[114256]=0;X(105,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}break r}w[114256]=0;c=(c-h|0)/12|0;h=c<<1;c=Z(106,e+88|0,(c>>>0>=178956970?357913941:b>>>0<h>>>0?h:b)|0,g|0,n|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break r}h=w[e+20>>2];b=w[c+8>>2];w[b>>2]=w[e+16>>2];w[b+4>>2]=h;w[b+8>>2]=w[e+24>>2];w[e+24>>2]=0;w[e+16>>2]=0;w[e+20>>2]=0;j=w[c+8>>2]+12|0;w[c+8>>2]=j;g=w[c+4>>2];f=w[a+4>>2];i=w[a>>2];y:{if((f|0)==(i|0)){b=i;break y}while(1){f=f-12|0;h=w[f+4>>2];b=g-12|0;w[b>>2]=w[f>>2];w[b+4>>2]=h;w[b+8>>2]=w[f+8>>2];w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;g=w[c+4>>2]-12|0;w[c+4>>2]=g;if((f|0)!=(i|0)){continue}break}j=w[c+8>>2];i=w[a+4>>2];b=w[a>>2]}w[a>>2]=g;w[c+4>>2]=b;w[a+4>>2]=j;w[c+8>>2]=i;h=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=h;sc(c);if(u[e+27|0]>=0){break x}zb(w[e+16>>2])}if(u[d+11|0]>=0){break v}zb(w[d>>2])}jb=e+112|0;return}f=P()|0;break b}f=P()|0;break b}f=P()|0;break q}f=P()|0;if(u[e+27|0]>=0){break q}zb(w[e+16>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2])}bc(a);R(f|0);M()}M()}function gP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-128|0;jb=g;e=x[b+11|0];f=e<<24>>24<0;e=f?w[b+4>>2]:e;a:{if(!e){break a}f=x[(e+(f?w[b>>2]:b)|0)-1|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=wl(g+112|0,b,0,e-1|0,b);if(u[b+11|0]<0){zb(w[b>>2])}e=w[f+4>>2];w[b>>2]=w[f>>2];w[b+4>>2]=e;w[b+8>>2]=w[f+8>>2]}f=82096;b:{c:{d:{e:{f:{g:{h:{i:{while(1){j:{h=w[f>>2];e=ec(h);i=x[b+11|0];if((e|0)==((i<<24>>24<0?w[b+4>>2]:i)|0)){w[114256]=0;e=da(186,b|0,0,-1,h|0,e|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break c}if(!e){break j}}f=f+8|0;if((f|0)!=82200){continue}break i}break}if((f|0)!=82200){break h}}k:{a=x[b+11|0];if(a<<24>>24<0?w[b+4>>2]:a){break k}w[114256]=0;a=da(186,b|0,0,-1,17256,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}if(a){break k}a=ba(8)|0;w[114256]=0;U(1445,g+112|0,13363,c|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}a=Pb(a,g+112|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}f=P()|0;if(u[g+123|0]>=0){break e}zb(w[g+112>>2]);break e}if(!d){break g}d=ba(8)|0;w[114256]=0;U(1445,g+80|0,13399,b|0);a=w[114256];w[114256]=0;l:{m:{n:{o:{if((a|0)!=1){w[114256]=0;a=Q(1315,g+80|0,13373)|0;b=w[114256];w[114256]=0;if((b|0)==1){break m}w[g+104>>2]=w[a+8>>2];b=w[a+4>>2];w[g+96>>2]=w[a>>2];w[g+100>>2]=b;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;b=w[c>>2];f=w[c+4>>2];a=x[c+11|0];w[114256]=0;e=b;b=a<<24>>24<0;a=S(92,g+96|0,(b?e:c)|0,(b?f:a)|0)|0;c=w[114256];w[114256]=0;b=1;if((c|0)==1){break o}w[g+120>>2]=w[a+8>>2];b=w[a+4>>2];w[g+112>>2]=w[a>>2];w[g+116>>2]=b;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,g+112|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}f=P()|0;b=0;if(u[g+123|0]>=0){break n}zb(w[g+112>>2]);break n}f=P()|0;break l}f=P()|0}if(u[g+107|0]<0){zb(w[g+96>>2])}if(u[g+91|0]<0){zb(w[g+80>>2])}if(b){break l}break e}f=P()|0;if(u[g+91|0]>=0){break l}zb(w[g+80>>2])}ca(d|0);break e}p:{switch(w[f+4>>2]){case 0:e=w[b>>2];h=x[b+11|0];f=h<<24>>24<0;w[g+76>>2]=f?w[b+4>>2]:h;w[g+72>>2]=f?e:b;b=(jw(c)|0)!=0;c=w[g+76>>2];w[g>>2]=w[g+72>>2];w[g+4>>2]=c;hv(a,g,b,d);break g;case 1:e=w[b>>2];h=x[b+11|0];f=h<<24>>24<0;w[g+68>>2]=f?w[b+4>>2]:h;w[g+64>>2]=f?e:b;b=jb-176|0;jb=b;c=Zg(b+24|0,c,8);e=w[w[c>>2]-12>>2];w[114256]=0;f=ea(79)|0;h=w[114256];w[114256]=0;q:{r:{s:{t:{if((h|0)==1){break t}w[114256]=0;e=c+e|0;T(10,b+16|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break t}w[114256]=0;U(80,b+8|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break r}Ab(b+8|0);e=w[e+24>>2];if(e){h=w[w[e>>2]+8>>2];w[114256]=0;T(h|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break r}e=e+4|0;h=Ic(b+168|0,e);Wc(e,f);Ab(h)}Ab(b+16|0);w[114256]=0;f=Q(97,c|0,b+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break s}f=w[(f+w[w[f>>2]-12>>2]|0)+16>>2];e=w[b+8>>2];h=w[b+12>>2];i=w[15045];w[c>>2]=i;w[w[i-12>>2]+c>>2]=w[15048];w[c+8>>2]=59272;if(u[c+51|0]<0){zb(w[c+40>>2])}wc(c+8|0);pc(c+60|0);jb=b+176|0;b=f&5;c=b?0:e;b=b?0:h;break q}a=P()|0;break b}a=P()|0;break b}a=P()|0;Ab(b+16|0);break b}f=w[g+68>>2];w[g+8>>2]=w[g+64>>2];w[g+12>>2]=f;gv(a,g+8|0,c,b,d);break g;case 2:e=w[b>>2];h=x[b+11|0];f=h<<24>>24<0;w[g+60>>2]=f?w[b+4>>2]:h;w[g+56>>2]=f?e:b;b=jb-176|0;jb=b;c=Zg(b+24|0,c,8);e=w[w[c>>2]-12>>2];w[114256]=0;f=ea(79)|0;h=w[114256];w[114256]=0;u:{v:{w:{x:{if((h|0)==1){break x}w[114256]=0;e=c+e|0;T(10,b+16|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break x}w[114256]=0;U(80,b+8|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break v}Ab(b+8|0);e=w[e+24>>2];if(e){h=w[w[e>>2]+8>>2];w[114256]=0;T(h|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break v}e=e+4|0;h=Ic(b+168|0,e);Wc(e,f);Ab(h)}Ab(b+16|0);w[114256]=0;f=Q(98,c|0,b+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break w}f=w[(f+w[w[f>>2]-12>>2]|0)+16>>2];j=B[b+8>>3];e=w[15045];w[c>>2]=e;w[w[e-12>>2]+c>>2]=w[15048];w[c+8>>2]=59272;if(u[c+51|0]<0){zb(w[c+40>>2])}wc(c+8|0);pc(c+60|0);jb=b+176|0;j=f&5?0:j;break u}a=P()|0;break b}a=P()|0;break b}a=P()|0;Ab(b+16|0);break b}b=w[g+60>>2];w[g+16>>2]=w[g+56>>2];w[g+20>>2]=b;fv(a,g+16|0,j,d);break g;case 3:break p;default:break g}}e=w[b>>2];h=x[b+11|0];f=h<<24>>24<0;w[g+52>>2]=f?w[b+4>>2]:h;w[g+48>>2]=f?e:b;f=w[c>>2];e=x[c+11|0];b=e<<24>>24<0;w[g+44>>2]=b?w[c+4>>2]:e;w[g+40>>2]=b?f:c;b=w[g+52>>2];w[g+32>>2]=w[g+48>>2];w[g+36>>2]=b;b=w[g+44>>2];w[g+24>>2]=w[g+40>>2];w[g+28>>2]=b;dv(a,g+32|0,g+24|0,d)}jb=g+128|0;return}f=P()|0;ca(a|0)}R(f|0)}M()}W(0)|0;Eb();M()}Se(c);R(a|0);M()}function Sx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-96|0;jb=h;w[c+8>>2]=0;a:{b:{d=w[c>>2];if(!(ob[w[w[d>>2]+36>>2]](d,0,4)|0)){break b}c:{while(1){d:{d=h- -64|0;f=jb-16|0;jb=f;g=w[c>>2];e:{if(ob[w[w[g>>2]+36>>2]](g,w[c+8>>2],3)|0){i=w[c+8>>2];g=w[c>>2];w[f+8>>2]=d;w[f+12>>2]=d+3;r=c,s=(ob[w[w[g>>2]+32>>2]](g,i,f+8|0)|0)+w[c+8>>2]|0,w[r+8>>2]=s;break e}u[d|0]=0;u[d+1|0]=0;u[d+2|0]=0}jb=f+16|0;f:{if(!Jb(d,10518,3)){d=h+24|0;f=jb-16|0;jb=f;g=w[c>>2];g:{if(ob[w[w[g>>2]+36>>2]](g,w[c+8>>2],7)|0){i=w[c+8>>2];g=w[c>>2];w[f+8>>2]=d;w[f+12>>2]=d+7;r=c,s=(ob[w[w[g>>2]+32>>2]](g,i,f+8|0)|0)+w[c+8>>2]|0,w[r+8>>2]=s;break g}u[d|0]=0;u[d+1|0]=0;u[d+2|0]=0;u[d+3|0]=0;u[d+3|0]=0;u[d+4|0]=0;u[d+5|0]=0;u[d+6|0]=0}jb=f+16|0;f=3;d=0;while(1){g=u[(h+24|0)+f|0];if((g|0)<0){break c}d=g&255|d<<7;f=f+1|0;if((f|0)!=7){continue}break}f=w[c>>2];h:{if(ob[w[w[f>>2]+36>>2]](f,w[c+8>>2],d)|0){d=w[c+8>>2]+d|0;break h}d=w[c>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[c+8>>2]=d;break f}i:{if(Jb(h- -64|0,9858,3)){break i}if(!gd(c,9357,5)){break i}d=Nc(c,h+24|0);f=w[c>>2];d=d?w[h+24>>2]+16|0:16;j:{if(ob[w[w[f>>2]+36>>2]](f,w[c+8>>2],d)|0){d=d+w[c+8>>2]|0;break j}d=w[c>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[c+8>>2]=d;break f}if(!Jb(h- -64|0,25593,3)){break f}if(!Jb(h- -64|0,25597,3)){break f}if(x[h+64|0]){break d}d=w[c+8>>2];f=d-2|0;w[c+8>>2]=d>>>0>=f>>>0?f:0}d=w[c>>2];if(ob[w[w[d>>2]+36>>2]](d,w[c+8>>2],4)|0){continue}break b}break}d=0;f=h- -64|0;k:{if(x[f|0]!=255){break k}g=x[f+1|0];if((g&224)!=224|(g&24)==8|!(g&6)){break k}f=x[f+2|0];if((f&12)==12){break k}d=(f&240)!=240}if(d){break b}}f=0;break a}w[c+8>>2]=0;k=Wk(h- -64|0,c);f=w[k+12>>2];i=w[k>>2];c=w[k+4>>2];d=w[k+8>>2];w[114256]=0;w[h+56>>2]=0;w[h+48>>2]=0;w[h+52>>2]=0;g=V(22,6668)|0;j=w[114256];w[114256]=0;l:{m:{n:{o:{p:{if((j|0)!=1){o=Cb(g,0,6668);w[114256]=0;X(734,o|0);g=w[114256];w[114256]=0;if((g|0)!=1){w[114256]=0;w[h+40>>2]=0;w[h+44>>2]=0;w[h+32>>2]=0;w[h+36>>2]=0;w[h+24>>2]=0;w[h+28>>2]=0;g=V(22,4608)|0;j=w[114256];w[114256]=0;if((j|0)!=1){p=c?c:(d|0)!=(f|0)?d:0;j=Cb(g,0,4608);d=0;c=0;while(1){w[114256]=0;q=(m|0)>=0&i>>>0>=2147483647|(m|0)>0?2147483647:i;n=da(735,o|0,p|0,q|0,j|0,h+24|0)|0;f=w[114256];w[114256]=0;q:{r:{if((f|0)!=1){if((n|0)<0){break o}l=w[h+24>>2];if((l|0)<0|!l&(n|0)!=0|!(n|l)){break o}if(!l){break q}g=w[h+36>>2];if((g|0)!=(d|0)?d:0){break o}f=w[h+32>>2];if((f|0)!=(c|0)?c:0){break o}if(f-3>>>0<4294967294|(g|0)<=0){break p}c=l>>>0<q>>>0?l:q;p=c+p|0;d=i;i=d-c|0;m=m-(c>>>0>d>>>0)|0;if(!n){break r}w[114256]=0;Z(736,h+48|0,w[h+52>>2],j|0,j+(C(f,n)<<1)|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break r}d=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break n}$(d|0)|0;w[114256]=0;_(18);i=w[114256];w[114256]=0;c=f;d=g;if((i|0)!=1){break o}d=P()|0;break n}d=P()|0;break n}d=g;c=f}if((w[h+52>>2]-w[h+48>>2]>>1>>>0)/(c>>>0)>>>0>268435456){break o}if(!!i&(m|0)>=0|(m|0)>0){continue}break}break o}d=P()|0;break m}d=P()|0;break m}d=P()|0;break l}c=f;d=g}f=0;s:{t:{u:{v:{w:{if(!d|!c){break w}g=w[h+48>>2];i=w[h+52>>2];if((g|0)==(i|0)|(i-g>>1>>>0)/(c>>>0)>>>0>268435456){break w}w[114256]=0;Q(737,a|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break s}if(!e){w[114256]=0;f=Q(5,h+8|0,17256)|0;g=w[114256];w[114256]=0;if((g|0)==1){break v}w[114256]=0;w[h+92>>2]=32;w[h+88>>2]=((b<<5)+a|0)+946304;Q(200,h+88|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break u}if(u[f+11|0]<0){zb(w[f>>2])}w[114256]=0;f=C(b,104)+a|0;T(266,f+484380|0,0);g=w[114256];w[114256]=0;if((g|0)==1){break s}w[f+484404>>2]=d}d=C(b,104)+a|0;b=d+484380|0;w[b>>2]=(w[h+52>>2]-w[h+48>>2]>>1>>>0)/(c>>>0);g=d+484414|0;f=y[g>>1];v[g>>1]=(c|0)==2?f|65:f&65470|1;w[114256]=0;V(252,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break s}d=d+484400|0;f=w[d>>2];x:{if(!f|!w[b>>2]){break x}g=w[h+52>>2];c=w[h+48>>2];if((g|0)==(c|0)){break x}hc(f,c,g-c|0)}if(!e){c=w[a+480180>>2];w[114256]=0;U(738,b|0,32,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break t}w[114256]=0;U(739,b|0,a|0,0);a=w[114256];w[114256]=0;if((a|0)==1){break s}}f=w[d>>2]!=0&w[b>>2]!=0}zb(j);zb(o);a=w[h+48>>2];if(a){w[h+52>>2]=a;zb(a)}a=w[k+8>>2];if(!a){break a}w[k+12>>2]=a;zb(a);break a}d=P()|0;break n}d=P()|0;if(u[f+11|0]>=0){break n}zb(w[f>>2]);break n}d=P()|0;break n}d=P()|0}zb(j)}zb(o);a=w[h+48>>2];if(!a){break l}w[h+52>>2]=a;zb(a)}a=w[k+8>>2];if(a){w[k+12>>2]=a;zb(a)}R(d|0);M()}jb=h+96|0;return f|0}function jc(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=jb-96|0;jb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;v=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=F(h?b:d)+32|0;b=F(h?c:p);b=i+((b|0)==32?l:b)|0;$c(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=w[k+88>>2];v=w[k+92>>2];c=w[k+84>>2];b=w[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=F(e?f:t)+32|0;e=F(e?g:u);e=h+((e|0)==32?i:e)|0;$c(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=w[k+72>>2];u=w[k+76>>2];f=w[k+64>>2];g=w[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;A=BV(p,0,c,0);c=nb;y=c;B=e;i=0;j=BV(e,0,b,i);e=j+A|0;h=nb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=BV(b,i,p,i);l=0+n|0;e=nb+e|0;e=l>>>0<n>>>0?e+1|0:e;z=l;n=l;l=e;C=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=BV(p,i,d,0);H=nb;e=BV(q,i,B,i);d=e+M|0;j=nb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;D=e<<15|g>>>17;g=BV(D,0,b,i);e=g+n|0;f=nb+d|0;I=e;f=e>>>0<g>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(y|0)&c>>>0<A>>>0|h>>>0<y>>>0;c=h+I|0;f=e+f|0;A=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;E=v|65536;v=x;N=BV(p,i,E,x);J=nb;g=BV(r,o,B,i);f=g+N|0;e=nb+J|0;O=f;e=f>>>0<g>>>0?e+1|0:e;x=e;G=j|-2147483648;y=0;g=BV(G,y,b,i);b=g+f|0;f=nb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=BV(D,o,q,i);b=b+e|0;p=f;j=f+nb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+A|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+C|0;C=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=BV(G,y,q,i);h=nb;i=BV(E,v,B,i);e=i+j|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=BV(D,o,r,o);e=i+e|0;j=nb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=BV(G,y,E,v);i=q+f|0;f=nb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;B=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=B+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=BV(D,o,E,v);e=nb;r=BV(G,y,r,o);d=r+j|0;f=nb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;v=d+q|0;e=f+h|0;e=v>>>0<d>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+v|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(x|0)&O>>>0>P>>>0|p>>>0<x>>>0;f=j+((x|0)==(J|0)&O>>>0<N>>>0|x>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(C|0)&A>>>0>R>>>0|t>>>0>C>>>0;d=i+((t|0)==(u|0)&A>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}x=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=z;f=l<<1|g>>>31;z=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|x;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;$c(k+48|0,z,l,b,c,g);$c(k+32|0,d,e,h,i,g);fg(k+16|0,z,l,b,c,f);fg(k,d,e,h,i,f);z=w[k+32>>2]|w[k+16>>2]|(w[k+48>>2]|w[k+56>>2]|(w[k+52>>2]|w[k+60>>2]))!=0;l=w[k+36>>2]|w[k+20>>2];b=w[k+40>>2]|w[k+24>>2];c=w[k+44>>2]|w[k+28>>2];d=w[k>>2];e=w[k+4>>2];f=w[k+8>>2];g=w[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|z):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|z|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=o;w[a+12>>2]=m;jb=k+96|0}function ZF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-560|0;jb=e;w[b+8>>2]=0;d=jb-16|0;jb=d;h=w[b+8>>2];g=w[b>>2];i=e+48|0;w[d+8>>2]=i;w[d+12>>2]=i+497;h=ob[w[w[g>>2]+32>>2]](g,h,d+8|0)|0;if((h|0)==497){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],497)|0){i=w[b+8>>2]+497|0;break a}g=w[b>>2];i=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=i}jb=d+16|0;b:{if((h|0)!=497){break b}if(!Kq(e+48|0)){break b}c:{if(!c){break c}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],C(x[e+159|0],1536)+C(x[e+158|0],25)|0)|0)){break b}tc(a,64);w[a+480204>>2]=78e4;w[a+480260>>2]=112;w[a+480264>>2]=13696;w[a+480196>>2]=4;v[a+480188>>1]=8;d=a+1304436|0;f=Hb(e+16|0,10108);if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=a+1304448|0;f=Hb(e+16|0,10141);if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[f+4>>2];w[d>>2]=w[f>>2];w[d+4>>2]=g;w[d+8>>2]=w[f+8>>2];d=y[e+48>>1]==26217;Jf(a+1304460|0,d?10108:10136,d?12:8);w[a+1304496>>2]=4;d=x[e+158|0];v[a+480190>>1]=d;d:{e:{f:{g:{if(d){f=1;g=1;while(1){d=jb-16|0;jb=d;i=w[b+8>>2];h=w[b>>2];j=e+16|0;w[d+8>>2]=j;w[d+12>>2]=j+25;i=ob[w[w[h>>2]+32>>2]](h,i,d+8|0)|0;if((i|0)==25){h=w[b>>2];h:{if(ob[w[w[h>>2]+36>>2]](h,w[b+8>>2],25)|0){m=w[b+8>>2]+25|0;break h}h=w[b>>2];m=ob[w[w[h>>2]+24>>2]](h)|0}w[b+8>>2]=m}jb=d+16|0;i:{if((i|0)!=25){u[e+40|0]=0;w[e+32>>2]=0;w[e+36>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;w[e+16>>2]=0;w[e+20>>2]=0;break i}if((x[e+29|0]|x[e+30|0]<<8|(x[e+31|0]<<16|x[e+32|0]<<24))>>>0>67108863){break e}}h=(C(f,104)+a|0)+484380|0;lc(h,0);w[h+24>>2]=8363;i=e+16|0;d=i;j=x[d+13|0]|x[d+14|0]<<8|(x[d+15|0]<<16|x[d+16|0]<<24);w[h>>2]=j;k=x[d+17|0]|x[d+18|0]<<8|(x[d+19|0]<<16|x[d+20|0]<<24);w[h+4>>2]=k;d=x[d+21|0]|x[d+22|0]<<8|(x[d+23|0]<<16|x[d+24|0]<<24);d=d>>>0>j>>>0?k?d:0:d;w[h+8>>2]=d;if(d){v[h+34>>1]=2;tg(h)}Vb(e,2,i,13);w[114256]=0;w[e+556>>2]=32;w[e+552>>2]=((f<<5)+a|0)+946304;Q(200,e+552|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}if(u[e+11|0]<0){zb(w[e>>2])}g=g+1|0;f=g&65535;if(f>>>0<=y[a+480190>>1]){continue}break}}g=e+48|2;Vb(e+16|0,3,g,36);d=a+1304400|0;if(u[a+1304411|0]<0){zb(w[d>>2])}f=w[e+20>>2];w[d>>2]=w[e+16>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+24>>2];f=0;Ro(a+1304424|0,g,108,36,0);d=a+484376|0;Ze(w[a+484360>>2]+(x[d|0]<<5)|0,e+161|0,128,255,254);d=w[a+484360>>2]+(x[d|0]<<5)|0;g=x[e+160|0];if(y[w[d>>2]+(g<<1)>>1]<x[e+159|0]){break f}break d}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}v[d+28>>1]=g;break d}f=0;break b}while(1){d=(f<<5)+a|0;Qd(d+480280|0);v[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;td(h,x[e+159|0]);if(x[e+159|0]){m=c&1;while(1){j:{k:{if(m){if(ie(h,l&65535,64)){break k}}d=w[b>>2];l:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],1536)|0){i=w[b+8>>2]+1536|0;break l}d=w[b>>2];i=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=i;break j}w[e>>2]=-1;w[e+4>>2]=-1;i=0;while(1){n=C(l,52);d=n+w[h>>2]|0;f=ld(d);f=w[d>>2]+C(C(f,i),6)|0;g=0;while(1){nl(b,e+16|0);j=x[e+17|0];d=x[e+16|0];if(d>>>0<=253){u[f|0]=(d>>>2|0)+37;u[f+1|0]=(d<<4&48|j>>>4)+1;u[e+g|0]=255;d=x[e+16|0]}if((d|0)!=255){u[f+2|0]=1;u[f+4|0]=(((j&15)<<6|8)>>>0)/15}j=e+g|0;m:{n:{d=x[e+18|0];o:{if((d|0)!=255){u[j|0]=d;if(d&15|(d|0)==48){break o}break n}d=x[j|0];if((d|0)==255){break m}}k=d&15;u[f+5|0]=k;p:{if(d<<24>>24<0){break p}d=d>>>4|0;u[f+3|0]=x[d+23160|0];q:{switch(d-3|0){case 0:u[f+5|0]=k|32;break n;case 1:u[f+5|0]=C(k,17);break m;case 2:break n;case 3:break q;default:break m}}r:{switch(k|0){case 0:u[f+5|0]=79;break m;case 1:break r;default:break p}}u[f+5|0]=244;break m}u[f+3|0]=0;break m}u[j|0]=255}f=f+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if((i|0)!=64){continue}break}d=(e+48|0)+l|0;f=x[d+369|0];if(f>>>0<63){g=w[h>>2];w[e+24>>2]=983039;w[e+20>>2]=f;f=x[e+28|0];w[e+16>>2]=1;u[e+28|0]=f&248|1;ng(g+n|0,e+16|0)}f=w[h>>2];u[e+26|0]=16;v[e+24>>1]=65535;w[e+16>>2]=1;w[e+20>>2]=0;u[e+27|0]=x[d+241|0];u[e+28|0]=x[e+28|0]&248|1;ng(f+n|0,e+16|0)}l=l+1|0;if(l>>>0<x[e+159|0]){continue}break}}f=1;if(!(c&2)){break b}w[e+16>>2]=16777480;if(!y[a+480190>>1]){break c}while(1){Fd(e+16|0,(C(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(y[a+480190>>1]>=(f&65535)>>>0){continue}break}}f=1}jb=e+560|0;return f|0}function yr(){var a=0,b=0,c=0,d=0,e=0,f=0;if(x[460400]){return w[115099]}b=nc(462040);w[b>>2]=65016;w[114256]=0;c=Q(1792,b+8|0,30)|0;a=w[114256];w[114256]=0;a:{b:{c:{d:{e:{if((a|0)!=1){w[114256]=0;d=Q(5,b+152|0,9910)|0;a=w[114256];w[114256]=0;if((a|0)==1){break e}ae(c);Ir(c);Hr(c);e=nc(461712),f=67604,w[e>>2]=f;w[114256]=0;T(1793,b|0,461712);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461720),f=67636,w[e>>2]=f;w[114256]=0;T(1794,b|0,461720);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;vr();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1796,b|0,461728);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461744),f=66552,w[e>>2]=f;w[114256]=0;T(1797,b|0,461744);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461752),f=66700,w[e>>2]=f;w[114256]=0;T(1798,b|0,461752);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;_(1799);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1800,b|0,461760);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461776),f=66848,w[e>>2]=f;w[114256]=0;T(1801,b|0,461776);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461784),f=67080,w[e>>2]=f;w[114256]=0;T(1802,b|0,461784);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461792),f=66964,w[e>>2]=f;w[114256]=0;T(1803,b|0,461792);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461800),f=67196,w[e>>2]=f;w[114256]=0;T(1804,b|0,461800);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;_(1805);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1806,b|0,461808);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;_(1807);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1808,b|0,461832);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461864),f=67668,w[e>>2]=f;w[114256]=0;T(1809,b|0,461864);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461872),f=67912,w[e>>2]=f;w[114256]=0;T(1810,b|0,461872);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461880),f=68124,w[e>>2]=f;w[114256]=0;T(1811,b|0,461880);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461888),f=68356,w[e>>2]=f;w[114256]=0;T(1812,b|0,461888);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Gr();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1814,b|0,461896);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461904),f=69488,w[e>>2]=f;w[114256]=0;T(1815,b|0,461904);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461912),f=69604,w[e>>2]=f;w[114256]=0;T(1816,b|0,461912);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(461920),f=69720,w[e>>2]=f;w[114256]=0;T(1817,b|0,461920);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Fr();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1819,b|0,461928);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Er();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1821,b|0,461936);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Dr();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1823,b|0,461944);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Cr();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1825,b|0,461952);a=w[114256];w[114256]=0;if((a|0)==1){break d}a=nc(461960);w[a+8>>2]=71584;w[a>>2]=68556;w[a+8>>2]=68604;w[114256]=0;T(1826,b|0,461960);a=w[114256];w[114256]=0;if((a|0)==1){break d}a=nc(461976);w[a+8>>2]=71620;w[a>>2]=68820;w[a+8>>2]=68868;w[114256]=0;T(1827,b|0,461976);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;_(1828);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1829,b|0,461992);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;_(1830);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1831,b|0,462008);a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;Br();a=w[114256];w[114256]=0;if((a|0)==1){break d}w[114256]=0;T(1833,b|0,462024);a=w[114256];w[114256]=0;if((a|0)==1){break d}e=nc(462032),f=70612,w[e>>2]=f;w[114256]=0;T(1834,b|0,462032);b=w[114256];w[114256]=0;if((b|0)==1){break d}break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;Gb(d)}Kr(c)}R(b|0);M()}w[115098]=462040;u[460400]=1;w[115099]=460392;return 460392}function rv(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb+-64|0;jb=j;w[j+60>>2]=0;a:{b:{c:{d:{if(d|g|h|i){n=g?j+60|0:0;e:{if(!g){break e}k=w[n>>2];if(!k){break e}zb(k);w[n>>2]=0}w[114256]=0;_(56);k=w[114256];w[114256]=0;if((k|0)!=1){break d}m=cb(74720,81948,81960,82064,74888,74992,74940,74832,74820,75116,75084,75052,75040,74672,0)|0;k=kb;f:{g:{h:{if((fa(74720)|0)==(k|0)){l=277;break h}if((fa(81948)|0)==(k|0)){l=358;break h}if((fa(81960)|0)==(k|0)){l=359;break h}if((fa(82064)|0)==(k|0)){l=357;break h}if((fa(74888)|0)==(k|0)){l=300;break h}if((fa(74992)|0)==(k|0)){l=299;break h}if((fa(74940)|0)==(k|0)){l=298;break h}if((fa(74832)|0)==(k|0)){l=297;break h}if((fa(74820)|0)==(k|0)){l=296;break h}if((fa(75116)|0)==(k|0)){l=289;break h}if((fa(75084)|0)==(k|0)){l=288;break h}if((fa(75052)|0)==(k|0)){l=287;break h}if((fa(75040)|0)==(k|0)){l=286;break h}o=fa(74672)|0;l=267;m=$(m|0)|0;k=(k|0)!=(o|0);if(!(k|!g)){break g}l=k?257:267;break f}m=$(m|0)|0;if(!g){break f}}k=ob[w[w[m>>2]+8>>2]](m)|0;p=n,q=rc(k?k:17256),w[p>>2]=q}aa();m=!g;if(d){k=ob[d|0](l,e)|0}else{k=3}if(!(m|!(k&2))){w[g+16>>2]=l;m=g;g=w[j+60>>2];p=m,q=rc(g?g:17256),w[p+20>>2]=q}if(h){w[h>>2]=l}g=w[j+60>>2];if(i){p=i,q=rc(g?g:17256),w[p>>2]=q}if(g){zb(g)}if(!(k&1)){break a}}w[114256]=0;w[j+56>>2]=0;w[j+48>>2]=0;w[j+52>>2]=0;_(56);g=w[114256];w[114256]=0;if((g|0)!=1){break d}g=bb(82064,74720,74672,0)|0;h=kb;i:{j:{k:{if((fa(82064)|0)==(h|0)){g=$(g|0)|0;w[114256]=0;Q(1315,j+48|0,a|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}w[114256]=0;Q(1315,j+48|0,13499)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}w[114256]=0;Q(1315,j+48|0,13475)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}g=ob[w[w[g>>2]+8>>2]](g)|0;w[114256]=0;Q(1315,j+48|0,(g?g:17256)|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break k}w[114256]=0;_(18);g=w[114256];w[114256]=0;if((g|0)!=1){break c}g=W(0)|0;break b}l:{if((fa(74720)|0)==(h|0)){g=$(g|0)|0;w[114256]=0;Q(1315,j+48|0,a|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break l}w[114256]=0;Q(1315,j+48|0,13499)|0;h=w[114256];w[114256]=0;if((h|0)==1){break l}w[114256]=0;Q(1315,j+48|0,13450)|0;h=w[114256];w[114256]=0;if((h|0)==1){break l}g=ob[w[w[g>>2]+8>>2]](g)|0;w[114256]=0;Q(1315,j+48|0,(g?g:17256)|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break l}w[114256]=0;_(18);g=w[114256];w[114256]=0;if((g|0)!=1){break c}g=W(0)|0;break b}i=fa(74672)|0;g=$(g|0)|0;m:{if((h|0)==(i|0)){w[114256]=0;Q(1315,j+48|0,a|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break m}w[114256]=0;Q(1315,j+48|0,13499)|0;h=w[114256];w[114256]=0;if((h|0)==1){break m}w[114256]=0;Q(1315,j+48|0,13466)|0;h=w[114256];w[114256]=0;if((h|0)==1){break m}g=ob[w[w[g>>2]+8>>2]](g)|0;w[114256]=0;Q(1315,j+48|0,(g?g:17256)|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break m}w[114256]=0;_(18);g=w[114256];w[114256]=0;if((g|0)!=1){break c}g=W(0)|0;break b}w[114256]=0;Q(1315,j+48|0,a|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}w[114256]=0;Q(1315,j+48|0,13499)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}w[114256]=0;Q(1315,j+48|0,9488)|0;g=w[114256];w[114256]=0;if((g|0)==1){break j}w[114256]=0;_(18);g=w[114256];w[114256]=0;if((g|0)!=1){break c}g=W(0)|0;break b}g=W(0)|0;w[114256]=0;_(18);h=w[114256];w[114256]=0;if((h|0)!=1){break b}break i}g=W(0)|0;w[114256]=0;_(18);h=w[114256];w[114256]=0;if((h|0)!=1){break b}break i}g=W(0)|0;w[114256]=0;_(18);h=w[114256];w[114256]=0;if((h|0)==1){break i}break b}g=W(0)|0;w[114256]=0;_(18);h=w[114256];w[114256]=0;if((h|0)!=1){break b}}W(0)|0;Eb()}M()}n:{o:{if(f){w[114256]=0;T(1316,f|0,j+48|0);g=w[114256];w[114256]=0;if((g|0)!=1){break o}break n}g=u[j+59|0]<0?w[j+48>>2]:j+48|0;if(b){w[114256]=0;T(b|0,g|0,c|0);g=w[114256];w[114256]=0;if((g|0)==1){break n}break o}w[j+32>>2]=g;a=w[14612];Nj(a,13564,j+32|0);wf(a)}if(u[j+59|0]>=0){break a}zb(w[j+48>>2]);break a}g=W(0)|0}if(u[j+59|0]<0){zb(w[j+48>>2])}$(g|0)|0;w[j+28>>2]=f;w[j+24>>2]=e;w[j+20>>2]=d;w[j+16>>2]=c;w[j+12>>2]=b;w[j+4>>2]=252;w[j>>2]=5104;w[j+8>>2]=a?a:17256;a=w[14612];Nj(a,13577,j);wf(a);aa()}jb=j- -64|0}function Zj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if(b){g=a+327720|0;c=jb-400|0;jb=c;oo(c+384|0,8);w[114256]=0;sa(724,c+368|0,9);i=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){w[114256]=0;i=Q(725,c+352|0,14)|0;f=w[114256];w[114256]=0;if((f|0)==1){break l}w[114256]=0;T(726,c+384|0,i|0);f=w[114256];w[114256]=0;if((f|0)==1){break k}w[114256]=0;T(726,c+368|0,i|0);f=w[114256];w[114256]=0;if((f|0)==1){break k}w[c+296>>2]=0;w[c+300>>2]=0;w[c+288>>2]=0;w[c+292>>2]=0;w[c+280>>2]=1796352177;w[c+284>>2]=1065459645;w[c+304>>2]=173258589;w[c+308>>2]=-1074808447;Cb(c+312|0,0,40);w[c+224>>2]=0;w[c+228>>2]=0;w[c+216>>2]=0;w[c+220>>2]=0;w[c+208>>2]=1701513148;w[c+212>>2]=1068201844;w[c+232>>2]=-1180086396;w[c+236>>2]=-1074902904;Cb(c+240|0,0,40);w[c+184>>2]=0;w[c+188>>2]=0;w[c+192>>2]=0;w[c+196>>2]=0;w[c+200>>2]=0;w[c+204>>2]=0;w[114256]=0;w[c+176>>2]=0;w[c+180>>2]=0;w[c+168>>2]=1222514645;w[c+172>>2]=1072674680;w[c+160>>2]=25329086;w[c+164>>2]=-1073751143;w[c+152>>2]=1192642221;w[c+156>>2]=1054970230;w[c+144>>2]=1192642221;w[c+148>>2]=1056018806;w[c+136>>2]=1192642221;w[c+140>>2]=1054970230;f=Q(727,c+104|0,c+384|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}vi(c+120|0,c+280|0,f);e=w[f>>2];if(e){w[f+4>>2]=e;zb(e)}w[114256]=0;f=Q(727,c+72|0,c+368|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break i}vi(c+88|0,c+208|0,f);e=w[f>>2];if(e){w[f+4>>2]=e;zb(e)}w[114256]=0;f=Q(727,c+40|0,c+120|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}vi(c+56|0,c+136|0,f);e=w[f>>2];if(e){w[f+4>>2]=e;zb(e)}w[114256]=0;f=Q(727,c+8|0,c+88|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}vi(c+24|0,c+136|0,f);e=w[f>>2];if(e){w[f+4>>2]=e;zb(e)}f=c+120|0;kh(f);e=c+56|0;kh(e);j=c+88|0;kh(j);n=c+24|0;kh(n);o=c+368|0;kh(o);jh(f,g);jh(e,g- -8192|0);jh(j,g+16384|0);jh(n,g+24576|0);jh(o,g+32768|0);g=w[c+24>>2];if(g){zb(g)}g=w[c+56>>2];if(g){zb(g)}g=w[c+88>>2];if(g){w[c+92>>2]=g;zb(g)}g=w[c+120>>2];if(g){w[c+124>>2]=g;zb(g)}g=w[i>>2];if(g){w[i+4>>2]=g;zb(g)}i=w[c+368>>2];if(i){w[c+372>>2]=i;zb(i)}i=w[c+384>>2];if(i){w[c+388>>2]=i;zb(i)}jb=c+400|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;b=w[c+56>>2];if(!b){break f}zb(b)}b=w[c+88>>2];if(!b){break e}w[c+92>>2]=b;zb(b)}b=w[c+120>>2];if(!b){break d}w[c+124>>2]=b;zb(b)}b=w[i>>2];if(!b){break c}w[i+4>>2]=b;zb(b)}b=w[c+368>>2];if(!b){break b}w[c+372>>2]=b;zb(b)}b=w[c+384>>2];if(b){w[c+388>>2]=b;zb(b)}R(a|0);M()}kn(a+131112|0,9.6377,.97);kn(a+196648|0,8.5,.5);kn(a+262184|0,2.7625,.425)}m:{n:{if(x[a+368680|0]!=x[a|0]){k=B[a+8>>3];break n}k=B[a+8>>3];if(x[a+368696|0]!=x[a+16|0]|k!=B[a+368688>>3]|w[a+368700>>2]!=w[a+20>>2]){break n}if(!b){break m}}g=a+24|0;f=x[a+16|0];c=jb+-64|0;jb=c;while(1){q=+(l-4096|0)*.0001220703125;m=0;b=0;while(1){h=1;e=c+(b<<3)|0;d=+(b|0)-q;p=d+-3.5;if(E(p)<1e-8){d=k}else{o:{p:{switch(f|0){case 0:h=.5-Fc(d*.8975979010256552)*.5;break o;case 1:h=Fc(d*.8975979010256552)*-.46+.54;break o;case 2:d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.5+.42+h*.08;break o;case 3:d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.49364+.44959+h*.05677;break o;case 4:d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.49755+.42323+h*.07922;break o;case 5:d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.48829+.35875+h*.14128+Fc(d*3)*-.01168;break o;case 6:d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.49703+.40217+h*.09392+Fc(d*3)*-.00183;break o;case 7:break p;default:break o}}d=d*.8975979010256552;h=Fc(d+d);h=Fc(d)*-.49804+.40243+h*.09831+Fc(d*3)*-.00122}d=p*3.141592653589793;d=ee(d*k)/d}d=d*h;B[e>>3]=d;m=d+m;b=b+1|0;if((b|0)!=8){continue}break}d=1/m;e=l<<3;b=0;while(1){j=g+(b+e<<1)|0;h=H(G(I(B[c+(b<<3)>>3]*32768*d+.5),32768),-32768);q:{if(E(h)<2147483648){i=~~h;break q}i=-2147483648}v[j>>1]=i;b=b+1|0;if((b|0)!=8){continue}break}l=l+1|0;if((l|0)!=8193){continue}break}jb=c- -64|0;c=w[a+20>>2];b=a+368680|0;w[b+16>>2]=w[a+16>>2];w[b+20>>2]=c;c=w[a+12>>2];w[b+8>>2]=w[a+8>>2];w[b+12>>2]=c;c=w[a+4>>2];w[b>>2]=w[a>>2];w[b+4>>2]=c}}function fv(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-96|0;jb=e;B[e+88>>3]=c;g=w[b+4>>2];a:{if(!g){break a}h=w[b>>2];f=g-1|0;i=x[h+f|0];if((i|0)==33){d=1}else{if((i|0)!=63){break a}d=0}w[b>>2]=h;w[b+4>>2]=f>>>0>g>>>0?g:f}f=82096;h=w[b+4>>2];i=h;g=w[b>>2];b:{c:{d:{e:{f:{g:{while(1){h:{j=w[f>>2];if((ec(j)|0)==(h|0)){if(!h){break h}if(!Jb(j,g,h)){break h}}f=f+8|0;if((f|0)!=82200){continue}break g}break}if((f|0)!=82200){break f}}if(!i){b=ba(8)|0;w[114256]=0;T(1449,e+56|0,e+88|0);a=w[114256];w[114256]=0;i:{if((a|0)!=1){w[114256]=0;a=S(1436,e+56|0,0,13363)|0;d=w[114256];w[114256]=0;if((d|0)!=1){w[e+80>>2]=w[a+8>>2];d=w[a+4>>2];w[e+72>>2]=w[a>>2];w[e+76>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,e+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}f=P()|0;if(u[e+83|0]<0){zb(w[e+72>>2])}if(u[e+67|0]>=0){break c}zb(w[e+56>>2]);break c}f=P()|0;if(u[e+67|0]>=0){break i}zb(w[e+56>>2]);break i}f=P()|0}ca(b|0);break c}if(!d){break e}g=ba(8)|0;w[114256]=0;b=Q(1447,e+24|0,b|0)|0;a=w[114256];w[114256]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;d=w[114256];w[114256]=0;if((d|0)==1){break k}w[e+48>>2]=w[a+8>>2];d=w[a+4>>2];w[e+40>>2]=w[a>>2];w[e+44>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;a=Q(1315,e+40|0,13373)|0;f=w[114256];w[114256]=0;d=1;if((f|0)==1){break q}w[e- -64>>2]=w[a+8>>2];f=w[a+4>>2];w[e+56>>2]=w[a>>2];w[e+60>>2]=f;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;T(1449,e+8|0,e+88|0);a=w[114256];w[114256]=0;if((a|0)==1){break p}w[114256]=0;a=x[e+19|0];d=a<<24>>24<0;a=S(92,e+56|0,(d?w[e+8>>2]:e+8|0)|0,(d?w[e+12>>2]:a)|0)|0;f=w[114256];w[114256]=0;d=1;if((f|0)==1){break o}w[e+80>>2]=w[a+8>>2];d=w[a+4>>2];w[e+72>>2]=w[a>>2];w[e+76>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(g,e+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}f=P()|0;d=0;if(u[e+83|0]>=0){break n}zb(w[e+72>>2]);break n}f=P()|0;break j}f=P()|0;break l}f=P()|0;break m}f=P()|0}if(u[e+19|0]>=0){break m}zb(w[e+8>>2])}if(u[e+67|0]>=0){break l}zb(w[e+56>>2])}if(u[e+51|0]<0){zb(w[e+40>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(d){break j}break c}f=P()|0;if(u[b+11|0]>=0){break j}zb(w[b>>2])}ca(g|0);break c}r:{if((h|0)!=17){if((h|0)==24){break r}if(h){break e}b=ba(8)|0;w[114256]=0;T(1449,e+56|0,e+88|0);a=w[114256];w[114256]=0;s:{if((a|0)!=1){w[114256]=0;a=S(1436,e+56|0,0,13363)|0;d=w[114256];w[114256]=0;if((d|0)!=1){w[e+80>>2]=w[a+8>>2];d=w[a+4>>2];w[e+72>>2]=w[a>>2];w[e+76>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,e+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}f=P()|0;if(u[e+83|0]<0){zb(w[e+72>>2])}if(u[e+67|0]>=0){break c}zb(w[e+56>>2]);break c}f=P()|0;if(u[e+67|0]>=0){break s}zb(w[e+56>>2]);break s}f=P()|0}ca(b|0);break c}if(!Jb(g,3971,17)){if(!x[a+28|0]){break e}if(!(!(c<=0)&c<=4)){b=ba(8)|0;w[114256]=0;a=Q(5,e+72|0,4066)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}f=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}c=Tb(65536/c);b=-1;t:{if(c>=4294967295){break t}b=0;if(c<=0){break t}b=~~c>>>0;if(c<4294967296&c>=0){break t}b=0}a=w[a+24>>2];w[a+480244>>2]=b;_g(a);break e}if(Jb(g,4023,17)|!x[a+28|0]){break e}if(!(!(c<=0)&c<=4)){b=ba(8)|0;w[114256]=0;a=Q(5,e+72|0,4087)|0;d=w[114256];w[114256]=0;if((d|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}f=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}f=P()|0;ca(b|0);break c}c=Tb(c*65536);b=-1;u:{if(c>=4294967295){break u}b=0;if(c<=0){break u}b=~~c>>>0;if(c<4294967296&c>=0){break u}b=0}a=w[a+24>>2];w[a+480240>>2]=b;_g(a);break e}if(Jb(g,4041,h)){break e}c=Tb(c*65536);b=2147483647;v:{if(c>=2147483647){break v}b=-2147483648;if(c<=-2147483648){break v}b=~~c;if(E(c)<2147483648){break v}b=-2147483648}w[w[a+24>>2]+480236>>2]=b}jb=e+96|0;return}f=P()|0;ca(b|0)}R(f|0)}M()}function nu(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0;h=jb-560|0;jb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+C(s,-24)|0;o=w[(e<<2)+48256>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){B[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+w[(c<<2)+48272>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}p=l-24|0;g=0;i=(o|0)>0?o:0;n=(d|0)<=0;while(1){a:{if(n){f=0;break a}k=g+j|0;c=0;f=0;while(1){f=B[(c<<3)+a>>3]*B[(h+320|0)+(k-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}B[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=o;b:{while(1){f=B[(g<<3)+h>>3];c=0;i=g;k=(g|0)<=0;if(!k){while(1){n=(h+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(E(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(E(f)<2147483648){j=~~f;break d}j=-2147483648}w[n>>2]=j;i=i-1|0;f=B[(i<<3)+h>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=vf(f,p);f=f+I(f*.125)*-8;e:{if(E(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{u=(p|0)<=0;i:{if(!u){i=(g<<2)+h|0;j=w[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;w[r+476>>2]=i;n=c+n|0;j=i>>y;break i}if(p){break h}j=w[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;i=0;if(!k){while(1){r=(h+480|0)+(c<<2)|0;v=w[r>>2];k=16777215;j:{k:{if(i){break k}k=16777216;if(v){break k}i=0;break j}w[r>>2]=k-v;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}k=(g<<2)+h|0;w[k+476>>2]=w[k+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!i){break f}f=f-vf(1,p)}if(f==0){i=0;c=g;n:{if((g|0)<=(o|0)){break n}while(1){c=c-1|0;i=w[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(o|0)){continue}break}if(!i){break n}l=p;while(1){l=l-24|0;g=g-1|0;if(!w[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!w[(h+480|0)+(o-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;B[(h+320|0)+(j<<3)>>3]=w[(s+g<<2)+48272>>2];c=0;f=0;if((d|0)>0){while(1){f=B[(c<<3)+a>>3]*B[(h+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}B[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=vf(f,24-l|0);o:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(E(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(E(f)<2147483648){a=~~f;break q}a=-2147483648}w[d>>2]=a;g=g+1|0;break o}if(E(f)<2147483648){c=~~f}else{c=-2147483648}l=p}w[(h+480|0)+(g<<2)>>2]=c}f=vf(1,l);r:{if((g|0)<0){break r}d=g;while(1){a=d;B[(d<<3)+h>>3]=f*+w[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}k=0;if((g|0)<0){break r}a=(o|0)>0?o:0;i=g;while(1){d=a>>>0<k>>>0?a:k;l=g-i|0;c=0;f=0;while(1){f=B[(c<<3)+51040>>3]*B[(c+i<<3)+h>>3]+f;p=(c|0)!=(d|0);c=c+1|0;if(p){continue}break}B[(h+160|0)+(l<<3)>>3]=f;i=i-1|0;c=(g|0)!=(k|0);k=k+1|0;if(c){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<=0){break v}f=B[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;x=B[e>>3];f=x+f;B[d+(c<<3)>>3]=m+(x-f);B[e>>3]=f;d=c>>>0>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=B[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;q=B[e>>3];f=q+f;B[d+(c<<3)>>3]=m+(q-f);B[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}q=0;if((g|0)<=1){break v}while(1){q=q+B[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=B[h+160>>3];if(j){break t}B[b>>3]=f;f=B[h+168>>3];B[b+16>>3]=q;B[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+B[(h+160|0)+(a<<3)>>3];if(a){continue}break}}B[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+B[(h+160|0)+(a<<3)>>3];if(a){continue}break}}B[b>>3]=j?-f:f;f=B[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+B[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}B[b+8>>3]=j?-f:f;break s}B[b>>3]=-f;f=B[h+168>>3];B[b+16>>3]=-q;B[b+8>>3]=-f}jb=h+560|0;return n&7}function $x(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-288|0;jb=e;i=Cb(e,0,282);e=jb-112|0;jb=e;d=Cb(i,0,282);a:{b:{c:{d:{if(!gd(a,9437,4)){break d}b=w[a+8>>2];c=b-4|0;w[a+8>>2]=b>>>0>=c>>>0?c:0;w[e+96>>2]=w[a>>2];b=w[a+4>>2];w[e+100>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[a+12>>2];c=w[a+8>>2];w[114256]=0;w[e+104>>2]=c;w[e+108>>2]=b;b=Q(721,e+96|0,d|0)|0;c=w[114256];w[114256]=0;e:{f:{g:{if((c|0)==1){break g}if(!b){u[d|0]=0;u[d+1|0]=0;u[d+2|0]=0;u[d+3|0]=0;u[d+4|0]=0;u[d+5|0]=0;u[d+6|0]=0;u[d+7|0]=0;b=0;u[d+23|0]=0;u[d+24|0]=0;u[d+25|0]=0;u[d+26|0]=0;u[d+16|0]=0;u[d+17|0]=0;u[d+18|0]=0;u[d+19|0]=0;u[d+20|0]=0;u[d+21|0]=0;u[d+22|0]=0;u[d+23|0]=0;u[d+8|0]=0;u[d+9|0]=0;u[d+10|0]=0;u[d+11|0]=0;u[d+12|0]=0;u[d+13|0]=0;u[d+14|0]=0;u[d+15|0]=0;break e}c=x[d+26|0];f=w[e+96>>2];g=w[w[f>>2]+36>>2];b=0;w[114256]=0;c=S(g|0,f|0,w[e+104>>2],c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(!c){break e}if(!x[d+26|0]){c=0;break f}c=0;while(1){h:{w[114256]=0;f=Q(201,e+96|0,e+48|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break h}f=f?x[e+48|0]:0;u[(b+d|0)+27|0]=f;c=(f&255)+c|0;b=b+1|0;if(b>>>0<x[d+26|0]){continue}break f}break}c=P()|0;break b}c=P()|0;break b}f=w[e+96>>2];g=w[w[f>>2]+36>>2];b=0;w[114256]=0;h=g;g=c&65535;c=S(h|0,f|0,w[e+104>>2],g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}if(!c){break e}b=w[e+96>>2];c=w[w[b>>2]+36>>2];w[114256]=0;b=S(c|0,b|0,w[e+104>>2],g|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}i:{if(b){b=g+w[e+104>>2]|0;break i}b=w[e+96>>2];c=w[w[b>>2]+24>>2];w[114256]=0;b=V(c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}}w[e+104>>2]=b;f=x[d+26|0];c=f+27|0;if(f){b=0;while(1){c=x[(b+d|0)+27|0]+c|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}w[114256]=0;b=w[e+104>>2];c=b-(c&65535)|0;w[e+104>>2]=b>>>0>=c>>>0?c:0;f=V(722,e+88|0)|0;b=w[114256];w[114256]=0;j:{k:{if((b|0)!=1){w[114256]=0;u[e+71|0]=0;u[e+72|0]=0;u[e+73|0]=0;u[e+74|0]=0;b=e- -64|0;w[b>>2]=0;w[b+4>>2]=0;w[e+56>>2]=0;w[e+60>>2]=0;w[e+48>>2]=0;w[e+52>>2]=0;Q(723,e+96|0,e+48|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}c=0;v[e+70>>1]=0;v[e+72>>1]=0;b=w[f>>2];while(1){b=w[((x[(e+48|0)+c|0]^b>>>24)<<2)+85568>>2]^b<<8;c=c+1|0;if((c|0)!=27){continue}break}w[f>>2]=b;b=x[d+26|0];c=w[e+96>>2];h=w[w[c>>2]+36>>2];w[114256]=0;c=S(h|0,c|0,w[e+104>>2],b|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break k}l:{if(c){c=b+w[e+104>>2]|0;break l}b=w[e+96>>2];c=w[w[b>>2]+24>>2];w[114256]=0;c=V(c|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break k}}w[e+104>>2]=c;b=x[d+26|0];if(b){c=d+27|0;h=b+c|0;b=w[f>>2];while(1){b=w[((x[c|0]^b>>>24)<<2)+85568>>2]^b<<8;c=c+1|0;if((h|0)!=(c|0)){continue}break}w[f>>2]=b}break j}c=P()|0;break b}c=P()|0;break b}w[114256]=0;U(188,e+32|0,e+96|0,g|0);b=w[114256];w[114256]=0;m:{n:{if((b|0)!=1){w[114256]=0;g=Q(484,e+8|0,e+32|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break n}b=w[g+4>>2];o:{p:{if(b){h=w[g>>2]+b|0;break p}b=w[g+8>>2];h=w[g+12>>2];if((b|0)==(h|0)){break o}}if((b|0)==(h|0)){break o}c=w[f>>2];while(1){c=w[((x[b|0]^c>>>24)<<2)+85568>>2]^c<<8;w[f>>2]=c;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=w[g+8>>2];if(b){w[g+12>>2]=b;zb(b)}b=w[e+36>>2];if(!b){break m}c=w[b+4>>2];w[b+4>>2]=c-1;if(c){break m}ob[w[w[b>>2]+8>>2]](b);Ib(b);break m}c=P()|0;break b}c=P()|0;Bb(e+32|0);break b}b=0;if(w[f>>2]!=(x[d+22|0]|x[d+23|0]<<8|(x[d+24|0]<<16|x[d+25|0]<<24))){break e}f=x[d+26|0];c=f+27|0;if(f){while(1){c=x[(b+d|0)+27|0]+c|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}b=w[a+8>>2];d=w[a>>2];f=w[w[d>>2]+36>>2];w[114256]=0;h=b;b=c&65535;d=S(f|0,d|0,h|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}q:{if(d){c=b+w[a+8>>2]|0;break q}b=w[a>>2];d=w[w[b>>2]+24>>2];w[114256]=0;c=V(d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}}w[a+8>>2]=c;b=1}a=w[e+100>>2];if(!a){break d}d=w[a+4>>2];w[a+4>>2]=d-1;if(d){break d}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=e+112|0;break a}c=P()|0}Bb(e+96|0);R(c|0);M()}jb=i+288|0;return b|0}function vv(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-96|0;jb=e;a:{b:{c:{f=w[a+24>>2];d:{if(!(w[a+4>>2]|f&2048)){d=w[a+72>>2];c=w[a+76>>2];break d}d=w[a+28>>2];b=w[a+64>>2];g=b+w[a+8>>2]|0;f=w[a+12>>2];f=b>>>0>g>>>0?f+1|0:f;b=g;w[e+80>>2]=b;w[e+84>>2]=f;w[e+32>>2]=b;w[e+36>>2]=f;w[e+72>>2]=0;w[e+76>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;rf(d,e+24|0);c=w[a+28>>2];d=1073741826;if(x[(w[w[c>>2]-12>>2]+c|0)+16|0]&5){break b}b=a+44|0;d=w[b>>2];c=w[b+4>>2]-d>>4;g=w[a+92>>2];e:{if(c>>>0<g>>>0){n=jb-32|0;jb=n;f:{j=g-c|0;f=w[b+8>>2];d=w[b+4>>2];g:{if(j>>>0<=f-d>>4>>>0){if(j){c=(j<<4)+d|0;while(1){v[d+12>>1]=0;w[d+8>>2]=-1;w[d>>2]=0;w[d+4>>2]=0;d=d+16|0;if((c|0)!=(d|0)){continue}break}}else{c=d}w[b+4>>2]=c;break g}c=w[b>>2];g=d-c>>4;i=g+j|0;if(i>>>0>=268435456){break f}d=f-c|0;c=d>>3;h=gi(n+8|0,d>>>0>=2147483632?268435455:c>>>0>i>>>0?c:i,g,b+8|0);d=w[h+8>>2];f=d+(j<<4)|0;while(1){v[d+12>>1]=0;w[d+8>>2]=-1;w[d>>2]=0;w[d+4>>2]=0;d=d+16|0;if((f|0)!=(d|0)){continue}break}w[h+8>>2]=f;i=w[b+4>>2];d=w[b>>2];c=i-d|0;g=w[h+4>>2]-c|0;w[h+4>>2]=g;if((c|0)>0){Fb(g,d,c);i=w[b+4>>2];g=w[h+4>>2];f=w[h+8>>2];d=w[b>>2]}w[b>>2]=g;w[h+4>>2]=d;w[b+4>>2]=f;w[h+8>>2]=i;c=w[b+8>>2];w[b+8>>2]=w[h+12>>2];w[h>>2]=d;w[h+12>>2]=c;if((d|0)!=(i|0)){w[h+8>>2]=((d-i|0)+15&-16)+i}if(!d){break g}zb(d)}jb=n+32|0;break e}Mb(b);M()}if(c>>>0>g>>>0){w[b+4>>2]=d+(g<<4)}}n=a+32|0;Vj(n,w[a+92>>2]<<2);if(w[a+92>>2]){k=e+96|0;while(1){b=w[a+28>>2];d=1073741828;if(x[(w[w[b>>2]-12>>2]+b|0)+16|0]&5){break b}f=y[a+16>>1];h:{if((f|0)!=65535){break h}u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(b,e+56|0);c=x[e+95|0];f=c>>>1|0;if(!(c&1)){break h}u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(b,e+56|0);f=x[e+95|0]<<7|f}b=w[a+36>>2]-w[a+32>>2]|0;if(!(!f|(b^-1)>>>0<f>>>0)){$e(n,b+f|0);sf(w[a+28>>2],b+w[a+32>>2]|0,f)}d=w[a+44>>2];l=o<<4;c=d+l|0;w[c>>2]=b;v[c+12>>1]=f;if(x[a+24|0]&64){j=w[a+28>>2];u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(j,e+56|0);b=x[e+95|0];f=(b&252)>>>2|0;m=0;c=b&3;if(c){c=-1<<c;i=(c>>>0>=4294967294?-2:c)^-1;d=0;c=0;while(1){u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(j,e+56|0);g=x[e+95|0];b=c;c=d+1|0;b=c?b:b+1|0;d=c;c=b;b=(d<<3)-2|0;h=b&31;if((b&63)>>>0>=32){b=g<<h;g=0}else{b=(1<<h)-1&g>>>32-h;g=g<<h}f=g|f;m=b|m;if((d|0)!=(i|0)|c){continue}break}if((m|0)<0){break c}}d=w[a+44>>2];w[(l+d|0)+4>>2]=f}f=w[a+4>>2];i:{if(f){w[(d+l|0)+8>>2]=f;break i}if(!(x[a+24|0]&128)){f=w[(d+l|0)+8>>2];break i}j=w[a+28>>2];u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(j,e+56|0);b=x[e+95|0];f=(b&252)>>>2|0;m=0;c=b&3;if(c){c=-1<<c;i=(c>>>0>=4294967294?-2:c)^-1;d=0;c=0;while(1){u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(j,e+56|0);g=x[e+95|0];b=c;c=d+1|0;b=c?b:b+1|0;d=c;c=b;b=(d<<3)-2|0;h=b&31;if((b&63)>>>0>=32){b=g<<h;g=0}else{b=(1<<h)-1&g>>>32-h;g=g<<h}f=g|f;m=b|m;if((d|0)!=(i|0)|c){continue}break}if((m|0)<0){break c}}d=w[a+44>>2];w[(l+d|0)+8>>2]=f}if(!(x[a+24|0]&64|(f|0)==-1)){b=d+l|0;if(o){c=(d+l|0)-16|0;c=w[c+8>>2]+w[c+4>>2]|0}else{c=0}w[b+4>>2]=c}if(u[a+25|0]&1){b=w[a+28>>2];u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(b,e+56|0);c=x[e+95|0];f=c>>>1|0;if(c&1){u[e+95|0]=0;w[e+60>>2]=k;w[e+56>>2]=e+95;Ob(b,e+56|0);f=x[e+95|0]<<7|f}cg(w[a+28>>2],f<<(w[a+24>>2]>>>9&1),-1)}o=o+1|0;if(o>>>0<z[a+92>>2]){continue}break}}rd(e+56|0,w[a+28>>2]);c=w[e+68>>2];d=w[e+64>>2];w[a+72>>2]=d;w[a+76>>2]=c;f=w[a+24>>2]}w[a+24>>2]=f|16;f=d;d=w[a+88>>2];g=d+w[a+8>>2]|0;b=w[a+12>>2];b=d>>>0>g>>>0?b+1|0:b;d=(d|0)==w[a+64>>2];g=d?f:g;w[a+80>>2]=g;b=d?c:b;w[a+84>>2]=b;c=w[a+28>>2];w[e+48>>2]=g;w[e+52>>2]=b;w[e+16>>2]=g;w[e+20>>2]=b;w[e+40>>2]=0;w[e+44>>2]=0;w[e+8>>2]=0;w[e+12>>2]=0;rf(c,e+8|0);c=w[a+24>>2];if(c&64|!(w[a+4>>2]|c&128)){break a}g=w[a+92>>2];if(!g){break a}b=w[a+80>>2];c=w[a+8>>2];d=b-c|0;b=w[a+44>>2];a=0;while(1){c=b+(a<<4)|0;w[c+4>>2]=d+w[c+4>>2];a=a+1|0;if((g|0)!=(a|0)){continue}break}break a}d=1073741829}w[a>>2]=d|w[a>>2]}jb=e+96|0}function Uw(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;w[a+24588>>2]=0;w[a+24592>>2]=0;w[a+4>>2]=0;w[a>>2]=25728;w[a+8>>2]=w[19471];b=a+24596|0;w[b>>2]=0;w[b+4>>2]=0;ph(a+24604|0);w[a+393348>>2]=0;u[a+393344|0]=7;b=a+393336|0;w[b>>2]=1889785610;w[b+4>>2]=1072630333;u[a+393328|0]=3;w[a+24668>>2]=0;u[a+24664|0]=7;b=a+24656|0;w[b>>2]=1889785610;w[b+4>>2]=1072630333;u[a+24648|0]=3;if(!x[455304]){u[455280]=3;w[21655]=0;u[86616]=7;w[21652]=1889785610;w[21653]=1072630333;u[86600]=3;w[113825]=0;u[455296]=7;w[113822]=1889785610;w[113823]=1072630333;Zj(86600,1);u[455304]=1}b=a+24648|0;hc(b+131112|0,217712,65536);hc(b+196648|0,283248,65536);hc(b+262184|0,348784,65536);hc(b+24|0,86624,131088);Fb(b+327720|0,414320,40960);b=a+393352|0;w[b+4104>>2]=0;w[b+4108>>2]=0;w[b>>2]=8;w[b+4>>2]=0;c=b+4112|0;w[c>>2]=0;w[c+4>>2]=0;c=b+4120|0;w[c>>2]=0;w[c+4>>2]=0;v[b+4128>>1]=0;Cb(b+4132|0,0,40);Cb(b+8|0,0,4096);Cb(b+4172|0,0,82656);w[a+480224>>2]=0;v[a+480212>>1]=0;w[a+480204>>2]=0;w[a+480208>>2]=0;w[a+480180>>2]=0;w[a+480184>>2]=0;b=a+480186|0;v[b>>1]=0;v[b+2>>1]=0;v[b+4>>1]=0;v[b+6>>1]=0;w[a+480272>>2]=0;w[a+480256>>2]=0;w[a+480248>>2]=0;w[a+480252>>2]=0;w[a+480240>>2]=65536;w[a+480244>>2]=65536;f=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0;u[b+16|0]=0;w[b>>2]=0;u[b+17|0]=0;u[b+18|0]=0;u[b+19|0]=0;u[b+20|0]=0;u[b+21|0]=0;u[b+22|0]=0;u[b+23|0]=0;u[b+24|0]=0;u[b+25|0]=0;u[b+26|0]=0;u[b+27|0]=0;u[b+28|0]=0;w[114256]=0;X(224,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break j}b=b+32|0;if((f|0)!=(b|0)){continue}break}w[a+484344>>2]=0;w[a+484348>>2]=0;w[a+484356>>2]=a;w[a+484352>>2]=0;w[114256]=0;g=Q(811,a+484360|0,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break i}c=a+900380|0;b=a+484380|0;while(1){u[b+43|0]=0;u[b+44|0]=0;u[b+45|0]=0;u[b+46|0]=0;u[b+47|0]=0;u[b+48|0]=0;u[b+49|0]=0;u[b+50|0]=0;v[b+34>>1]=0;w[b+20>>2]=0;u[b+51|0]=0;u[b+52|0]=0;u[b+53|0]=0;u[b+54|0]=0;u[b+55|0]=0;u[b+56|0]=0;u[b+57|0]=0;u[b+58|0]=0;u[b+57|0]=0;u[b+58|0]=0;u[b+59|0]=0;u[b+60|0]=0;u[b+61|0]=0;u[b+62|0]=0;u[b+63|0]=0;u[b+64|0]=0;w[114256]=0;T(266,b|0,0);d=w[114256];w[114256]=0;if((d|0)==1){break h}b=b+104|0;if((c|0)!=(b|0)){continue}break}w[114256]=0;X(564,a+901404|0);b=w[114256];w[114256]=0;if((b|0)==1){break g}h=Cb(a+906300|0,0,168028);w[114256]=0;b=ea(812)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}w[114256]=0;b=ml(b);d=w[114256];w[114256]=0;if((d|0)==1){break f}w[a+1074328>>2]=C(b,214013)+2531011;w[114256]=0;V(814,a+1074332|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;V(815,a+1074376|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;e=S(787,a+1304360|0,a|0,255)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}w[a+1304520>>2]=0;w[a+1304524>>2]=0;b=a+1304544|0;w[b>>2]=0;w[b+4>>2]=0;b=a+1304536|0;w[b>>2]=0;w[b+4>>2]=0;b=a+1304528|0;w[b>>2]=0;w[b+4>>2]=0;i=Cb(a+1304392|0,0,121);w[a+1304560>>2]=0;b=a+1304552|0;w[b>>2]=0;w[b+4>>2]=1072693248;Cb(a+12|0,0,16384);b=a+1074408|0;w[b>>2]=4;w[b+4>>2]=16;w[a+480216>>2]=4;w[a+480220>>2]=16;Cb(c,0,1024);Cb(a+946304|0,0,128e3);w[114256]=0;b=V(22,12)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[a+4>>2]=b;return a|0}d=P()|0;break a}d=P()|0;break b}d=P()|0;break c}d=P()|0;break c}d=P()|0;break d}d=P()|0;b=a+1304436|0;if(u[b+59|0]<0){zb(w[b+48>>2])}if(u[b+47|0]<0){zb(w[b+36>>2])}if(u[b+35|0]<0){zb(w[b+24>>2])}if(u[b+23|0]<0){zb(w[b+12>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(u[a+1304435|0]<0){zb(w[a+1304424>>2])}if(u[a+1304423|0]<0){zb(w[a+1304412>>2])}if(u[a+1304411|0]<0){zb(w[a+1304400>>2])}kk(a+1304396|0,0);jk(i,0);Zn(e)}b=a+946300|0;while(1){c=b-160|0;e=w[c+4>>2];if(e){w[b-152>>2]=e;zb(e)}b=c;if((b|0)!=(h|0)){continue}break}}Ak(g)}Gn(f)}b=w[a+480248>>2];if(b){w[a+480252>>2]=b;zb(b)}R(d|0);M()}function iJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb+-64|0;jb=h;w[h+56>>2]=b;w[e>>2]=0;Sb(h,d);w[114256]=0;i=V(1735,h|0)|0;j=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ab(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;Ab(h);R(a|0);M()}hs(a,f+24|0,h+56|0,c,e,i);break b}gs(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=ob[w[w[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Ie(g,b,c,d,e,f,Qb(a),Qb(a)+(Db(a)<<2)|0),w[k+56>>2]=l;break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];B:{if(!(b&4|a-1>>>0>30)){w[f+12>>2]=a;break B}w[e>>2]=b|4}break b}g=w[16215];w[h+24>>2]=w[16214];w[h+28>>2]=g;g=w[16213];w[h+16>>2]=w[16212];w[h+20>>2]=g;g=w[16211];w[h+8>>2]=w[16210];w[h+12>>2]=g;g=w[16209];w[h>>2]=w[16208];w[h+4>>2]=g;k=h,l=Ie(a,b,c,d,e,f,h,h+32|0),w[k+56>>2]=l;break b}g=w[16223];w[h+24>>2]=w[16222];w[h+28>>2]=g;g=w[16221];w[h+16>>2]=w[16220];w[h+20>>2]=g;g=w[16219];w[h+8>>2]=w[16218];w[h+12>>2]=g;g=w[16217];w[h>>2]=w[16216];w[h+4>>2]=g;k=h,l=Ie(a,b,c,d,e,f,h,h+32|0),w[k+56>>2]=l;break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];C:{if(!(b&4|(a|0)>23)){w[f+8>>2]=a;break C}w[e>>2]=b|4}break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];D:{if(!(b&4|a-1>>>0>11)){w[f+8>>2]=a;break D}w[e>>2]=b|4}break b}a=oe(h+56|0,c,e,i,3);b=w[e>>2];E:{if(!(b&4|(a|0)>365)){w[f+28>>2]=a;break E}w[e>>2]=b|4}break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];F:{if(!(b&4|(a|0)>12)){w[f+16>>2]=a-1;break F}w[e>>2]=b|4}break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];G:{if(!(b&4|(a|0)>59)){w[f+4>>2]=a;break G}w[e>>2]=b|4}break b}a=h+56|0;b=jb-16|0;jb=b;w[b+8>>2]=c;while(1){H:{if(!zj(a,b+8|0)){break H}if(!pf(i,1,bg(a))){break H}Mg(a);continue}break}if(Le(a,b+8|0)){w[e>>2]=w[e>>2]|2}jb=b+16|0;break b}b=h+56|0;a=ob[w[w[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Db(a)|0)==(0-Db(a+12|0)|0)){w[e>>2]=w[e>>2]|4;break I}c=lj(b,c,a,a+24|0,i,e,0);b=w[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){w[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){w[f+8>>2]=b+12}}break b}g=Fb(h,64896,44);k=g,l=Ie(a,b,c,d,e,f,g,g+44|0),w[k+56>>2]=l;break b}w[h+16>>2]=w[16240];g=w[16239];w[h+8>>2]=w[16238];w[h+12>>2]=g;g=w[16237];w[h>>2]=w[16236];w[h+4>>2]=g;k=h,l=Ie(a,b,c,d,e,f,h,h+20|0),w[k+56>>2]=l;break b}a=oe(h+56|0,c,e,i,2);b=w[e>>2];J:{if(!(b&4|(a|0)>60)){w[f>>2]=a;break J}w[e>>2]=b|4}break b}g=w[16251];w[h+24>>2]=w[16250];w[h+28>>2]=g;g=w[16249];w[h+16>>2]=w[16248];w[h+20>>2]=g;g=w[16247];w[h+8>>2]=w[16246];w[h+12>>2]=g;g=w[16245];w[h>>2]=w[16244];w[h+4>>2]=g;k=h,l=Ie(a,b,c,d,e,f,h,h+32|0),w[k+56>>2]=l;break b}a=oe(h+56|0,c,e,i,1);b=w[e>>2];K:{if(!(b&4|(a|0)>6)){w[f+24>>2]=a;break K}w[e>>2]=b|4}break b}a=ob[w[w[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=ob[w[w[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Ie(g,b,c,d,e,f,Qb(a),Qb(a)+(Db(a)<<2)|0),w[k+56>>2]=l;break b}fs(f+20|0,h+56|0,c,e,i);break b}a=oe(h+56|0,c,e,i,4);if(!(x[e|0]&4)){w[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}w[e>>2]=w[e>>2]|4;break b}a=jb-16|0;jb=a;w[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(Le(c,a+8|0)){break M}b=4;if((Bg(i,bg(c))|0)!=37){break M}b=2;if(!Le(Mg(c),a+8|0)){break L}}w[e>>2]=w[e>>2]|b}jb=a+16|0}a=w[h+56>>2]}jb=h- -64|0;return a|0}function ek(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-208|0;jb=d;a:{b:{c:{d:{e:{if(x[c|0]&2){b=w[b>>2];if((b|0)==-2147483648){w[114256]=0;v[d+48>>1]=45;u[d+59|0]=1;w[d+200>>2]=-2147483648;U(91,d+184|0,d+200|0,c|0);b=w[114256];w[114256]=0;f:{g:{if((b|0)!=1){w[114256]=0;b=x[d+195|0];c=b<<24>>24<0;b=S(92,d+48|0,(c?w[d+184>>2]:d+184|0)|0,(c?w[d+188>>2]:b)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break g}c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;if(u[d+195|0]<0){zb(w[d+184>>2])}if(u[d+59|0]>=0){break d}zb(w[d+48>>2]);break d}c=P()|0;break f}c=P()|0;if(u[d+195|0]>=0){break f}zb(w[d+184>>2])}if(u[d+59|0]>=0){break a}zb(w[d+48>>2]);break a}if((b|0)>=0){break e}w[114256]=0;v[d+48>>1]=45;u[d+59|0]=1;w[d+200>>2]=0-b;U(91,d+184|0,d+200|0,c|0);b=w[114256];w[114256]=0;h:{i:{if((b|0)!=1){w[114256]=0;b=x[d+195|0];c=b<<24>>24<0;b=S(92,d+48|0,(c?w[d+184>>2]:d+184|0)|0,(c?w[d+188>>2]:b)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;if(u[d+195|0]<0){zb(w[d+184>>2])}if(u[d+59|0]>=0){break d}zb(w[d+48>>2]);break d}c=P()|0;break h}c=P()|0;if(u[d+195|0]>=0){break h}zb(w[d+184>>2])}if(u[d+59|0]>=0){break a}zb(w[d+48>>2]);break a}g=Od(d+48|0);e=w[w[g>>2]-12>>2];w[114256]=0;f=ea(79)|0;h=w[114256];w[114256]=0;j:{k:{l:{m:{if((h|0)==1){break m}w[114256]=0;e=e+g|0;T(10,d+40|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break m}w[114256]=0;U(80,d+184|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break c}Ab(d+184|0);e=w[e+24>>2];if(e){h=w[w[e>>2]+8>>2];w[114256]=0;T(h|0,e|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break c}e=e+4|0;h=Ic(d+200|0,e);Wc(e,f);Ab(h)}Ab(d+40|0);f=2;e=w[c>>2];h=w[c+8>>2];e=w[c+4>>2]?e&24576?e:(h|0)!=-1?e&-12289|8192:e:e;n:{if(!(e&1)){f=8;if(!(e&2)){break n}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]&-75|f}o:{if(e&4096){break o}f=4;if(!(e&8192)){f=256;if(!(e&16384)){break o}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]|f}p:{if(e&16){f=w[w[g>>2]-12>>2]+g|0;w[f+4>>2]=w[f+4>>2]&-16385;break p}if(!(e&32)){break p}f=w[w[g>>2]-12>>2]+g|0;w[f+4>>2]=w[f+4>>2]|16384}if((h|0)!=-1){w[(w[w[g>>2]-12>>2]+g|0)+8>>2]=h}b=w[b>>2];w[114256]=0;Q(81,g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break m}w[114256]=0;k=g+4|0;T(82,d+8|0,k|0);b=w[114256];w[114256]=0;if((b|0)==1){break m}q:{if(!(x[c+1|0]&4)){break q}e=w[c+4>>2];h=w[d+8>>2];f=x[d+19|0];i=f<<24>>24;j=(i|0)<0;b=j?h:d+8|0;j=j?w[d+12>>2]:f;r:{if(!j){f=b;break r}f=b;s:{switch(x[b|0]-43|0){case 0:e=e+1|0;f=((i|0)<0?h:d+8|0)+1|0;break r;case 2:break s;default:break r}}e=e+1|0;f=((i|0)<0?h:d+8|0)+1|0}if(e>>>0<=j>>>0){break q}w[114256]=0;Z(93,d+8|0,f-b|0,e-j|0,48)|0;b=w[114256];w[114256]=0;if((b|0)==1){break l}}w[d+32>>2]=w[d+16>>2];w[d+16>>2]=0;b=w[d+12>>2];w[d+24>>2]=w[d+8>>2];w[d+28>>2]=b;w[d+8>>2]=0;w[d+12>>2]=0;f=w[c+12>>2];t:{if(!f){break t}b=x[d+35|0];b=b<<24>>24<0?w[d+28>>2]:b;if(!b){break t}e=b-1|0;h=u[c+16|0];c=0;while(1){u:{if(!c|(c>>>0)%(f>>>0)){break u}v:{if((c|0)!=(e|0)){break v}switch(x[(u[d+35|0]<0?w[d+24>>2]:d+24|0)|0]-43|0){case 0:case 2:break u;default:break v}}w[114256]=0;Z(93,d+24|0,b-c|0,1,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break k}}c=c+1|0;if((b|0)!=(c|0)){continue}break}}b=w[d+28>>2];w[a>>2]=w[d+24>>2];w[a+4>>2]=b;w[a+8>>2]=w[d+32>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;if(u[d+19|0]<0){zb(w[d+8>>2])}a=w[15e3];w[g>>2]=a;w[w[a-12>>2]+g>>2]=w[15003];w[g+4>>2]=59272;if(u[g+47|0]<0){zb(w[g+36>>2])}wc(k);pc(g+56|0);break d}c=P()|0;break b}c=P()|0;break j}c=P()|0;if(u[d+35|0]>=0){break j}zb(w[d+24>>2])}if(u[d+19|0]>=0){break b}zb(w[d+8>>2]);break b}w[d+48>>2]=b;mi(a,d+48|0,c)}jb=d+208|0;return}c=P()|0;Ab(d+40|0)}nd(g)}R(c|0);M()}function hv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-96|0;jb=e;u[e+95|0]=c;f=w[b+4>>2];a:{if(!f){break a}h=w[b>>2];g=f-1|0;i=x[h+g|0];if((i|0)==33){d=1}else{if((i|0)!=63){break a}d=0}w[b>>2]=h;w[b+4>>2]=f>>>0<g>>>0?f:g}g=82096;h=w[b+4>>2];i=h;f=w[b>>2];b:{c:{d:{e:{f:{while(1){g:{j=w[g>>2];if((ec(j)|0)==(h|0)){if(!h){break g}if(!Jb(j,f,h)){break g}}g=g+8|0;if((g|0)!=82200){continue}break f}break}if((g|0)!=82200){break e}}if(!i){b=ba(8)|0;w[114256]=0;T(1446,e+80|0,e+95|0);a=w[114256];w[114256]=0;h:{if((a|0)!=1){w[114256]=0;a=S(1436,e+80|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[e+91|0]>=0){break c}zb(w[e+80>>2]);break c}g=P()|0;if(u[e+91|0]>=0){break h}zb(w[e+80>>2]);break h}g=P()|0}ca(b|0);break c}if(!d){break d}d=ba(8)|0;w[114256]=0;b=Q(1447,e+48|0,b|0)|0;a=w[114256];w[114256]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;c=w[114256];w[114256]=0;if((c|0)==1){break j}w[e+72>>2]=w[a+8>>2];c=w[a+4>>2];w[e+64>>2]=w[a>>2];w[e+68>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;a=Q(1315,e- -64|0,13373)|0;f=w[114256];w[114256]=0;c=1;if((f|0)==1){break p}w[e+88>>2]=w[a+8>>2];f=w[a+4>>2];w[e+80>>2]=w[a>>2];w[e+84>>2]=f;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;T(1446,e+32|0,e+95|0);a=w[114256];w[114256]=0;if((a|0)==1){break o}w[114256]=0;a=x[e+43|0];c=a<<24>>24<0;a=S(92,e+80|0,(c?w[e+32>>2]:e+32|0)|0,(c?w[e+36>>2]:a)|0)|0;f=w[114256];w[114256]=0;c=1;if((f|0)==1){break n}w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;c=0;if(u[e+19|0]>=0){break m}zb(w[e+8>>2]);break m}g=P()|0;break i}g=P()|0;break k}g=P()|0;break l}g=P()|0}if(u[e+43|0]>=0){break l}zb(w[e+32>>2])}if(u[e+91|0]>=0){break k}zb(w[e+80>>2])}if(u[e+75|0]<0){zb(w[e+64>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(c){break i}break c}g=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2])}ca(d|0);break c}q:{r:{s:{t:{u:{switch(h-17|0){default:if((h|0)==30){break q}if(h){break d}b=ba(8)|0;w[114256]=0;T(1446,e+80|0,e+95|0);a=w[114256];w[114256]=0;v:{if((a|0)!=1){w[114256]=0;a=S(1436,e+80|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[e+16>>2]=w[a+8>>2];c=w[a+4>>2];w[e+8>>2]=w[a>>2];w[e+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,e+8|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}if(u[e+91|0]>=0){break c}zb(w[e+80>>2]);break c}g=P()|0;if(u[e+91|0]>=0){break v}zb(w[e+80>>2]);break v}g=P()|0}ca(b|0);break c;case 0:if(Jb(f,3674,17)){if(Jb(f,3656,17)){break t}}u[a+60|0]=c;break d;case 6:break s;case 1:break u;case 2:case 3:case 4:case 5:break d}}if(Jb(f,3240,h)){if(Jb(f,3221,18)){break d}}u[a+61|0]=c;break d}if(Jb(f,3324,h)){break r}u[a+62|0]=c;break d}if(Jb(f,2484,h)){break d}u[a+63|0]=c;break d}if(Jb(f,3723,h)){break d}u[a+64|0]=c;break d}if(Jb(f,9194,h)){break d}b=w[a+24>>2];d=b+24664|0;f=w[d+4>>2];w[e+24>>2]=w[d>>2];w[e+28>>2]=f;d=b+24656|0;f=w[d+4>>2];w[e+16>>2]=w[d>>2];w[e+20>>2]=f;d=w[b+24652>>2];w[e+8>>2]=w[b+24648>>2];w[e+12>>2]=d;d=0;if(c){a=w[a+56>>2];d=a?(a|0)==2?3:2:1}w[e+28>>2]=d;if(!(x[e+8|0]!=x[b+24648|0]|B[e+16>>3]!=B[b+24656>>3]|x[e+24|0]!=x[b+24664|0])){if(w[b+24668>>2]==(d|0)){break d}}dk(b,e+8|0)}jb=e+96|0;return}R(g|0)}M()}function pJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;w[h+24>>2]=b;w[e>>2]=0;i=h+8|0;Sb(i,d);w[114256]=0;i=V(1561,i|0)|0;j=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ab(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;Ab(h+8|0);R(a|0);M()}ks(a,f+24|0,h+24|0,c,e,i);break b}js(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=ob[w[w[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Je(g,b,c,d,e,f,Qb(a),Qb(a)+Db(a)|0),w[k+24>>2]=l;break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];B:{if(!(b&4|a-1>>>0>30)){w[f+12>>2]=a;break B}w[e>>2]=b|4}break b}w[h+8>>2]=623865125;w[h+12>>2]=2032480100;k=h,l=Je(a,b,c,d,e,f,h+8|0,h+16|0),w[k+24>>2]=l;break b}w[h+8>>2]=623728933;w[h+12>>2]=1680158061;k=h,l=Je(a,b,c,d,e,f,h+8|0,h+16|0),w[k+24>>2]=l;break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];C:{if(!(b&4|(a|0)>23)){w[f+8>>2]=a;break C}w[e>>2]=b|4}break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];D:{if(!(b&4|a-1>>>0>11)){w[f+8>>2]=a;break D}w[e>>2]=b|4}break b}a=pe(h+24|0,c,e,i,3);b=w[e>>2];E:{if(!(b&4|(a|0)>365)){w[f+28>>2]=a;break E}w[e>>2]=b|4}break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];F:{if(!(b&4|(a|0)>12)){w[f+16>>2]=a-1;break F}w[e>>2]=b|4}break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];G:{if(!(b&4|(a|0)>59)){w[f+4>>2]=a;break G}w[e>>2]=b|4}break b}a=h+24|0;b=jb-16|0;jb=b;w[b+8>>2]=c;while(1){H:{if(!Wh(a,b+8|0)){break H}if(!Ld(i,1,tf(a))){break H}eg(a);continue}break}if(ue(a,b+8|0)){w[e>>2]=w[e>>2]|2}jb=b+16|0;break b}b=h+24|0;a=ob[w[w[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Db(a)|0)==(0-Db(a+12|0)|0)){w[e>>2]=w[e>>2]|4;break I}c=nj(b,c,a,a+24|0,i,e,0);b=w[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){w[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){w[f+8>>2]=b+12}}break b}g=x[64808]|x[64809]<<8|(x[64810]<<16|x[64811]<<24);u[h+15|0]=g;u[h+16|0]=g>>>8;u[h+17|0]=g>>>16;u[h+18|0]=g>>>24;g=x[64805]|x[64806]<<8|(x[64807]<<16|x[64808]<<24);w[h+8>>2]=x[64801]|x[64802]<<8|(x[64803]<<16|x[64804]<<24);w[h+12>>2]=g;k=h,l=Je(a,b,c,d,e,f,h+8|0,h+19|0),w[k+24>>2]=l;break b}u[h+12|0]=x[64816];w[h+8>>2]=x[64812]|x[64813]<<8|(x[64814]<<16|x[64815]<<24);k=h,l=Je(a,b,c,d,e,f,h+8|0,h+13|0),w[k+24>>2]=l;break b}a=pe(h+24|0,c,e,i,2);b=w[e>>2];J:{if(!(b&4|(a|0)>60)){w[f>>2]=a;break J}w[e>>2]=b|4}break b}w[h+8>>2]=624576549;w[h+12>>2]=1394948685;k=h,l=Je(a,b,c,d,e,f,h+8|0,h+16|0),w[k+24>>2]=l;break b}a=pe(h+24|0,c,e,i,1);b=w[e>>2];K:{if(!(b&4|(a|0)>6)){w[f+24>>2]=a;break K}w[e>>2]=b|4}break b}a=ob[w[w[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=ob[w[w[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Je(g,b,c,d,e,f,Qb(a),Qb(a)+Db(a)|0),w[k+24>>2]=l;break b}is(f+20|0,h+24|0,c,e,i);break b}a=pe(h+24|0,c,e,i,4);if(!(x[e|0]&4)){w[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}w[e>>2]=w[e>>2]|4;break b}a=jb-16|0;jb=a;w[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(ue(c,a+8|0)){break M}b=4;if((Cg(i,tf(c))|0)!=37){break M}b=2;if(!ue(eg(c),a+8|0)){break L}}w[e>>2]=w[e>>2]|b}jb=a+16|0}a=w[h+24>>2]}jb=h+32|0;return a|0}function hk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-128|0;jb=g;a:{b:{c:{d:{if(!c){l=w[b>>2];break d}f=w[c+4>>2];l=w[b>>2];if(!f&z[c>>2]>=w[b+4>>2]-l>>>0|f){break d}b=ba(8)|0;w[114256]=0;a=Q(21,b|0,17256)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}ka(a|0,74992,20);M()}if(l){break b}b=ba(8)|0;w[114256]=0;a=Q(817,b|0,17256)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}}a=P()|0;ca(b|0);R(a|0);M()}n=w[b+4>>2]-l|0;e:{if(a&2){w[g+116>>2]=0;w[g+120>>2]=0;w[g+112>>2]=n;w[g+108>>2]=l;w[g+104>>2]=75592;f=jb-32|0;jb=f;o=-1;e=jb-16|0;jb=e;d=g+104|0;h=w[d+12>>2];j=f+16|0;w[e+8>>2]=j;w[e+12>>2]=j+10;j=ob[w[w[d>>2]+32>>2]](d,h,e+8|0)|0;if((j|0)==10){f:{if(ob[w[w[d>>2]+36>>2]](d,w[d+12>>2],10)|0){h=w[d+12>>2]+10|0;break f}h=ob[w[w[d>>2]+24>>2]](d)|0}w[d+12>>2]=h}jb=e+16|0;g:{if((j|0)!=10){break g}o=0;if(w[f+16>>2]!=1129474426|w[f+20>>2]!=1634291279|y[f+24>>1]!=14){break g}o=-1;e=jb-16|0;jb=e;h=w[d+12>>2];w[e+8>>2]=f;w[e+12>>2]=f+14;j=ob[w[w[d>>2]+32>>2]](d,h,e+8|0)|0;if((j|0)==14){h:{if(ob[w[w[d>>2]+36>>2]](d,w[d+12>>2],14)|0){h=w[d+12>>2]+14|0;break h}h=ob[w[w[d>>2]+24>>2]](d)|0}w[d+12>>2]=h}jb=e+16|0;if((j|0)!=14){break g}o=y[f+2>>1]!=0&(w[f+4>>2]-1|0)>=0}jb=f+32|0;e=1;if((o|0)==1){break e}w[g+92>>2]=0;w[g+96>>2]=0;w[g+88>>2]=n;w[g+84>>2]=l;w[g+80>>2]=75592;f=jb-16|0;jb=f;d=-1;if(lf(g+80|0,f+8|0)){d=vs(f+8|0)}jb=f+16|0;e=1;if((d|0)==1){break e}j=d;w[g+68>>2]=0;w[g+72>>2]=0;w[g+64>>2]=n;w[g+60>>2]=l;w[g+56>>2]=75592;f=0;i=jb-48|0;jb=i;e=g+56|0;d=-1;i:{if(!rs(e,i+8|0)){break i}d=0;if(!vw(i+8|0)){break i}k=jb-16|0;jb=k;q=ec(8925);j:{if(!q){break j}p=w[e+12>>2];d=x[i+24|0]|x[i+25|0]<<8|(x[i+26|0]<<16|x[i+27|0]<<24);k:{if(p>>>0<d>>>0){f=0;if(ob[w[w[e>>2]+24>>2]](e)>>>0<d>>>0){break k}}w[e+12>>2]=d;l:{if(!(x[i+20|0]|x[i+21|0]<<8|(x[i+22|0]<<16|x[i+23|0]<<24))){break l}while(1){if(!(ob[w[w[e>>2]+36>>2]](e,w[e+12>>2],4)|0)){break l}m:{if((x[i+12|0]|x[i+13|0]<<8)>>>0>=64){d=zh(e,k+13|0);h=d?x[k+13|0]:0;d=h&63;m=h<<24>>24;f=6;n:{if(!(h&64)){break n}while(1){h=zh(e,k+14|0);h=h?x[k+14|0]:0;d=(h&127)<<f|d;if(h<<24>>24>=0){break n}h=f>>>0<25;f=f+7|0;if(h){continue}break}}if((((m|0)<0?0-d|0:d)|0)<=0){break m}}f=0;d=1;o:{if(!zh(e,k+15|0)){h=1;break o}h=1;m=x[k+15|0];if(!m){break o}while(1){s=f>>>0>=q>>>0;h=s&d;m=wo(m<<24>>24);h=!(d&1)|s?h:x[f+8925|0]==(m&255);f=f+1|0;if(!zh(e,k+15|0)){break o}d=h;m=x[k+15|0];if(m){continue}break}}r=(f|0)==(q|0)?h?1:r:r;p:{if(ob[w[w[e>>2]+36>>2]](e,w[e+12>>2],4)|0){d=w[e+12>>2]+4|0;break p}d=ob[w[w[e>>2]+24>>2]](e)|0}w[e+12>>2]=d}t=t+1|0;if(t>>>0<(x[i+20|0]|x[i+21|0]<<8|(x[i+22|0]<<16|x[i+23|0]<<24))>>>0){continue}break}}f=r&1}if(z[e+12>>2]<p>>>0){if(ob[w[w[e>>2]+24>>2]](e)>>>0<p>>>0){break j}}w[e+12>>2]=p}jb=k+16|0;d=f}jb=i+48|0;f=d;e=1;if((d|0)==1){break e}w[g+44>>2]=0;w[g+48>>2]=0;w[g+40>>2]=n;w[g+36>>2]=l;w[g+32>>2]=75592;e=jb-48|0;jb=e;d=-1;q:{if(!rs(g+32|0,e+8|0)){break q}d=0;if(!ns(e+8|0)){break q}if(c){h=w[e+12>>2];if(!w[c+4>>2]&z[c>>2]<(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24))-8>>>0){break q}}d=1}jb=e+48|0;e=1;if((d|0)==1){break e}d=0-((o|0)==-1|(j|0)==-1|(f|0)==-1|(d|0)==-1)|0}if(a&1){a=76368;while(1){f=w[a>>2];if(f){w[g+20>>2]=0;w[g+24>>2]=0;w[g+16>>2]=n;w[g+12>>2]=l;w[g+8>>2]=75592;f=ob[f|0](g+8|0,c)|0;e=1;if((f|0)==1){break e}d=(f|0)==-1?-1:d}a=a+12|0;if((a|0)!=76824){continue}break}}if(c){e=0;if((d|0)!=-1){break e}a=w[c+4>>2];d=a;c=w[c>>2];a=!a&(c|0)==-1|(a|0)!=0;e=w[b+4>>2]-w[b>>2]>>>0<(a?-1:c)>>>0?-1:0;break e}e=0;if((d|0)!=-1){break e}e=w[b+4>>2]-w[b>>2]>>>0>2047?1:-1}jb=g+128|0;return e}ka(a|0,74888,20);M()}function Pn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c&15;f=C(b,896)+a|0;e=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;w[a>>2]=w[a>>2]&-1048577|((d|0)!=0)<<20;return;case 1:if(!(x[a+480209|0]&16)){break a}c=w[a+480180>>2];if((c|0)!=64){if((c|0)==33554432){c=C(b,896)+a|0;e=c+1075684|0;if(!w[e>>2]){break a}c=w[c+1075088>>2];if(!c){break a}f=C(b,896)+a|0;d=y[C(d,24)+25968>>1];b=w[c+24>>2];g=BV(b,b>>31,1712,0);c=(d>>>1|0)+g|0;b=nb;c=CV(c,c>>>0<g>>>0?b+1|0:b,d,0);d=c;b=nb;c=(b|0)>=0&c>>>0>=2147483647|(b|0)>0;d=c?2147483647:d;b=c?0:b;b=(b|0)<0&d>>>0<=2147483648|(b|0)<-1?-2147483648:d;w[f+1075688>>2]=b;i=e,j=md(a,x[f+1075803|0],0,b),w[i>>2]=j;return}b=C(b,896)+a|0;c=d<<28>>24;w[b+1075752>>2]=c;e=y[(d<<1)+26400>>1];w[b+1075688>>2]=e;d=b+1075684|0;if(!w[d>>2]){break a}i=d,j=md(a,x[b+1075803|0],c,e),w[i>>2]=j;return}a=C(b,896)+a|0;b=w[a+1075088>>2];if(!b){break a}w[a+1075688>>2]=w[b+24>>2]+C(d,80);return;case 2:if(w[a+480180>>2]==2){u[(C(b,896)+a|0)+1075826|0]=c&3;return}if(x[a+1074314|0]&32){u[(C(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;return}u[(C(b,896)+a|0)+1075826|0]=c&7;return;case 3:if(w[a+480180>>2]==2){u[(C(b,896)+a|0)+1075829|0]=c&3;return}if(x[a+1074314|0]&32){u[(C(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;return}u[(C(b,896)+a|0)+1075829|0]=c&7;return;case 4:if(x[a+1074314|0]&32){a=C(b,896)+a|0;u[a+1075825|0]=0;u[a+1075832|0]=d>>>0<4?d:0;return}u[(C(b,896)+a|0)+1075832|0]=c&7;return;case 5:if(w[a+1074392>>2]|!(x[a+480209|0]&16)){break a}a=a+1074400|0;w[a>>2]=w[a>>2]+d;return;case 6:if(!(x[a+480209|0]&16)){break a}if(d>>>0<=2){d=y[a+480188>>1];if(d>>>0>255){break a}g=b+1|0;h=(c&15)-1|0;while(1){c=C(d,896)+a|0;c:{if(y[c+1075792>>1]!=(g|0)){break c}d:{e:{switch(h|0){case 0:pg(a,c+1074984|0);if(!(x[c+1075073|0]&2)){break d}e=w[a+1304392>>2];if(!e){break d}Ue(e,d&65535);break d;case 1:f=c+1075072|0;e=w[f>>2];w[f>>2]=e|4096;if(!(e&512)){break d}e=w[a+1304392>>2];if(!e){break d}Ue(e,d&65535);break d;default:break e}}w[c+1075680>>2]=0;f=c+1075072|0;e=w[f>>2];w[f>>2]=e|4096;if(!(e&512)){break d}e=w[a+1304392>>2];if(!e){break d}le(e,d&65535,1)}e=w[c+1075640>>2];if(!e){break c}f=x[e+34|0];if(!f){break c}f=w[(C(f,160)+a|0)+906140>>2];if(!f){break c}ob[w[w[f>>2]+88>>2]](f,e,x[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a}Fo(e,d,a);return;case 7:if(!(x[a+480209|0]&16)){break a}Hf(a,e,d,4);return;case 8:b=e;c=w[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:w[b+88>>2]=w[b+88>>2]&-257;break f;case 1:w[b+692>>2]=128;w[b+88>>2]=w[b+88>>2]|256;break f;case 8:w[b+88>>2]=w[b+88>>2]&-25165825|16777216;break f;case 9:w[b+88>>2]=w[b+88>>2]&-25165825|8388608;break f;case 10:w[a+480208>>2]=c&-16385;break f;case 11:w[a+480208>>2]=c|16384;break f;case 12:w[a+480208>>2]=c&-8193;break f;case 13:w[a+480208>>2]=c|8192;break f;case 14:w[b+88>>2]=w[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(w[b>>2]|w[b+4>>2]){break h}a=w[b+76>>2];if(!a|(x[b+88|0]&2?(x[b+810|0]-1&255)>>>0>=120:0)){break h}w[b>>2]=-1;w[b+4>>2]=a-1}w[b+88>>2]=w[b+88>>2]|128}return;case 9:if(!(x[a+480209|0]&16)){break a}c=C(b,896)+a|0;u[c+1075840|0]=d;if(x[a+1074316|0]&8|(x[c+1075794|0]-1&255)>>>0>119){break a}b=w[(C(b,896)+a|0)+1075060>>2];a=d<<16;if(b>>>0<=a>>>0){break a}w[e+4>>2]=a;return;case 11:c=w[a+480180>>2];i:{if(d){break i}d=1;if(c&16777248){break i}d=0;if((c|0)==2){break a}}ok(a,b,d,(w[a+1074312>>2]&1073741824)>>>30|(c|0)==2);return;case 14:break b;default:break a}}if(w[a+480180>>2]==2){break a}u[(C(b,896)+a|0)+1075848|0]=d}}function YB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-560|0;jb=f;a:{if(z[b+8>>2]<=1463){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<1464){break a}}w[b+8>>2]=1464;if(!vh(b,f+556|0)){break a}tc(a,1);d=a+1074320|0;w[d>>2]=w[d>>2]&-3670017|3145728;b:{if((x[f+556|0]|x[f+557|0]<<8|(x[f+558|0]<<16|x[f+559|0]<<24))==5133389){d=a+1304436|0;e=Hb(f+32|0,4629);if(u[a+1304447|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];d=a+1304448|0;e=Hb(f+32|0,10312);if(u[a+1304459|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];e=Hb(f+32|0,10377);d=a+1304460|0;break b}if((x[f+556|0]|x[f+557|0]<<8|(x[f+558|0]<<16|x[f+559|0]<<24))!=808539209){break a}d=a+1304436|0;e=Hb(f+32|0,4771);if(u[a+1304447|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];d=a+1304448|0;e=Hb(f+32|0,8055);if(u[a+1304459|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];e=Hb(f+32|0,11156);d=a+1304460|0}if(u[a+1304471|0]<0){zb(w[d>>2])}h=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=h;w[d+8>>2]=w[e+8>>2];w[a+1304496>>2]=2;w[b+8>>2]=0;Li(b,a+1304400|0,20);v[a+480190>>1]=31;e=1;while(1){g=Rk(b,f+32|0,(C(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+g|0;e=e+1|0;if((e|0)!=32){continue}break}e=0;if(g>>>0>40){break a}Pi(b,f+552|0);if(x[f+552|0]>128){break a}dl(b,f+32|0);p=x[f+553|0];d=p;c:{while(1){q=x[(f+32|0)+e|0];if(d>>>0<q>>>0){break c}e=e+1|0;if((e|0)!=512){continue}break}if(!c){break c}w[a+480260>>2]=56;w[a+480264>>2]=13696;w[a+480204>>2]=125e4;w[a+480196>>2]=6;v[a+480192>>1]=0;v[a+480188>>1]=4;w[a+480228>>2]=64;w[a+480208>>2]=w[a+480208>>2]|18874368;Ce(a,0);d=x[a+484376|0];e=w[a+484360>>2];g=x[f+552|0];v[f+8>>1]=65535;$d(e+(d<<5)|0,g,f+8|0);v[f+30>>1]=0;h=a+484344|0;td(h,x[f+552|0]);if(x[f+552|0]){while(1){v[w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]+(k<<1)>>1]=k;if(ie(h,k&65535,64)){l=k<<2;d=0;while(1){e=(x[f+32+(d+l)|0]<<8)+1468|0;d:{if(e>>>0>z[b+8>>2]){g=w[b>>2];if(ob[w[w[g>>2]+24>>2]](g)>>>0<e>>>0){break d}}w[b+8>>2]=e}m=C(k,52);e=m+w[h>>2]|0;ld(e);e=w[e>>2]+C(d,6)|0;g=0;while(1){Of(b,f+8|0);w[f+4>>2]=w[f+8>>2];Kf(f+4|0,e);e:{f:{j=x[e+3|0];g:{if((j|0)!=14){if(!j){if(x[e+5|0]){break f}break g}if((j-5&255)>>>0<5){break g}break f}if(x[e+5|0]<=15){break f}}u[e+3|0]=0;break e}We(e)}e=e+24|0;g=g+1|0;if((g|0)!=64){continue}break}d=d+1|0;if((d|0)!=4){continue}break}e=w[w[h>>2]+m>>2];j=0;while(1){d=0;h:{while(1){i:{j:{if((x[e+3|0]&254)==16){l=e+3|0;g=d;k:{while(1){u[l|0]=16;d=x[e+5|0];if(d>>>0>=16){i=d>>>4|0;u[e+5|0]=i;l=i;d=d&15;i=(d|0)==(i|0)|!d;n=i?n:l;o=i?o:d;i=!i;break j}d=e+6|0;if((g&65535)>>>0>=3){break k}g=g+1|0;i=e;l=e+9|0;e=d;if((x[i+9|0]&254)==16){continue}break}i=0;break i}u[f+30|0]=n;u[f+31|0]=o;e=d;d=0;break h}g=d}d=e}e=d+6|0;d=g+1|0;if((g&65535)>>>0<=2){continue}break}u[f+30|0]=n;u[f+31|0]=o;g=i&255;d=0;if(!g){break h}d=w[h>>2];u[f+18|0]=16;v[f+16>>1]=65535;w[f+8>>2]=0;w[f+12>>2]=j;u[f+19|0]=x[(f+g|0)+29|0];u[f+20|0]=x[f+20|0]&248|1;ng(d+m|0,f+8|0);d=i+1|0;d=(d&255)==3?1:d}i=d;j=j+1|0;if((j|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[f+552|0]){continue}break}}if(!(c&2)){break c}c=(x[f+553|0]<<8)+1468|0;l:{if(c>>>0>z[b+8>>2]){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<c>>>0){break l}}w[b+8>>2]=c}e=1;while(1){c=(C(e,104)+a|0)+484380|0;if(w[c>>2]){w[f+8>>2]=264;Fd(f+8|0,c,b)}e=e+1|0;if((e|0)!=32){continue}break}}e=p>>>0>=q>>>0}jb=f+560|0;return e|0}function $O(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-144|0;jb=g;a:{b:{c:{if(!(b<.8)){w[114256]=0;e=V(22,1304568)|0;f=w[114256];w[114256]=0;d:{e:{f:{if((f|0)!=1){w[114256]=0;f=V(1444,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){a=W(0)|0;zb(e);break c}w[114256]=0;e=V(22,8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}w[e+4>>2]=c;w[e>>2]=82380;w[f+1304560>>2]=e;w[g+128>>2]=w[a>>2];d=w[a+4>>2];w[g+132>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[a+12>>2];a=w[a+8>>2];w[114256]=0;w[g+136>>2]=a;w[g+140>>2]=d;w[g+48>>2]=a;w[g+52>>2]=d;a=w[g+132>>2];w[g+40>>2]=w[g+128>>2];w[g+44>>2]=a;a=S(1450,f|0,g+40|0,15)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(a){w[114256]=0;V(816,f|0)|0;a=w[114256];w[114256]=0;h=1;if((a|0)==1){break f}}ob[w[w[e>>2]+4>>2]](e);zb(Df(f));break a}a=W(0)|0;break c}a=W(0)|0;ob[w[w[e>>2]+4>>2]](e);break d}a=W(0)|0}zb(Df(f));break c}if(!(b<.6)){w[114256]=0;e=V(22,1304568)|0;f=w[114256];w[114256]=0;g:{h:{i:{if((f|0)!=1){w[114256]=0;f=V(1444,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){a=W(0)|0;zb(e);break c}w[114256]=0;e=V(22,8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break h}w[e+4>>2]=c;w[e>>2]=82380;w[f+1304560>>2]=e;w[g+112>>2]=w[a>>2];d=w[a+4>>2];w[g+116>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[a+12>>2];a=w[a+8>>2];w[114256]=0;w[g+120>>2]=a;w[g+124>>2]=d;w[g+32>>2]=a;w[g+36>>2]=d;a=w[g+116>>2];w[g+24>>2]=w[g+112>>2];w[g+28>>2]=a;a=S(1450,f|0,g+24|0,2)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}if(a){w[114256]=0;V(816,f|0)|0;a=w[114256];w[114256]=0;h=.8;if((a|0)==1){break i}}ob[w[w[e>>2]+4>>2]](e);zb(Df(f));break a}a=W(0)|0;break c}a=W(0)|0;ob[w[w[e>>2]+4>>2]](e);break g}a=W(0)|0}zb(Df(f));break c}h=.2;if(!(b<.2)){w[114256]=0;e=V(22,1304568)|0;f=w[114256];w[114256]=0;j:{k:{l:{if((f|0)!=1){w[114256]=0;f=V(1444,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){a=W(0)|0;zb(e);break c}w[114256]=0;e=V(22,8)|0;d=w[114256];w[114256]=0;if((d|0)==1){break k}w[e+4>>2]=c;w[e>>2]=82380;w[f+1304560>>2]=e;w[g+96>>2]=w[a>>2];d=w[a+4>>2];w[g+100>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[a+12>>2];a=w[a+8>>2];w[114256]=0;w[g+104>>2]=a;w[g+108>>2]=d;w[g+16>>2]=a;w[g+20>>2]=d;a=w[g+100>>2];w[g+8>>2]=w[g+96>>2];w[g+12>>2]=a;a=S(1450,f|0,g+8|0,0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break l}h=0;if(a){w[114256]=0;V(816,f|0)|0;a=w[114256];w[114256]=0;h=.6;if((a|0)==1){break l}}ob[w[w[e>>2]+4>>2]](e);zb(Df(f));break a}a=W(0)|0;break c}a=W(0)|0;ob[w[w[e>>2]+4>>2]](e);break j}a=W(0)|0}zb(Df(f));break c}if(b<.1){break a}w[114256]=0;e=S(482,g+72|0,a|0,2048)|0;f=w[114256];w[114256]=0;m:{n:{o:{if((f|0)!=1){j=w[e+12>>2];k=w[e>>2];f=w[e+8>>2];d=w[e+4>>2];a=w[a>>2];i=w[w[a>>2]+24>>2];w[114256]=0;a=V(i|0,a|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break n}w[114256]=0;a=Cq(1456,3,0,d?d:(f|0)!=(j|0)?f:0,k,a,0);f=w[114256];w[114256]=0;if((f|0)==1){break n}a=a+1|0;if(a>>>0>=3){break o}h=B[(a<<3)+37480>>3];a=w[e+8>>2];if(!a){break a}w[e+12>>2]=a;zb(a);break a}a=W(0)|0;break c}d=ba(8)|0;w[114256]=0;f=Q(5,g+56|0,17256)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=Pb(d,f);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}a=W(0)|0;if(u[f+11|0]>=0){break m}zb(w[f>>2]);break m}a=W(0)|0;ca(d|0);break m}a=W(0)|0}f=w[e+8>>2];if(!f){break c}w[e+12>>2]=f;zb(f)}$(a|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;h=0;if((a|0)!=1){break a}a=P()|0;if(c){ob[w[w[c>>2]+4>>2]](c)}R(a|0)}M()}if(c){ob[w[w[c>>2]+4>>2]](c)}jb=g+144|0;return+h}function vK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-32|0;jb=h;w[b+8>>2]=0;e=w[a+4>>2];g=w[a>>2];if((e|0)!=(g|0)){while(1){e=e-32|0;Tg(e);if((e|0)!=(g|0)){continue}break}}w[a+4>>2]=g;a:{if(!Mc(b,h+24|0)){break a}if(!vs(h+24|0)){break a}b:{if(!c){break b}c=w[b>>2];if(!(ob[w[w[c>>2]+36>>2]](c,w[b+8>>2],4)|0)){break a}c:{if(z[a+4>>2]<z[a+8>>2]){Jm(a);break c}Gm(a)}d=w[a+4>>2];c=Kb(12);w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[h+8>>2]=0;g=d-4|0;d=w[g>>2];w[g>>2]=c;if(d){kd(d)}c=w[h+8>>2];w[h+8>>2]=0;if(c){kd(c)}m=w[w[a+4>>2]-4>>2];d=0;c=w[b>>2];g=ob[w[w[c>>2]+24>>2]](c)|0;if(g&1){break a}c=g-4|0;d:{if(c>>>0>z[b+8>>2]){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<c>>>0){break d}}w[b+8>>2]=c}j=Xb(b,h+8|0);l=x[h+8|0];e=Xb(b,h+8|0);f=x[h+8|0];d=0;i=Xb(b,h+8|0);l=(e?f<<8:0)|(j?l<<16:0)|(i?x[h+8|0]:0);if(!l){break a}w[114256]=0;T(181,m|0,l|0);d=w[114256];w[114256]=0;e:{if((d|0)==1){a=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break e}$(a|0)|0;aa();d=0;break a}f:{if(z[b+8>>2]<=3){d=w[b>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<4){break f}}w[b+8>>2]=4}d=w[b>>2];d=ob[w[w[d>>2]+20>>2]](d)|0;o=w[m>>2];i=d+w[b+8>>2]|0;u[h+8|0]=x[i|0];u[h+9|0]=x[i+1|0];u[h+10|0]=x[i+2|0];p=x[i+3|0];u[h+11|0]=p;f=(c+i|0)-4|0;b=0;c=x[(g+i|0)-5|0];g:{if(!c){e=0;break g}e=0;d=0;while(1){if(!e){b=f-1|0;g=(f|0)==(i|0);f=g?f:b;e=8;b=x[(g?i:b)|0]}e=e-1|0;b=b>>>1|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}j=l;while(1){if(!e){b=f-1|0;c=(f|0)==(i|0);f=c?f:b;e=8;b=x[(c?i:b)|0]}e=e-1|0;g=1;d=b>>>1|0;h:{if(!(b&1)){while(1){c=0;b=0;while(1){if(!e){d=f-1|0;e=(f|0)==(i|0);f=e?f:d;d=x[(e?i:d)|0];e=8}b=d&1|b<<1;e=e-1|0;d=d>>>1|0;c=c+1|0;if((c|0)!=2){continue}break}g=b+g|0;if((b|0)==3){continue}break}k=0;g=g>>>0<j>>>0?g:j;if(g){while(1){c=0;b=0;while(1){if(!e){d=f-1|0;e=(f|0)==(i|0);f=e?f:d;d=x[(e?i:d)|0];e=8}b=d&1|b<<1;e=e-1|0;d=d>>>1|0;c=c+1|0;if((c|0)!=8){continue}break}j=j-1|0;u[o+j|0]=b;k=k+1|0;if((g|0)!=(k|0)){continue}break}}if(!j){break h}}c=0;b=0;while(1){if(!e){d=f-1|0;g=(f|0)==(i|0);f=g?f:d;e=8;d=x[(g?i:d)|0]}b=d&1|b<<1;e=e-1|0;d=d>>>1|0;c=c+1|0;if((c|0)!=2){continue}break}k=b+2|0;i:{if((b|0)==3){if(!e){b=f-1|0;c=(f|0)==(i|0);f=c?f:b;e=8;d=x[(c?i:b)|0]}c=d&1;n=c?p:7;e=e-1|0;b=d>>>1|0;d=0;j:{k:{if(!c){g=0;break k}g=0;if(!p){break j}}while(1){if(!e){b=f-1|0;c=(f|0)==(i|0);f=c?f:b;e=8;b=x[(c?i:b)|0]}g=b&1|g<<1;e=e-1|0;b=b>>>1|0;d=d+1|0;if((n|0)!=(d|0)){continue}break}}while(1){c=0;d=0;while(1){if(!e){b=f-1|0;e=(f|0)==(i|0);f=e?f:b;b=x[(e?i:b)|0];e=8}d=b&1|d<<1;e=e-1|0;b=b>>>1|0;c=c+1|0;if((c|0)!=3){continue}break}k=d+k|0;if((d|0)==7){continue}break}break i}g=0;c=0;b=x[(h+8|0)+b|0];if(!b){b=d;break i}while(1){if(!e){d=f-1|0;e=(f|0)==(i|0);f=e?f:d;d=x[(e?i:d)|0];e=8}c=d&1|c<<1;e=e-1|0;d=d>>>1|0;g=g+1|0;if((b|0)!=(g|0)){continue}break}b=d;g=c}c=0;k=j>>>0>k>>>0?k:j;if(k){while(1){d=0;n=g+j|0;if(n>>>0<l>>>0){d=x[o+n|0]}j=j-1|0;u[o+j|0]=d;c=c+1|0;if((k|0)!=(c|0)){continue}break}}if(j){continue}}break}d=w[m+4>>2];c=w[m>>2];b=Kb(24);w[b+12>>2]=75592;w[b>>2]=75552;w[b+4>>2]=0;w[b+8>>2]=0;w[b+20>>2]=d-c;w[b+16>>2]=c;w[h+16>>2]=0;w[h+20>>2]=0;w[h+12>>2]=b;w[h+8>>2]=b+12;a=w[a+4>>2];he(a-20|0,h+8|0);b=w[h+20>>2];a=a-12|0;w[a>>2]=w[h+16>>2];w[a+4>>2]=b;a=w[h+12>>2];if(!a){break b}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break b}ob[w[w[a>>2]+8>>2]](a);Ib(a);break b}R(a|0);M()}d=1}jb=h+32|0;return d|0}function EN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=jb-48|0;jb=e;Ci(b,c,d,A[a+28>>2]);w[e+44>>2]=b;w[e+40>>2]=c;w[e+36>>2]=d;b=w[a+8>>2];w[e+28>>2]=e+36;w[e+24>>2]=e+40;c=w[e+28>>2];w[e+8>>2]=w[e+24>>2];w[e+12>>2]=c;w[e+16>>2]=a;w[e+20>>2]=e+44;c=w[e+20>>2];w[e>>2]=w[e+16>>2];w[e+4>>2]=c;c=jb-160|0;jb=c;a:{b:{switch(w[b+40>>2]){case 0:g=w[w[e+12>>2]>>2];if(!g){break a}b=w[e>>2];h=w[b+4>>2]+w[b+24>>2]|0;d=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(d){m=h+i|0;n=C(d,i);b=0;while(1){l=Tb(H(G(B[j+(b+n<<3)>>3],1),-1)*32768);c:{if(E(l)<2147483648){f=~~l;break c}f=-2147483648}f=(f|0)>=32767?32767:f;v[w[k+(b<<2)>>2]+(m<<1)>>1]=(f|0)<=-32768?-32768:f;b=b+1|0;if((d|0)!=(b|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break};break a;case 2:d=w[e>>2];g=w[d+24>>2];i=w[d+16>>2];f=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];w[c+152>>2]=h-d;w[c+144>>2]=f;w[c+148>>2]=i;w[c+156>>2]=d+g;d=w[w[e+4>>2]>>2];g=w[e+8>>2];h=w[g>>2];j=w[e+12>>2];k=w[j>>2];w[c+136>>2]=k;w[c+132>>2]=h;w[c+128>>2]=d;d=w[g>>2];g=w[j>>2];w[c+40>>2]=k;h=w[c+156>>2];w[c+56>>2]=w[c+152>>2];w[c+60>>2]=h;h=w[c+132>>2];w[c+32>>2]=w[c+128>>2];w[c+36>>2]=h;w[c+48>>2]=f;w[c+52>>2]=i;Qm(c+48|0,c+32|0,b+8|0,d,g);break a;case 3:d=w[e>>2];g=w[d+24>>2];i=w[d+16>>2];f=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];w[c+152>>2]=h-d;w[c+144>>2]=f;w[c+148>>2]=i;w[c+156>>2]=d+g;d=w[w[e+4>>2]>>2];g=w[e+8>>2];h=w[g>>2];j=w[e+12>>2];k=w[j>>2];w[c+136>>2]=k;w[c+132>>2]=h;w[c+128>>2]=d;h=w[g>>2];j=w[j>>2];w[c+72>>2]=k;d=w[c+156>>2];w[c+88>>2]=w[c+152>>2];w[c+92>>2]=d;d=w[c+132>>2];w[c+64>>2]=w[c+128>>2];w[c+68>>2]=d;w[c+80>>2]=f;w[c+84>>2]=i;d=c- -64|0;g=b+20|0;b=0;if(j){i=w[g+16>>2];k=w[c+92>>2];m=w[c+80>>2];n=w[d+4>>2];r=w[d>>2];while(1){if(h){s=b+k|0;t=C(b,n);d=0;while(1){o=d<<2;p=g+o|0;l=Tb(B[(d+t<<3)+r>>3]*134217728);f=2147483647;d:{if(l>=2147483647){break d}f=-2147483648;if(l<=-2147483648){break d}f=~~l;if(E(l)<2147483648){break d}f=-2147483648}q=f+(w[p>>2]>>1)|0;f=q+(i>>>16&4095)&-4096;w[p>>2]=q-f;l=Tb(H(G(+(f|0)*7.450580596923828e-9,1),-1)*32768);e:{if(E(l)<2147483648){f=~~l;break e}f=-2147483648}f=(f|0)>=32767?32767:f;v[w[m+o>>2]+(s<<1)>>1]=(f|0)<=-32768?-32768:f;i=C(i,214013)+2531011|0;d=d+1|0;if((h|0)!=(d|0)){continue}break}w[g+16>>2]=i}b=b+1|0;if((j|0)!=(b|0)){continue}break}}break a;case 1:d=w[e>>2];g=w[d+24>>2];i=w[d+16>>2];f=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];w[c+152>>2]=h-d;w[c+144>>2]=f;w[c+148>>2]=i;w[c+156>>2]=d+g;d=w[w[e+4>>2]>>2];g=w[e+8>>2];h=w[g>>2];j=w[e+12>>2];k=w[j>>2];w[c+136>>2]=k;w[c+132>>2]=h;w[c+128>>2]=d;d=w[g>>2];g=w[j>>2];w[c+104>>2]=k;h=w[c+156>>2];w[c+120>>2]=w[c+152>>2];w[c+124>>2]=h;h=w[c+132>>2];w[c+96>>2]=w[c+128>>2];w[c+100>>2]=h;w[c+112>>2]=f;w[c+116>>2]=i;Qm(c+112|0,c+96|0,b+8|0,d,g);break a;default:break b}}d=w[e>>2];g=w[d+24>>2];i=w[d+16>>2];f=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];w[c+152>>2]=h-d;w[c+144>>2]=f;w[c+148>>2]=i;w[c+156>>2]=d+g;d=w[w[e+4>>2]>>2];g=w[e+8>>2];h=w[g>>2];j=w[e+12>>2];k=w[j>>2];w[c+136>>2]=k;w[c+132>>2]=h;w[c+128>>2]=d;d=w[g>>2];g=w[j>>2];w[c+8>>2]=k;h=w[c+156>>2];w[c+24>>2]=w[c+152>>2];w[c+28>>2]=h;h=w[c+132>>2];w[c>>2]=w[c+128>>2];w[c+4>>2]=h;w[c+16>>2]=f;w[c+20>>2]=i;Qm(c+16|0,c,b+8|0,d,g)}jb=c+160|0;w[a+4>>2]=w[a+4>>2]+w[e+36>>2];jb=e+48|0}function XA(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;a:{b:{c:{d:{e:{if(w[a+24>>2]){break e}m=x[a+15|0];o=w[a+8>>2];i=jb-16|0;jb=i;f=i+8|0;b=f;w[b>>2]=-1;w[b+4>>2]=-1;if(!(u[83500]&1)){while(1){d=0;j=0;b=c;while(1){j=b&1|j<<1;b=(b&254)>>>1|0;d=d+1|0;if((d|0)!=8){continue}break}g=0;d=j<<24;b=0;j=0;while(1){k=0;l=0;n=d<<1|g>>>31;g=g<<1;d=(d|0)<0;g=d?g^-1798752855:g;d=d?n^-1382821323:n;j=j+1|0;if((j|0)!=8){continue}break}while(1){l=l<<1|k>>>31;k=g&1|k<<1;g=(d&1)<<31|g>>>1;d=d>>>1|0;b=b+1|0;if((b|0)!=64){continue}break}b=(c<<3)+83504|0;w[b>>2]=k;w[b+4>>2]=l;c=c+1|0;if((c|0)!=256){continue}break}u[83500]=1}w[114256]=0;b=Bq(1559);c=w[114256];w[114256]=0;d=nb;if((c|0)==1){W(0)|0;Eb();M()}b=BV(b,d,1e3,0);d=b<<24|b<<8&16711680;g=b>>>8|0;c=nb;b=b>>>24|0;d=d|((g|c<<24)&65280|(b|c<<8)&255);w[i>>2]=(g|(c&255)<<24)&-16777216|(b|(c&16777215)<<8)&16711680|(c>>>8&65280|c>>>24);w[i+4>>2]=d;b=f;g=w[b>>2];d=w[b+4>>2];while(1){c=((x[h+i|0]^g&255)<<3)+83504|0;g=w[c>>2]^((d&255)<<24|g>>>8);d=w[c+4>>2]^d>>>8;h=h+1|0;if((h|0)!=8){continue}break}w[b>>2]=g;w[b+4>>2]=d;w[114256]=0;c=Bq(1560);d=w[114256];w[114256]=0;f=nb;if((d|0)==1){W(0)|0;Eb();M()}d=c<<8&16711680|c<<24;g=c>>>8|0;c=c>>>24|0;d=d|((g|f<<24)&65280|(c|f<<8)&255);w[i>>2]=(g|(f&255)<<24)&-16777216|(c|(f&16777215)<<8)&16711680|(f>>>8&65280|f>>>24);w[i+4>>2]=d;g=w[b>>2];d=w[b+4>>2];h=0;while(1){b=((x[h+i|0]^g&255)<<3)+83504|0;g=w[b>>2]^((d&255)<<24|g>>>8);d=w[b+4>>2]^d>>>8;h=h+1|0;if((h|0)!=8){continue}break}jb=i+16|0;f:{if(m<<24>>24<0?o:m){w[114256]=0;w[e+24>>2]=0;w[e+16>>2]=0;w[e+20>>2]=0;w[e>>2]=d;T(59,e+16|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}w[e>>2]=g;b=w[e+20>>2];g:{if(b>>>0<z[e+24>>2]){w[b>>2]=g;w[e+20>>2]=b+4;break g}w[114256]=0;T(59,e+16|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}}h=0;c=x[a+15|0];b=c<<24>>24<0;if(b?w[a+8>>2]:c){c=a+4|0;while(1){f=x[(b?w[c>>2]:c)+h|0];w[e>>2]=f;b=w[e+20>>2];h:{if(b>>>0<z[e+24>>2]){w[b>>2]=f;w[e+20>>2]=b+4;break h}w[114256]=0;T(59,e+16|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}}f=x[a+15|0];b=f<<24>>24<0;h=h+1|0;if(h>>>0<(b?w[a+8>>2]:f)>>>0){continue}break}}w[114256]=0;b=S(60,e|0,w[e+16>>2],w[e+20>>2])|0;c=w[114256];w[114256]=0;i:{j:{if((c|0)!=1){w[114256]=0;c=V(22,2500)|0;f=w[114256];w[114256]=0;if((f|0)==1){break j}w[114256]=0;T(61,c|0,b|0);f=w[114256];w[114256]=0;if((f|0)==1){a=P()|0;zb(c);break i}f=w[a+24>>2];w[a+24>>2]=c;if(f){zb(f)}a=w[b>>2];if(a){w[b+4>>2]=a;zb(a)}a=w[e+16>>2];if(!a){break e}w[e+20>>2]=a;zb(a);break e}a=P()|0;break b}a=P()|0}c=w[b>>2];if(!c){break b}w[b+4>>2]=c;zb(c);break b}nb=g;w[e>>2]=d;w[e+4>>2]=nb;b=e+16|0;w[b+8>>2]=0;w[b>>2]=0;w[b+4>>2]=0;w[114256]=0;U(63,b|0,e|0,e+8|0);c=w[114256];w[114256]=0;if((c|0)==1){c=P()|0;a=w[b>>2];if(a){w[b+4>>2]=a;zb(a)}R(c|0);M()}w[114256]=0;c=V(22,2500)|0;f=w[114256];w[114256]=0;k:{if((f|0)!=1){w[114256]=0;T(61,c|0,b|0);f=w[114256];w[114256]=0;if((f|0)==1){a=P()|0;zb(c);break k}f=w[a+24>>2];w[a+24>>2]=c;if(f){zb(f)}a=w[b>>2];if(!a){break e}w[b+4>>2]=a;zb(a);break e}a=P()|0}c=w[b>>2];if(!c){break a}w[b+4>>2]=c;zb(c);break a}a=P()|0;break b}jb=e+32|0;return}a=P()|0;break b}a=P()|0}b=w[e+16>>2];if(!b){break a}w[e+20>>2]=b;zb(b)}R(a|0);M()}function zQ(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=jb-96|0;jb=k;b=Hb(k+80|0,11528);j=w[b+4>>2];h=x[b+11|0];i=h<<24>>24;a:{d=(i|0)<0?j:h;if(d){g=w[b>>2];b:{if((d|0)<=0){break b}e=(i|0)<0?g:b;f=e+d|0;a=d;c=e;while(1){a=uc(c,58,a);if(!a){break b}if(x[a|0]!=58){c=a+1|0;a=f-c|0;if((a|0)>0){continue}break b}break}if((a|0)==(f|0)|(a-e|0)==-1){break b}a=e;c:{while(1){d:{if(!d){break d}a=uc(a,58,d);if(!a){break d}if(x[a|0]==58){break c}a=a+1|0;d=f-a|0;if((d|0)>0){continue}}break}a=f}w[114256]=0;a=da(114,k- -64|0,b|0,((a|0)!=(f|0)?(a-e|0)+1|0:0)|0,-1,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}c=w[a+4>>2];g=w[a>>2];w[b>>2]=g;w[b+4>>2]=c;w[b+8>>2]=w[a+8>>2];j=w[b+4>>2];h=x[b+11|0];i=h}a=i<<24>>24<0;d=a?j:h;e:{if((d|0)<=0){break e}e=a?g:b;f=e+d|0;a=d;c=e;while(1){a=uc(c,45,a);if(!a){break e}if(x[a|0]!=45){c=a+1|0;a=f-c|0;if((a|0)>0){continue}break e}break}if((a|0)==(f|0)|(a-e|0)==-1){break e}a=e;f:{while(1){g:{if(!d){break g}a=uc(a,45,d);if(!a){break g}if(x[a|0]==45){break f}a=a+1|0;d=f-a|0;if((d|0)>0){continue}}break}a=f}w[114256]=0;a=da(114,k+48|0,b|0,((a|0)!=(f|0)?(a-e|0)+1|0:0)|0,-1,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}c=w[a+4>>2];g=w[a>>2];w[b>>2]=g;w[b+4>>2]=c;w[b+8>>2]=w[a+8>>2];j=w[b+4>>2];h=x[b+11|0];i=h}a=i<<24>>24<0;d=a?j:h;h:{if((d|0)<=0){break h}e=a?g:b;f=e+d|0;a=d;c=e;while(1){a=uc(c,77,a);if(!a){break h}if(x[a|0]!=77){c=a+1|0;a=f-c|0;if((a|0)>0){continue}break h}break}if((a|0)==(f|0)|(a-e|0)==-1){break h}a=e;i:{while(1){j:{if(!d){break j}a=uc(a,77,d);if(!a){break j}if(x[a|0]==77){break i}a=a+1|0;d=f-a|0;if((d|0)>0){continue}}break}a=f}w[114256]=0;a=da(114,k+32|0,b|0,0,((a|0)==(f|0)?-1:a-e|0)|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}c=w[a+4>>2];g=w[a>>2];w[b>>2]=g;w[b+4>>2]=c;w[b+8>>2]=w[a+8>>2];j=w[b+4>>2];h=x[b+11|0];i=h}a=i<<24>>24<0;d=a?j:h;k:{if((d|0)<=0){break k}e=a?g:b;f=e+d|0;a=d;c=e;while(1){a=uc(c,83,a);if(!a){break k}if(x[a|0]!=83){c=a+1|0;a=f-c|0;if((a|0)>0){continue}break k}break}if((a|0)==(f|0)|(a-e|0)==-1){break k}a=e;l:{while(1){m:{if(!d){break m}a=uc(a,83,d);if(!a){break m}if(x[a|0]==83){break l}a=a+1|0;d=f-a|0;if((d|0)>0){continue}}break}a=f}w[114256]=0;a=da(114,k+16|0,b|0,0,((a|0)==(f|0)?-1:a-e|0)|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}c=w[a+4>>2];g=w[a>>2];w[b>>2]=g;w[b+4>>2]=c;w[b+8>>2]=w[a+8>>2];j=w[b+4>>2];h=x[b+11|0];i=h}a=i<<24>>24<0;e=a?j:h;n:{if((e|0)<=0){break n}d=a?g:b;g=d+e|0;a=e;c=d;while(1){a=uc(c,80,a);if(!a){break n}if(x[a|0]!=80){c=a+1|0;a=g-c|0;if((a|0)>0){continue}break n}break}if((a|0)==(g|0)|(a-d|0)==-1){break n}a=d;o:{while(1){p:{if(!e){break p}a=uc(a,80,e);if(!a){break p}if(x[a|0]==80){break o}a=a+1|0;e=g-a|0;if((e|0)>0){continue}}break}a=g}w[114256]=0;a=da(114,k|0,b|0,0,((a|0)==(g|0)?-1:a-d|0)|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}c=w[a+4>>2];w[b>>2]=w[a>>2];w[b+4>>2]=c;w[b+8>>2]=w[a+8>>2]}w[114256]=0;a=V(115,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}i=x[b+11|0]}if(i<<24>>24<0){zb(w[b>>2])}jb=k+96|0;return a|0}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}function gv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-96|0;jb=f;w[f+88>>2]=c;w[f+92>>2]=d;i=w[b+4>>2];a:{if(!i){break a}h=w[b>>2];g=i-1|0;j=x[h+g|0];if((j|0)==33){e=1}else{if((j|0)!=63){break a}e=0}w[b>>2]=h;w[b+4>>2]=g>>>0>i>>>0?i:g}g=82096;h=w[b+4>>2];j=h;i=w[b>>2];b:{c:{d:{e:{f:{while(1){g:{k=w[g>>2];if((ec(k)|0)==(h|0)){if(!h){break g}if(!Jb(k,i,h)){break g}}g=g+8|0;if((g|0)!=82200){continue}break f}break}if((g|0)!=82200){break e}}if(!j){b=ba(8)|0;w[114256]=0;T(1448,f+56|0,f+88|0);a=w[114256];w[114256]=0;h:{if((a|0)!=1){w[114256]=0;a=S(1436,f+56|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[f+80>>2]=w[a+8>>2];c=w[a+4>>2];w[f+72>>2]=w[a>>2];w[f+76>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,f+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;if(u[f+83|0]<0){zb(w[f+72>>2])}if(u[f+67|0]>=0){break c}zb(w[f+56>>2]);break c}g=P()|0;if(u[f+67|0]>=0){break h}zb(w[f+56>>2]);break h}g=P()|0}ca(b|0);break c}if(!e){break d}c=ba(8)|0;w[114256]=0;b=Q(1447,f+24|0,b|0)|0;a=w[114256];w[114256]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;d=w[114256];w[114256]=0;if((d|0)==1){break j}w[f+48>>2]=w[a+8>>2];d=w[a+4>>2];w[f+40>>2]=w[a>>2];w[f+44>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;a=Q(1315,f+40|0,13373)|0;d=w[114256];w[114256]=0;e=1;if((d|0)==1){break p}w[f- -64>>2]=w[a+8>>2];d=w[a+4>>2];w[f+56>>2]=w[a>>2];w[f+60>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;T(1448,f+8|0,f+88|0);a=w[114256];w[114256]=0;if((a|0)==1){break o}w[114256]=0;a=x[f+19|0];d=a<<24>>24<0;a=S(92,f+56|0,(d?w[f+8>>2]:f+8|0)|0,(d?w[f+12>>2]:a)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}w[f+80>>2]=w[a+8>>2];d=w[a+4>>2];w[f+72>>2]=w[a>>2];w[f+76>>2]=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(c,f+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;e=0;if(u[f+83|0]>=0){break m}zb(w[f+72>>2]);break m}g=P()|0;break i}g=P()|0;break k}g=P()|0;break l}g=P()|0}if(u[f+19|0]>=0){break l}zb(w[f+8>>2])}if(u[f+67|0]>=0){break k}zb(w[f+56>>2])}if(u[f+51|0]<0){zb(w[f+40>>2])}if(u[b+11|0]<0){zb(w[b>>2])}if(e){break i}break c}g=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2])}ca(c|0);break c}q:{switch(h-6|0){default:if(h){break d}b=ba(8)|0;w[114256]=0;T(1448,f+56|0,f+88|0);a=w[114256];w[114256]=0;r:{if((a|0)!=1){w[114256]=0;a=S(1436,f+56|0,0,13363)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[f+80>>2]=w[a+8>>2];c=w[a+4>>2];w[f+72>>2]=w[a>>2];w[f+76>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(b,f+72|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}g=P()|0;if(u[f+83|0]<0){zb(w[f+72>>2])}if(u[f+67|0]>=0){break c}zb(w[f+56>>2]);break c}g=P()|0;if(u[f+67|0]>=0){break r}zb(w[f+56>>2]);break r}g=P()|0}ca(b|0);break c;case 1:if(Jb(i,6873,7)){break d}e=a;a=(d|0)>=0&c>>>0>=2147483647|(d|0)>0;b=a?2147483647:c;a=a?0:d;Zu(e,(a|0)<0&b>>>0<=2147483648|(a|0)<-1?-2147483648:b);break d;case 0:break q}}if(Jb(i,4783,h)){break d}e=w[a+32>>2];a=(d|0)>=0&c>>>0>=2147483647|(d|0)>0;b=a?2147483647:c;a=a?0:d;a=(a|0)<0&b>>>0<=2147483648|(a|0)<-1?-2147483648:b;w[e+40>>2]=a>>>0>3?1:a}jb=f+96|0;return}R(g|0)}M()}function eO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb+-64|0;jb=d;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{b:{c:{d:{e=w[b+36>>2];f=w[b+40>>2];e:{if((e|0)!=(f|0)){w[d+32>>2]=0;break e}w[114256]=0;T(1471,d+40|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}w[114256]=0;g=V(22,12)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}w[g>>2]=w[d+40>>2];w[g+4>>2]=w[d+44>>2];w[g+8>>2]=w[d+48>>2];w[d+32>>2]=g;f=w[b+40>>2];e=w[b+36>>2]}c=(e|0)==(f|0)?g:b+36|0;e=w[c>>2];f=w[c+4>>2];w[114256]=0;T(918,a|0,(f-e|0)/24|0);e=w[114256];w[114256]=0;f:{if((e|0)!=1){h=w[c>>2];l=w[c+4>>2];if((h|0)==(l|0)){break a}m=a+8|0;g:{h:{i:{j:{k:{l:{while(1){k=w[w[b+24>>2]+484360>>2]+(x[h+16|0]<<5)|0;c=k;m:{if(u[c+23|0]>=0){w[d+8>>2]=w[c+20>>2];e=w[c+16>>2];w[d>>2]=w[c+12>>2];w[d+4>>2]=e;break m}e=w[k+16>>2];c=w[c+12>>2];w[114256]=0;U(3,d|0,c|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break l}}w[114256]=0;U(9,d+16|0,0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break k}c=w[a+4>>2];e=w[a+8>>2];n:{if(c>>>0<e>>>0){e=w[d+20>>2];w[c>>2]=w[d+16>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+24>>2];w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;w[a+4>>2]=c+12;break n}f=w[a>>2];i=(c-f|0)/12|0;c=i+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break j}M()}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;i=Z(921,d+40|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,i|0,m|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break j}e=w[d+20>>2];c=w[d+48>>2];w[c>>2]=w[d+16>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+24>>2];w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;j=w[d+48>>2]+12|0;w[d+48>>2]=j;f=w[d+44>>2];e=w[a+4>>2];c=w[a>>2];o:{if((e|0)==(c|0)){e=c;break o}while(1){e=e-12|0;j=w[e+4>>2];f=f-12|0;w[f>>2]=w[e>>2];w[f+4>>2]=j;w[f+8>>2]=w[e+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;f=w[d+44>>2]-12|0;w[d+44>>2]=f;if((c|0)!=(e|0)){continue}break}c=w[a+4>>2];j=w[d+48>>2];e=w[a>>2]}w[a>>2]=f;w[d+44>>2]=e;w[a+4>>2]=j;w[d+48>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+52>>2];w[d+52>>2]=c;w[i>>2]=e;sc(i);if(u[d+27|0]>=0){break n}zb(w[d+16>>2])}if(u[d+11|0]<0){zb(w[d>>2])}e=w[a+4>>2];c=x[e-1|0];p:{q:{if(c<<24>>24<0?w[e-8>>2]:c){break q}c=x[h+12|0];w[114256]=0;c=Q(305,k|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break p}if(!c){break q}c=w[b+24>>2];e=w[c+1304496>>2];c=w[c+484344>>2]+C(y[w[k>>2]+(w[h+12>>2]<<1)>>1],52)|0;r:{if(u[c+47|0]>=0){w[d+8>>2]=w[c+44>>2];f=w[c+40>>2];w[d>>2]=w[c+36>>2];w[d+4>>2]=f;break r}f=w[c+40>>2];c=w[c+36>>2];w[114256]=0;U(76,d|0,c|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break h}}w[114256]=0;Y(229,d+16|0,0,e|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}e=w[a+4>>2];c=e-12|0;if(u[e-1|0]<0){zb(w[c>>2])}e=w[d+20>>2];w[c>>2]=w[d+16>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+24>>2];u[d+27|0]=0;u[d+16|0]=0;if(u[d+11|0]>=0){break q}zb(w[d>>2])}h=h+24|0;if((l|0)!=(h|0)){continue}break a}break}e=P()|0;break f}e=P()|0;break f}e=P()|0;break i}e=P()|0;if(u[d+27|0]>=0){break i}zb(w[d+16>>2])}if(u[d+11|0]>=0){break f}zb(w[d>>2]);break f}e=P()|0;break f}e=P()|0;if(u[d+11|0]>=0){break f}zb(w[d>>2]);break f}e=P()|0}w[d+32>>2]=0;if(!g){break b}kd(g);break b}e=P()|0;b=w[d+40>>2];if(!b){break b}w[d+44>>2]=b;zb(b);break b}e=P()|0}bc(a);R(e|0);M()}w[d+32>>2]=0;if(g){kd(g)}jb=d- -64|0}function FN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=D(0),p=0,q=0,r=0,s=0,t=0,u=0,x=0;f=jb-48|0;jb=f;o=_b(D(A[a+28>>2]*D(65536)));e=2147483647;a:{if(o>=D(2147483648)){break a}e=-2147483648;if(o<=D(-2147483648)){break a}e=~~o;if(D(E(o))<D(2147483648)){break a}e=-2147483648}Mo(b,c,d,e);w[f+44>>2]=b;w[f+40>>2]=c;w[f+36>>2]=d;k=w[a+8>>2];w[f+28>>2]=f+36;w[f+24>>2]=f+40;b=w[f+28>>2];w[f+8>>2]=w[f+24>>2];w[f+12>>2]=b;w[f+16>>2]=a;w[f+20>>2]=f+44;b=w[f+20>>2];w[f>>2]=w[f+16>>2];w[f+4>>2]=b;e=jb-160|0;jb=e;b:{c:{switch(w[k+40>>2]){case 0:k=w[w[f+12>>2]>>2];if(!k){break b}b=w[f>>2];i=w[b+4>>2]+w[b+24>>2]|0;m=w[w[f+8>>2]>>2];h=w[w[f+4>>2]>>2];j=w[b+12>>2];while(1){if(m){g=i+l|0;d=C(m,l);b=0;while(1){c=w[h+(b+d<<2)>>2]-2147481600>>>12|0;c=c>>>0<=491520?491520:c;v[w[j+(b<<2)>>2]+(g<<1)>>1]=(c|0)>=557055?557055:c;b=b+1|0;if((m|0)!=(b|0)){continue}break}}l=l+1|0;if((k|0)!=(l|0)){continue}break};break b;case 2:b=w[f>>2];c=w[b+24>>2];i=w[b+16>>2];h=w[b+12>>2];d=w[b+20>>2];b=w[b+4>>2];w[e+152>>2]=d-b;w[e+144>>2]=h;w[e+148>>2]=i;w[e+156>>2]=b+c;j=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=j;d=w[g>>2];c=w[c>>2];w[e+40>>2]=b;b=w[e+156>>2];w[e+56>>2]=w[e+152>>2];w[e+60>>2]=b;b=w[e+132>>2];w[e+32>>2]=w[e+128>>2];w[e+36>>2]=b;w[e+48>>2]=h;w[e+52>>2]=i;Rm(e+48|0,e+32|0,k+8|0,d,c);break b;case 3:b=w[f>>2];c=w[b+24>>2];i=w[b+16>>2];h=w[b+12>>2];d=w[b+20>>2];b=w[b+4>>2];w[e+152>>2]=d-b;w[e+144>>2]=h;w[e+148>>2]=i;w[e+156>>2]=b+c;j=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=j;r=w[g>>2];d=w[c>>2];w[e+72>>2]=b;b=w[e+156>>2];w[e+88>>2]=w[e+152>>2];w[e+92>>2]=b;b=w[e+132>>2];w[e+64>>2]=w[e+128>>2];w[e+68>>2]=b;w[e+80>>2]=h;w[e+84>>2]=i;b=e- -64|0;q=k+20|0;if(d){s=w[e+92>>2];t=w[e+80>>2];u=w[b+4>>2];m=w[b>>2];while(1){if(r){l=p+s|0;k=C(p,u);b=w[q+16>>2];n=0;while(1){i=w[(k+n<<2)+m>>2];h=n<<2;j=q+h|0;g=w[j>>2];c=C(b,214013)+2531011|0;w[q+16>>2]=c;x=b>>>16&4095;b=i+(g>>1)|0;g=x+b&-4096;w[j>>2]=b-g;b=g-2147481600>>>12|0;b=b>>>0<=491520?491520:b;v[w[h+t>>2]+(l<<1)>>1]=(b|0)>=557055?557055:b;b=c;n=n+1|0;if((r|0)!=(n|0)){continue}break}}p=p+1|0;if((d|0)!=(p|0)){continue}break}}break b;case 1:b=w[f>>2];c=w[b+24>>2];i=w[b+16>>2];h=w[b+12>>2];d=w[b+20>>2];b=w[b+4>>2];w[e+152>>2]=d-b;w[e+144>>2]=h;w[e+148>>2]=i;w[e+156>>2]=b+c;j=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=j;d=w[g>>2];c=w[c>>2];w[e+104>>2]=b;b=w[e+156>>2];w[e+120>>2]=w[e+152>>2];w[e+124>>2]=b;b=w[e+132>>2];w[e+96>>2]=w[e+128>>2];w[e+100>>2]=b;w[e+112>>2]=h;w[e+116>>2]=i;Rm(e+112|0,e+96|0,k+8|0,d,c);break b;default:break c}}b=w[f>>2];c=w[b+24>>2];i=w[b+16>>2];h=w[b+12>>2];d=w[b+20>>2];b=w[b+4>>2];w[e+152>>2]=d-b;w[e+144>>2]=h;w[e+148>>2]=i;w[e+156>>2]=b+c;j=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=j;d=w[g>>2];c=w[c>>2];w[e+8>>2]=b;b=w[e+156>>2];w[e+24>>2]=w[e+152>>2];w[e+28>>2]=b;b=w[e+132>>2];w[e>>2]=w[e+128>>2];w[e+4>>2]=b;w[e+16>>2]=h;w[e+20>>2]=i;Rm(e+16|0,e,k+8|0,d,c)}jb=e+160|0;w[a+4>>2]=w[a+4>>2]+w[f+36>>2];jb=f+48|0}function AN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=jb-48|0;jb=f;Ci(b,c,d,A[a+24>>2]);w[f+44>>2]=b;w[f+40>>2]=c;w[f+36>>2]=d;b=w[a+8>>2];w[f+28>>2]=f+36;w[f+24>>2]=f+40;c=w[f+28>>2];w[f+8>>2]=w[f+24>>2];w[f+12>>2]=c;w[f+16>>2]=a;w[f+20>>2]=f+44;c=w[f+20>>2];w[f>>2]=w[f+16>>2];w[f+4>>2]=c;c=jb-160|0;jb=c;a:{b:{switch(w[b+40>>2]){case 0:i=w[w[f+12>>2]>>2];if(!i){break a}b=w[f>>2];h=w[b+16>>2];j=w[b+12>>2]+(C(h,w[b+4>>2])<<1)|0;d=w[w[f+8>>2]>>2];l=w[w[f+4>>2]>>2];while(1){if(d){n=C(g,h);o=C(d,g);b=0;while(1){m=j+(b+n<<1)|0;k=Tb(H(G(B[l+(b+o<<3)>>3],1),-1)*32768);c:{if(E(k)<2147483648){e=~~k;break c}e=-2147483648}e=(e|0)>=32767?32767:e;v[m>>1]=(e|0)<=-32768?-32768:e;b=b+1|0;if((d|0)!=(b|0)){continue}break}}g=g+1|0;if((i|0)!=(g|0)){continue}break};break a;case 2:d=w[f>>2];g=w[d+16>>2];e=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];h=h-d|0;w[c+152>>2]=h;w[c+148>>2]=g;w[c+144>>2]=e+(C(d,g)<<1);d=w[w[f+4>>2]>>2];g=w[f+8>>2];e=w[g>>2];i=w[f+12>>2];j=w[i>>2];w[c+136>>2]=j;w[c+132>>2]=e;w[c+128>>2]=d;d=w[i>>2];g=w[g>>2];w[c+40>>2]=j;w[c+56>>2]=h;e=w[c+132>>2];w[c+32>>2]=w[c+128>>2];w[c+36>>2]=e;e=w[c+148>>2];w[c+48>>2]=w[c+144>>2];w[c+52>>2]=e;Om(c+48|0,c+32|0,b+8|0,g,d);break a;case 3:d=w[f>>2];g=w[d+16>>2];e=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];h=h-d|0;w[c+152>>2]=h;w[c+148>>2]=g;w[c+144>>2]=e+(C(d,g)<<1);d=w[w[f+4>>2]>>2];g=w[f+8>>2];e=w[g>>2];i=w[f+12>>2];l=w[i>>2];w[c+136>>2]=l;w[c+132>>2]=e;w[c+128>>2]=d;i=w[i>>2];j=w[g>>2];w[c+72>>2]=l;w[c+88>>2]=h;d=w[c+132>>2];w[c+64>>2]=w[c+128>>2];w[c+68>>2]=d;d=w[c+148>>2];w[c+80>>2]=w[c+144>>2];w[c+84>>2]=d;e=c- -64|0;h=b+20|0;g=0;if(i){d=w[h+16>>2];l=w[c+84>>2];n=w[c+80>>2];o=w[e+4>>2];q=w[e>>2];while(1){if(j){r=C(g,l);s=C(g,o);b=0;while(1){m=h+(b<<2)|0;k=Tb(B[q+(b+s<<3)>>3]*134217728);e=2147483647;d:{if(k>=2147483647){break d}e=-2147483648;if(k<=-2147483648){break d}e=~~k;if(E(k)<2147483648){break d}e=-2147483648}p=e+(w[m>>2]>>1)|0;e=p+(d>>>16&4095)&-4096;w[m>>2]=p-e;m=n+(b+r<<1)|0;k=Tb(H(G(+(e|0)*7.450580596923828e-9,1),-1)*32768);e:{if(E(k)<2147483648){e=~~k;break e}e=-2147483648}e=(e|0)>=32767?32767:e;v[m>>1]=(e|0)<=-32768?-32768:e;d=C(d,214013)+2531011|0;b=b+1|0;if((j|0)!=(b|0)){continue}break}w[h+16>>2]=d}g=g+1|0;if((i|0)!=(g|0)){continue}break}}break a;case 1:d=w[f>>2];g=w[d+16>>2];e=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];h=h-d|0;w[c+152>>2]=h;w[c+148>>2]=g;w[c+144>>2]=e+(C(d,g)<<1);d=w[w[f+4>>2]>>2];g=w[f+8>>2];e=w[g>>2];i=w[f+12>>2];j=w[i>>2];w[c+136>>2]=j;w[c+132>>2]=e;w[c+128>>2]=d;d=w[i>>2];g=w[g>>2];w[c+104>>2]=j;w[c+120>>2]=h;e=w[c+132>>2];w[c+96>>2]=w[c+128>>2];w[c+100>>2]=e;e=w[c+148>>2];w[c+112>>2]=w[c+144>>2];w[c+116>>2]=e;Om(c+112|0,c+96|0,b+8|0,g,d);break a;default:break b}}d=w[f>>2];g=w[d+16>>2];e=w[d+12>>2];h=w[d+20>>2];d=w[d+4>>2];h=h-d|0;w[c+152>>2]=h;w[c+148>>2]=g;w[c+144>>2]=e+(C(d,g)<<1);d=w[w[f+4>>2]>>2];g=w[f+8>>2];e=w[g>>2];i=w[f+12>>2];j=w[i>>2];w[c+136>>2]=j;w[c+132>>2]=e;w[c+128>>2]=d;d=w[i>>2];g=w[g>>2];w[c+8>>2]=j;w[c+24>>2]=h;e=w[c+132>>2];w[c>>2]=w[c+128>>2];w[c+4>>2]=e;e=w[c+148>>2];w[c+16>>2]=w[c+144>>2];w[c+20>>2]=e;Om(c+16|0,c,b+8|0,g,d)}jb=c+160|0;w[a+4>>2]=w[a+4>>2]+w[f+36>>2];jb=f+48|0}function BN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=jb-48|0;jb=f;n=_b(D(A[a+24>>2]*D(65536)));e=2147483647;a:{if(n>=D(2147483648)){break a}e=-2147483648;if(n<=D(-2147483648)){break a}e=~~n;if(D(E(n))<D(2147483648)){break a}e=-2147483648}Mo(b,c,d,e);w[f+44>>2]=b;w[f+40>>2]=c;w[f+36>>2]=d;j=w[a+8>>2];w[f+28>>2]=f+36;w[f+24>>2]=f+40;b=w[f+28>>2];w[f+8>>2]=w[f+24>>2];w[f+12>>2]=b;w[f+16>>2]=a;w[f+20>>2]=f+44;b=w[f+20>>2];w[f>>2]=w[f+16>>2];w[f+4>>2]=b;e=jb-160|0;jb=e;b:{c:{switch(w[j+40>>2]){case 0:j=w[w[f+12>>2]>>2];if(!j){break b}b=w[f>>2];o=w[b+16>>2];h=w[b+12>>2]+(C(o,w[b+4>>2])<<1)|0;m=w[w[f+8>>2]>>2];i=w[w[f+4>>2]>>2];while(1){if(m){g=C(k,o);d=C(m,k);b=0;while(1){c=w[i+(b+d<<2)>>2]-2147481600>>>12|0;c=c>>>0<=491520?491520:c;v[h+(b+g<<1)>>1]=(c|0)>=557055?557055:c;b=b+1|0;if((m|0)!=(b|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break};break b;case 2:b=w[f>>2];d=w[b+16>>2];c=w[b+12>>2];g=w[b+20>>2];b=w[b+4>>2];h=g-b|0;w[e+152>>2]=h;w[e+148>>2]=d;w[e+144>>2]=c+(C(b,d)<<1);i=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=i;d=w[c>>2];c=w[g>>2];w[e+40>>2]=b;w[e+56>>2]=h;b=w[e+132>>2];w[e+32>>2]=w[e+128>>2];w[e+36>>2]=b;b=w[e+148>>2];w[e+48>>2]=w[e+144>>2];w[e+52>>2]=b;Pm(e+48|0,e+32|0,j+8|0,c,d);break b;case 3:b=w[f>>2];d=w[b+16>>2];c=w[b+12>>2];g=w[b+20>>2];b=w[b+4>>2];h=g-b|0;w[e+152>>2]=h;w[e+148>>2]=d;w[e+144>>2]=c+(C(b,d)<<1);i=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=i;d=w[c>>2];r=w[g>>2];w[e+72>>2]=b;w[e+88>>2]=h;b=w[e+132>>2];w[e+64>>2]=w[e+128>>2];w[e+68>>2]=b;b=w[e+148>>2];w[e+80>>2]=w[e+144>>2];w[e+84>>2]=b;b=e- -64|0;q=j+20|0;if(d){s=w[e+84>>2];t=w[e+80>>2];m=w[b+4>>2];k=w[b>>2];while(1){if(r){o=C(p,s);j=C(m,p);b=w[q+16>>2];l=0;while(1){h=w[(j+l<<2)+k>>2];i=q+(l<<2)|0;g=w[i>>2];c=C(b,214013)+2531011|0;w[q+16>>2]=c;u=b>>>16&4095;b=h+(g>>1)|0;g=u+b&-4096;w[i>>2]=b-g;b=g-2147481600>>>12|0;b=b>>>0<=491520?491520:b;v[t+(l+o<<1)>>1]=(b|0)>=557055?557055:b;b=c;l=l+1|0;if((r|0)!=(l|0)){continue}break}}p=p+1|0;if((d|0)!=(p|0)){continue}break}}break b;case 1:b=w[f>>2];d=w[b+16>>2];c=w[b+12>>2];g=w[b+20>>2];b=w[b+4>>2];h=g-b|0;w[e+152>>2]=h;w[e+148>>2]=d;w[e+144>>2]=c+(C(b,d)<<1);i=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=i;d=w[c>>2];c=w[g>>2];w[e+104>>2]=b;w[e+120>>2]=h;b=w[e+132>>2];w[e+96>>2]=w[e+128>>2];w[e+100>>2]=b;b=w[e+148>>2];w[e+112>>2]=w[e+144>>2];w[e+116>>2]=b;Pm(e+112|0,e+96|0,j+8|0,c,d);break b;default:break c}}b=w[f>>2];d=w[b+16>>2];c=w[b+12>>2];g=w[b+20>>2];b=w[b+4>>2];h=g-b|0;w[e+152>>2]=h;w[e+148>>2]=d;w[e+144>>2]=c+(C(b,d)<<1);i=w[w[f+4>>2]>>2];g=w[f+8>>2];d=w[g>>2];c=w[f+12>>2];b=w[c>>2];w[e+136>>2]=b;w[e+132>>2]=d;w[e+128>>2]=i;d=w[c>>2];c=w[g>>2];w[e+8>>2]=b;w[e+24>>2]=h;b=w[e+132>>2];w[e>>2]=w[e+128>>2];w[e+4>>2]=b;b=w[e+148>>2];w[e+16>>2]=w[e+144>>2];w[e+20>>2]=b;Pm(e+16|0,e,j+8|0,c,d)}jb=e+160|0;w[a+4>>2]=w[a+4>>2]+w[f+36>>2];jb=f+48|0}function zb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=w[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=w[d>>2];d=d-b|0;if(d>>>0<z[114136]){break a}a=a+b|0;if(w[114137]!=(d|0)){if(b>>>0<=255){e=w[d+8>>2];b=b>>>3|0;c=w[d+12>>2];if((c|0)==(e|0)){i=456528,j=w[114132]&FV(-2,b),w[i>>2]=j;break b}w[e+12>>2]=c;w[c+8>>2]=e;break b}h=w[d+24>>2];b=w[d+12>>2];c:{if((d|0)!=(b|0)){c=w[d+8>>2];w[c+12>>2]=b;w[b+8>>2]=c;break c}d:{e=d+20|0;c=w[e>>2];if(c){break d}e=d+16|0;c=w[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=w[e>>2];if(c){continue}e=b+16|0;c=w[b+16>>2];if(c){continue}break}w[g>>2]=0}if(!h){break b}e=w[d+28>>2];c=(e<<2)+456832|0;e:{if(w[c>>2]==(d|0)){w[c>>2]=b;if(b){break e}i=456532,j=w[114133]&FV(-2,e),w[i>>2]=j;break b}w[h+(w[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}w[b+24>>2]=h;c=w[d+16>>2];if(c){w[b+16>>2]=c;w[c+24>>2]=b}c=w[d+20>>2];if(!c){break b}w[b+20>>2]=c;w[c+24>>2]=b;break b}b=w[f+4>>2];if((b&3)!=3){break b}w[114134]=a;w[f+4>>2]=b&-2;w[d+4>>2]=a|1;w[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=w[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(w[114138]==(f|0)){w[114138]=d;a=w[114135]+a|0;w[114135]=a;w[d+4>>2]=a|1;if(w[114137]!=(d|0)){break a}w[114134]=0;w[114137]=0;return}if(w[114137]==(f|0)){w[114137]=d;a=w[114134]+a|0;w[114134]=a;w[d+4>>2]=a|1;w[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=w[f+8>>2];b=b>>>3|0;c=w[f+12>>2];if((c|0)==(e|0)){i=456528,j=w[114132]&FV(-2,b),w[i>>2]=j;break g}w[e+12>>2]=c;w[c+8>>2]=e;break g}h=w[f+24>>2];b=w[f+12>>2];h:{if((f|0)!=(b|0)){c=w[f+8>>2];w[c+12>>2]=b;w[b+8>>2]=c;break h}i:{e=f+20|0;c=w[e>>2];if(c){break i}e=f+16|0;c=w[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=w[e>>2];if(c){continue}e=b+16|0;c=w[b+16>>2];if(c){continue}break}w[g>>2]=0}if(!h){break g}e=w[f+28>>2];c=(e<<2)+456832|0;j:{if(w[c>>2]==(f|0)){w[c>>2]=b;if(b){break j}i=456532,j=w[114133]&FV(-2,e),w[i>>2]=j;break g}w[h+(w[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}w[b+24>>2]=h;c=w[f+16>>2];if(c){w[b+16>>2]=c;w[c+24>>2]=b}c=w[f+20>>2];if(!c){break g}w[b+20>>2]=c;w[c+24>>2]=b}w[d+4>>2]=a|1;w[a+d>>2]=a;if(w[114137]!=(d|0)){break f}w[114134]=a;return}w[f+4>>2]=b&-2;w[d+4>>2]=a|1;w[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+456568|0;c=w[114132];a=1<<(a>>>3);k:{if(!(c&a)){w[114132]=a|c;a=b;break k}a=w[b+8>>2]}w[b+8>>2]=d;w[a+12>>2]=d;w[d+12>>2]=b;w[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}w[d+28>>2]=e;w[d+16>>2]=0;w[d+20>>2]=0;g=(e<<2)+456832|0;l:{m:{c=w[114133];b=1<<e;n:{if(!(c&b)){w[114133]=b|c;w[g>>2]=d;w[d+24>>2]=g;break n}e=a<<((e|0)!=31?25-(e>>>1|0)|0:0);b=w[g>>2];while(1){c=b;if((w[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=w[g+16>>2];if(b){continue}break}w[g+16>>2]=d;w[d+24>>2]=c}w[d+12>>2]=d;w[d+8>>2]=d;break l}a=w[c+8>>2];w[a+12>>2]=d;w[c+8>>2]=d;w[d+24>>2]=0;w[d+12>>2]=c;w[d+8>>2]=a}a=w[114140]-1|0;w[114140]=a?a:-1}}function yv(a){var b=0,c=D(0),d=D(0),e=D(0),f=D(0),g=0,h=0,i=D(0),j=0,k=D(0),l=D(0),m=D(0),n=0,o=D(0),p=0,q=D(0);c=_b(D(A[a+4256>>2]*D(3)));b=-1;a:{if(c>=D(4294967296)){break a}b=0;if(c<=D(0)){break a}b=~~c>>>0;if(c<D(4294967296)&c>=D(0)){break a}b=0}w[a+4264>>2]=b;g=w[w[a+16>>2]+24620>>2];A[a+4272>>2]=A[a+4244>>2]*D(.6180340051651001);d=D(g>>>((b^-1)>>>1&1)>>>0);A[a+4268>>2]=d;p=a,q=D(D(G(jd(D(D(D(D(A[a+4228>>2]*D(11e3))+D(A[a+4208>>2]*D(1e4)))*D(.0016609641024842858))+D(-33.21928024291992))),D(1)))*D(.7609999775886536)),A[p+4280>>2]=q;c=jd(D(D(A[a+4212>>2]*D(33.21928024291992))+D(-33.21928024291992)));if(c!=D(1)){d=ai(D(D(D(A[a+4252>>2]*D(125538.046875))+D(125.66371154785156))/d));i=D(c+c);e=D(c*c);c=D(c*D(8));c=D(H(D(G(D(D(D(D(d*i)+D(-2))+D(L(D(D(D(e*D(-4))+c)+D(D(D(D(e*D(4))*d)-c)*d)))))/D(i+D(-2))),D(1))),D(0)))}else{c=D(0)}A[a+4276>>2]=c;g=0;d=D(A[a+4232>>2]*D(.30000001192092896));i=D(H(D(A[a+4240>>2]*D(.10000000149011612)),D(.004999999888241291)));c=A[a+4268>>2];e=D(D(D(d+D(.007000000216066837))+i)*c);b:{if(D(E(e))<D(2147483648)){b=~~e;break b}b=-2147483648}w[a+4352>>2]=b;b=1;while(1){j=((C(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=D(D(D(A[(b<<2)+36192>>2]*i)+d)*c);c:{if(D(E(e))<D(2147483648)){h=~~e;break c}h=-2147483648}w[j>>2]=h;b=b+1|0;if((b|0)!=12){continue}break}d=D(D(G(D(D(A[a+4248>>2]*D(.9090999960899353))+D(.09091000258922577)),D(1)))*c);i=D(d*D(.07500000298023224));d=D(d*D(.06700000166893005));b=0;while(1){h=(b<<2)+a|0;n=h+4316|0;g=b+g|0;e=jd(D(D(g|0)*D(-.10469736903905869)));f=D(i*e);d:{if(D(E(f))<D(2147483648)){j=~~f;break d}j=-2147483648}w[n>>2]=j;j=h+4292|0;e=D(d*e);e:{if(D(E(e))<D(2147483648)){h=~~e;break e}h=-2147483648}w[j>>2]=h;b=b+1|0;if((b|0)!=6){continue}break}g=a+4348|0;d=D(c*D(.0035299998708069324));f:{if(D(E(d))<D(2147483648)){b=~~d;break f}b=-2147483648}w[g>>2]=b;g=a+4344|0;d=D(c*D(.0032500000670552254));g:{if(D(E(d))<D(2147483648)){b=~~d;break g}b=-2147483648}w[g>>2]=b;g=a+4340|0;c=D(c*D(.009999999776482582));h:{if(D(E(c))<D(2147483648)){b=~~c;break h}b=-2147483648}w[g>>2]=b;b=0;while(1){g=C(b,24)+a|0;h=w[g+4516>>2];if((h|0)>0){w[g+4524>>2]=(w[g+4520>>2]+(h+w[((b<<2)+a|0)+4292>>2]|0)|0)%(h|0)}b=b+1|0;if((b|0)!=15){continue}break}d=Nd(a,5);e=Nd(a,11);c=D(d*Nd(a,4));i=D(D(c*D(.03999999910593033))+D(d*D(.02250000089406967)));d=D(e*Nd(a,10));e=D(D(d*D(.03999999910593033))+D(e*D(.02250000089406967)));if(u[a+4264|0]&1){f=Nd(a,3);k=Nd(a,9);f=D(f*c);c=D(Nd(a,2)*f);i=D(D(D(f*D(.12250000238418579))+i)+D(c*D(.1444000005722046)));f=D(k*d);d=D(Nd(a,8)*f);e=D(D(D(f*D(.12250000238418579))+e)+D(d*D(.1444000005722046)))}Nd(a,12);f=A[a+4496>>2];k=Nd(a,1);l=Nd(a,7);o=Nd(a,0);f=D(f*f);l=D(l*D(f*d));d=D(Nd(a,6)*l);m=D(G(jd(D(D(D(D(A[a+4236>>2]*D(12e3))+D(A[a+4208>>2]*D(1e4)))*D(.0016609641024842858))+D(-33.21928024291992))),D(1)));c=D(k*D(f*c));f=D(o*c);k=D(D(D(d+f)*D(-.5))+D(1));A[a+4288>>2]=m*D(L(D(k/D(D(D(d+c)*D(.1444000005722046))+e))));A[a+4284>>2]=m*D(L(D(k/D(D(D(f+l)*D(.1444000005722046))+i))));u[a+5046|0]=0}function qd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=jb-112|0;jb=k;l=i&2147483647;j=e&2147483647;m=j;a:{b:{o=!(b|c);if(!(d|j?j-2147418112>>>0<2147549184:o)){n=l-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?o:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(l|0)==2147418112?!(f|g):l>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(l^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|l)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|l)){break b}f=b;g=c;h=d;i=e;break a}j=(l|0)==(m|0);j=j&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&d>>>0<h>>>0|l>>>0>m>>>0;p=j?f:b;m=j?g:c;l=j?i:e;s=l;q=j?h:d;o=l&65535;e=j?e:i;r=e;h=j?d:h;l=e>>>16&32767;n=s>>>16&32767;if(!n){d=!(o|q);e=d<<6;i=F(d?p:q)+32|0;d=F(d?m:o);d=e+((d|0)==32?i:d)|0;$c(k+96|0,p,m,q,o,d-15|0);q=w[k+104>>2];o=w[k+108>>2];p=w[k+96>>2];n=16-d|0;m=w[k+100>>2]}f=j?b:f;g=j?c:g;i=r&65535;if(!l){b=!(h|i);c=b<<6;d=F(b?f:h)+32|0;b=F(b?g:i);b=c+((b|0)==32?d:b)|0;$c(k+80|0,f,g,h,i,b-15|0);l=16-b|0;h=w[k+88>>2];i=w[k+92>>2];g=w[k+84>>2];f=w[k+80>>2]}c=h;b=i<<3|c>>>29;d=c<<3;c=b;b=g>>>29|d;c=c|524288;d=q;j=o<<3|d>>>29;h=d<<3|m>>>29;i=j;r=r^s;d=f;e=g<<3|d>>>29;d=d<<3;c:{if((l|0)==(n|0)){break c}f=n-l|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}$c(k- -64|0,d,e,b,c,128-f|0);fg(k+48|0,d,e,b,c,f);b=w[k+56>>2];c=w[k+60>>2];e=w[k+52>>2];d=w[k+48>>2]|(w[k+64>>2]|w[k+72>>2]|(w[k+68>>2]|w[k+76>>2]))!=0}l=d;o=e;j=h;q=i|524288;d=p;e=m<<3|d>>>29;m=d<<3;p=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(l^m|b^j|(o^p|c^q))){break a}d=m-l|0;e=p-((l>>>0>m>>>0)+o|0)|0;c=q-((b>>>0>j>>>0)+c|0)|0;f=j-b|0;b=(o|0)==(p|0)&l>>>0>m>>>0|o>>>0>p>>>0;i=c-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;f=F(b?d:h)+32|0;b=F(b?e:i);b=c+((b|0)==32?f:b)|0;b=b-12|0;$c(k+32|0,d,e,h,i,b);n=n-b|0;h=w[k+40>>2];i=w[k+44>>2];d=w[k+32>>2];e=w[k+36>>2];break d}e=o+p|0;d=l+m|0;e=d>>>0<m>>>0?e+1|0:e;f=b;b=j;f=f+b|0;j=c+q|0;j=b>>>0>f>>>0?j+1|0:j;c=f;b=c+((e|0)==(o|0)&d>>>0<l>>>0|e>>>0<o>>>0)|0;h=b;i=b>>>0<c>>>0?j+1|0:j;if(!(i&1048576)){break d}c=h;j=c<<31;d=l&1|((e&1)<<31|d>>>1);e=j|e>>>1;n=n+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}c=0;m=s&-2147483648;if((n|0)>=32767){h=c;i=m|2147418112;f=0;g=0;break a}l=0;e:{if((n|0)>0){l=n;break e}$c(k+16|0,d,e,h,i,n+127|0);fg(k,d,e,h,i,1-n|0);d=w[k>>2]|(w[k+16>>2]|w[k+24>>2]|(w[k+20>>2]|w[k+28>>2]))!=0;e=w[k+4>>2];h=w[k+8>>2];i=w[k+12>>2]}j=h<<29;o=(e&7)<<29|d>>>3;f=o;n=d&7;d=f+(n>>>0>4)|0;b=e>>>3|j;e=d>>>0<f>>>0?b+1|0:b;f=d;c=c|((i&7)<<29|h>>>3);g=e;b=c+((b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0)|0;i=m|(i>>>3&65535|l<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((n|0)==4){c=0;j=g+c|0;d=f&1;b=f+d|0;j=b>>>0<f>>>0?j+1|0:j;f=b;g=j;c=(c|0)==(j|0)&b>>>0<d>>>0|c>>>0>j>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!n){break a}}}w[a>>2]=f;w[a+4>>2]=g;w[a+8>>2]=h;w[a+12>>2]=i;jb=k+112|0}function nF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-368|0;jb=f;w[b+8>>2]=0;d=jb-16|0;jb=d;i=w[b+8>>2];g=w[b>>2];h=f+320|0;w[d+8>>2]=h;w[d+12>>2]=h+38;i=ob[w[w[g>>2]+32>>2]](g,i,d+8|0)|0;if((i|0)==38){g=w[b>>2];a:{if(ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],38)|0){g=w[b+8>>2]+38|0;break a}g=w[b>>2];g=ob[w[w[g>>2]+24>>2]](g)|0}w[b+8>>2]=g}jb=d+16|0;b:{c:{if((i|0)!=38){break c}if(Jb(f+320|0,23168,25)|x[f+354|0]>64){break c}d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],(x[f+355|0]<<11)+2624|0)|0)){break c}d:{if(!c){break d}tc(a,2097152);je(a);Ce(a,1);v[a+480188>>1]=8;w[a+480196>>2]=x[f+352|0];w[a+480204>>2]=C(x[f+353|0],1e4);v[a+480190>>1]=x[f+354|0];d=x[f+357|0];if(d>>>0<x[f+356|0]){v[(w[a+484360>>2]+(x[a+484376|0]<<5)|0)+28>>1]=d}d=a+1304436|0;e=Hb(f- -64|0,2848);if(u[a+1304447|0]<0){zb(w[d>>2])}g=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];d=a+1304448|0;e=Hb(f- -64|0,6982);if(u[a+1304459|0]<0){zb(w[d>>2])}g=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];w[a+1304496>>2]=4;d=f- -64|0;ll(b,d);Pf(w[a+484360>>2]+(x[a+484376|0]<<5)|0,d,x[f+356|0],65535,65535);if(y[a+480190>>1]){e=1;while(1){if(!Aq(b,f+24|0)){Cb(f+24|0,0,37)}i=e&65535;g=(C(i,104)+a|0)+484380|0;lc(g,0);d=f+24|0;u[g+37|0]=x[d+22|0]<<4;h=x[d+23|0];v[g+30>>1]=(h>>>0>=64?64:h)<<2;u[g+36|0]=x[d+24|0];w[g>>2]=x[d+25|0]|x[d+26|0]<<8|(x[d+27|0]<<16|x[d+28|0]<<24);h=x[d+33|0]|x[d+34|0]<<8|(x[d+35|0]<<16|x[d+36|0]<<24);if(!(h>>>0<3|h+(x[d+29|0]|x[d+30|0]<<8|(x[d+31|0]<<16|x[d+32|0]<<24))>>>0>(x[d+25|0]|x[d+26|0]<<8|(x[d+27|0]<<16|x[d+28|0]<<24))>>>0)){v[g+34>>1]=y[g+34>>1]|2;w[g+4>>2]=x[d+29|0]|x[d+30|0]<<8|(x[d+31|0]<<16|x[d+32|0]<<24);w[g+8>>2]=(x[d+33|0]|x[d+34|0]<<8|(x[d+35|0]<<16|x[d+36|0]<<24))+(x[d+29|0]|x[d+30|0]<<8|(x[d+31|0]<<16|x[d+32|0]<<24))}g=f+8|0;Vb(g,2,d,22);w[114256]=0;w[f+364>>2]=32;w[f+360>>2]=((i<<5)+a|0)+946304;Q(200,f+360|0,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}if(u[f+19|0]<0){zb(w[f+8>>2])}e=e+1|0;if(y[a+480190>>1]>=(e&65535)>>>0){continue}break}}d=w[b>>2];e=C(64-x[f+354|0]|0,37);e:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],e)|0){d=e+w[b+8>>2]|0;break e}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d;g=a+484344|0;td(g,x[f+355|0]);if(x[f+355|0]){i=c&1;d=0;while(1){f:{g:{if(!i){break g}if(!ie(g,d&65535,64)){break g}h=w[g>>2]+C(d,52)|0;e=w[h>>2];h=w[h+4>>2];if((e|0)==(h|0)){break f}while(1){Of(b,f+24|0);j=x[f+24|0];if((j-1&255)>>>0<=106){u[e|0]=j+13}u[e+1|0]=x[f+25|0];u[e+3|0]=x[f+26|0];u[e+5|0]=x[f+27|0];We(e);e=e+6|0;if((h|0)!=(e|0)){continue}break}break f}e=w[b>>2];h:{if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],2048)|0){e=w[b+8>>2]+2048|0;break h}e=w[b>>2];e=ob[w[w[e>>2]+24>>2]](e)|0}w[b+8>>2]=e}d=d+1|0;if(d>>>0<x[f+355|0]){continue}break}}if(!(c&2)){break d}w[f+24>>2]=264;if(!y[a+480190>>1]){break d}e=1;while(1){Fd(f+24|0,(C(e&65535,104)+a|0)+484380|0,b);e=e+1|0;if(y[a+480190>>1]>=(e&65535)>>>0){continue}break}}e=1}jb=f+368|0;return e|0}a=P()|0;if(u[f+19|0]<0){zb(w[f+8>>2])}R(a|0);M()}function Gj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=w[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=w[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=w[114137]){if(c>>>0<=255){e=w[a+8>>2];c=c>>>3|0;d=w[a+12>>2];if((d|0)!=(e|0)){break c}i=456528,j=w[114132]&FV(-2,c),w[i>>2]=j;break b}h=w[a+24>>2];c=w[a+12>>2];d:{if((c|0)!=(a|0)){d=w[a+8>>2];w[d+12>>2]=c;w[c+8>>2]=d;break d}e:{e=a+20|0;d=w[e>>2];if(d){break e}e=a+16|0;d=w[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=w[e>>2];if(d){continue}e=c+16|0;d=w[c+16>>2];if(d){continue}break}w[g>>2]=0}if(!h){break b}e=w[a+28>>2];d=(e<<2)+456832|0;f:{if(w[d>>2]==(a|0)){w[d>>2]=c;if(c){break f}i=456532,j=w[114133]&FV(-2,e),w[i>>2]=j;break b}w[h+(w[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}w[c+24>>2]=h;d=w[a+16>>2];if(d){w[c+16>>2]=d;w[d+24>>2]=c}d=w[a+20>>2];if(!d){break b}w[c+20>>2]=d;w[d+24>>2]=c;break b}c=w[f+4>>2];if((c&3)!=3){break b}w[114134]=b;w[f+4>>2]=c&-2;w[a+4>>2]=b|1;w[f>>2]=b;return}w[e+12>>2]=d;w[d+8>>2]=e}c=w[f+4>>2];g:{if(!(c&2)){if(w[114138]==(f|0)){w[114138]=a;b=w[114135]+b|0;w[114135]=b;w[a+4>>2]=b|1;if(w[114137]!=(a|0)){break a}w[114134]=0;w[114137]=0;return}if(w[114137]==(f|0)){w[114137]=a;b=w[114134]+b|0;w[114134]=b;w[a+4>>2]=b|1;w[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=w[f+8>>2];c=c>>>3|0;d=w[f+12>>2];if((d|0)==(e|0)){i=456528,j=w[114132]&FV(-2,c),w[i>>2]=j;break h}w[e+12>>2]=d;w[d+8>>2]=e;break h}h=w[f+24>>2];c=w[f+12>>2];i:{if((f|0)!=(c|0)){d=w[f+8>>2];w[d+12>>2]=c;w[c+8>>2]=d;break i}j:{d=f+20|0;e=w[d>>2];if(e){break j}d=f+16|0;e=w[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=w[d>>2];if(e){continue}d=c+16|0;e=w[c+16>>2];if(e){continue}break}w[g>>2]=0}if(!h){break h}e=w[f+28>>2];d=(e<<2)+456832|0;k:{if(w[d>>2]==(f|0)){w[d>>2]=c;if(c){break k}i=456532,j=w[114133]&FV(-2,e),w[i>>2]=j;break h}w[h+(w[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}w[c+24>>2]=h;d=w[f+16>>2];if(d){w[c+16>>2]=d;w[d+24>>2]=c}d=w[f+20>>2];if(!d){break h}w[c+20>>2]=d;w[d+24>>2]=c}w[a+4>>2]=b|1;w[a+b>>2]=b;if(w[114137]!=(a|0)){break g}w[114134]=b;return}w[f+4>>2]=c&-2;w[a+4>>2]=b|1;w[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+456568|0;d=w[114132];b=1<<(b>>>3);l:{if(!(d&b)){w[114132]=b|d;b=c;break l}b=w[c+8>>2]}w[c+8>>2]=a;w[b+12>>2]=a;w[a+12>>2]=c;w[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}w[a+28>>2]=e;w[a+16>>2]=0;w[a+20>>2]=0;g=(e<<2)+456832|0;m:{d=w[114133];c=1<<e;n:{if(!(d&c)){w[114133]=c|d;w[g>>2]=a;w[a+24>>2]=g;break n}e=b<<((e|0)!=31?25-(e>>>1|0)|0:0);c=w[g>>2];while(1){d=c;if((w[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=w[g+16>>2];if(c){continue}break}w[g+16>>2]=a;w[a+24>>2]=d}w[a+12>>2]=a;w[a+8>>2]=a;return}b=w[d+8>>2];w[b+12>>2]=a;w[d+8>>2]=a;w[a+24>>2]=0;w[a+12>>2]=d;w[a+8>>2]=b}}function mk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c&15;l=C(b,896)+a|0;m=l+1075782|0;h=v[m>>1];j=w[a+1074312>>2];a:{b:{c:{if(j&8388608){if(!(w[a+1074392>>2]|!x[(C(b,896)+a|0)+1075794|0])){v[m>>1]=f;break c}if(h){g=h-1|0;v[m>>1]=g;if(g&65535){break c}}v[m>>1]=f;e=1;break c}d:{e:{f:{i=c&256;k=w[a+1074316>>2]&1048576;if(!(!i|!k)){if(!(x[a+480209|0]&16)){break f}e=C(b,896)+a|0;if(x[e+1075795|0]){h=x[e+1075794|0]<121?1:h}if(x[(C(b,896)+a|0)+1075798|0]?x[e+1075796|0]==1:0){break b}e=0;if((x[(C(b,896)+a|0)+1075794|0]-1&255)>>>0<120|(f|0)>(h|0)){break c}break d}e=w[a+480180>>2];if(e&16777250){e=!(h?(h|0)%((f?f:1)|0)|0:1);h=h+1|0;break c}g:{if((e|0)!=16){if((e|0)!=1){break g}e=z[a+1074392>>2]%z[a+1074416>>2]|0;if(!e&(x[(C(b,896)+a|0)+1075794|0]-1&255)>>>0<120){break a}e=!(f?(e>>>0)%(f>>>0)|0:1);break c}e=w[a+1074392>>2]==(f|0)&(f|0)!=0;break c}h:{i:{j:{k:{l:{if(i){e=C(b,896)+a|0;if(x[e+1075796|0]==1){f=(x[e+1075799|0]>15)+f|0}f=f?f:1;break l}if(x[a+480209|0]&16){break i}f=f?f:1;if(w[a+1074416>>2]){break k}}g=0;break j}g=!(z[a+1074392>>2]%(f>>>0)|0)}h=h+1|0;break h}h=e&1048580?0:h}if(h<<16>>16<(f|0)){e=g;break e}f=w[a+1074392>>2];e=(f|0)!=0|g;if(f|!i){break e}e=!x[(C(b,896)+a|0)+1075794|0]|g;break c}if((f|0)<=(h|0)){break d}break c}if(!k|c){break c}e=!w[a+1074392>>2];break c}h=0;e=1}f=w[(C(b,896)+a|0)+1075060>>2];if(!(f|!(x[a+1074316|0]&64))){g=w[(C(b,896)+a|0)+1075640>>2];if(!g|(x[g+31|0]-1&255)>>>0>16){break a}}i=w[a+1074324>>2];if(w[(C(b,896)+a|0)+1075680>>2]?0:i&1024){break a}m:{if(!e){break m}g=C(b,896)+a|0;o=g+1075672|0;j=w[o>>2];e=c>>>4&15;if(e){n:{if(x[(C(b,896)+a|0)+1075796|0]==1?x[a+1074318|0]&16:0){break n}k=u[e+26816|0];if(k){j=(C(j,k)|0)/16|0;break n}j=(u[e+26832|0]<<2)+j|0}e=0;o:{if((j|0)>=0){e=256;if(j>>>0<257){break o}}j=e}e=(C(b,896)+a|0)+1075072|0;w[e>>2]=w[e>>2]|2097152}p=g+1075684|0;k=w[p>>2];g=x[g+1075808|0];if(!(!(!(x[(C(b,896)+a|0)+1075073|0]&2)|w[a+480180>>2]!=2|i&4096)|(!f|(g-121&255)>>>0<136))){Wn(a,b,0,g,1)}e=l+1074984|0;f=0;p:{if(!(w[a+480180>>2]&1048580)){break p}f=(c|0)<256;if((c|0)>255){break p}i=x[(C(b,896)+a|0)+1075795|0];if(!i){break p}f=1;fh(a,e,i,0,0,1)}i=C(b,896)+a|0;l=i+1075644|0;q=w[l>>2];w[l>>2]=0;n=i+1075072|0;r=w[n>>2];qi(a,e,g,(w[a+1074312>>2]&8388608)>>>23|0,f,0,b);if(!x[i+1075795|0]){w[l>>2]=q}f=w[a+480180>>2];if(!(!(r&4096)|(f|0)!=4)){w[n>>2]=w[n>>2]|4096}i=i+1075794|0;w[o>>2]=j;if(y[a+480192>>1]){u[i|0]=g;yw(a,b);f=w[a+480180>>2]}if(!(!(f&16777248)|(x[i|0]|!k))){w[p>>2]=k}j=w[a+1074312>>2];if(j&8388608){w[e>>2]=0;w[e+4>>2]=0}h=f&16777250?h:0;if(d-1>>>0>9){break m}g=w[(C(b,896)+a|0)+1075088>>2];if(!g){break m}q:{if((d|0)==1){b=w[(C(b,896)+a|0)+1075648>>2];break q}j=(C(b,896)+a|0)+1075648|0;b=w[(g+(d<<2)|0)+60>>2];w[j>>2]=b}Gf(a,e,b);j=w[a+1074312>>2]}if(j&8388608){break a}h=(c>>>8&(x[a+1074318|0]&16)>>>4)+h|0}v[m>>1]=h}}function vn(a,b){var c=0,d=D(0),e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=0,q=0,r=0,s=0,t=0,u=D(0),x=0,B=0;if(b){w[a+24588>>2]=0;w[a+24592>>2]=0;v[a+480214>>1]=0;e=a+24596|0;w[e>>2]=0;w[e+4>>2]=0;An(a)}Zj(a+24648|0,0);s=w[a+24620>>2];p=jb-144|0;jb=p;B=b;e=!b;c=a+393352|0;b=w[c+4>>2];if(b>>>0>=29){w[c+4>>2]=0;b=0}i=C(b,44)+80672|0;if(!((i|0)==w[c+4112>>2]&e)){w[c+4112>>2]=i;n=D(s>>>0);d=D(D(G(A[i+20>>2],D(.10000000149011612)))*n);a:{if(D(E(d))<D(2147483648)){b=~~d;break a}b=-2147483648}j=(b|0)<=96?96:b;e=j-7500|0;e=e>>>0<=j>>>0?e:0;b=(b|0)<96?b-96|0:0;d=D(A[i+28>>2]*n);b:{if(D(E(d))<D(2147483648)){f=~~d;break b}f=-2147483648}b=e+(f+b|0)|0;l=(b|0)<=128?128:b;m=l-3800|0;o=(b|0)<128;e=b-128|0;d=D(A[i+8>>2]*n);c:{if(D(E(d))<D(2147483648)){b=~~d;break c}b=-2147483648}f=l>>>0<m>>>0;e=o?e:0;d=D(D(A[i+32>>2]*D(117.9612045288086))+D(4915.05029296875));d:{if(D(E(d))<D(2147483648)){o=~~d;break d}o=-2147483648}q=l>>>0<3800;h=f?0:m;m=b+e|0;e=j>>>0<7500;r=w[i+24>>2];k=w[i+16>>2];b=(k|0)<(r|0)?r:k;t=(b|0)<-600?b+600|0:0;d=D(A[i+36>>2]*D(79.30999755859375));e:{if(D(E(d))<D(2147483648)){f=~~d;break e}f=-2147483648}q=q?l:3800;l=h+m|0;e=e?j:7500;m=k-t|0;h=w[i+4>>2];while(1){b=C(g,12);j=b+(p+8|0)|0;k=b+36320|0;v[j+42>>1]=y[k+10>>1];v[j+36>>1]=y[k+4>>1];b=y[k+6>>1]|y[k+8>>1]<<16;v[j+38>>1]=b;v[j+40>>1]=b>>>16;w[j+44>>2]=e+((C(q,w[k>>2])+50|0)/100|0);g=g+1|0;if((g|0)!=8){continue}break}w[c+4124>>2]=l;d=D(l|0);u=D(A[i+12>>2]*d);d=D(jd((l|0)<4721?D(-9.965784072875977):D(D(-47038.5)/d))*D(32768));f:{if(D(E(d))<D(2147483648)){e=~~d;break f}e=-2147483648}d=D(1);g:{if(!h){break g}d=D(0);if((h|0)<-99999){break g}x=+(h|0)*.0016609640474436812;d=D(Ed(x-K(x+.5)))}b=tv(d,n);v[c+4190>>1]=b;v[c+4188>>1]=b;b=(f<<1)+16384|0;v[c+4198>>1]=b;v[c+4196>>1]=b;g=0;while(1){h=(g<<4)+c|0;f=(p+8|0)+C(g,12)|0;b=w[f+44>>2];w[h+4204>>2]=b;w[h+4208>>2]=b;v[h+4212>>1]=y[f+36>>1];v[h+4214>>1]=y[f+42>>1];v[h+4216>>1]=y[f+40>>1];v[h+4218>>1]=y[f+38>>1];g=g+1|0;if((g|0)!=8){continue}break}w[c+53996>>2]=q;b=0;g=c+4184|0;if((m|0)>-9e3){f=sv(m)}else{f=0}w[g>>2]=f;f=r-t|0;if((f|0)>=-8999){b=sv(f)}d=u>D(4720)?D(D(-47038.5)/u):D(-9.965784072875977);f=c+54036|0;w[f>>2]=268464128;w[f+4>>2]=1879052288;w[c+54052>>2]=b;b=(o|0)>=32512?32512:o;b=b>>>0>=32512?32512:b;v[c+54010>>1]=b;v[c+54008>>1]=b;v[c+54006>>1]=b;v[c+54004>>1]=b;b=0;h:{if((e|0)>=0){b=32752;if(e>>>0<32753){break h}}e=b}v[c+54018>>1]=e;v[c+54014>>1]=0;v[c+54016>>1]=0;v[c+54012>>1]=e;g=256;b=tv(jd(D(d+d)),n);i:{if((b|0)>=256){g=32512;if(b>>>0<32513){break i}}b=g}v[c+54026>>1]=b;v[c+54022>>1]=0;v[c+54024>>1]=0;v[c+54020>>1]=b}if(B){w[c+4116>>2]=0;w[c+4120>>2]=0;v[c+4128>>1]=0;w[c+4104>>2]=0;w[c+4108>>2]=0;Cb(c+4132|0,0,40);Cb(c+4332|0,0,49664);Cb(c+54060|0,0,32768)}b=C(s,5);if(b>>>0>z[c+4124>>2]){w[c+4124>>2]=b}jb=p+144|0;b=w[a+1304392>>2];if(b){ro(b,w[a+24620>>2])}}function eD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=D(0),i=D(0);c=jb+-64|0;jb=c;d=jb-16|0;jb=d;f=w[a+8>>2];e=w[a>>2];g=b+16|0;w[d+8>>2]=g;w[d+12>>2]=g+128;f=ob[w[w[e>>2]+32>>2]](e,f,d+8|0)|0;if((f|0)==128){e=w[a>>2];a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],128)|0){e=w[a+8>>2]+128|0;break a}e=w[a>>2];e=ob[w[w[e>>2]+24>>2]](e)|0}w[a+8>>2]=e}jb=d+16|0;if((f|0)!=128){Cb(g,0,128)}w[b+152>>2]=-2147483648;w[b+156>>2]=-2147483648;u[b+143|0]=0;u[b+79|0]=0;d=Nc(a,c+24|0);oc(c+40|0,a,d?w[c+24>>2]:0);d=w[c+40>>2];e=w[w[d>>2]+24>>2];w[114256]=0;d=V(e|0,d|0)|0;e=w[114256];w[114256]=0;b:{c:{if((e|0)==1){break c}w[114256]=0;T(279,b+4|0,d-w[c+48>>2]|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}d=w[b+8>>2];w[c+24>>2]=w[b+4>>2];w[c+28>>2]=d;d=w[c+40>>2];e=w[w[d>>2]+32>>2];w[114256]=0;d=S(e|0,d|0,w[c+48>>2],c+24|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;w[c+48>>2]=d+w[c+48>>2];d=Q(232,a|0,c|0)|0;e=w[114256];w[114256]=0;d:{if((e|0)==1){break d}w[114256]=0;U(188,c+24|0,a|0,(d?w[c>>2]:0)|0);a=w[114256];w[114256]=0;if((a|0)==1){break d}a=w[c+24>>2];d=w[w[a>>2]+8>>2];w[114256]=0;a=V(d|0,a|0)|0;d=w[114256];w[114256]=0;e:{if((d|0)!=1){f:{g:{if(!a){break g}e=c+24|0;while(1){h:{a=w[c+24>>2];d=w[w[a>>2]+36>>2];w[114256]=0;a=S(d|0,a|0,w[c+32>>2],5)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(!a){break g}a=w[c+24>>2];d=w[w[a>>2]+36>>2];w[114256]=0;a=S(d|0,a|0,w[c+32>>2],4)|0;d=w[114256];w[114256]=0;i:{j:{k:{l:{m:{n:{if((d|0)==1){break n}o:{if(a){w[c+4>>2]=e;w[c>>2]=c+20;a=w[c+24>>2];d=w[w[a>>2]+32>>2];w[114256]=0;a=S(d|0,a|0,w[c+32>>2],c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break n}w[c+32>>2]=a+w[c+32>>2];a=w[c+20>>2];break o}w[c+20>>2]=0;a=0}d=4;if(!((a|0)==1196380752|(a|0)==1414682436)){w[114256]=0;a=Q(232,c+24|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break m}d=a?w[c>>2]:0}w[114256]=0;U(188,c|0,c+24|0,d|0);a=w[114256];w[114256]=0;if((a|0)==1){break l}a=w[c+20>>2];if((a|0)==1196380752){break k}if((a|0)!=1414682436){break j}w[114256]=0;a=Q(407,c|0,c+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break h}h=D(H(D(G(a?A[c+56>>2]:D(0),D(1))),D(0)));i=D(E(h));A[b+144>>2]=i<D(O)?i>=D(11754943508222875e-54)?h:D(0):D(0);break j}a=P()|0;break e}a=P()|0;break e}a=P()|0;break e}w[114256]=0;a=Q(232,c|0,c+56|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break i}w[b+148>>2]=a?w[c+56>>2]:0}a=w[c+4>>2];if(!a){continue}d=w[a+4>>2];w[a+4>>2]=d-1;if(d){continue}ob[w[w[a>>2]+8>>2]](a);Ib(a);continue}}break}a=P()|0;Bb(c);break e}a=w[c+28>>2];p:{if(!a){break p}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break p}ob[w[w[a>>2]+8>>2]](a);Ib(a)}a=w[c+44>>2];q:{if(!a){break q}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break q}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=c- -64|0;return}a=P()|0;break e}a=P()|0}Bb(c+24|0);break b}a=P()|0;break b}a=P()|0}Bb(c+40|0);R(a|0);M()}function By(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-32|0;jb=h;z=w[a+16>>2];A=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);q=w[a+128>>2];a:{if(!q){r=w[a+8>>2];s=w[a+12>>2];k=w[a>>2];o=w[a+4>>2];t=0;break a}o=w[a+4>>2];e=w[a+76>>2];k=w[a>>2];r=w[a+8>>2];s=w[a+12>>2];l=BV(r,s,d,0);b=k+l|0;f=nb+o|0;u=e>>>0<(b>>>0<l>>>0?f+1|0:f)>>>0?d:0;l=CV(r,s,q,q>>31);t=nb}e=w[a+44>>2];w[h+12>>2]=e;g=w[a+48>>2];w[h+16>>2]=g;f=w[a+52>>2];w[h+20>>2]=f;j=w[a+56>>2];w[h+24>>2]=j;m=w[a+40>>2];n=w[a+36>>2];b:{c:{if(!d){b=m>>12;i=n>>12;break c}j=a+112|0;B=(q|0)>0;while(1){u=u-1|0;b=u;l=b?l:0;t=b?t:0;f=0;e=k;i=((((o&2147483647)<<1|e>>>31)&2147483646)<<1)+z|0;b=q;d:{if(!B){break d}while(1){e:{g=(f&2147483647)<<1|e>>>31;p=v[(g<<1|2)+i>>1];g=v[i+((g&2147483646)<<1)>>1];w[114256]=0;T(604,j|0,(g+p|0)/8<<16>>16);g=w[114256];w[114256]=0;if((g|0)==1){break e}w[114256]=0;T(605,j|0,4);g=w[114256];w[114256]=0;if((g|0)==1){break e}f=f+t|0;e=e+l|0;f=e>>>0<l>>>0?f+1|0:f;g=b>>>0>1;b=b-1|0;if(g){continue}break d}break}break b}p=w[a+120>>2];g=p+w[a+112>>2]|0;b=w[a+116>>2]+w[a+124>>2]|0;b=g>>>0<p>>>0?b+1|0:b;w[a+112>>2]=g;w[a+116>>2]=b;if(b){f=(f&2147483647)<<1|e>>>31;e=v[(f<<1|2)+i>>1];f=v[i+((f&2147483646)<<1)>>1];w[114256]=0;T(604,j|0,(e+f|0)/8<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,A|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}d=d-1|0;w[h+4>>2]=b;w[h>>2]=b;p=w[a+72>>2];b=w[a+68>>2];D=b;E=b>>31;b=w[a+64>>2];F=b;G=b>>31;b=w[a+60>>2];H=b;I=b>>31;b=0;f=1;while(1){e=(h+8|0)+(b<<3)|0;g=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;x=(b<<2)+h|0;y=w[x>>2]<<8;b=y;b=BV(H,I,b,b>>31);J=nb;K=e;e=b;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;i=BV(b,b>>31,F,G);e=e+i|0;b=nb+J|0;b=e>>>0<i>>>0?b+1|0:b;i=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);e=i+g|0;b=nb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[K+4>>2]=b-(p&y);w[x>>2]=(b|0)/256;e=f&1;f=0;b=1;if(e){continue}break}b=w[a+32>>2];n=w[a+28>>2]+n|0;i=n>>12;w[c>>2]=w[c>>2]+C(i,w[h>>2]);m=b+m|0;b=m>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[h+4>>2]);f=o+s|0;k=k+r|0;f=k>>>0<r>>>0?f+1|0:f;o=f;c=c+8|0;if(d){continue}break}j=w[h+24>>2];f=w[h+20>>2];g=w[h+16>>2];e=w[h+12>>2]}w[a+36>>2]=n;w[a>>2]=k;w[a+4>>2]=o;w[a+40>>2]=m;w[a+20>>2]=i;w[a+56>>2]=j;w[a+52>>2]=f;w[a+48>>2]=g;w[a+44>>2]=e;w[a+24>>2]=b;jb=h+32|0;return}b=P()|0;w[a+40>>2]=m;w[a+36>>2]=n;w[a+20>>2]=n>>12;w[a+24>>2]=m>>12;w[a+44>>2]=w[h+12>>2];w[a+48>>2]=w[h+16>>2];w[a+52>>2]=w[h+20>>2];w[a+56>>2]=w[h+24>>2];R(b|0);M()}function uR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-160|0;jb=c;a:{b=w[b>>2];if(!b){Hb(a,5621);break a}g=b>>>24|0;b:{if(!(b&65535)){d=Hb(c+104|0,11012);f=w[d>>2];w[c+124>>2]=w[d+4>>2];e=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[c+127|0]=e;u[c+128|0]=e>>>8;u[c+129|0]=e>>>16;u[c+130|0]=e>>>24;w[d>>2]=0;w[d+4>>2]=0;e=x[d+11|0];w[d+8>>2]=0;w[114256]=0;w[c+120>>2]=f;u[c+131|0]=e;w[c+32>>2]=g;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=290;w[c+140>>2]=0;U(7,c+88|0,c+32|0,c+136|0);e=w[114256];w[114256]=0;c:{d:{e:{f:{if((e|0)!=1){w[114256]=0;w[c+16>>2]=b>>>16&255;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=1058;w[c+140>>2]=2;U(7,c+72|0,c+16|0,c+136|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;Y(107,a|0,c+120|0,c+88|0,c+72|0);a=w[114256];w[114256]=0;if((a|0)==1){break e}if(u[c+83|0]<0){zb(w[c+72>>2])}if(u[c+99|0]<0){zb(w[c+88>>2])}if(u[c+131|0]<0){zb(w[c+120>>2])}if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}b=P()|0;break c}b=P()|0;break d}b=P()|0;if(u[c+83|0]>=0){break d}zb(w[c+72>>2])}if(u[c+99|0]>=0){break c}zb(w[c+88>>2])}if(u[c+131|0]<0){zb(w[c+120>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}d=Hb(c+56|0,10479);f=w[d>>2];w[c+124>>2]=w[d+4>>2];e=x[d+7|0]|x[d+8|0]<<8|(x[d+9|0]<<16|x[d+10|0]<<24);u[c+127|0]=e;u[c+128|0]=e>>>8;u[c+129|0]=e>>>16;u[c+130|0]=e>>>24;w[d>>2]=0;w[d+4>>2]=0;e=x[d+11|0];w[d+8>>2]=0;w[114256]=0;w[c+120>>2]=f;u[c+131|0]=e;w[c+52>>2]=g;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=290;w[c+140>>2]=0;U(7,c+88|0,c+52|0,c+136|0);e=w[114256];w[114256]=0;g:{h:{i:{j:{k:{l:{m:{n:{if((e|0)!=1){w[114256]=0;w[c+48>>2]=b>>>16&255;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=1058;w[c+140>>2]=2;U(7,c+72|0,c+48|0,c+136|0);e=w[114256];w[114256]=0;if((e|0)==1){break n}w[114256]=0;w[c+28>>2]=b>>>8&255;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=1058;w[c+140>>2]=2;U(7,c+32|0,c+28|0,c+136|0);e=w[114256];w[114256]=0;if((e|0)==1){break m}w[114256]=0;w[c+12>>2]=b&255;u[c+152|0]=44;w[c+144>>2]=-1;w[c+148>>2]=0;w[c+136>>2]=1058;w[c+140>>2]=2;U(7,c+16|0,c+12|0,c+136|0);b=w[114256];w[114256]=0;if((b|0)==1){break l}w[114256]=0;ia(108,a|0,c+120|0,c+88|0,c+72|0,c+32|0,c+16|0);a=w[114256];w[114256]=0;if((a|0)==1){break k}if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[c+43|0]<0){zb(w[c+32>>2])}if(u[c+83|0]<0){zb(w[c+72>>2])}if(u[c+99|0]<0){zb(w[c+88>>2])}if(u[c+131|0]<0){zb(w[c+120>>2])}if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}b=P()|0;break g}b=P()|0;break h}b=P()|0;break i}b=P()|0;break j}b=P()|0;if(u[c+27|0]>=0){break j}zb(w[c+16>>2])}if(u[c+43|0]>=0){break i}zb(w[c+32>>2])}if(u[c+83|0]>=0){break h}zb(w[c+72>>2])}if(u[c+99|0]>=0){break g}zb(w[c+88>>2])}if(u[c+131|0]<0){zb(w[c+120>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2])}R(b|0);M()}jb=c+160|0}function Cy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-32|0;jb=h;z=w[a+16>>2];A=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);q=w[a+128>>2];a:{if(!q){r=w[a+8>>2];s=w[a+12>>2];k=w[a>>2];o=w[a+4>>2];t=0;break a}o=w[a+4>>2];e=w[a+76>>2];k=w[a>>2];r=w[a+8>>2];s=w[a+12>>2];l=BV(r,s,d,0);b=k+l|0;f=nb+o|0;v=e>>>0<(b>>>0<l>>>0?f+1|0:f)>>>0?d:0;l=CV(r,s,q,q>>31);t=nb}e=w[a+44>>2];w[h+12>>2]=e;g=w[a+48>>2];w[h+16>>2]=g;f=w[a+52>>2];w[h+20>>2]=f;j=w[a+56>>2];w[h+24>>2]=j;m=w[a+40>>2];n=w[a+36>>2];b:{c:{if(!d){b=m>>12;i=n>>12;break c}j=a+112|0;B=(q|0)>0;while(1){v=v-1|0;b=v;l=b?l:0;t=b?t:0;f=0;e=k;i=(((o&2147483647)<<1|e>>>31)&-2)+z|0;b=q;d:{if(!B){break d}while(1){e:{g=(f&2147483647)<<1|e>>>31;p=u[(g|1)+i|0];g=u[i+(g&-2)|0];w[114256]=0;T(604,j|0,g+p<<5);g=w[114256];w[114256]=0;if((g|0)==1){break e}w[114256]=0;T(605,j|0,4);g=w[114256];w[114256]=0;if((g|0)==1){break e}f=f+t|0;e=e+l|0;f=e>>>0<l>>>0?f+1|0:f;g=b>>>0>1;b=b-1|0;if(g){continue}break d}break}break b}p=w[a+120>>2];g=p+w[a+112>>2]|0;b=w[a+116>>2]+w[a+124>>2]|0;b=g>>>0<p>>>0?b+1|0:b;w[a+112>>2]=g;w[a+116>>2]=b;if(b){f=(f&2147483647)<<1|e>>>31;e=u[(f|1)+i|0];f=u[i+(f&-2)|0];w[114256]=0;T(604,j|0,e+f<<5);f=w[114256];w[114256]=0;if((f|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,A|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}d=d-1|0;w[h+4>>2]=b;w[h>>2]=b;p=w[a+72>>2];b=w[a+68>>2];D=b;E=b>>31;b=w[a+64>>2];F=b;G=b>>31;b=w[a+60>>2];H=b;I=b>>31;b=0;f=1;while(1){e=(h+8|0)+(b<<3)|0;g=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;x=(b<<2)+h|0;y=w[x>>2]<<8;b=y;b=BV(H,I,b,b>>31);J=nb;K=e;e=b;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;i=BV(b,b>>31,F,G);e=e+i|0;b=nb+J|0;b=e>>>0<i>>>0?b+1|0:b;i=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);e=i+g|0;b=nb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[K+4>>2]=b-(p&y);w[x>>2]=(b|0)/256;e=f&1;f=0;b=1;if(e){continue}break}b=w[a+32>>2];n=w[a+28>>2]+n|0;i=n>>12;w[c>>2]=w[c>>2]+C(i,w[h>>2]);m=b+m|0;b=m>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[h+4>>2]);f=o+s|0;k=k+r|0;f=k>>>0<r>>>0?f+1|0:f;o=f;c=c+8|0;if(d){continue}break}j=w[h+24>>2];f=w[h+20>>2];g=w[h+16>>2];e=w[h+12>>2]}w[a+36>>2]=n;w[a>>2]=k;w[a+4>>2]=o;w[a+40>>2]=m;w[a+20>>2]=i;w[a+56>>2]=j;w[a+52>>2]=f;w[a+48>>2]=g;w[a+44>>2]=e;w[a+24>>2]=b;jb=h+32|0;return}b=P()|0;w[a+40>>2]=m;w[a+36>>2]=n;w[a+20>>2]=n>>12;w[a+24>>2]=m>>12;w[a+44>>2]=w[h+12>>2];w[a+48>>2]=w[h+16>>2];w[a+52>>2]=w[h+20>>2];w[a+56>>2]=w[h+24>>2];R(b|0);M()}function IU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb-32|0;jb=c;a:{if(w[b>>2]==w[b+4>>2]){break a}m=w[b+12>>2];n=y[w[w[b+48>>2]+12>>2]+480188>>1];d=n;f=c+8|0;w[f+8>>2]=0;w[f>>2]=0;w[f+4>>2]=0;if(d){yh(f,d);d=C(d,6)-6|0;d=(d-((d>>>0)%6|0)|0)+6|0;p=f,q=Cb(w[f+4>>2],0,d)+d|0,w[p+4>>2]=q}b:{if(!m){break b}i=c+24|0;o=c+1|0;while(1){if(w[(w[w[a>>2]-12>>2]+a|0)+16>>2]){break b}w[114256]=0;u[c|0]=0;w[c+28>>2]=o;w[c+24>>2]=c;kc(a,c+24|0);d=w[114256];w[114256]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){d=u[c|0];if(!d){k=k+1|0;break c}g=0;if((d|0)<0){w[114256]=0;u[c|0]=0;w[c+28>>2]=o;w[c+24>>2]=c;kc(a,c+24|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}g=x[c|0]}v[c+4>>1]=0;w[c>>2]=0;t:{d=d&127;h=(d?d-1|0:0)&65535;j=n>>>0<=h>>>0;u:{v:{if(!j){d=w[b>>2]+C(C(y[w[w[b+48>>2]+12>>2]+480188>>1],k)+h|0,6)|0;if(g&1){break v}e=w[f>>2];l=x[e+C(h,6)|0];break u}d=c;if(!(g&1)){break t}}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break t}e=w[f>>2];l=x[c+23|0];u[e+C(h,6)|0]=l}u[d|0]=l;if(!(g&2)){break r}break s}if(g&2){break s}break q}break d}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break q}e=w[f>>2];u[(e+C(h,6)|0)+1|0]=x[c+23|0]}u[d+1|0]=x[(C(h,6)+e|0)+1|0];if(g&4){break p}break o}if(!(g&4)){break n}}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break n}e=w[f>>2];u[(e+C(h,6)|0)+2|0]=x[c+23|0]}u[d+2|0]=x[(C(h,6)+e|0)+2|0];if(!(g&8)){break l}break m}if(!(g&8)){break k}}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break k}e=w[f>>2];u[(e+C(h,6)|0)+4|0]=x[c+23|0]}u[d+4|0]=x[(C(h,6)+e|0)+4|0];if(g&16){break j}break i}if(!(g&16)){break h}}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break h}e=w[f>>2];u[(e+C(h,6)|0)+3|0]=x[c+23|0]}u[d+3|0]=x[(C(h,6)+e|0)+3|0];if(!(g&32)){break f}break g}if(!(g&32)){break e}}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}if(j){break e}e=w[f>>2];u[(e+C(h,6)|0)+5|0]=x[c+23|0]}u[d+5|0]=x[(C(h,6)+e|0)+5|0]}if(!(g&64)){break c}w[114256]=0;u[c+23|0]=0;w[c+28>>2]=i;w[c+24>>2]=c+23;kc(a,c+24|0);d=w[114256];w[114256]=0;if((d|0)!=1){w[114256]=0;S(950,a|0,x[c+23|0],-1)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break c}}}b=P()|0;a=w[f>>2];if(a){w[f+4>>2]=a;zb(a)}R(b|0);M()}if(k>>>0<m>>>0){continue}break}}a=w[f>>2];if(!a){break a}w[f+4>>2]=a;zb(a)}jb=c+32|0}function YU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;j=c;d=jb-192|0;jb=d;f=Od(d+40|0);e=w[w[f>>2]-12>>2];w[114256]=0;c=ea(79)|0;g=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)==1){break g}w[114256]=0;e=e+f|0;T(10,d+32|0,e|0);g=w[114256];w[114256]=0;if((g|0)==1){break g}w[114256]=0;U(80,d+184|0,e|0,c|0);g=w[114256];w[114256]=0;if((g|0)==1){break c}Ab(d+184|0);e=w[e+24>>2];if(e){g=w[w[e>>2]+8>>2];w[114256]=0;T(g|0,e|0,c|0);g=w[114256];w[114256]=0;if((g|0)==1){break c}e=e+4|0;g=Ic(d+176|0,e);Wc(e,c);Ab(g)}Ab(d+32|0);e=2;c=w[j>>2];g=w[j+8>>2];c=w[j+4>>2]?c&24576?c:(g|0)!=-1?c&-12289|8192:c:c;h:{if(!(c&1)){e=8;if(!(c&2)){break h}}h=w[w[f>>2]-12>>2]+f|0;w[h+4>>2]=w[h+4>>2]&-75|e}i:{if(c&4096){break i}e=4;if(!(c&8192)){e=256;if(!(c&16384)){break i}}h=w[w[f>>2]-12>>2]+f|0;w[h+4>>2]=w[h+4>>2]|e}j:{if(c&16){c=w[w[f>>2]-12>>2]+f|0;w[c+4>>2]=w[c+4>>2]&-16385;break j}if(!(c&32)){break j}c=w[w[f>>2]-12>>2]+f|0;w[c+4>>2]=w[c+4>>2]|16384}if((g|0)!=-1){w[(w[w[f>>2]-12>>2]+f|0)+8>>2]=g}b=y[b>>1];w[114256]=0;Q(87,f|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break g}w[114256]=0;l=f+4|0;T(82,d|0,l|0);b=w[114256];w[114256]=0;if((b|0)==1){break g}k:{if(!(x[j+1|0]&4)){break k}e=w[j+4>>2];g=w[d>>2];b=x[d+11|0];h=b<<24>>24;k=(h|0)<0;c=k?g:d;k=k?w[d+4>>2]:b;l:{if(!k){b=c;break l}m:{n:{b=c;switch(x[c|0]-43|0){case 2:break m;case 0:break n;default:break l}}e=e+1|0;b=((h|0)<0?g:d)+1|0;break l}e=e+1|0;b=((h|0)<0?g:d)+1|0}if(e>>>0<=k>>>0){break k}w[114256]=0;Z(93,d|0,b-c|0,e-k|0,48)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}}w[d+24>>2]=w[d+8>>2];w[d+8>>2]=0;b=w[d+4>>2];w[d+16>>2]=w[d>>2];w[d+20>>2]=b;w[d>>2]=0;w[d+4>>2]=0;e=w[j+12>>2];o:{if(!e){break o}b=x[d+27|0];c=b<<24>>24<0?w[d+20>>2]:b;if(!c){break o}g=c-1|0;j=u[j+16|0];b=0;while(1){p:{if(!b|(b>>>0)%(e>>>0)){break p}q:{if((b|0)!=(g|0)){break q}switch(x[(u[d+27|0]<0?w[d+16>>2]:d+16|0)|0]-43|0){case 0:case 2:break p;default:break q}}w[114256]=0;Z(93,d+16|0,c-b|0,1,j|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break e}}b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=w[d+20>>2];w[i>>2]=w[d+16>>2];w[i+4>>2]=b;w[i+8>>2]=w[d+24>>2];w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;if(u[d+11|0]<0){zb(w[d>>2])}b=w[15e3];w[f>>2]=b;w[w[b-12>>2]+f>>2]=w[15003];w[f+4>>2]=59272;if(u[f+47|0]<0){zb(w[f+36>>2])}wc(l);pc(f+56|0);jb=d+192|0;break a}b=P()|0;break b}b=P()|0;break d}b=P()|0;if(u[d+27|0]>=0){break d}zb(w[d+16>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}b=P()|0;Ab(d+32|0)}nd(f);R(b|0);M()}w[114256]=0;U(6,a|0,0,i|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[i+11|0]<0){zb(w[i>>2])}jb=i+16|0;return}a=P()|0;if(u[i+11|0]<0){zb(w[i>>2])}R(a|0);M()}function wv(a){var b=D(0),c=D(0),d=0,e=D(0),f=D(0),g=0,h=0,i=0,k=D(0),m=D(0),r=D(0),s=D(0),t=0,u=0,v=D(0);b=A[a+4208>>2];c=A[a+4272>>2];if(!(b<=c)){A[a+4208>>2]=c;b=c}c=A[a+4212>>2];s=D(D(D(b*D(100028.3125))+D(502.65484619140625))/D(z[w[a+16>>2]+24620>>2]));b=Wt(s);v=b;f=D(D(D(D(c*D(1.0108397006988525))+D(.02888113260269165))*s)/b);r=(l(2,(p(f),j(2))&-2147483648|1056964608),q());h=(p(f),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{i=(p(c),j(2));d=i&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=D(-1);if((i|0)<0){break b}if(!(c>D(88.7216796875))){break g}b=D(c*D(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((i|0)>=0){d=1;e=D(905800061445916e-20);b=D(c+D(-.6931381225585938));break f}d=-1;e=D(-905800061445916e-20);b=D(c+D(.6931381225585938));break f}b=D(D(c*D(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(D(E(b))<D(2147483648)){d=~~b;break h}d=-2147483648}b=D(d|0);e=D(b*D(905800061445916e-20));b=D(c+D(b*D(-.6931381225585938)))}c=D(b-e);e=D(D(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=D(c*D(.5));k=D(c*b);m=D(D(k*D(D(k*D(.0015807170420885086))+D(-.03333321213722229)))+D(1));b=D(D(3)-D(m*b));m=D(k*D(D(m-b)/D(D(6)-D(c*b))));b=D(c-D(D(c*m)-k));if(!d){break b}e=D(D(D(c*D(m-e))-e)-k);i:{switch(d+1|0){case 0:b=D(D(D(c-e)*D(.5))+D(-.5));break b;case 2:b=D(D(e-D(c+D(.5)))*D(-2));if(c<D(-.25)){break b}b=D(c-e);b=D(D(b+b)+D(1));break b;default:break i}}i=d<<23;b=(l(2,i+1065353216|0),q());if(d>>>0>=57){c=D(D(c-e)+D(1));b=D(((d|0)==128?D(D(c+c)*D(17014118346046923e22)):D(c*b))+D(-1));break b}k=(l(2,1065353216-i|0),q());c=D((d>>>0<=22?D(D(D(1)-k)+D(c-e)):D(D(c-D(e+k))+D(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}f=D(r*D(D(b+b)-D(D(b*b)/D(b+D(1)))));break a}f=D(r*D(b+D(b/D(b+D(1)))));break a}e=D(D(r+r)*D(1661534994731145e20));b=D(c+D(-162.88958740234375));d=Sg(b)&2047;j:{k:{if(Sg(D(88))>>>0>d>>>0){break k}c=D(0);if(((p(b),j(2))|0)==-8388608){break j}c=D(b+b);if(Sg(D(O))>>>0<=d>>>0){break j}if(b>D(88.72283172607422)){c=Cm(0);break j}if(!(b<D(-103.97207641601562))){break k}c=Bm(0);break j}g=B[6425]*+b;t=B[6424];u=g+t;g=g-(u-t);g=(B[6426]*g+B[6427])*(g*g)+(B[6428]*g+1);o(+u);j(1)|0;d=j(0)|0;i=d<<15;d=((d&31)<<3)+51104|0;h=w[d>>2];d=w[d+4>>2]+i|0;l(0,h|0);l(1,(h>>>0<h>>>0?d+1|0:d)|0);c=D(g*+n())}f=D(D(e*c)*D(1661534994731145e20))}c=D(v*f);f=jd(D(D(A[a+4216>>2]*D(2.491446018218994))+D(-1.245723009109497)));e=D(c/f);b=D(e+D(1));A[a+4236>>2]=D(D(1)-e)/b;e=D(D(ai(s)*D(-2))/b);A[a+4232>>2]=e;c=D(c*f);A[a+4228>>2]=D(D(1)-c)/b;A[a+4224>>2]=e;A[a+4220>>2]=D(c+D(1))/b}function JU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=jb-240|0;jb=c;a=mg(c+112|0,a);w[114256]=0;d=Q(5,c+96|0,35803)|0;e=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){w[114256]=0;w[c+216>>2]=19469585;w[c+220>>2]=0;U(397,a|0,d|0,c+216|0);e=w[114256];w[114256]=0;if((e|0)==1){break q}if(u[d+11|0]<0){zb(w[d>>2])}if(x[a+3|0]&64){break d}w[114256]=0;d=Q(5,c+80|0,9157)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}w[114256]=0;Z(946,a|0,b|0,d|0,947)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;w[c+76>>2]=0;w[c+72>>2]=0;d=Q(5,c+56|0,12501)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}w[114256]=0;S(948,a|0,c+76|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;d=Q(5,c+40|0,12496)|0;e=w[114256];w[114256]=0;if((e|0)==1){break i}w[114256]=0;S(948,a|0,c+72|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}if(u[d+11|0]<0){zb(w[d>>2])}d=w[c+76>>2];r:{if(!d){break r}f=w[w[w[w[b+48>>2]+12>>2]+8>>2]+40>>2];e=w[c+72>>2];if(f>>>0<e>>>0|d>>>0>e>>>0|d>>>0>f>>>0){break r}w[b+20>>2]=e;w[b+16>>2]=d}w[114256]=0;w[c+32>>2]=0;w[c+24>>2]=0;w[c+28>>2]=0;d=Q(5,c+8|0,9819)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;e=Q(399,a|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}f=w[a+28>>2];w[114256]=0;T(400,c+216|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break f}f=w[c+228>>2];w[c+232>>2]=w[c+224>>2];w[c+236>>2]=f;if(e){break p}f=-1;if(!(x[a+24|0]&32)){break o}break n}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}f=w[e+8>>2]}g=w[a+28>>2];w[114256]=0;U(392,g|0,c+24|0,f|0);f=w[114256];w[114256]=0;if((f|0)==1){break f}}w[114256]=0;Z(402,a|0,e|0,d|0,c+232|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}if(u[d+11|0]<0){zb(w[d>>2])}if(w[c+24>>2]==w[c+28>>2]){break e}d=w[b+16>>2];w[114256]=0;w[c+216>>2]=16777216;U(826,c+24|0,d|0,c+216|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}w[114256]=0;X(827,c+24|0);d=w[114256];w[114256]=0;if((d|0)!=1){break e}break c}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}b=P()|0;break b}b=P()|0;if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}w[114256]=0;T(949,b|0,c+24|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[c+24>>2];if(!b){break d}w[c+28>>2]=b;zb(b)}b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}b=w[a+32>>2];if(b){w[a+36>>2]=b;zb(b)}jb=c+240|0;return}b=P()|0}d=w[c+24>>2];if(!d){break a}w[c+28>>2]=d;zb(d)}Mf(a);R(b|0);M()}function Fy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-32|0;jb=h;x=w[a+16>>2];y=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);o=w[a+128>>2];a:{if(!o){p=w[a+8>>2];q=w[a+12>>2];l=w[a>>2];m=w[a+4>>2];r=0;break a}m=w[a+4>>2];e=w[a+76>>2];l=w[a>>2];p=w[a+8>>2];q=w[a+12>>2];k=BV(p,q,d,0);f=l+k|0;b=nb+m|0;s=e>>>0<(f>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(p,q,o,o>>31);r=nb}b=w[a+44>>2];w[h+12>>2]=b;f=w[a+48>>2];w[h+16>>2]=f;e=w[a+52>>2];w[h+20>>2]=e;g=w[a+56>>2];w[h+24>>2]=g;b:{if(d){j=a+112|0;z=w[a+24>>2];A=w[a+20>>2];B=(o|0)>0;while(1){s=s-1|0;b=s;k=b?k:0;r=b?r:0;f=0;e=l;i=((((m&2147483647)<<1|e>>>31)&2147483646)<<1)+x|0;b=o;c:{if(!B){break c}while(1){d:{g=(f&2147483647)<<1|e>>>31;n=v[(g<<1|2)+i>>1];g=v[i+((g&2147483646)<<1)>>1];w[114256]=0;T(604,j|0,(g+n|0)/8<<16>>16);g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;T(605,j|0,4);g=w[114256];w[114256]=0;if((g|0)==1){break d}f=f+r|0;e=e+k|0;f=e>>>0<k>>>0?f+1|0:f;g=b>>>0>1;b=b-1|0;if(g){continue}break c}break}break b}n=w[a+120>>2];g=n+w[a+112>>2]|0;b=w[a+116>>2]+w[a+124>>2]|0;b=g>>>0<n>>>0?b+1|0:b;w[a+112>>2]=g;w[a+116>>2]=b;if(b){f=(f&2147483647)<<1|e>>>31;e=v[(f<<1|2)+i>>1];f=v[i+((f&2147483646)<<1)>>1];w[114256]=0;T(604,j|0,(e+f|0)/8<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,y|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}d=d-1|0;w[h+4>>2]=b;w[h>>2]=b;n=w[a+72>>2];b=w[a+68>>2];D=b;E=b>>31;b=w[a+64>>2];F=b;G=b>>31;b=w[a+60>>2];H=b;I=b>>31;b=0;f=1;while(1){e=(h+8|0)+(b<<3)|0;g=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;t=(b<<2)+h|0;u=w[t>>2]<<8;b=u;b=BV(H,I,b,b>>31);J=nb;K=e;e=b;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;i=BV(b,b>>31,F,G);e=e+i|0;b=nb+J|0;b=e>>>0<i>>>0?b+1|0:b;i=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);e=i+g|0;b=nb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[K+4>>2]=b-(n&u);w[t>>2]=(b|0)/256;e=f;f=0;b=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[h>>2],A);w[c+4>>2]=w[c+4>>2]+C(w[h+4>>2],z);b=m+q|0;f=l+p|0;b=f>>>0<p>>>0?b+1|0:b;l=f;m=b;c=c+8|0;if(d){continue}break}g=w[h+24>>2];e=w[h+20>>2];f=w[h+16>>2];b=w[h+12>>2]}w[a+56>>2]=g;w[a+52>>2]=e;w[a+48>>2]=f;w[a+44>>2]=b;w[a>>2]=l;w[a+4>>2]=m;jb=h+32|0;return}b=P()|0;w[a+44>>2]=w[h+12>>2];w[a+48>>2]=w[h+16>>2];w[a+52>>2]=w[h+20>>2];w[a+56>>2]=w[h+24>>2];R(b|0);M()}function hh(a,b,c,d){var e=D(0),f=0,g=0,h=D(0),i=D(0),j=0,k=0,l=0,m=D(0);f=v[b+794>>1]+(x[b+858|0]&127)|0;g=v[b+792>>1]+x[b+857|0]|0;a:{if((g|0)>=0){j=127;if(g>>>0<128){break a}}g=j}j=0;b:{if((f|0)>=0){j=127;if(f>>>0<128){break b}}f=j}if(!(x[a+1074312|0]&2)){u[b+858|0]=f;u[b+857|0]=g;w[b+792>>2]=0}k=C(d+256|0,g);j=(k|0)/256|0;l=w[a+1074316>>2]&16;c:{if(!(!l|f|(k|0)<65024)){j=-1;if((x[b+810|0]-1&255)>>>0>119){break c}d:{switch(x[b+813|0]-4|0){case 0:case 2:break c;default:break d}}if(!(x[b+872|0]&2)|(y[b+808>>1]|x[b+812|0]==11)){break c}w[b+88>>2]=w[b+88>>2]&-32769;return-1}w[b+88>>2]=w[b+88>>2]|32768;e=D(C(d+256|0,g)>>>0);g=2e4;e:{if(w[a+480180>>2]!=33554432){i=D(110);e=D(D(e/(x[a+480209|0]&128?D(10240):D(12288)))+D(.25));break e}i=D(125);e=D(e*D(9227362170349807e-20))}e=_b(D(jd(e)*i));f:{g:{if(e>=D(2147483648)){break g}g=120;if(e<=D(-2147483648)){break g}if(D(E(e))<D(2147483648)){d=~~e}else{d=-2147483648}if((d|0)<120){break g}g=2e4;if(d>>>0<20001){break f}}d=g}g=w[a+24620>>2];i=D(D(((g|0)<d<<1?g>>>1|0:d)>>>0)*D(6.2831854820251465));e=jd(D(D(0-f|0)*D(.031143076717853546)));h:{if(!(!l|x[a+480209|0]&128)){h=D(D(z[a+24620>>2])/i);i=D(D(e+D(-1))+D(h*e));e=D(h*h);break h}h=D(e+e);e=D(i/D(z[a+24620>>2]));i=D(D(h-D(G(D(e*D(D(1)-h)),D(2))))/e);e=D(D(1)/D(e*e))}h=D(D(e+i)+D(1));i=D(D(D(e+e)+i)/h);m=D(D(16777216)/h);h=D(D(-e)/h);i:{if(x[b+865|0]==1){f=2147483647;e=_b(D(D(16777216)-m));a=2147483647;j:{if(e>=D(2147483648)){break j}a=-2147483648;if(e<=D(-2147483648)){break j}a=~~e;if(D(E(e))<D(2147483648)){break j}a=-2147483648}w[b+60>>2]=a;e=_b(D(i*D(16777216)));k:{if(e>=D(2147483648)){break k}f=-2147483648;if(e<=D(-2147483648)){break k}f=D(E(e))<D(2147483648)?~~e:f}w[b+64>>2]=f;e=_b(D(h*D(16777216)));a=2147483647;l:{if(e>=D(2147483648)){break l}a=-2147483648;if(e<=D(-2147483648)){break l}a=~~e;if(D(E(e))<D(2147483648)){break l}a=-2147483648}w[b+68>>2]=a;f=-1;break i}f=2147483647;e=_b(m);a=2147483647;m:{if(e>=D(2147483648)){break m}a=-2147483648;if(e<=D(-2147483648)){break m}a=~~e;if(D(E(e))<D(2147483648)){break m}a=-2147483648}w[b+60>>2]=a;e=_b(D(i*D(16777216)));n:{if(e>=D(2147483648)){break n}f=-2147483648;if(e<=D(-2147483648)){break n}f=D(E(e))<D(2147483648)?~~e:f}w[b+64>>2]=f;e=_b(D(h*D(16777216)));d=2147483647;o:{if(e>=D(2147483648)){break o}d=-2147483648;if(e<=D(-2147483648)){break o}d=~~e;if(D(E(e))<D(2147483648)){break o}d=-2147483648}w[b+68>>2]=d;f=0;if(a){break i}w[b+60>>2]=1}w[b+72>>2]=f;if(!c){break c}w[b+44>>2]=0;w[b+48>>2]=0;w[b+52>>2]=0;w[b+56>>2]=0}return j}function mu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=jb-48|0;jb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;B[b>>3]=c;B[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;B[b>>3]=c;B[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;B[b>>3]=c;B[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;B[b>>3]=c;B[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;B[b>>3]=c;B[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;B[b>>3]=c;B[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;B[b>>3]=c;B[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;B[b>>3]=c;B[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(E(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;B[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;B[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;B[b>>3]=a}B[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;B[b>>3]=a;B[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(E(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);B[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}B[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(B[(i+16|0)+(h<<3)>>3]==0){continue}break}d=nu(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=B[i>>3];if((e|0)<0){B[b>>3]=-a;B[b+8>>3]=-B[i+8>>3];d=0-d|0;break a}B[b>>3]=a;B[b+8>>3]=B[i+8>>3]}jb=i+48|0;return d}function FD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-128|0;jb=d;b=b&4095;v[d+102>>1]=b;a:{b:{if(b>>>0>=81){b=((b|0)==4095?c:b-80|0)+734016|0;f=BV(b,b>>31,1e4,0)+14780|0;c=nb;c=CV(f,f>>>0<14780?c+1|0:c,3652425,0);f=(((b+((c|0)/-4|0)|0)+C(c,-365)|0)+((c|0)/100|0)|0)+((c|0)/-400|0)|0;if((f|0)<0){c=c-1|0;f=(((b+((c|0)/-4|0)|0)+C(c,-365)|0)+((c|0)/100|0)|0)+((c|0)/-400|0)|0}b=Hb(d+72|0,10565);g=w[b>>2];w[d+92>>2]=w[b+4>>2];e=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+95|0]=e;u[d+96|0]=e>>>8;u[d+97|0]=e>>>16;u[d+98|0]=e>>>24;w[b>>2]=0;w[b+4>>2]=0;e=x[b+11|0];w[b+8>>2]=0;w[114256]=0;w[d+88>>2]=g;u[d+99|0]=e;h=c;c=(C(f,100)+52|0)/3060|0;e=c+2|0;g=(e|0)/12|0;w[d+52>>2]=h+g;u[d+120|0]=44;w[d+112>>2]=-1;w[d+116>>2]=0;w[d+104>>2]=1025;w[d+108>>2]=4;U(101,d+56|0,d+52|0,d+104|0);h=w[114256];w[114256]=0;c:{d:{e:{f:{g:{h:{if((h|0)!=1){w[114256]=0;w[d+36>>2]=(e-C(g,12)|0)+1;u[d+120|0]=44;w[d+112>>2]=-1;w[d+116>>2]=0;w[d+104>>2]=1025;w[d+108>>2]=2;U(101,d+40|0,d+36|0,d+104|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}w[114256]=0;w[d+20>>2]=(((C(c,306)+5|0)/-10|0)+f|0)+1;u[d+120|0]=44;w[d+112>>2]=-1;w[d+116>>2]=0;w[d+104>>2]=1025;w[d+108>>2]=2;U(101,d+24|0,d+20|0,d+104|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}w[114256]=0;ga(344,a|0,d+88|0,d+56|0,d+40|0,d+24|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}if(u[d+35|0]<0){zb(w[d+24>>2])}if(u[d+51|0]<0){zb(w[d+40>>2])}if(u[d+67|0]<0){zb(w[d+56>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[b+11|0]>=0){break a}zb(w[b>>2]);break a}c=P()|0;break c}c=P()|0;break d}c=P()|0;break e}c=P()|0;if(u[d+35|0]>=0){break e}zb(w[d+24>>2])}if(u[d+51|0]>=0){break d}zb(w[d+40>>2])}if(u[d+67|0]>=0){break c}zb(w[d+56>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}b=Hb(d+8|0,11381);f=w[b>>2];w[d+92>>2]=w[b+4>>2];c=x[b+7|0]|x[b+8|0]<<8|(x[b+9|0]<<16|x[b+10|0]<<24);u[d+95|0]=c;u[d+96|0]=c>>>8;u[d+97|0]=c>>>16;u[d+98|0]=c>>>24;w[b>>2]=0;w[b+4>>2]=0;c=x[b+11|0];w[b+8>>2]=0;w[114256]=0;u[d+99|0]=c;w[d+88>>2]=f;u[d+120|0]=44;w[d+112>>2]=-1;w[d+116>>2]=0;w[d+104>>2]=1042;w[d+108>>2]=2;U(345,d+56|0,d+102|0,d+104|0);c=w[114256];w[114256]=0;i:{j:{if((c|0)!=1){w[114256]=0;U(124,a|0,d+88|0,d+56|0);a=w[114256];w[114256]=0;if((a|0)==1){break j}if(u[d+67|0]<0){zb(w[d+56>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[b+11|0]>=0){break a}zb(w[b>>2]);break a}c=P()|0;break i}c=P()|0;if(u[d+67|0]>=0){break i}zb(w[d+56>>2])}if(u[d+99|0]<0){zb(w[d+88>>2])}if(u[b+11|0]>=0){break b}zb(w[b>>2])}R(c|0);M()}jb=d+128|0}function Gy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-32|0;jb=h;x=w[a+16>>2];y=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);o=w[a+128>>2];a:{if(!o){p=w[a+8>>2];q=w[a+12>>2];l=w[a>>2];m=w[a+4>>2];r=0;break a}m=w[a+4>>2];e=w[a+76>>2];l=w[a>>2];p=w[a+8>>2];q=w[a+12>>2];k=BV(p,q,d,0);f=l+k|0;b=nb+m|0;s=e>>>0<(f>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(p,q,o,o>>31);r=nb}b=w[a+44>>2];w[h+12>>2]=b;f=w[a+48>>2];w[h+16>>2]=f;e=w[a+52>>2];w[h+20>>2]=e;g=w[a+56>>2];w[h+24>>2]=g;b:{if(d){j=a+112|0;z=w[a+24>>2];A=w[a+20>>2];B=(o|0)>0;while(1){s=s-1|0;b=s;k=b?k:0;r=b?r:0;f=0;e=l;i=(((m&2147483647)<<1|e>>>31)&-2)+x|0;b=o;c:{if(!B){break c}while(1){d:{g=(f&2147483647)<<1|e>>>31;n=u[(g|1)+i|0];g=u[i+(g&-2)|0];w[114256]=0;T(604,j|0,g+n<<5);g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;T(605,j|0,4);g=w[114256];w[114256]=0;if((g|0)==1){break d}f=f+r|0;e=e+k|0;f=e>>>0<k>>>0?f+1|0:f;g=b>>>0>1;b=b-1|0;if(g){continue}break c}break}break b}n=w[a+120>>2];g=n+w[a+112>>2]|0;b=w[a+116>>2]+w[a+124>>2]|0;b=g>>>0<n>>>0?b+1|0:b;w[a+112>>2]=g;w[a+116>>2]=b;if(b){f=(f&2147483647)<<1|e>>>31;e=u[(f|1)+i|0];f=u[i+(f&-2)|0];w[114256]=0;T(604,j|0,e+f<<5);f=w[114256];w[114256]=0;if((f|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,y|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}d=d-1|0;w[h+4>>2]=b;w[h>>2]=b;n=w[a+72>>2];b=w[a+68>>2];D=b;E=b>>31;b=w[a+64>>2];F=b;G=b>>31;b=w[a+60>>2];H=b;I=b>>31;b=0;f=1;while(1){e=(h+8|0)+(b<<3)|0;g=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;t=(b<<2)+h|0;v=w[t>>2]<<8;b=v;b=BV(H,I,b,b>>31);J=nb;K=e;e=b;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;i=BV(b,b>>31,F,G);e=e+i|0;b=nb+J|0;b=e>>>0<i>>>0?b+1|0:b;i=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);e=i+g|0;b=nb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[K+4>>2]=b-(n&v);w[t>>2]=(b|0)/256;e=f;f=0;b=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[h>>2],A);w[c+4>>2]=w[c+4>>2]+C(w[h+4>>2],z);b=m+q|0;f=l+p|0;b=f>>>0<p>>>0?b+1|0:b;l=f;m=b;c=c+8|0;if(d){continue}break}g=w[h+24>>2];e=w[h+20>>2];f=w[h+16>>2];b=w[h+12>>2]}w[a+56>>2]=g;w[a+52>>2]=e;w[a+48>>2]=f;w[a+44>>2]=b;w[a>>2]=l;w[a+4>>2]=m;jb=h+32|0;return}b=P()|0;w[a+44>>2]=w[h+12>>2];w[a+48>>2]=w[h+16>>2];w[a+52>>2]=w[h+20>>2];w[a+56>>2]=w[h+24>>2];R(b|0);M()}function pn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=C(b,896)+a|0;b:{if(x[e+1075074|0]&2){e=w[a+480180>>2];c:{d:{e:{f:{f=w[a+480208>>2];if(f&4096){if(!(e&16777248)){break f}if((e|0)!=64){break e}break a}if((e|0)==64){break a}g=a+480180|0;break d}if((e|0)==64){break a}g=a+480180|0;break c}g=a+480180|0;if(f&4){break c}}n=1;if(!(x[a+1074314|0]&32)){break c}e=C(b,896)+a|0;f=e+1075823|0;u[f|0]=x[f|0]+(x[e+1075827|0]<<2)}f=C(b,896)+a|0;h=f+1075826|0;k=f+1075823|0;e=on(a,x[h|0],x[k|0]);m=f+1075640|0;f=w[m>>2];g:{if(!(!f|!w[f+44>>2])){c=C(b,896)+a|0;A[d>>2]=D(D(C(x[c+1075828|0],e)|0)*D(6510417279059766e-21))+A[d>>2];c=c+1075856|0;d=x[c|0];u[c|0]=d&231|16;if(w[a+1074416>>2]!=(w[a+1074392>>2]+1|0)){break g}u[c|0]=d|24;break g}f=w[a+480208>>2];if((f&2101248)==2101248){break b}g=w[g>>2];if(f&4096?g&67633152:0){break b}e=g&5?(x[h|0]&3)==1?0-e|0:e:e;h=w[a+1074312>>2];h:{if(h&2097152){d=f&4;e=d?e:0-e|0;d=d?5:6;break h}d=5;i:{if(f&131072){break i}d=8;if((g|0)==1024){break i}d=7;if(g&524304){break i}d=g&16777248?(f&4)>>>2|0?6:7:6}if(!(u[a+1074322|0]&1)){break h}d=x[(C(b,896)+a|0)+1075797|0]==26?d+2|0:d}e=(C(x[(C(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;l=0-e|0;j:{if(!((g|0)!=4?f&16:0)){g=w[c>>2];break j}f=h&128;g=w[c>>2];h=g>>31;if((e|0)<0){d=w[(l&-4)+(f?30256:31280)>>2];e=CV(BV(d,d>>31,g,h),nb,65536,0);i=e;d=nb;e=(d|0)>=0&e>>>0>=2147483647|(d|0)>0;i=e?2147483647:i;d=e?0:d;e=((d|0)<0&i>>>0<=2147483648|(d|0)<-1?-2147483648:i)-g|0;d=l&3;if(!d){break j}d=w[(d<<2)+(f?30128:30192)>>2];f=CV(BV(d,d>>31,g,h),nb,65536,0);i=f;d=nb;f=(d|0)>=0&f>>>0>=2147483647|(d|0)>0;h=f?2147483647:i;d=f?0:d;e=(e-g|0)+((d|0)<0&h>>>0<=2147483648|(d|0)<-1?-2147483648:h)|0;break j}d=w[(e&-4)+(f?31280:30256)>>2];i=CV(BV(d,d>>31,g,h),nb,65536,0);j=i;d=nb;i=(d|0)>=0&i>>>0>=2147483647|(d|0)>0;j=i?2147483647:j;d=i?0:d;d=((d|0)<0&j>>>0<=2147483648|(d|0)<-1?-2147483648:j)-g|0;e=e&3;if(!e){e=d;break j}e=w[(e<<2)+(f?30192:30128)>>2];f=CV(BV(e,e>>31,g,h),nb,65536,0);i=f;e=nb;f=(e|0)>=0&f>>>0>=2147483647|(e|0)>0;h=f?2147483647:i;e=f?0:e;e=(d-g|0)+((e|0)<0&h>>>0<=2147483648|(e|0)<-1?-2147483648:h)|0}w[c>>2]=e+g;c=lk(a,b);if(!c){break g}e=l<<16>>16;d=w[m>>2];if(d){d=x[d+33|0]}else{d=2}ob[w[w[c>>2]+84>>2]](c,e,d<<24>>24,b)}if(!n|x[a+1074314|0]&32){break b}u[k|0]=x[k|0]+x[(C(b,896)+a|0)+1075827|0];return}if(!(x[e+1075654|0]&2)){break b}a=lk(a,b);if(!a){break b}ob[w[w[a>>2]+84>>2]](a,0,0,b)}return}a=C(b,896)+a|0;b=a+1075823|0;d=x[b|0];if(d&1){w[c>>2]=w[c>>2]+C(x[a+1075828|0],167)}u[b|0]=d+1}function yN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;Ci(b,c,d,A[a+24>>2]);w[e+44>>2]=b;w[e+40>>2]=c;w[e+36>>2]=d;b=w[a+8>>2];w[e+28>>2]=e+36;w[e+24>>2]=e+40;c=w[e+28>>2];w[e+8>>2]=w[e+24>>2];w[e+12>>2]=c;w[e+16>>2]=a;w[e+20>>2]=e+44;c=w[e+20>>2];w[e>>2]=w[e+16>>2];w[e+4>>2]=c;a:{b:{switch(w[b+40>>2]){case 0:i=w[w[e+12>>2]>>2];if(!i){break a}b=w[e>>2];d=w[b+16>>2];j=w[b+12>>2]+(C(d,w[b+4>>2])<<2)|0;c=w[w[e+8>>2]>>2];k=w[w[e+4>>2]>>2];while(1){if(c){l=C(d,f);m=C(c,f);b=0;while(1){A[j+(b+l<<2)>>2]=B[k+(b+m<<3)>>3];b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break};break a;case 2:i=w[w[e+12>>2]>>2];if(!i){break a}b=w[e>>2];d=w[b+16>>2];j=w[b+12>>2]+(C(d,w[b+4>>2])<<2)|0;c=w[w[e+8>>2]>>2];k=w[w[e+4>>2]>>2];while(1){if(c){l=C(d,f);m=C(c,f);b=0;while(1){n=j+(b+l<<2)|0;h=Tb(B[k+(b+m<<3)>>3]*134217728);g=15.99999999254942;c:{if(h>=2147483647){break c}g=-16;if(h<=-2147483648){break c}g=K(h)*7.450580596923828e-9}A[n>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break};break a;case 3:i=w[w[e+12>>2]>>2];if(!i){break a}b=w[e>>2];d=w[b+16>>2];j=w[b+12>>2]+(C(d,w[b+4>>2])<<2)|0;c=w[w[e+8>>2]>>2];k=w[w[e+4>>2]>>2];while(1){if(c){l=C(d,f);m=C(c,f);b=0;while(1){n=j+(b+l<<2)|0;h=Tb(B[k+(b+m<<3)>>3]*134217728);g=15.99999999254942;d:{if(h>=2147483647){break d}g=-16;if(h<=-2147483648){break d}g=K(h)*7.450580596923828e-9}A[n>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break};break a;case 1:i=w[w[e+12>>2]>>2];if(!i){break a}b=w[e>>2];d=w[b+16>>2];j=w[b+12>>2]+(C(d,w[b+4>>2])<<2)|0;c=w[w[e+8>>2]>>2];k=w[w[e+4>>2]>>2];while(1){if(c){l=C(d,f);m=C(c,f);b=0;while(1){n=j+(b+l<<2)|0;h=Tb(B[k+(b+m<<3)>>3]*134217728);g=15.99999999254942;e:{if(h>=2147483647){break e}g=-16;if(h<=-2147483648){break e}g=K(h)*7.450580596923828e-9}A[n>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break};break a;default:break b}}i=w[w[e+12>>2]>>2];if(!i){break a}b=w[e>>2];d=w[b+16>>2];j=w[b+12>>2]+(C(d,w[b+4>>2])<<2)|0;c=w[w[e+8>>2]>>2];k=w[w[e+4>>2]>>2];while(1){if(c){l=C(d,f);m=C(c,f);b=0;while(1){n=j+(b+l<<2)|0;h=Tb(B[k+(b+m<<3)>>3]*134217728);g=15.99999999254942;f:{if(h>=2147483647){break f}g=-16;if(h<=-2147483648){break f}g=K(h)*7.450580596923828e-9}A[n>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break}}w[a+4>>2]=w[a+4>>2]+w[e+36>>2];jb=e+48|0}function mi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-192|0;jb=d;g=Od(d+40|0);f=w[w[g>>2]-12>>2];w[114256]=0;e=ea(79)|0;h=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}w[114256]=0;f=f+g|0;T(10,d+32|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break f}w[114256]=0;U(80,d+184|0,f|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break b}Ab(d+184|0);f=w[f+24>>2];if(f){h=w[w[f>>2]+8>>2];w[114256]=0;T(h|0,f|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break b}f=f+4|0;h=Ic(d+176|0,f);Wc(f,e);Ab(h)}Ab(d+32|0);f=2;e=w[c>>2];h=w[c+8>>2];e=w[c+4>>2]?e&24576?e:(h|0)!=-1?e&-12289|8192:e:e;g:{if(!(e&1)){f=8;if(!(e&2)){break g}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]&-75|f}h:{if(e&4096){break h}f=4;if(!(e&8192)){f=256;if(!(e&16384)){break h}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]|f}i:{if(e&16){e=w[w[g>>2]-12>>2]+g|0;w[e+4>>2]=w[e+4>>2]&-16385;break i}if(!(e&32)){break i}e=w[w[g>>2]-12>>2]+g|0;w[e+4>>2]=w[e+4>>2]|16384}if((h|0)!=-1){w[(w[w[g>>2]-12>>2]+g|0)+8>>2]=h}b=w[b>>2];w[114256]=0;Q(85,g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;k=g+4|0;T(82,d|0,k|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}j:{if(!(x[c+1|0]&4)){break j}f=w[c+4>>2];h=w[d>>2];b=x[d+11|0];i=b<<24>>24;j=(i|0)<0;e=j?h:d;j=j?w[d+4>>2]:b;k:{if(!j){b=e;break k}b=e;l:{switch(x[e|0]-43|0){case 0:f=f+1|0;b=((i|0)<0?h:d)+1|0;break k;case 2:break l;default:break k}}f=f+1|0;b=((i|0)<0?h:d)+1|0}if(f>>>0<=j>>>0){break j}w[114256]=0;Z(93,d|0,b-e|0,f-j|0,48)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}}w[d+24>>2]=w[d+8>>2];w[d+8>>2]=0;b=w[d+4>>2];w[d+16>>2]=w[d>>2];w[d+20>>2]=b;w[d>>2]=0;w[d+4>>2]=0;e=w[c+12>>2];m:{if(!e){break m}b=x[d+27|0];b=b<<24>>24<0?w[d+20>>2]:b;if(!b){break m}f=b-1|0;h=u[c+16|0];c=0;while(1){n:{if(!c|(c>>>0)%(e>>>0)){break n}o:{if((c|0)!=(f|0)){break o}switch(x[(u[d+27|0]<0?w[d+16>>2]:d+16|0)|0]-43|0){case 0:case 2:break n;default:break o}}w[114256]=0;Z(93,d+16|0,b-c|0,1,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}}c=c+1|0;if((b|0)!=(c|0)){continue}break}}b=w[d+20>>2];w[a>>2]=w[d+16>>2];w[a+4>>2]=b;w[a+8>>2]=w[d+24>>2];w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;if(u[d+11|0]<0){zb(w[d>>2])}a=w[15e3];w[g>>2]=a;w[w[a-12>>2]+g>>2]=w[15003];w[g+4>>2]=59272;if(u[g+47|0]<0){zb(w[g+36>>2])}wc(k);pc(g+56|0);jb=d+192|0;return}c=P()|0;break a}c=P()|0;break c}c=P()|0;if(u[d+27|0]>=0){break c}zb(w[d+16>>2])}if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}c=P()|0;Ab(d+32|0)}nd(g);R(c|0);M()}function _v(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=w[b+4>>2];a:{if(!c){c=b;while(1){e=w[c+8>>2];d=w[e>>2]!=(c|0);c=e;if(d){continue}break}break a}while(1){e=c;c=w[c>>2];if(c){continue}break}}if(w[a>>2]==(b|0)){w[a>>2]=e}w[a+8>>2]=w[a+8>>2]-1;c=w[a+4>>2];g=b;b:{c:{d=w[b>>2];if(d){a=w[g+4>>2];if(!a){break c}while(1){b=a;a=w[a>>2];if(a){continue}break}}d=w[b+4>>2];if(d){break c}d=0;e=1;break b}w[d+8>>2]=w[b+8>>2];e=0}f=w[b+8>>2];a=w[f>>2];d:{if((b|0)==(a|0)){w[f>>2]=d;if((b|0)==(c|0)){a=0;c=d;break d}a=w[f+4>>2];break d}w[f+4>>2]=d}e:{f:{g:{h=!x[b+12|0];if((b|0)!=(g|0)){f=w[g+8>>2];w[b+8>>2]=f;w[f+(((g|0)!=w[w[g+8>>2]>>2])<<2)>>2]=b;f=w[g>>2];w[b>>2]=f;w[f+8>>2]=b;f=w[g+4>>2];w[b+4>>2]=f;if(f){w[f+8>>2]=b}u[b+12|0]=x[g+12|0];c=(c|0)==(g|0)?b:c}if(!(h|!c)){if(e){while(1){b=x[a+12|0];h:{d=w[a+8>>2];if(w[d>>2]!=(a|0)){if(!b){u[a+12|0]=1;u[d+12|0]=0;e=w[d+4>>2];b=w[e>>2];w[d+4>>2]=b;if(b){w[b+8>>2]=d}w[e+8>>2]=w[d+8>>2];b=w[d+8>>2];w[(((d|0)!=w[b>>2])<<2)+b>>2]=e;w[e>>2]=d;w[d+8>>2]=e;b=a;a=w[a>>2];c=(a|0)==(c|0)?b:c;a=w[a+4>>2]}i:{j:{b=w[a>>2];k:{if(!(x[b+12|0]?0:b)){e=w[a+4>>2];if(x[e+12|0]?0:e){break k}u[a+12|0]=0;a=w[a+8>>2];l:{if((c|0)==(a|0)){a=c;break l}if(x[a+12|0]){break h}}u[a+12|0]=1;break e}e=w[a+4>>2];if(!e){break j}}if(x[e+12|0]){break j}b=a;break i}u[b+12|0]=1;u[a+12|0]=0;c=w[b+4>>2];w[a>>2]=c;if(c){w[c+8>>2]=a}w[b+8>>2]=w[a+8>>2];c=w[a+8>>2];w[((w[c>>2]!=(a|0))<<2)+c>>2]=b;w[b+4>>2]=a;w[a+8>>2]=b;e=a}c=w[b+8>>2];u[b+12|0]=x[c+12|0];u[c+12|0]=1;u[e+12|0]=1;b=w[c+4>>2];a=w[b>>2];w[c+4>>2]=a;if(a){w[a+8>>2]=c}w[b+8>>2]=w[c+8>>2];a=w[c+8>>2];w[(((c|0)!=w[a>>2])<<2)+a>>2]=b;w[b>>2]=c;w[c+8>>2]=b;break e}if(!b){u[a+12|0]=1;u[d+12|0]=0;b=w[a+4>>2];w[d>>2]=b;if(b){w[b+8>>2]=d}w[a+8>>2]=w[d+8>>2];b=w[d+8>>2];w[(((d|0)!=w[b>>2])<<2)+b>>2]=a;w[a+4>>2]=d;w[d+8>>2]=a;c=(c|0)==(d|0)?a:c;a=w[d>>2]}e=w[a>>2];if(x[e+12|0]?0:e){break g}b=w[a+4>>2];if(!(x[b+12|0]?0:b)){u[a+12|0]=0;a=w[a+8>>2];if((a|0)!=(c|0)?x[a+12|0]:0){break h}u[a+12|0]=1;break e}if(e){if(!x[e+12|0]){break g}b=w[a+4>>2]}u[b+12|0]=1;u[a+12|0]=0;c=w[b>>2];w[a+4>>2]=c;if(c){w[c+8>>2]=a}w[b+8>>2]=w[a+8>>2];c=w[a+8>>2];w[((w[c>>2]!=(a|0))<<2)+c>>2]=b;w[b>>2]=a;w[a+8>>2]=b;e=a;break f}b=a;a=w[a+8>>2];a=w[(((b|0)==w[a>>2])<<2)+a>>2];continue}}u[d+12|0]=1}break e}b=a}c=w[b+8>>2];u[b+12|0]=x[c+12|0];u[c+12|0]=1;u[e+12|0]=1;b=w[c>>2];a=w[b+4>>2];w[c>>2]=a;if(a){w[a+8>>2]=c}w[b+8>>2]=w[c+8>>2];a=w[c+8>>2];w[(((c|0)!=w[a>>2])<<2)+a>>2]=b;w[b+4>>2]=c;w[c+8>>2]=b}}function CN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-48|0;jb=e;Ci(b,c,d,A[a+28>>2]);w[e+44>>2]=b;w[e+40>>2]=c;w[e+36>>2]=d;b=w[a+8>>2];w[e+28>>2]=e+36;w[e+24>>2]=e+40;c=w[e+28>>2];w[e+8>>2]=w[e+24>>2];w[e+12>>2]=c;w[e+16>>2]=a;w[e+20>>2]=e+44;c=w[e+20>>2];w[e>>2]=w[e+16>>2];w[e+4>>2]=c;a:{b:{switch(w[b+40>>2]){case 0:d=w[w[e+12>>2]>>2];if(!d){break a}b=w[e>>2];i=w[b+4>>2]+w[b+24>>2]|0;c=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(c){l=f+i|0;m=C(c,f);b=0;while(1){A[w[k+(b<<2)>>2]+(l<<2)>>2]=B[j+(b+m<<3)>>3];b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break};break a;case 2:d=w[w[e+12>>2]>>2];if(!d){break a}b=w[e>>2];i=w[b+4>>2]+w[b+24>>2]|0;c=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(c){l=f+i|0;m=C(c,f);b=0;while(1){g=Tb(B[j+(b+m<<3)>>3]*134217728);h=15.99999999254942;c:{if(g>=2147483647){break c}h=-16;if(g<=-2147483648){break c}h=K(g)*7.450580596923828e-9}g=h;A[w[k+(b<<2)>>2]+(l<<2)>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break};break a;case 3:d=w[w[e+12>>2]>>2];if(!d){break a}b=w[e>>2];i=w[b+4>>2]+w[b+24>>2]|0;c=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(c){l=f+i|0;m=C(c,f);b=0;while(1){g=Tb(B[j+(b+m<<3)>>3]*134217728);h=15.99999999254942;d:{if(g>=2147483647){break d}h=-16;if(g<=-2147483648){break d}h=K(g)*7.450580596923828e-9}g=h;A[w[k+(b<<2)>>2]+(l<<2)>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break};break a;case 1:d=w[w[e+12>>2]>>2];if(!d){break a}b=w[e>>2];i=w[b+4>>2]+w[b+24>>2]|0;c=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(c){l=f+i|0;m=C(c,f);b=0;while(1){g=Tb(B[j+(b+m<<3)>>3]*134217728);h=15.99999999254942;e:{if(g>=2147483647){break e}h=-16;if(g<=-2147483648){break e}h=K(g)*7.450580596923828e-9}g=h;A[w[k+(b<<2)>>2]+(l<<2)>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break};break a;default:break b}}d=w[w[e+12>>2]>>2];if(!d){break a}b=w[e>>2];i=w[b+4>>2]+w[b+24>>2]|0;c=w[w[e+8>>2]>>2];j=w[w[e+4>>2]>>2];k=w[b+12>>2];while(1){if(c){l=f+i|0;m=C(c,f);b=0;while(1){g=Tb(B[j+(b+m<<3)>>3]*134217728);h=15.99999999254942;f:{if(g>=2147483647){break f}h=-16;if(g<=-2147483648){break f}h=K(g)*7.450580596923828e-9}g=h;A[w[k+(b<<2)>>2]+(l<<2)>>2]=g;b=b+1|0;if((c|0)!=(b|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break}}w[a+4>>2]=w[a+4>>2]+w[e+36>>2];jb=e+48|0}function un(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-192|0;jb=d;g=Od(d+40|0);f=w[w[g>>2]-12>>2];w[114256]=0;e=ea(79)|0;h=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}w[114256]=0;f=f+g|0;T(10,d+32|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break f}w[114256]=0;U(80,d+184|0,f|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break b}Ab(d+184|0);f=w[f+24>>2];if(f){h=w[w[f>>2]+8>>2];w[114256]=0;T(h|0,f|0,e|0);h=w[114256];w[114256]=0;if((h|0)==1){break b}f=f+4|0;h=Ic(d+176|0,f);Wc(f,e);Ab(h)}Ab(d+32|0);f=2;e=w[c>>2];h=w[c+8>>2];e=w[c+4>>2]?e&24576?e:(h|0)!=-1?e&-12289|8192:e:e;g:{if(!(e&1)){f=8;if(!(e&2)){break g}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]&-75|f}h:{if(e&4096){break h}f=4;if(!(e&8192)){f=256;if(!(e&16384)){break h}}i=w[w[g>>2]-12>>2]+g|0;w[i+4>>2]=w[i+4>>2]|f}i:{if(e&16){e=w[w[g>>2]-12>>2]+g|0;w[e+4>>2]=w[e+4>>2]&-16385;break i}if(!(e&32)){break i}e=w[w[g>>2]-12>>2]+g|0;w[e+4>>2]=w[e+4>>2]|16384}if((h|0)!=-1){w[(w[w[g>>2]-12>>2]+g|0)+8>>2]=h}b=x[b|0];w[114256]=0;Q(85,g|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;k=g+4|0;T(82,d|0,k|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}j:{if(!(x[c+1|0]&4)){break j}f=w[c+4>>2];h=w[d>>2];b=x[d+11|0];i=b<<24>>24;j=(i|0)<0;e=j?h:d;j=j?w[d+4>>2]:b;k:{if(!j){b=e;break k}b=e;l:{switch(x[e|0]-43|0){case 0:f=f+1|0;b=((i|0)<0?h:d)+1|0;break k;case 2:break l;default:break k}}f=f+1|0;b=((i|0)<0?h:d)+1|0}if(f>>>0<=j>>>0){break j}w[114256]=0;Z(93,d|0,b-e|0,f-j|0,48)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}}w[d+24>>2]=w[d+8>>2];w[d+8>>2]=0;b=w[d+4>>2];w[d+16>>2]=w[d>>2];w[d+20>>2]=b;w[d>>2]=0;w[d+4>>2]=0;e=w[c+12>>2];m:{if(!e){break m}b=x[d+27|0];b=b<<24>>24<0?w[d+20>>2]:b;if(!b){break m}f=b-1|0;h=u[c+16|0];c=0;while(1){n:{if(!c|(c>>>0)%(e>>>0)){break n}o:{if((c|0)!=(f|0)){break o}switch(x[(u[d+27|0]<0?w[d+16>>2]:d+16|0)|0]-43|0){case 0:case 2:break n;default:break o}}w[114256]=0;Z(93,d+16|0,b-c|0,1,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}}c=c+1|0;if((b|0)!=(c|0)){continue}break}}b=w[d+20>>2];w[a>>2]=w[d+16>>2];w[a+4>>2]=b;w[a+8>>2]=w[d+24>>2];w[d+24>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;if(u[d+11|0]<0){zb(w[d>>2])}a=w[15e3];w[g>>2]=a;w[w[a-12>>2]+g>>2]=w[15003];w[g+4>>2]=59272;if(u[g+47|0]<0){zb(w[g+36>>2])}wc(k);pc(g+56|0);jb=d+192|0;return}c=P()|0;break a}c=P()|0;break c}c=P()|0;if(u[d+27|0]>=0){break c}zb(w[d+16>>2])}if(u[d+11|0]>=0){break a}zb(w[d>>2]);break a}c=P()|0;Ab(d+32|0)}nd(g);R(c|0);M()}function DN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0;e=jb+-64|0;jb=e;o=w[a+4>>2];w[e+60>>2]=b;w[e+56>>2]=c;w[e+52>>2]=d;b=w[a+8>>2];w[e+44>>2]=e+52;w[e+40>>2]=e+56;f=w[e+44>>2];w[e+24>>2]=w[e+40>>2];w[e+28>>2]=f;w[e+32>>2]=a;w[e+36>>2]=e+60;f=w[e+36>>2];w[e+16>>2]=w[e+32>>2];w[e+20>>2]=f;a:{b:{switch(w[b+40>>2]){case 0:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+4>>2]+w[b+24>>2]|0;g=w[w[e+24>>2]>>2];j=w[w[e+20>>2]>>2];k=w[b+12>>2];b=0;while(1){if(g){l=b+i|0;m=C(b,g);f=0;while(1){A[w[k+(f<<2)>>2]+(l<<2)>>2]=D(w[j+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 2:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+4>>2]+w[b+24>>2]|0;g=w[w[e+24>>2]>>2];j=w[w[e+20>>2]>>2];k=w[b+12>>2];b=0;while(1){if(g){l=b+i|0;m=C(b,g);f=0;while(1){A[w[k+(f<<2)>>2]+(l<<2)>>2]=D(w[j+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 3:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+4>>2]+w[b+24>>2]|0;g=w[w[e+24>>2]>>2];j=w[w[e+20>>2]>>2];k=w[b+12>>2];b=0;while(1){if(g){l=b+i|0;m=C(b,g);f=0;while(1){A[w[k+(f<<2)>>2]+(l<<2)>>2]=D(w[j+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 1:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+4>>2]+w[b+24>>2]|0;g=w[w[e+24>>2]>>2];j=w[w[e+20>>2]>>2];k=w[b+12>>2];b=0;while(1){if(g){l=b+i|0;m=C(b,g);f=0;while(1){A[w[k+(f<<2)>>2]+(l<<2)>>2]=D(w[j+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;default:break b}}h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+4>>2]+w[b+24>>2]|0;g=w[w[e+24>>2]>>2];j=w[w[e+20>>2]>>2];k=w[b+12>>2];b=0;while(1){if(g){l=b+i|0;m=C(b,g);f=0;while(1){A[w[k+(f<<2)>>2]+(l<<2)>>2]=D(w[j+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break}}w[a+4>>2]=w[a+4>>2]+w[e+52>>2];n=A[a+28>>2];b=w[a+24>>2];w[e+8>>2]=w[a+20>>2];w[e+12>>2]=b;b=w[a+16>>2];w[e>>2]=w[a+12>>2];w[e+4>>2]=b;a=0;if(!(!d|n==D(1))){f=w[e+12>>2];g=w[e>>2];while(1){if(c){h=f+(a+o|0)|0;b=0;while(1){i=w[g+(b<<2)>>2]+(h<<2)|0;A[i>>2]=A[i>>2]*n;b=b+1|0;if((c|0)!=(b|0)){continue}break}}a=a+1|0;if((d|0)!=(a|0)){continue}break}}jb=e- -64|0}function tc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+480180>>2]=b;b=77868;a:{b:{c:{d:{e:{f:{g:{h:{e=$g(a);switch(e-1|0){case 2:break c;case 0:break e;case 3:break f;case 1:break g;default:break h}}if((e|0)==32){break d}if((e|0)!=16777216){break c}c=389766;d=-684218752;e=840;break a}b=77876;f=17162240;c=33587200;d=1281;e=1025;break a}b=77880;f=658513919;c=-524032;d=132865;e=4;break a}f=16777216;break b}b=77884;f=25165824;c=393215;d=-127;e=464;break a}d=1409}b=77872;e=0}w[a+1074312>>2]=d;w[a+1074324>>2]=e;w[a+1074320>>2]=f;w[a+1074316>>2]=c;w[a+8>>2]=w[b>>2];c=y[a+480192>>1];if(c){d=1;while(1){e=(((d&65535)<<2)+a|0)+900380|0;b=w[e>>2];if(b){c=w[b+88>>2];if(c){w[b+92>>2]=c;zb(c)}c=w[b+68>>2];if(c){w[b+72>>2]=c;zb(c)}c=w[b+48>>2];if(c){w[b+52>>2]=c;zb(c)}zb(b);c=y[a+480192>>1]}w[e>>2]=0;d=d+1|0;if((d&65535)>>>0<=(c&65535)>>>0){continue}break}}w[a+480184>>2]=0;w[a+480188>>2]=0;w[a+480236>>2]=65536;w[a+480228>>2]=48;w[a+480232>>2]=48;u[a+480268|0]=5;w[a+480260>>2]=16;w[a+480264>>2]=32767;w[a+480204>>2]=125e4;w[a+480208>>2]=0;w[a+480196>>2]=6;w[a+480200>>2]=256;w[a+1074304>>2]=0;w[a+1074308>>2]=0;v[a+480192>>1]=0;ik(a,4);b=jb+-64|0;jb=b;c=a+484344|0;d=w[c+4>>2];e=w[c>>2];if((d|0)!=(e|0)){while(1){d=d-52|0;Cf(d);if((d|0)!=(e|0)){continue}break}d=w[c>>2]}w[c+4>>2]=e;f=b+8|0;Cb(f,0,48);w[114256]=0;w[b+56>>2]=c;U(951,c|0,(e-d|0)/52|0,f|0);d=w[114256];w[114256]=0;i:{if((d|0)!=1){if(u[b+55|0]<0){zb(w[b+44>>2])}d=w[b+32>>2];if(d){w[b+36>>2]=d;zb(d)}d=w[b+8>>2];if(d){w[b+12>>2]=d;zb(d)}jb=b- -64|0;break i}a=P()|0;Cf(b+8|0);R(a|0);M()}vo(a+484360|0);j:{if(u[a+1304411|0]<0){u[w[a+1304400>>2]]=0;w[a+1304404>>2]=0;break j}u[a+1304411|0]=0;u[a+1304400|0]=0}k:{if(u[a+1304423|0]<0){u[w[a+1304412>>2]]=0;w[a+1304416>>2]=0;break k}u[a+1304423|0]=0;u[a+1304412|0]=0}l:{if(u[a+1304435|0]<0){u[w[a+1304424>>2]]=0;w[a+1304428>>2]=0;break l}u[a+1304435|0]=0;u[a+1304424|0]=0}b=a+1304436|0;if(u[a+1304447|0]<0){zb(w[b>>2])}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;b=a+1304448|0;if(u[a+1304459|0]<0){zb(w[b>>2])}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;b=a+1304460|0;if(u[a+1304471|0]<0){zb(w[b>>2])}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;b=a+1304472|0;if(u[a+1304483|0]<0){zb(w[b>>2])}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;b=a+1304484|0;if(u[a+1304495|0]<0){zb(w[b>>2])}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;w[a+1304504>>2]=w[a+1304500>>2];w[a+480252>>2]=w[a+480248>>2];if(w[a+480180>>2]&738230281){w[a+480208>>2]=w[a+480208>>2]|8388608}}function _x(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0;u=jb-16|0;jb=u;f=mo(u,1<<w[b+12>>2]);c=w[a+4>>2];g=w[a>>2];if((c|0)!=(g|0)){c=c-g>>3;m=c>>>0<=1?1:c;c=w[f>>2];while(1){e=B[g+(d<<3)>>3];h=c+(d<<4)|0;w[h+8>>2]=0;w[h+12>>2]=0;B[h>>3]=e;d=d+1|0;if((m|0)!=(d|0)){continue}break}}w[114256]=0;T(729,b|0,f|0);c=w[114256];w[114256]=0;a:{if((c|0)==1){break a}d=w[f>>2];g=w[f+4>>2];if((d|0)!=(g|0)){while(1){k=B[d+8>>3];e=B[d>>3];w[d+8>>2]=0;w[d+12>>2]=0;p=jb-32|0;jb=p;o(+e);m=j(1)|0;s=j(0)|0;o(+k);c=j(1)|0;t=j(0)|0;q=m&2147483647;r=c&2147483647;h=r;c=(q|0)==(h|0)&s>>>0<t>>>0|h>>>0>q>>>0;m=c?s:t;c=c?q:h;h=c;l(0,m|0);l(1,c|0);e=+n();v=c>>>20|0;i=e;b:{if((v|0)==2047){break b}c=(q|0)==(r|0)&s>>>0>t>>>0|q>>>0>r>>>0;l(0,(c?s:t)|0);c=c?q:r;l(1,c|0);k=+n();c:{if(!(h|m)){break c}c=c>>>20|0;if((c|0)==2047){break c}i=k+e;if((c-v|0)>=65){break b}d:{if(c>>>0>=1534){e=e*190109156629516e-225;k=k*190109156629516e-225;i=5.260135901548374e210;break d}i=1;if(v>>>0>572){break d}e=e*5.260135901548374e210;k=k*5.260135901548374e210;i=190109156629516e-225}du(p+24|0,p+16|0,k);du(p+8|0,p,e);i=i*L(B[p>>3]+B[p+16>>3]+B[p+8>>3]+B[p+24>>3]);break b}i=k}e=i;jb=p+32|0;x=d,y=$h(e),B[x>>3]=y;d=d+16|0;if((g|0)!=(d|0)){continue}break}}w[114256]=0;T(730,b|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;X(731,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}h=w[f>>2];c=w[f+4>>2]-h|0;if(c>>>0>=49){m=c>>4>>>1|0;c=m>>>0<=2?2:m;d=1;while(1){g=h+(d<<4)|0;e=B[g>>3];B[g>>3]=e+e;e=B[g+8>>3];B[g+8>>3]=e+e;g=h+(d+m<<4)|0;w[g+8>>2]=0;w[g+12>>2]=0;w[g>>2]=0;w[g+4>>2]=0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}w[114256]=0;T(729,b|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}d=w[f>>2];h=w[f+4>>2];if((d|0)!=(h|0)){while(1){i=B[d+8>>3];k=Em(B[d>>3]);e:{if(i==0){o(0);m=j(1)|0;r=j(0)|0;o(+i);c=j(1)|0;j(0)|0;l(0,r|0);l(1,m&2147483647|c&-2147483648);e=+n();break e}e=k*ee(i);k=k*Fc(i)}B[d+8>>3]=e;B[d>>3]=k;d=d+16|0;if((h|0)!=(d|0)){continue}break}}w[114256]=0;T(730,b|0,f|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}w[114256]=0;X(731,f|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}b=w[a+4>>2];c=w[a>>2];f:{g:{if((b|0)!=(c|0)){a=b-c>>3;b=a>>>0<=1?1:a;a=w[f>>2];d=0;while(1){B[c+(d<<3)>>3]=B[(d<<4)+a>>3];d=d+1|0;if((b|0)!=(d|0)){continue}break}break g}a=w[f>>2];if(!a){break f}}w[f+4>>2]=a;zb(a)}jb=u+16|0;return}a=P()|0;b=w[f>>2];if(b){w[f+4>>2]=b;zb(b)}R(a|0);M()}function Ww(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,z=0,A=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0;k=jb-16|0;jb=k;f=w[a+20>>2];s=w[(f+C(b,24)|0)+16>>2];a:{if(s+1>>>0<2){break a}p=w[a+4>>2];e=p+C(b,896)|0;t=e;j=e+616|0;g=w[j+4>>2];h=w[j>>2];j=g;if(!(h|g|x[(f+C(b,24)|0)+20|0])){break a}i=C(b,896)+p|0;if(!w[i+712>>2]){break a}g=e+608|0;E=c;c=BV(h,j,c,0);e=w[i+696>>2];f=e&128;j=f?0-c|0:c;h=nb;l=f?0-(h+((c|0)!=0)|0)|0:h;f=0;F=f;c=e&2;v=w[(c?i+692|0:i+684|0)>>2];e=c;z=c?f:0;c=w[i+688>>2];o=e?c:0;m=w[i+692>>2]-c|0;G=m<<1;H=i+1308|0;n=i+1480|0;A=w[w[a>>2]+1074312>>2];I=(A|0)>=0;B=i+1356|0;J=(x[B|0]&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){c=(x[B|0]&17)==1;break c}u[n|0]=x[n|0]&254;c=w[a+4>>2];e=w[c+48>>2];c=w[w[a>>2]+484344>>2]+C(y[c+60>>1],52)|0;f=ld(c);e=w[c>>2]+C(C(e,f)+b|0,6)|0;f=x[e+3|0];if(x[e+2|0]==11){qk(k+8|0,w[a>>2],e,0);og(w[a>>2],g,w[k+8>>2]);c=1;if(x[k+12|0]){break c}}c=1;d:{switch(f-4|0){case 0:og(w[a>>2],g,x[e+5|0]);break c;case 2:break d;default:break c}}og(w[a>>2],g,0)}w[k+8>>2]=w[H>>2];if(!I){ji(w[a>>2],g)}if(!J){qn(w[a>>2],g,k+8|0);c=1}if((A|0)>=0){ji(w[a>>2],g)}w[k+4>>2]=0;sn(g,k+4|0);e:{f=w[i+696>>2];f:{if(f&512){break f}if(c|x[(w[a+20>>2]+C(b,24)|0)+20|0]){if(x[n|0]&24){Go(g,D(1),0,w[a>>2]);c=x[n|0];u[n|0]=(c&16?-17:-9)&c}c=ck(w[a>>2],g,w[k+8>>2],0);w[t+616>>2]=c;j=nb;w[t+620>>2]=j;u[(w[a+20>>2]+C(b,24)|0)+20|0]=0;c=BV(c,j,E,0);f=w[i+696>>2];e=f&128;j=e?0-c|0:c;h=nb;l=e?0-(h+((c|0)!=0)|0)|0:h}c=l+w[g+4>>2]|0;e=j+w[g>>2]|0;c=e>>>0<j>>>0?c+1|0:c;h=e;w[g>>2]=e;w[g+4>>2]=c;if(((l|0)>0|(l|0)>=0|((c|0)>=(o|0)&e>>>0>=z>>>0|(c|0)>(o|0)))&(e>>>0<F>>>0&(c|0)<=(v|0)|(c|0)<(v|0))){break f}if(!(f&2)){break e}if(f&4){r=w[i+688>>2];if(h>>>0<z>>>0&(c|0)<=(o|0)|(c|0)<(o|0)){e=0;c=(r<<1)-((h>>>0>e>>>0)+c|0)|0;h=e-h|0;w[g>>2]=h;w[g+4>>2]=c;f=f^128;w[i+696>>2]=f;e=j;j=0-e|0;l=0-(((e|0)!=0)+l|0)|0}c=(c-r>>>0)%((w[w[a>>2]+1074316>>2]<<30>>31)+G>>>0)|0;e=c>>>0<m>>>0;g:{if(!e){c=w[i+692>>2]+(m-c|0)|0;w[g>>2]=h;w[g+4>>2]=c;if(!((f&128)>>>7^e)){break g}break f}w[g>>2]=h;w[g+4>>2]=c+r;if((f&128)>>>7^e){break f}}w[i+696>>2]=f^128;c=j;j=0-c|0;l=0-(((c|0)!=0)+l|0)|0;break f}f=c;e=w[i+692>>2];if(c>>>0>=e+m>>>0){f=e+((f-e>>>0)%(m>>>0)|0)|0}while(1){c=f;f=c-m|0;if(c>>>0>=e>>>0){continue}break}w[g>>2]=h;w[g+4>>2]=c}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}Jo(g);w[(C(b,896)+p|0)+1316>>2]=0}w[(w[a+20>>2]+C(b,24)|0)+16>>2]=0}jb=k+16|0}function iy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=jb-224|0;jb=c;a=mg(c+120|0,a);w[114256]=0;e=Q(5,c+104|0,24208)|0;f=w[114256];w[114256]=0;a:{b:{c:{d:{if((f|0)!=1){w[114256]=0;w[c+88>>2]=19469585;w[c+92>>2]=0;U(397,a|0,e|0,c+88|0);f=w[114256];w[114256]=0;if((f|0)==1){break d}if(u[e+11|0]<0){zb(w[e>>2])}if(!(x[a+3|0]&64)){break c}break a}b=P()|0;break b}b=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}w[114256]=0;u[c+103|0]=0;e=Q(5,c+88|0,1991)|0;f=w[114256];w[114256]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){w[114256]=0;S(398,a|0,c+103|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break p}if(u[e+11|0]<0){zb(w[e>>2])}w[c+80>>2]=0;w[114256]=0;w[c+72>>2]=0;w[c+76>>2]=0;e=Q(5,c+56|0,6039)|0;f=w[114256];w[114256]=0;if((f|0)==1){break o}w[114256]=0;S(714,a|0,c+72|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break n}if(u[e+11|0]<0){zb(w[e>>2])}w[114256]=0;U(6,c+40|0,(x[c+103|0]?0:d)|0,c+72|0);d=w[114256];w[114256]=0;if((d|0)==1){break m}w[114256]=0;Q(117,b+12|0,c+40|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break l}if(u[c+51|0]<0){zb(w[c+40>>2])}w[114256]=0;v[c+38>>1]=0;d=Q(5,c+40|0,6686)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}w[114256]=0;S(715,a|0,c+38|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break j}if(u[d+11|0]<0){zb(w[d>>2])}d=y[w[19467]+12>>1];if(d>>>0<y[c+38>>1]){v[c+38>>1]=d}w[114256]=0;d=Q(5,c+24|0,9223)|0;e=w[114256];w[114256]=0;if((e|0)==1){break i}w[114256]=0;Z(716,a|0,b|0,d|0,y[c+38>>1])|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}if(u[d+11|0]<0){zb(w[d>>2])}w[114256]=0;v[c+22>>1]=65535;d=Q(5,c+8|0,5049)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;e=S(715,a|0,c+22|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}e=(e|0)!=1&y[c+22>>1]<y[c+38>>1];if(u[d+11|0]<0){zb(w[d>>2])}if(e){v[b+28>>1]=y[c+22>>1]}if(u[c+83|0]>=0){break a}zb(w[c+72>>2]);break a}b=P()|0;break b}b=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}b=P()|0;break e}b=P()|0;if(u[e+11|0]>=0){break e}zb(w[e>>2]);break e}b=P()|0;break e}b=P()|0;if(u[c+51|0]>=0){break e}zb(w[c+40>>2]);break e}b=P()|0;break e}b=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2]);break e}b=P()|0;break e}b=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2]);break e}b=P()|0;break e}b=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2])}if(u[c+83|0]>=0){break b}zb(w[c+72>>2])}Mf(a);R(b|0);M()}b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}b=w[a+32>>2];if(b){w[a+36>>2]=b;zb(b)}jb=c+224|0}function zN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0;e=jb+-64|0;jb=e;o=w[a+4>>2];w[e+60>>2]=b;w[e+56>>2]=c;w[e+52>>2]=d;b=w[a+8>>2];w[e+44>>2]=e+52;w[e+40>>2]=e+56;f=w[e+44>>2];w[e+24>>2]=w[e+40>>2];w[e+28>>2]=f;w[e+32>>2]=a;w[e+36>>2]=e+60;f=w[e+36>>2];w[e+16>>2]=w[e+32>>2];w[e+20>>2]=f;a:{b:{switch(w[b+40>>2]){case 0:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+16>>2];j=w[b+12>>2]+(C(i,w[b+4>>2])<<2)|0;g=w[w[e+24>>2]>>2];k=w[w[e+20>>2]>>2];b=0;while(1){if(g){l=C(b,i);m=C(b,g);f=0;while(1){A[j+(f+l<<2)>>2]=D(w[k+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 2:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+16>>2];j=w[b+12>>2]+(C(i,w[b+4>>2])<<2)|0;g=w[w[e+24>>2]>>2];k=w[w[e+20>>2]>>2];b=0;while(1){if(g){l=C(b,i);m=C(b,g);f=0;while(1){A[j+(f+l<<2)>>2]=D(w[k+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 3:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+16>>2];j=w[b+12>>2]+(C(i,w[b+4>>2])<<2)|0;g=w[w[e+24>>2]>>2];k=w[w[e+20>>2]>>2];b=0;while(1){if(g){l=C(b,i);m=C(b,g);f=0;while(1){A[j+(f+l<<2)>>2]=D(w[k+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;case 1:h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+16>>2];j=w[b+12>>2]+(C(i,w[b+4>>2])<<2)|0;g=w[w[e+24>>2]>>2];k=w[w[e+20>>2]>>2];b=0;while(1){if(g){l=C(b,i);m=C(b,g);f=0;while(1){A[j+(f+l<<2)>>2]=D(w[k+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break};break a;default:break b}}h=w[w[e+28>>2]>>2];if(!h){break a}b=w[e+16>>2];i=w[b+16>>2];j=w[b+12>>2]+(C(i,w[b+4>>2])<<2)|0;g=w[w[e+24>>2]>>2];k=w[w[e+20>>2]>>2];b=0;while(1){if(g){l=C(b,i);m=C(b,g);f=0;while(1){A[j+(f+l<<2)>>2]=D(w[k+(f+m<<2)>>2])*D(7.450580596923828e-9);f=f+1|0;if((g|0)!=(f|0)){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break}}w[a+4>>2]=w[a+4>>2]+w[e+52>>2];n=A[a+24>>2];w[e+8>>2]=w[a+20>>2];b=w[a+16>>2];w[e>>2]=w[a+12>>2];w[e+4>>2]=b;a=0;if(!(!d|n==D(1))){f=w[e+4>>2];g=w[e>>2];while(1){if(c){i=C(f,a+o|0);b=0;while(1){h=g+(b+i<<2)|0;A[h>>2]=A[h>>2]*n;b=b+1|0;if((c|0)!=(b|0)){continue}break}}a=a+1|0;if((d|0)!=(a|0)){continue}break}}jb=e- -64|0}function zJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=nm(g);o=Rl(g);Ad(k,o);w[f>>2]=d;a:{b:{c:{i=a;g=x[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}w[114256]=0;g=Q(1761,m|0,g<<24>>24)|0;i=w[114256];w[114256]=0;if((i|0)==1){break a}i=w[f>>2];w[f>>2]=i+4;w[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|x[g|0]!=48|(x[g+1|0]|32)!=120)){w[114256]=0;g=Q(1761,m|0,48)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+4;w[h>>2]=g;g=u[i+1|0];w[114256]=0;g=Q(1761,m|0,g|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+4;w[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=u[g|0];w[114256]=0;j=ea(1732)|0;l=w[114256];w[114256]=0;e:{if((l|0)==1){break e}w[114256]=0;h=am(h,j);j=w[114256];w[114256]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=u[g|0];w[114256]=0;ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break a}w[114256]=0;h=Wd(h);j=w[114256];w[114256]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Id(k)){h=w[f>>2];w[114256]=0;Z(1749,m|0,i|0,g|0,h|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}w[f>>2]=w[f>>2]+(g-i<<2);break f}l=0;w[114256]=0;ef(i,g);h=w[114256];w[114256]=0;if((h|0)==1){break a}w[114256]=0;q=V(1746,o|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=w[f>>2];w[114256]=0;Nh((i-a<<2)+d|0,h);i=w[114256];w[114256]=0;if((i|0)!=1){break f}break a}g:{if(u[Rb(k,j)|0]<=0){break g}if(u[Rb(k,j)|0]!=(l|0)){break g}l=w[f>>2];w[f>>2]=l+4;w[l>>2]=q;j=(Db(k)-1>>>0>j>>>0)+j|0;l=0}p=u[h|0];w[114256]=0;p=Q(1761,m|0,p|0)|0;n=w[114256];w[114256]=0;if((n|0)!=1){n=w[f>>2];w[f>>2]=n+4;w[n>>2]=p;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=x[g|0];if((i|0)==46){w[114256]=0;i=V(1750,o|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}j=w[f>>2];h=j+4|0;w[f>>2]=h;w[j>>2]=i;g=g+1|0;break h}w[114256]=0;i=Q(1761,m|0,i<<24>>24)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+4;w[h>>2]=i;g=g+1|0;continue}break}h=w[f>>2]}w[114256]=0;Z(1749,m|0,g|0,c|0,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break a}i=f;f=w[f>>2]+(c-g<<2)|0;w[i>>2]=f;w[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;Gb(k);jb=k+16|0;return}a=P()|0;Gb(k);R(a|0);M()}function JJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=rm(g);o=Wl(g);Ad(k,o);w[f>>2]=d;a:{b:{c:{i=a;g=x[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}w[114256]=0;g=Q(1578,m|0,g<<24>>24)|0;i=w[114256];w[114256]=0;if((i|0)==1){break a}i=w[f>>2];w[f>>2]=i+1;u[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|x[g|0]!=48|(x[g+1|0]|32)!=120)){w[114256]=0;g=Q(1578,m|0,48)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+1;u[h|0]=g;g=u[i+1|0];w[114256]=0;g=Q(1578,m|0,g|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+1;u[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=u[g|0];w[114256]=0;j=ea(1732)|0;l=w[114256];w[114256]=0;e:{if((l|0)==1){break e}w[114256]=0;h=am(h,j);j=w[114256];w[114256]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=u[g|0];w[114256]=0;ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break a}w[114256]=0;h=Wd(h);j=w[114256];w[114256]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Id(k)){h=w[f>>2];w[114256]=0;Z(1728,m|0,i|0,g|0,h|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}w[f>>2]=w[f>>2]+(g-i|0);break f}l=0;w[114256]=0;ef(i,g);h=w[114256];w[114256]=0;if((h|0)==1){break a}w[114256]=0;q=V(1719,o|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=w[f>>2];w[114256]=0;ef((i-a|0)+d|0,h);i=w[114256];w[114256]=0;if((i|0)!=1){break f}break a}g:{if(u[Rb(k,j)|0]<=0){break g}if(u[Rb(k,j)|0]!=(l|0)){break g}l=w[f>>2];w[f>>2]=l+1;u[l|0]=q;j=(Db(k)-1>>>0>j>>>0)+j|0;l=0}p=u[h|0];w[114256]=0;p=Q(1578,m|0,p|0)|0;n=w[114256];w[114256]=0;if((n|0)!=1){n=w[f>>2];w[f>>2]=n+1;u[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=x[g|0];if((i|0)!=46){break h}w[114256]=0;i=V(1729,o|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+1;u[h|0]=i;g=g+1|0}i=w[f>>2];w[114256]=0;Z(1728,m|0,g|0,c|0,i|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break a}i=f;f=w[f>>2]+(c-g|0)|0;w[i>>2]=f;w[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;Gb(k);jb=k+16|0;return}w[114256]=0;i=Q(1578,m|0,i<<24>>24)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}h=w[f>>2];w[f>>2]=h+1;u[h|0]=i;g=g+1|0;continue}}a=P()|0;Gb(k);R(a|0);M()}function SP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb-112|0;jb=j;a:{b:{c:{k=Zh(1,32);d:{e:{if(!k){a=Ye(ba(4)|0);w[114256]=0;U(194,a|0,74720,68);a=w[114256];w[114256]=0;if((a|0)!=1){break a}k=W(0)|0;break e}w[k+12>>2]=f;w[k+8>>2]=e;w[k+4>>2]=d;w[k>>2]=c?c:1321;w[j+72>>2]=j+72|4;w[j+76>>2]=0;w[j+80>>2]=0;f:{g:{h:{i:{if(!i){break i}f=w[i>>2];if(!f){break i}while(1){j:{c=i;e=w[c+4>>2];if(e){w[114256]=0;d=Q(5,j+56|0,f|0)|0;f=w[114256];w[114256]=0;k:{if((f|0)!=1){w[114256]=0;w[j+96>>2]=d;ia(1329,j+104|0,j+72|0,d|0,36532,j+96|0,j+88|0);f=w[114256];w[114256]=0;if((f|0)==1){break k}w[114256]=0;Q(260,w[j+104>>2]+28|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}if(u[j+67|0]>=0){break j}zb(w[d>>2]);break j}c=W(0)|0;break h}c=W(0)|0;if(u[j+67|0]>=0){break h}zb(w[d>>2]);break h}w[114256]=0;d=Q(5,j+40|0,f|0)|0;e=w[114256];w[114256]=0;l:{if((e|0)!=1){w[114256]=0;Q(1330,j+72|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[j+51|0]>=0){break j}zb(w[d>>2]);break j}c=W(0)|0;break h}c=W(0)|0;if(u[j+51|0]>=0){break h}zb(w[d>>2]);break h}i=c+8|0;f=w[c+8>>2];if(f){continue}break}}c=w[a+8>>2];d=w[a+4>>2];e=w[a>>2];w[114256]=0;a=V(22,96)|0;f=w[114256];w[114256]=0;m:{if((f|0)!=1){w[114256]=0;w[j+36>>2]=c;w[j+32>>2]=d;w[j+28>>2]=e;w[j+24>>2]=b;b=Q(1331,k|0,k+4|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break m}w[114256]=0;c=w[j+36>>2];w[j+16>>2]=w[j+32>>2];w[j+20>>2]=c;c=w[j+28>>2];w[j+8>>2]=w[j+24>>2];w[j+12>>2]=c;b=Z(1405,a|0,j+8|0,b|0,j+72|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break g}break m}c=W(0)|0;break h}c=W(0)|0;zb(a)}ke(j+72|0,w[j+76>>2]);$(c|0)|0;w[114256]=0;Y(1333,7179,k|0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){a=w[k+28>>2];if(a){ob[w[w[a>>2]+4>>2]](a)}w[k+24>>2]=0;w[k+28>>2]=0;a=w[k+20>>2];if(a){zb(a);w[k+20>>2]=0}zb(k);k=0;break d}k=W(0)|0;break e}w[k+28>>2]=b;w[k+24>>2]=b+8;ke(j+72|0,w[j+76>>2]);break d}k=W(0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break b}}$(k|0)|0;k=0;w[114256]=0;na(1314,7179,0,0,0,0,0,0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=j+112|0;return k|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}W(0)|0;Eb()}M()}function Sy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{switch(b|0){case 0:w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;d=x[c+11|0];b=d<<24>>24<0;if(!(b?w[c+4>>2]:d)){break d}while(1){b=w[(h<<2)+(b&1?w[c>>2]:c)>>2];f:{if(b>>>0>=2097152){w[114256]=0;T(71,a|0,63);b=w[114256];w[114256]=0;if((b|0)!=1){break f}break c}e=0;g:{h:{while(1){g=b&63;u[(f+10|0)+e|0]=g;if(b>>>0<64){break h}b=b>>>6|0;e=e+1|0;if((e|0)!=6){continue}break}d=7;e=6;break g}if(e){d=e+1|0;if((d|0)!=2){break g}e=1;d=2;if((g|0)!=1){break g}b=x[f+10|0]|64}else{b=x[f+10|0]}w[114256]=0;T(71,a|0,b<<24>>24);b=w[114256];w[114256]=0;if((b|0)!=1){break f}break c}g=(-1<<d^-1)<<7-e;e=d-1|0;j=e+(f+10|0)|0;b=d;while(1){i:{if((b|0)==(d|0)){b=x[j|0];w[114256]=0;T(71,a|0,(b|g)<<24>>24);i=w[114256];w[114256]=0;b=e;if((i|0)!=1){break i}break c}w[114256]=0;b=b-1|0;T(71,a|0,u[b+(f+10|0)|0]|-128);i=w[114256];w[114256]=0;if((i|0)==1){break c}}if(b){continue}break}}d=x[c+11|0];b=d<<24>>24<0;h=h+1|0;if(h>>>0<(b?w[c+4>>2]:d)>>>0){continue}break};break d;default:w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break d;case 7:rh(a,c,21568);break d;case 6:rh(a,c,20544);break d;case 5:rh(a,c,19520);break d;case 4:rh(a,c,18496);break d;case 3:rh(a,c,17472);break d;case 2:w[a>>2]=0;w[a+4>>2]=0;b=0;w[a+8>>2]=0;d=x[c+11|0];e=w[c+4>>2];w[114256]=0;T(72,a|0,(d<<24>>24<0?e:d)|0);d=w[114256];w[114256]=0;if((d|0)!=1){j:{d=x[c+11|0];e=d<<24>>24<0;if(!(e?w[c+4>>2]:d)){break d}while(1){d=w[(b<<2)+(e&1?w[c>>2]:c)>>2];w[114256]=0;T(71,a|0,(d>>>0>=256?63:d)<<24>>24);d=w[114256];w[114256]=0;if((d|0)==1){break j}d=x[c+11|0];e=d<<24>>24<0;b=b+1|0;if(b>>>0<(e?w[c+4>>2]:d)>>>0){continue}break}break d}}b=P()|0;if(u[a+11|0]<0){break b}break a;case 1:break e}}w[a>>2]=0;w[a+4>>2]=0;b=0;w[a+8>>2]=0;d=x[c+11|0];e=w[c+4>>2];w[114256]=0;T(72,a|0,(d<<24>>24<0?e:d)|0);d=w[114256];w[114256]=0;if((d|0)!=1){k:{d=x[c+11|0];e=d<<24>>24<0;if(!(e?w[c+4>>2]:d)){break d}while(1){d=w[(b<<2)+(e&1?w[c>>2]:c)>>2];w[114256]=0;T(71,a|0,(d>>>0>=128?63:d)<<24>>24);d=w[114256];w[114256]=0;if((d|0)==1){break k}d=x[c+11|0];e=d<<24>>24<0;b=b+1|0;if(b>>>0<(e?w[c+4>>2]:d)>>>0){continue}break}break d}}b=P()|0;if(u[a+11|0]<0){break b}break a}jb=f+16|0;return}b=P()|0;if(u[a+11|0]>=0){break a}}zb(w[a>>2])}R(b|0);M()}function Uu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;e=w[b+4>>2];a:{if(!e){break a}f=w[b>>2];d=e-1|0;h=x[f+d|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}w[b>>2]=f;w[b+4>>2]=d>>>0>e>>>0?e:d}d=82096;f=w[b+4>>2];h=f;e=w[b>>2];b:{c:{d:{e:{f:{g:{while(1){h:{i=w[d>>2];if((ec(i)|0)==(f|0)){if(!f){break h}if(!Jb(i,e,f)){break h}}d=d+8|0;if((d|0)!=82200){continue}break g}break}if((d|0)!=82200){break f}}if(!h){b=ba(8)|0;w[114256]=0;a=Q(5,g+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=0;if(!c){break e}c=ba(8)|0;w[114256]=0;b=Q(1447,g|0,b|0)|0;a=w[114256];w[114256]=0;i:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;e=w[114256];w[114256]=0;if((e|0)!=1){w[g+24>>2]=w[a+8>>2];e=w[a+4>>2];w[g+16>>2]=w[a>>2];w[g+20>>2]=e;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(c,g+16|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}d=P()|0;if(u[g+27|0]<0){zb(w[g+16>>2])}if(u[b+11|0]>=0){break c}zb(w[b>>2]);break c}d=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2]);break i}d=P()|0}ca(c|0);break c}if(w[d+4>>2]){b=ba(8)|0;w[114256]=0;a=Q(5,g+16|0,7423)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=P()|0;ca(b|0);break c}d=0;j:{k:{l:{m:{n:{switch(f-17|0){default:if((f|0)==30){break j}if(f){break e}b=ba(8)|0;w[114256]=0;a=Q(5,g+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=P()|0;ca(b|0);break c;case 0:if(Jb(e,3674,17)){if(Jb(e,3656,17)){break m}}d=x[a+60|0]!=0;break e;case 6:break l;case 1:break n;case 2:case 3:case 4:case 5:break e}}if(Jb(e,3240,f)){if(Jb(e,3221,18)){break e}}d=x[a+61|0]!=0;break e}if(Jb(e,3324,f)){break k}d=x[a+62|0]!=0;break e}if(Jb(e,2484,f)){break e}d=x[a+63|0]!=0;break e}if(Jb(e,3723,f)){break e}d=x[a+64|0]!=0;break e}if(Jb(e,9194,f)){break e}d=w[w[a+24>>2]+24668>>2]!=0}jb=g+32|0;return d|0}d=P()|0;ca(b|0)}R(d|0)}M()}function lv(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb-112|0;jb=j;a:{b:{c:{d:{e:{f:{k=Zh(1,28);if(!k){a=Ye(ba(4)|0);w[114256]=0;U(194,a|0,74720,68);a=w[114256];w[114256]=0;if((a|0)!=1){break a}break f}w[k+12>>2]=f;w[k+8>>2]=e;w[k+4>>2]=d;w[k>>2]=c?c:1321;w[j+72>>2]=j+72|4;w[j+76>>2]=0;w[j+80>>2]=0;g:{h:{i:{j:{if(!i){break j}f=w[i>>2];if(!f){break j}while(1){k:{c=i;e=w[c+4>>2];if(e){w[114256]=0;d=Q(5,j+56|0,f|0)|0;f=w[114256];w[114256]=0;l:{if((f|0)!=1){w[114256]=0;w[j+96>>2]=d;ia(1329,j+104|0,j+72|0,d|0,36532,j+96|0,j+88|0);f=w[114256];w[114256]=0;if((f|0)==1){break l}w[114256]=0;Q(260,w[j+104>>2]+28|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[j+67|0]>=0){break k}zb(w[d>>2]);break k}c=W(0)|0;break i}c=W(0)|0;if(u[j+67|0]>=0){break i}zb(w[d>>2]);break i}w[114256]=0;d=Q(5,j+40|0,f|0)|0;e=w[114256];w[114256]=0;m:{if((e|0)!=1){w[114256]=0;Q(1330,j+72|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}if(u[j+51|0]>=0){break k}zb(w[d>>2]);break k}c=W(0)|0;break i}c=W(0)|0;if(u[j+51|0]>=0){break i}zb(w[d>>2]);break i}i=c+8|0;f=w[c+8>>2];if(f){continue}break}}c=w[a+8>>2];d=w[a+4>>2];e=w[a>>2];w[114256]=0;a=V(22,80)|0;f=w[114256];w[114256]=0;n:{if((f|0)!=1){w[114256]=0;w[j+36>>2]=c;w[j+32>>2]=d;w[j+28>>2]=e;w[j+24>>2]=b;b=Q(1331,k|0,k+4|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break n}w[114256]=0;c=w[j+36>>2];w[j+16>>2]=w[j+32>>2];w[j+20>>2]=c;c=w[j+28>>2];w[j+8>>2]=w[j+24>>2];w[j+12>>2]=c;b=Z(1332,a|0,j+8|0,b|0,j+72|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break h}break n}c=W(0)|0;break i}c=W(0)|0;zb(a)}ke(j+72|0,w[j+76>>2]);$(c|0)|0;w[114256]=0;Y(1333,10681,k|0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break g}w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break f}a=w[k+24>>2];if(a){zb(kg(a))}i=0;w[k+24>>2]=0;a=w[k+20>>2];if(a){zb(a);w[k+20>>2]=0}zb(k);break d}w[k+24>>2]=b;ke(j+72|0,w[j+76>>2]);i=k;break d}c=W(0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){break e}break b}c=W(0)|0}$(c|0)|0;i=0;w[114256]=0;na(1314,10681,0,0,0,0,0,0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=j+112|0;return i|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}W(0)|0;Eb()}M()}function DA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;j=c+484344|0;td(j,x[b+70|0]|x[b+71|0]<<8);a:{if(x[b+70|0]|x[b+71|0]<<8){while(1){d=w[a+8>>2];c=Nc(a,e+8|0);f=c?w[e+8>>2]:0;c=w[a>>2];b:{if(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],1)|0){c=w[a+8>>2]+1|0;break b}c=w[a>>2];c=ob[w[w[c>>2]+24>>2]](c)|0}w[a+8>>2]=c;c:{if((x[b+58|0]|x[b+59|0]<<8)==258){c=Xb(a,e+8|0);c=c?x[e+8|0]+1|0:1;break c}c=cd(a,e+8|0);c=c?y[e+8>>1]:0}g=cd(a,e+8|0);g=g?y[e+8>>1]:0;h=c?c>>>0>=1024?1024:c:64;c=d+f|0;d:{if(c>>>0>z[a+8>>2]){d=w[a>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<c>>>0){break d}}w[a+8>>2]=c}c=g&65535;oc(e+8|0,a,c);w[114256]=0;d=S(216,j|0,i&65535,h|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}e:{if(!(d&(c|0)!=0)){break e}d=w[j>>2]+C(i,52)|0;c=w[d>>2];h=w[d+4>>2];if((c|0)==(h|0)){break e}while(1){w[114256]=0;f=Q(241,e+8|0,e+31|0)|0;d=w[114256];w[114256]=0;f:{g:{h:{if((d|0)!=1){d=x[e+31|0];f=(f?d:0)<<24>>24;if((f|0)>=0){break h}if(f&1){w[114256]=0;f=Q(241,e+8|0,e+31|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}u[c|0]=f?x[e+31|0]:0}if(d&2){break g}break f}break a}u[c|0]=f;d=255}w[114256]=0;f=Q(241,e+8|0,e+31|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}u[c+1|0]=f?x[e+31|0]:0}f=0;if(d&4){w[114256]=0;f=Q(241,e+8|0,e+31|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}f=f?x[e+31|0]:0}if(d&8){w[114256]=0;g=Q(241,e+8|0,e+31|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break a}u[c+3|0]=g?x[e+31|0]:0}if(d&16){w[114256]=0;d=Q(241,e+8|0,e+31|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}u[c+5|0]=d?x[e+31|0]:0}i:{j:{d=x[c|0];if(!d){break j}g=255;if((d|0)==97){break i}if(d>>>0>96){break j}g=d+12|0;break i}g=0}u[c|0]=g;k:{if(x[c+5|0]|x[c+3|0]){w[114256]=0;X(312,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){break k}break a}u[c+3|0]=0}if(x[c+1|0]==255){u[c+1|0]=0}d=f-16|0;l:{if((d&255)>>>0<=64){u[c+4|0]=d;u[c+2|0]=1;break l}d=f&255;if(d>>>0<96){break l}f=f&15;u[c+4|0]=f;d=d-96>>>4|0;u[c+2|0]=x[d+23934|0];if((d|0)!=6){break l}u[c+4|0]=f<<2}c=c+6|0;if((h|0)!=(c|0)){continue}break}}c=w[e+12>>2];m:{if(!c){break m}d=w[c+4>>2];w[c+4>>2]=d-1;if(d){break m}ob[w[w[c>>2]+8>>2]](c);Ib(c)}i=i+1|0;if(i>>>0<(x[b+70|0]|x[b+71|0]<<8)>>>0){continue}break}}jb=e+32|0;return}a=P()|0;Bb(e+8|0);R(a|0);M()}function _m(a){a=a|0;var b=0,c=0,d=0,e=D(0),f=0;d=jb-16|0;jb=d;Cb(a+4960|0,0,85);b=w[a+4292>>2];e=A[a+4268>>2];w[114256]=0;f=a+4504|0;if(e<D(4294967296)&e>=D(0)){c=~~e>>>0}else{c=0}ga(1241,f|0,67,5,c|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)==1){break c}b=w[a+4296>>2];w[114256]=0;ga(1241,a+4528|0,62,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4300>>2];w[114256]=0;ga(1241,a+4552|0,53,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4304>>2];w[114256]=0;ga(1241,a+4576|0,43,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4308>>2];w[114256]=0;ga(1241,a+4600|0,32,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4312>>2];w[114256]=0;ga(1241,a+4624|0,22,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4316>>2];w[114256]=0;ga(1241,a+4648|0,75,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4320>>2];w[114256]=0;ga(1241,a+4672|0,69,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4324>>2];w[114256]=0;ga(1241,a+4696|0,60,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4328>>2];w[114256]=0;ga(1241,a+4720|0,48,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4332>>2];w[114256]=0;ga(1241,a+4744|0,36,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4336>>2];w[114256]=0;ga(1241,a+4768|0,25,5,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=a+4804|0;w[b>>2]=0;w[b+4>>2]=0;w[114256]=0;w[d+12>>2]=0;U(992,a+4792|0,0,d+12|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4344>>2];w[114256]=0;ga(1241,a+4816|0,3,0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4348>>2];w[114256]=0;ga(1241,a+4840|0,3,0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;ga(1241,a+4864|0,407,1,c|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;ga(1241,a+4888|0,400,1,c|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;ga(1241,a+4912|0,10,0,c|0,-1);b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;ga(1241,a+4936|0,10,0,c|0,-1);c=w[114256];w[114256]=0;if((c|0)==1){break c}u[a+5045|0]=1;break b}c=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(c|0)|0;u[a+5045|0]=0;aa()}jb=d+16|0;return}R(c|0);M()}function fy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;c=jb-208|0;jb=c;a=mg(c+96|0,a);w[114256]=0;e=Q(5,c+80|0,24215)|0;f=w[114256];w[114256]=0;a:{b:{c:{d:{if((f|0)!=1){w[114256]=0;w[c+16>>2]=19469585;w[c+20>>2]=0;U(397,a|0,e|0,c+16|0);f=w[114256];w[114256]=0;if((f|0)==1){break d}if(u[e+11|0]<0){zb(w[e>>2])}if(!(x[a+3|0]&64)){break c}break a}b=P()|0;break b}b=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}w[114256]=0;u[c+79|0]=0;u[c+78|0]=0;e=Q(5,c- -64|0,6039)|0;f=w[114256];w[114256]=0;e:{f:{g:{h:{i:{if((f|0)!=1){w[114256]=0;S(717,a|0,c+79|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}if(u[e+11|0]<0){zb(w[e>>2])}e=x[c+79|0];if(!e){break a}if(e>>>0>=51){u[c+79|0]=50}w[114256]=0;e=Q(5,c+48|0,9038)|0;f=w[114256];w[114256]=0;if((f|0)==1){break h}w[114256]=0;S(717,a|0,c+78|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(u[e+11|0]<0){zb(w[e>>2])}f=x[c+79|0];e=w[b>>2];if(f>>>0>(w[b+4>>2]-e>>>5&255)>>>0){e=w[b+12>>2];w[c+32>>2]=0;w[c+36>>2]=0;w[c+24>>2]=0;w[c+28>>2]=0;w[114256]=0;w[c+16>>2]=0;w[c+20>>2]=0;v[c+44>>1]=0;w[c+40>>2]=e;U(718,b|0,f|0,c+16|0);e=w[114256];w[114256]=0;if((e|0)==1){break e}if(u[c+39|0]<0){zb(w[c+28>>2])}e=w[c+16>>2];if(e){w[c+20>>2]=e;zb(e)}f=x[c+79|0];e=w[b>>2]}if(f){i=y[e+28>>1];e=0;while(1){h=w[b>>2]+(e<<5)|0;v[h+28>>1]=i;w[114256]=0;w[c>>2]=e;u[c+11|0]=1;f=Q(399,a|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break f}g=w[a+28>>2];w[114256]=0;T(400,c+16|0,g|0);g=w[114256];w[114256]=0;if((g|0)==1){break f}g=w[c+28>>2];w[c+200>>2]=w[c+24>>2];w[c+204>>2]=g;if(x[a+24|0]&32?f:1){g=w[a+28>>2];w[114256]=0;Y(719,g|0,h|0,c|0,d|0);h=w[114256];w[114256]=0;if((h|0)==1){break f}}w[114256]=0;Z(402,a|0,f|0,c|0,c+200|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}if(u[c+11|0]<0){zb(w[c>>2])}e=e+1|0;if(e>>>0<x[c+79|0]){continue}break}e=w[b>>2]}d=x[c+78|0];u[b+16|0]=d>>>0<(w[b+4>>2]-e>>>5&255)>>>0?d:0;break a}b=P()|0;break b}b=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}b=P()|0;break b}b=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}b=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}b=P()|0;mh(c+16|0)}Mf(a);R(b|0);M()}b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}b=w[a+32>>2];if(b){w[a+36>>2]=b;zb(b)}jb=c+208|0}function SN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-80|0;jb=e;g=x[c+11|0];f=g<<24>>24<0;g=f?w[c+4>>2]:g;a:{if(!g){break a}f=x[(g+(f?w[c>>2]:c)|0)-1|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=wl(e- -64|0,c,0,g-1|0,c);if(u[c+11|0]<0){zb(w[c>>2])}g=w[f+4>>2];w[c>>2]=w[f>>2];w[c+4>>2]=g;w[c+8>>2]=w[f+8>>2]}f=82096;b:{c:{d:{e:{f:{g:{h:{while(1){i:{h=w[f>>2];g=ec(h);i=x[c+11|0];if((g|0)==((i<<24>>24<0?w[c+4>>2]:i)|0)){w[114256]=0;g=da(186,c|0,0,-1,h|0,g|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}if(!g){break i}}f=f+8|0;if((f|0)!=82200){continue}break h}break}if((f|0)!=82200){break g}}j:{b=x[c+11|0];if(b<<24>>24<0?w[c+4>>2]:b){break j}w[114256]=0;b=da(186,c|0,0,-1,17256,0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(b){break j}b=ba(8)|0;w[114256]=0;a=Q(5,e- -64|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break c}f=P()|0;if(u[a+11|0]>=0){break d}zb(w[a>>2]);break d}if(d){a=ba(8)|0;w[114256]=0;U(1445,e- -64|0,13399,c|0);b=w[114256];w[114256]=0;if((b|0)!=1){a=Pb(a,e- -64|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break c}f=P()|0;if(u[e+75|0]>=0){break d}zb(w[e+64>>2]);break d}f=P()|0;ca(a|0);break d}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break f}k:{switch(w[f+4>>2]){case 0:g=w[c>>2];h=x[c+11|0];f=h<<24>>24<0;w[e+60>>2]=f?w[c+4>>2]:h;w[e+56>>2]=f?g:c;c=w[e+60>>2];w[e>>2]=w[e+56>>2];w[e+4>>2]=c;j=e,k=Uu(b,e,d),u[j+64|0]=k;eo(a,e- -64|0);break f;case 1:g=w[c>>2];h=x[c+11|0];f=h<<24>>24<0;w[e+52>>2]=f?w[c+4>>2]:h;w[e+48>>2]=f?g:c;c=w[e+52>>2];w[e+8>>2]=w[e+48>>2];w[e+12>>2]=c;j=e,k=Tu(b,e+8|0,d),w[j+64>>2]=k;w[e+68>>2]=nb;Xn(a,e- -64|0);break f;case 2:g=w[c>>2];h=x[c+11|0];f=h<<24>>24<0;w[e+44>>2]=f?w[c+4>>2]:h;w[e+40>>2]=f?g:c;c=w[e+44>>2];w[e+16>>2]=w[e+40>>2];w[e+20>>2]=c;j=e,l=Su(b,e+16|0,d),B[j+64>>3]=l;Sn(a,e- -64|0);break f;case 3:g=w[c>>2];h=x[c+11|0];f=h<<24>>24<0;w[e+36>>2]=f?w[c+4>>2]:h;w[e+32>>2]=f?g:c;c=w[e+36>>2];w[e+24>>2]=w[e+32>>2];w[e+28>>2]=c;Ru(a,b,e+24|0,d);break f;default:break k}}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0}jb=e+80|0;return}f=P()|0;ca(b|0)}R(f|0)}M()}W(0)|0;Eb();M()}function TU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-1120|0;jb=f;w[b+8>>2]=0;e=jb-16|0;jb=e;h=w[b+8>>2];d=w[b>>2];g=f+1096|0;w[e+8>>2]=g;w[e+12>>2]=g+24;h=ob[w[w[d>>2]+32>>2]](d,h,e+8|0)|0;if((h|0)==24){d=w[b>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],24)|0){d=w[b+8>>2]+24|0;break a}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d}jb=e+16|0;b:{if((h|0)!=24){break b}if(!tw(f+1096|0)){break b}e=w[b>>2];if(w[f+1104>>2]!=(ob[w[w[e>>2]+24>>2]](e)|0)){break b}e=w[b>>2];if(w[f+1112>>2]!=((ob[w[w[e>>2]+24>>2]](e)|0)-w[b+8>>2]|0)){break b}if(!c){i=1;break b}e=f+1040|0;Cb(e,0,56);g=-2;c:{if(!e){break c}w[e+44>>2]=0;w[e+48>>2]=0;w[e+52>>2]=0;w[e+20>>2]=0;w[e+24>>2]=0;w[e+8>>2]=0;d=w[e+32>>2];if(!d){w[e+32>>2]=1550;d=1550}if(!w[e+36>>2]){w[e+36>>2]=1551}d=ob[d|0](w[e+40>>2],1,43784)|0;g=-4;if(!d){break c}w[e+28>>2]=d;w[d+43780>>2]=1;w[d+10992>>2]=0;w[d+10996>>2]=0;w[d>>2]=0;w[d+11008>>2]=15;w[d+11e3>>2]=1;w[d+11004>>2]=0;g=0}if(g){break b}e=w[f+1116>>2];j=(e|0)!=0;i=w[f+1112>>2];h=Qp(f+1024|0,e);d:{e:{f:{if(!i|!e){break f}while(1){d=w[b+8>>2];g=w[b>>2];j=w[w[g>>2]+28>>2];w[114256]=0;k=g;g=i>>>0>=1024?1024:i;d=Z(j|0,k|0,f|0,d|0,g|0)|0;j=w[114256];w[114256]=0;if((j|0)==1){break e}w[b+8>>2]=d+w[b+8>>2];w[114256]=0;l=S(941,l|0,f|0,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}w[f+1056>>2]=e;w[f+1044>>2]=g;w[f+1040>>2]=f;d=w[h>>2];w[114256]=0;w[f+1052>>2]=d+m;k=Q(942,f+1040|0,0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}d=w[f+1056>>2];j=(d|0)!=0;i=i-g|0;if(!i|!d){break f}m=(e+m|0)-d|0;e=d;if((k|0)!=1){continue}break}}w[114256]=0;V(943,f+1040|0)|0;b=w[114256];w[114256]=0;g:{h:{if((b|0)!=1){i=0;if(!(w[f+1108>>2]!=(l|0)|j|(k|0)!=1)){d=w[h+4>>2];e=w[h>>2];w[114256]=0;b=V(22,24)|0;i=w[114256];w[114256]=0;if((i|0)==1){break h}w[b+4>>2]=0;w[b+8>>2]=0;w[b+20>>2]=d-e;w[b+16>>2]=e;w[b+12>>2]=75592;w[b>>2]=75552;w[114256]=0;w[f+8>>2]=0;w[f+12>>2]=0;w[f+4>>2]=b;w[f>>2]=b+12;i=S(895,a|0,f|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break g}Bb(f)}a=w[h>>2];if(!a){break b}w[h+4>>2]=a;zb(a);break b}b=P()|0;break d}b=P()|0;break d}b=P()|0;Bb(f);break d}b=P()|0}a=w[h>>2];if(a){w[h+4>>2]=a;zb(a)}R(b|0);M()}jb=f+1120|0;return i|0}function ho(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-48|0;jb=f;g=w[a+24>>2];i=w[g+484360>>2];e=x[a+30|0];if(e>>>0>=(w[g+484364>>2]-i>>>5&255)>>>0){e=x[g+484376|0]}g=0;m=i+(e<<5)|0;n=If(m);v[b>>1]=0;a:{if(n){while(1){i=w[a+24>>2];e=w[i+484344>>2];j=(w[i+484348>>2]-e|0)/52&65535;i=g&65535;h=y[w[m>>2]+(i<<1)>>1];b:{if(j>>>0<=h>>>0){break b}k=C(h,52);e=k+e|0;if(w[e>>2]==w[e+4>>2]){break b}e=w[a>>2];if(i>>>0>=(w[a+4>>2]-e|0)/12>>>0){w[c>>2]=0;a=1;break a}i=e+C(i,12)|0;g=w[i+4>>2];e=w[i>>2];c:{d:{if(d){w[f+8>>2]=e;w[f+12>>2]=0;w[f+40>>2]=e;w[f+44>>2]=0;e=w[f+12>>2];e:{if(e){h=w[f+8>>2];k=-1<<e;e=32-e|0;j=e;e=e>>>0<g>>>0;l=e?j:g;k=w[h>>2]&(k&-1>>>j-l);if(k){w[f+24>>2]=h;o=f,p=AV(k),w[o+28>>2]=p;break e}if(!e){h=w[f+8>>2];e=w[f+12>>2]+g|0;w[f+28>>2]=e&31;w[f+24>>2]=(((g|0)>=0?e>>>5|0:(e-31|0)/32|0)<<2)+h;break e}g=g-l|0;e=h+4|0}else{e=w[f+8>>2]}f:{if(g>>>0>=32){while(1){h=w[e>>2];if(h){break f}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}}g:{if(!g){break g}h=w[e>>2]&-1>>>32-g;if(!h){break g}break f}w[f+28>>2]=g;w[f+24>>2]=e;break e}w[f+24>>2]=e;o=f,p=AV(h),w[o+28>>2]=p}e=w[i+4>>2];if(w[f+24>>2]!=(w[i>>2]+(e>>>3&536870908)|0)|w[f+28>>2]!=(e&31)){break c}g=0;break d}w[f+16>>2]=e;w[f+20>>2]=0;w[f+32>>2]=e;w[f+36>>2]=0;e=w[f+20>>2];h:{if(e){h=32-e|0;l=h>>>0<g>>>0;j=h;h=l?h:g;j=-1<<e&-1>>>j-h;e=w[f+16>>2];j=j&(w[e>>2]^-1);if(j){w[f+24>>2]=e;o=f,p=AV(j),w[o+28>>2]=p;break h}if(!l){h=w[f+16>>2];e=w[f+20>>2]+g|0;w[f+28>>2]=e&31;w[f+24>>2]=(((g|0)>=0?e>>>5|0:(e-31|0)/32|0)<<2)+h;break h}g=g-h|0;e=e+4|0}else{e=w[f+16>>2]}if(g>>>0>=32){while(1){h=w[e>>2];if((h|0)!=-1){w[f+24>>2]=e;o=f,p=AV(h^-1),w[o+28>>2]=p;break h}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}}i:{if(!g){break i}h=(w[e>>2]^-1)&-1>>>32-g;if(!h){break i}w[f+24>>2]=e;o=f,p=AV(h),w[o+28>>2]=p;break h}w[f+28>>2]=g;w[f+24>>2]=e}e=w[i>>2];g=w[i+4>>2];if(!(w[f+24>>2]==(e+(g>>>3&536870908)|0)&w[f+28>>2]==(g&31))){g=w[f+28>>2]+(w[f+24>>2]-e<<3)|0;break d}if(z[(k+w[w[a+24>>2]+484344>>2]|0)+12>>2]<=g>>>0){break c}}w[c>>2]=g;a=1;break a}g=y[b>>1]}g=g+1|0;v[b>>1]=g;if((g&65535)>>>0<n>>>0){continue}break}}v[b>>1]=65535;w[c>>2]=-1;a=0}jb=f+48|0;return a|0}function Dy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0;B=w[a+16>>2];D=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);p=w[a+128>>2];a:{if(!p){q=w[a+8>>2];s=w[a+12>>2];m=w[a>>2];n=w[a+4>>2];t=0;break a}n=w[a+4>>2];g=w[a+76>>2];m=w[a>>2];q=w[a+8>>2];s=w[a+12>>2];e=BV(q,s,d,0);h=m+e|0;b=nb+n|0;y=g>>>0<(e>>>0>h>>>0?b+1|0:b)>>>0?d:0;u=CV(q,s,p,p>>31);t=nb}h=w[a+48>>2];k=w[a+40>>2];l=w[a+36>>2];b=w[a+44>>2];b:{c:{if(!d){i=k>>12;f=l>>12;break c}j=a+112|0;E=(p|0)>0;g=h;while(1){h=b;y=y-1|0;b=y;u=b?u:0;t=b?t:0;e=0;i=m;x=(n<<1)+B|0;b=p;d:{if(!E){break d}while(1){e:{f=v[(e<<1)+x>>1];w[114256]=0;T(604,j|0,(f|0)/4<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,j|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+t|0;i=i+u|0;e=i>>>0<u>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}r=w[a+120>>2];b=r+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<r>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=v[(e<<1)+x>>1];w[114256]=0;T(604,j|0,(e|0)/4<<16>>16);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,D|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}x=w[a+72>>2];i=w[a+32>>2];f=w[c>>2];e=w[a+60>>2];r=b<<8;b=r;b=BV(e,e>>31,b,b>>31);e=nb;z=b;b=w[a+64>>2];o=b;A=b>>31;b=(h|0)>=16776704?16776704:h;b=(b|0)<=-16777216?-16777216:b;o=BV(o,A,b,b>>31);b=z+o|0;e=nb+e|0;e=b>>>0<o>>>0?e+1|0:e;z=b;b=w[a+68>>2];o=b;A=b>>31;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(o,A,b,b>>31);b=z+g|0;e=nb+e|0;e=b>>>0<g>>>0?e+1|0:e;b=b+8388608|0;e=b>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|b>>>24;b=(e|0)/256|0;g=f;l=w[a+28>>2]+l|0;f=l>>12;w[c>>2]=g+C(b,f);k=i+k|0;i=k>>12;w[c+4>>2]=w[c+4>>2]+C(b,i);b=e-(x&r)|0;e=n+s|0;g=m+q|0;e=g>>>0<q>>>0?e+1|0:e;m=g;n=e;c=c+8|0;g=h;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=m;w[a+4>>2]=n;w[a+40>>2]=k;w[a+20>>2]=f;w[a+48>>2]=h;w[a+44>>2]=b;w[a+24>>2]=i;return}b=P()|0;w[a+40>>2]=k;w[a+36>>2]=l;w[a+48>>2]=g;w[a+44>>2]=h;w[a+20>>2]=l>>12;w[a+24>>2]=k>>12;R(b|0);M()}function RE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-16|0;jb=f;v[f+12>>1]=0;w[f+8>>2]=0;if(w[a+12>>2]){m=f|5;n=f|3;d=f+8|0;o=d|3;p=d|5;while(1){d=ld(a);q=w[a>>2]+C(C(d,k),6)|0;while(1){a:{d=w[c>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[c+8>>2],1)|0)){break a}d=Xb(c,f);d=d?x[f|0]:0;if((d&255)==255){break a}l=d<<24>>24;d=l&31;h=C(d,6)+q|0;i=ld(a)>>>0>d>>>0;d=i?h:f+8|0;b:{if(!(l&64)){e=Xb(c,f);g=e?x[f|0]:0;j=g<<24>>24;e=255;g=g&127;c:{d:{if((g|0)==1){break d}e=g-1|0;if(b?e>>>0<=120:0){break d}if((g-109&255)>>>0<159|b){break c}e=g+13|0}u[d|0]=e}e=Xb(c,f);u[d+1|0]=e?x[f|0]:0;if((j|0)>=0){break b}}j=i?h+3|0:o;h=i?h+5|0:p;while(1){w[f>>2]=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);v[f+4>>1]=x[d+4|0]|x[d+5|0]<<8;e=Xb(c,f+15|0);e=e?x[f+15|0]:0;g=e&63;i=e<<24>>24;e:{if(e&64){u[d+2|0]=1;u[d+4|0]=g;break e}e=Xb(c,f+15|0);e=e?x[f+15|0]:0;u[d+5|0]=e;f:{g:{if(g>>>0<=15){u[d+3|0]=g;We(d);h:{i:{j:{e=x[d+3|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}u[d+3|0]=9;u[d+5|0]=C(x[d+5|0]&15,17);break f}u[d+3|0]=0;u[d+2|0]=1;e=x[d+5|0]+1>>>1|0;u[d+4|0]=e>>>0>=64?64:e;break f}if((e|0)!=19){break f}if(x[d+5|0]==128){break g}ow(d);break f}if(g>>>0>44){break f}g=g-16|0;u[d+3|0]=x[g+23232|0];k:{switch(g|0){case 0:if((e&255)>>>0>1){break g}u[d+5|0]=e|158;break f;case 1:case 2:e=e&255;u[d+5|0]=(e>>>0>=15?15:e)|224;break f;case 5:case 6:e=e&255;u[d+5|0]=(e>>>0>=15?15:e)+1>>>1|240;break f;case 14:l:{m:{n:{o:{p:{g=e>>>4&15;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}u[d+3|0]=2;u[d+5|0]=e|240;break f}u[d+3|0]=3;u[d+5|0]=e|240;break f}u[d+3|0]=11;u[d+5|0]=(e<<3&120)+8|15;break f}u[d+3|0]=11;u[d+5|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}e=(e&255)+1>>>1|0;u[d+5|0]=e>>>0>=64?64:e;break f}u[d+3|0]=0}en(j,h,n,m);if(gn(x[f+3|0])>>>0<=gn(x[d+3|0])>>>0){break e}q:{if(x[d+2|0]){break q}if(!fn(j,h,1)){break q}u[d+2|0]=x[d+3|0];u[d+4|0]=x[d+5|0]}u[d+3|0]=x[f+3|0];u[d+5|0]=x[f+5|0]}if((i|0)<0){continue}break}}if((l|0)>=0){continue}}break}k=k+1|0;if(k>>>0<z[a+12>>2]){continue}break}}jb=f+16|0}function Ey(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0;B=w[a+16>>2];D=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);p=w[a+128>>2];a:{if(!p){q=w[a+8>>2];s=w[a+12>>2];m=w[a>>2];n=w[a+4>>2];t=0;break a}n=w[a+4>>2];g=w[a+76>>2];m=w[a>>2];q=w[a+8>>2];s=w[a+12>>2];e=BV(q,s,d,0);h=m+e|0;b=nb+n|0;y=g>>>0<(e>>>0>h>>>0?b+1|0:b)>>>0?d:0;v=CV(q,s,p,p>>31);t=nb}h=w[a+48>>2];k=w[a+40>>2];l=w[a+36>>2];b=w[a+44>>2];b:{c:{if(!d){i=k>>12;f=l>>12;break c}j=a+112|0;E=(p|0)>0;g=h;while(1){h=b;y=y-1|0;b=y;v=b?v:0;t=b?t:0;e=0;i=m;x=n+B|0;b=p;d:{if(!E){break d}while(1){e:{f=u[e+x|0];w[114256]=0;T(604,j|0,f<<6);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,j|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+t|0;i=i+v|0;e=i>>>0<v>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}r=w[a+120>>2];b=r+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<r>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=u[e+x|0];w[114256]=0;T(604,j|0,e<<6);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,D|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}x=w[a+72>>2];i=w[a+32>>2];f=w[c>>2];e=w[a+60>>2];r=b<<8;b=r;b=BV(e,e>>31,b,b>>31);e=nb;z=b;b=w[a+64>>2];o=b;A=b>>31;b=(h|0)>=16776704?16776704:h;b=(b|0)<=-16777216?-16777216:b;o=BV(o,A,b,b>>31);b=z+o|0;e=nb+e|0;e=b>>>0<o>>>0?e+1|0:e;z=b;b=w[a+68>>2];o=b;A=b>>31;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(o,A,b,b>>31);b=z+g|0;e=nb+e|0;e=b>>>0<g>>>0?e+1|0:e;b=b+8388608|0;e=b>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|b>>>24;b=(e|0)/256|0;g=f;l=w[a+28>>2]+l|0;f=l>>12;w[c>>2]=g+C(b,f);k=i+k|0;i=k>>12;w[c+4>>2]=w[c+4>>2]+C(b,i);b=e-(x&r)|0;e=n+s|0;g=m+q|0;e=g>>>0<q>>>0?e+1|0:e;m=g;n=e;c=c+8|0;g=h;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=m;w[a+4>>2]=n;w[a+40>>2]=k;w[a+20>>2]=f;w[a+48>>2]=h;w[a+44>>2]=b;w[a+24>>2]=i;return}b=P()|0;w[a+40>>2]=k;w[a+36>>2]=l;w[a+48>>2]=g;w[a+44>>2]=h;w[a+20>>2]=l>>12;w[a+24>>2]=k>>12;R(b|0);M()}function uy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;d=b&5;a:{if(!(c&5)){if(!d){break a}f=Tb(Ed((+u[a+36|0]*128+ +u[a+37|0])*.0006510416666666666)*8363);d=-1;b:{if(f>=4294967295){break b}d=0;if(f<=0){break b}d=~~f>>>0;if(f<4294967296&f>=0){break b}d=0}v[a+36>>1]=0;w[a+24>>2]=d;if((b|0)!=1){break a}e=BV(d,0,8272,0)+4181|0;d=nb;i=a,j=EV(e,e>>>0<4181?d+1|0:d,8363,0),w[i+24>>2]=j;break a}if(d){break a}d=w[a+24>>2];if((c|0)==1){e=BV(d,0,8363,0)+4136|0;d=nb;d=EV(e,e>>>0<4136?d+1|0:d,8272,0);e=nb;d=!e&(d|0)==-1|e?-1:d;w[a+24>>2]=d}e=jb-16|0;jb=e;c:{if(!d){u[g+8|0]=0;u[g+9|0]=0;break c}h=e+8|0;f=Tb($h(+(d>>>0)*.00011957431543704412)*2215.9795828054475);d=16383;d:{if(!(f<2147483647)){break d}e:{if(!(f>-2147483648)){break e}if(E(f)<2147483648){d=~~f}else{d=-2147483648}if((d|0)<=-16385){break e}d=(d|0)>=16383?16383:d;break d}d=-16384}ku(h,d,128);d=w[e+8>>2];u[g+9|0]=w[e+12>>2];u[g+8|0]=d}jb=e+16|0;u[a+36|0]=x[g+8|0];u[a+37|0]=x[g+9|0]}if(c&3){v[a+38>>1]=0;v[a+40>>1]=0;u[a+36|0]=0;v[a+34>>1]=y[a+34>>1]&65499}if(c&7){v[a+32>>1]=64;d=y[a+34>>1];if(d&8){e=w[a+16>>2];w[a+4>>2]=w[a+12>>2];w[a+8>>2]=e;d=d&16?d|6:d&65529|2}w[a+12>>2]=0;w[a+16>>2]=0;v[a+34>>1]=d&65511}f:{g:{h:{d=c&4;if(d){e=y[a+34>>1];if(!(e&32)){v[a+28>>1]=128;v[a+34>>1]=e|32}if(x[a+40|0]>=16){u[a+40|0]=15}if(x[a+41|0]>=64){u[a+41|0]=63}if(c&16777248?b&4:0){break h}if(!d|!(b&16777248)){break f}if(x[a+41|0]){break g}break f}if(!(b&4)|!(c&16777248)){break f}if(x[a+41|0]){break g}break f}if(!x[a+41|0]){break f}}d=x[a+40|0];if(!d){break f}b=x[a+39|0];if(b){b=((d<<8|b>>>1)>>>0)/(b>>>0)|0;b=b>>>0>=255?255:b}else{b=255}u[a+39|0]=b}i:{j:{k:{l:{m:{if((c|0)!=4){if((c|0)==16777216){break i}if((c|0)!=32){break l}if(x[a+38|0]!=2){break m}u[a+38|0]=3;break m}if(x[a+38|0]!=4){break m}u[a+38|0]=0}b=y[a+34>>1]&-16385;v[a+34>>1]=b;break k}b=y[a+34>>1]&-16385;v[a+34>>1]=b;if(c&16777218){break j}}if(!(b&512)){break j}d=a+68|0;c=0;while(1){e=d+(c<<2)|0;c=c+1|0;w[e>>2]=c<<11;if((c|0)!=9){continue}break}v[a+34>>1]=b&48639;break i}if(!(b&512)|(c|0)!=2){break i}u[a+77|0]=x[a+77|0]&3;u[a+76|0]=x[a+76|0]&3}jb=g+16|0}function RP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb-80|0;jb=j;a:{b:{c:{k=Zh(1,32);d:{e:{if(!k){a=Ye(ba(4)|0);w[114256]=0;U(194,a|0,74720,68);a=w[114256];w[114256]=0;if((a|0)!=1){break a}k=W(0)|0;break e}w[k+12>>2]=f;w[k+8>>2]=e;w[k+4>>2]=d;w[k>>2]=c?c:1321;w[j+40>>2]=j+40|4;w[j+44>>2]=0;w[j+48>>2]=0;f:{g:{h:{i:{if(!i){break i}f=w[i>>2];if(!f){break i}while(1){j:{c=i;e=w[c+4>>2];if(e){w[114256]=0;d=Q(5,j+24|0,f|0)|0;f=w[114256];w[114256]=0;k:{if((f|0)!=1){w[114256]=0;w[j+64>>2]=d;ia(1329,j+72|0,j+40|0,d|0,36532,j- -64|0,j+56|0);f=w[114256];w[114256]=0;if((f|0)==1){break k}w[114256]=0;Q(260,w[j+72>>2]+28|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}if(u[j+35|0]>=0){break j}zb(w[d>>2]);break j}c=W(0)|0;break h}c=W(0)|0;if(u[j+35|0]>=0){break h}zb(w[d>>2]);break h}w[114256]=0;d=Q(5,j+8|0,f|0)|0;e=w[114256];w[114256]=0;l:{if((e|0)!=1){w[114256]=0;Q(1330,j+40|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[j+19|0]>=0){break j}zb(w[d>>2]);break j}c=W(0)|0;break h}c=W(0)|0;if(u[j+19|0]>=0){break h}zb(w[d>>2]);break h}i=c+8|0;f=w[c+8>>2];if(f){continue}break}}w[114256]=0;d=V(22,96)|0;c=w[114256];w[114256]=0;m:{if((c|0)!=1){w[114256]=0;c=Q(1331,k|0,k+4|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}w[114256]=0;a=da(1406,d|0,a|0,b|0,c|0,j+40|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break g}break m}c=W(0)|0;break h}c=W(0)|0;zb(d)}ke(j+40|0,w[j+44>>2]);$(c|0)|0;w[114256]=0;Y(1333,1480,k|0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){a=w[k+28>>2];if(a){ob[w[w[a>>2]+4>>2]](a)}w[k+24>>2]=0;w[k+28>>2]=0;a=w[k+20>>2];if(a){zb(a);w[k+20>>2]=0}zb(k);k=0;break d}k=W(0)|0;break e}w[k+28>>2]=a;w[k+24>>2]=a+8;ke(j+40|0,w[j+44>>2]);break d}k=W(0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break b}}$(k|0)|0;k=0;w[114256]=0;na(1314,1480,0,0,0,0,0,0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=j+80|0;return k|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}W(0)|0;Eb()}M()}function ng(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;i=w[a>>2];a:{if((i|0)==w[a+4>>2]){break a}j=w[b+4>>2];if(j>>>0>=z[a+12>>2]){break a}c=y[b+8>>1];f=(c|0)==65535;l=w[w[a+48>>2]+12>>2];e=y[l+480188>>1];if(!f&e>>>0<=c>>>0){break a}k=f?e-1|0:c;g=f?0:c;c=i+C(g+C(e,j)|0,6)|0;b:{e=x[b+12|0];c:{if(e&2){break c}j=k&65535;if(j>>>0<g>>>0){break c}m=e&4;i=x[b+10|0];f=g;d=c;while(1){d:{if(!m){if((i|0)!=x[d+3|0]){break d}break b}if((i|0)==x[d+2|0]){break b}}d=d+6|0;f=f+1|0;if(j>>>0>=(f&65535)>>>0){continue}break}}i=k&65535;if(i>>>0>=g>>>0){j=e&4;f=g;d=c;while(1){e:{if(!j){if(x[d+3|0]){break e}u[d+3|0]=x[b+10|0];u[d+5|0]=x[b+11|0];break b}if(x[d+2|0]){break e}u[d+2|0]=x[b+10|0];u[d+4|0]=x[b+11|0];break b}d=d+6|0;f=f+1|0;if(i>>>0>=(f&65535)>>>0){continue}break}}f:{if(!(e&1)){break f}f=w[l+480180>>2]&2;g:{if(e&4){break g}k=k&65535;if(k>>>0<g>>>0){break g}while(1){h:{i:{switch(x[c+3|0]-9|0){case 4:if(!rw(w[w[w[a+48>>2]+12>>2]+8>>2],1)){break h}d=1;u[c+2|0]=1;u[c+4|0]=x[c+5|0];u[c+3|0]=x[b+10|0];u[c+5|0]=x[b+11|0];break a;case 0:break i;default:break h}}j:{if(f){d=x[c+5|0];if(d>>>0>128){break h}u[c+2|0]=2;u[c+3|0]=x[b+10|0];a=1;break j}u[c+2|0]=2;u[c+3|0]=x[b+10|0];d=x[c+5|0];a=2}u[c+4|0]=a+d>>>a;u[c+5|0]=x[b+11|0];break b}c=c+6|0;g=g+1|0;if(k>>>0>=(g&65535)>>>0){continue}break}e=x[b+12|0]}k:{if(e&4){d=x[b+11|0];c=13;l:{switch(x[b+10|0]-1|0){case 1:c=C(f?2:4,d);d=c>>>0>=255?255:c;c=9;break;case 0:break l;default:break k}}u[b+11|0]=d;u[b+10|0]=c;e=e&254;u[b+12|0]=e;break k}c=x[b+11|0];u[h+14|0]=c;d=x[b+10|0];m:{n:{if(!(!f|(d|0)!=9)){if(c>>>0>128){break m}d=2;c=(c&254)>>>1|0;break n}u[h+15|0]=d;if(!fn(h+15|0,h+14|0,1)){break m}d=x[h+15|0];if(!d){break m}e=x[b+12|0];c=x[h+14|0]}u[b+11|0]=c;u[b+10|0]=d;u[b+12|0]=e&254}e=x[b+12|0]}d=1;if(e&1){break f}u[b+12|0]=e^4;if(ng(a,b)){break a}}d=0;o:{p:{switch(w[b>>2]-1|0){case 0:c=w[b+4>>2]+1|0;if(c>>>0>=z[a+12>>2]){break a}w[b+4>>2]=c;break o;case 1:break p;default:break a}}c=w[b+4>>2];if(!c){break a}w[b+4>>2]=c-1}u[b+12|0]=x[b+12|0]|1;d=ng(a,b);break a}d=1}jb=h+16|0;return d|0}function gz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=jb-32|0;a:{b:{c:{i=w[a+12>>2];n=w[a+8>>2];d:{if((i|0)<=1&n>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&n>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&n>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&n>>>0>2147483648|i>>>0>1){break b}}y=b+196648|0;break a}y=b+131112|0;break a}y=b+262184|0}A=w[a+16>>2];k=w[a+44>>2];w[f+12>>2]=k;o=w[a+48>>2];w[f+16>>2]=o;p=w[a+52>>2];w[f+20>>2]=p;e=w[a+56>>2];w[f+24>>2]=e;q=w[a>>2];l=w[a+4>>2];r=w[a+40>>2];s=w[a+36>>2];e:{if(!d){b=r>>12;m=s>>12;break e}B=w[a+32>>2];D=w[a+28>>2];E=w[a+72>>2];b=w[a+68>>2];F=b;G=b>>31;b=w[a+64>>2];H=b;I=b>>31;b=w[a+60>>2];J=b;K=b>>31;while(1){p=1;j=((((l&2147483647)<<1|q>>>31)&2147483646)<<1)+A|0;b=(q>>>16&65520)+y|0;L=v[b+14>>1];z=v[b+12>>1];g=v[b+10>>1];t=v[b+8>>1];h=v[b+6>>1];u=v[b+4>>1];x=v[b+2>>1];e=v[b>>1];k=0;o=1;m=0;while(1){b=m<<1;w[(m<<2)+f>>2]=(((((((C(v[j+(b|-8)>>1],x)+C(v[j+(b|-12)>>1],e)|0)+C(v[j+(b|-4)>>1],u)|0)+C(v[b+j>>1],h)|0)+C(v[j+(b|4)>>1],t)|0)+C(v[j+(b|8)>>1],g)|0)+C(v[j+(b|12)>>1],z)|0)+C(v[j+(b|16)>>1],L)|0)/32768;b=o&1;o=0;m=1;if(b){continue}break}while(1){g=(f+8|0)+(k<<3)|0;t=w[g+8>>2];h=w[g+4>>2];w[g+8>>2]=h;u=(k<<2)+f|0;x=w[u>>2]<<8;b=x;b=BV(J,K,b,b>>31);e=nb;z=g;g=b;b=(h|0)>=16776704?16776704:h;b=(b|0)<=-16777216?-16777216:b;b=BV(b,b>>31,H,I);h=g+b|0;g=nb+e|0;g=b>>>0>h>>>0?g+1|0:g;b=(t|0)>=16776704?16776704:t;b=(b|0)<=-16777216?-16777216:b;e=BV(b,b>>31,F,G);h=e+h|0;b=nb+g|0;b=e>>>0>h>>>0?b+1|0:b;e=h+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[z+4>>2]=b-(x&E);w[u>>2]=(b|0)/256;k=1;b=p&1;p=0;if(b){continue}break}s=s+D|0;m=s>>12;w[c>>2]=w[c>>2]+C(m,w[f>>2]);r=r+B|0;b=r>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[f+4>>2]);l=i+l|0;e=n+q|0;l=e>>>0<n>>>0?l+1|0:l;q=e;c=c+8|0;d=d-1|0;if(d){continue}break}e=w[f+24>>2];p=w[f+20>>2];o=w[f+16>>2];k=w[f+12>>2]}w[a+36>>2]=s;w[a>>2]=q;w[a+4>>2]=l;w[a+40>>2]=r;w[a+20>>2]=m;w[a+56>>2]=e;w[a+52>>2]=p;w[a+48>>2]=o;w[a+44>>2]=k;w[a+24>>2]=b}function Su(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;e=w[b+4>>2];a:{if(!e){break a}g=w[b>>2];d=e-1|0;h=x[g+d|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}w[b>>2]=g;w[b+4>>2]=d>>>0>e>>>0?e:d}d=82096;g=w[b+4>>2];h=g;e=w[b>>2];b:{c:{d:{e:{f:{g:{h:{while(1){i:{j=w[d>>2];if((ec(j)|0)==(g|0)){if(!g){break i}if(!Jb(j,e,g)){break i}}d=d+8|0;if((d|0)!=82200){continue}break h}break}if((d|0)!=82200){break g}}if(!h){b=ba(8)|0;w[114256]=0;a=Q(5,f+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break d}d=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}if(!c){break b}c=ba(8)|0;w[114256]=0;b=Q(1447,f|0,b|0)|0;a=w[114256];w[114256]=0;j:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;e=w[114256];w[114256]=0;if((e|0)!=1){w[f+24>>2]=w[a+8>>2];e=w[a+4>>2];w[f+16>>2]=w[a>>2];w[f+20>>2]=e;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(c,f+16|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break d}d=P()|0;if(u[f+27|0]<0){zb(w[f+16>>2])}if(u[b+11|0]>=0){break e}zb(w[b>>2]);break e}d=P()|0;if(u[b+11|0]>=0){break j}zb(w[b>>2]);break j}d=P()|0}ca(c|0);break e}if(w[d+4>>2]!=2){b=ba(8)|0;w[114256]=0;a=Q(5,f+16|0,7423)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break d}d=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}d=P()|0;ca(b|0);break e}k:{if((g|0)!=17){if((g|0)==24){break k}if(g){break b}b=ba(8)|0;w[114256]=0;a=Q(5,f+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break d}d=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}d=P()|0;ca(b|0);break e}if(!Jb(e,3971,17)){if(!x[a+28|0]){break c}i=65536/+z[w[a+24>>2]+480244>>2];break b}if(Jb(e,4023,17)){break b}if(!x[a+28|0]){break c}i=+z[w[a+24>>2]+480240>>2]*152587890625e-16;break b}if(Jb(e,4041,g)){break b}i=+z[w[a+24>>2]+480236>>2]*152587890625e-16;break b}d=P()|0;ca(b|0)}R(d|0)}M()}i=1}jb=f+32|0;return+i}function bO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb+-64|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+24>>2];w[114256]=0;c=V(1472,c+484344|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)==1){break c}w[114256]=0;T(918,a|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}j=a+8|0;d:{e:{f:{g:{while(1){c=w[b+24>>2];w[114256]=0;c=V(1472,c+484344|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}if(c>>>0<=i>>>0){break d}h:{c=w[b+24>>2];d=w[c+484344>>2]+C(i,52)|0;i:{if(u[d+47|0]>=0){w[e+16>>2]=w[d+44>>2];f=w[d+40>>2];w[e+8>>2]=w[d+36>>2];w[e+12>>2]=f;break i}c=w[d+40>>2];d=w[d+36>>2];w[114256]=0;U(76,e+8|0,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break h}c=w[b+24>>2]}c=w[c+1304496>>2];w[114256]=0;Y(229,e+24|0,0,c|0,e+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}c=w[a+4>>2];d=w[a+8>>2];j:{if(c>>>0<d>>>0){d=w[e+28>>2];w[c>>2]=w[e+24>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+32>>2];w[e+32>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;w[a+4>>2]=c+12;break j}f=w[a>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}M()}w[114256]=0;d=(d-f|0)/12|0;f=d<<1;g=Z(921,e+40|0,(d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,j|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}d=w[e+28>>2];c=w[e+48>>2];w[c>>2]=w[e+24>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+32>>2];w[e+32>>2]=0;w[e+24>>2]=0;w[e+28>>2]=0;h=w[e+48>>2]+12|0;w[e+48>>2]=h;f=w[e+44>>2];d=w[a+4>>2];c=w[a>>2];k:{if((d|0)==(c|0)){d=c;break k}while(1){d=d-12|0;h=w[d+4>>2];f=f-12|0;w[f>>2]=w[d>>2];w[f+4>>2]=h;w[f+8>>2]=w[d+8>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;f=w[e+44>>2]-12|0;w[e+44>>2]=f;if((c|0)!=(d|0)){continue}break}c=w[a+4>>2];h=w[e+48>>2];d=w[a>>2]}w[a>>2]=f;w[e+44>>2]=d;w[a+4>>2]=h;w[e+48>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+52>>2];w[e+52>>2]=c;w[g>>2]=d;sc(g);if(u[e+35|0]>=0){break j}zb(w[e+24>>2])}if(u[e+19|0]<0){zb(w[e+8>>2])}i=i+1|0;continue}break}d=P()|0;break a}d=P()|0;break e}d=P()|0;if(u[e+35|0]>=0){break e}zb(w[e+24>>2])}if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}jb=e- -64|0;return}d=P()|0;break a}d=P()|0}bc(a);R(d|0);M()}function kv(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb-80|0;jb=j;a:{b:{c:{d:{e:{f:{k=Zh(1,28);if(!k){a=Ye(ba(4)|0);w[114256]=0;U(194,a|0,74720,68);a=w[114256];w[114256]=0;if((a|0)!=1){break a}break f}w[k+12>>2]=f;w[k+8>>2]=e;w[k+4>>2]=d;w[k>>2]=c?c:1321;w[j+40>>2]=j+40|4;w[j+44>>2]=0;w[j+48>>2]=0;g:{h:{i:{j:{if(!i){break j}f=w[i>>2];if(!f){break j}while(1){k:{c=i;e=w[c+4>>2];if(e){w[114256]=0;d=Q(5,j+24|0,f|0)|0;f=w[114256];w[114256]=0;l:{if((f|0)!=1){w[114256]=0;w[j+64>>2]=d;ia(1329,j+72|0,j+40|0,d|0,36532,j- -64|0,j+56|0);f=w[114256];w[114256]=0;if((f|0)==1){break l}w[114256]=0;Q(260,w[j+72>>2]+28|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break l}if(u[j+35|0]>=0){break k}zb(w[d>>2]);break k}c=W(0)|0;break i}c=W(0)|0;if(u[j+35|0]>=0){break i}zb(w[d>>2]);break i}w[114256]=0;d=Q(5,j+8|0,f|0)|0;e=w[114256];w[114256]=0;m:{if((e|0)!=1){w[114256]=0;Q(1330,j+40|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break m}if(u[j+19|0]>=0){break k}zb(w[d>>2]);break k}c=W(0)|0;break i}c=W(0)|0;if(u[j+19|0]>=0){break i}zb(w[d>>2]);break i}i=c+8|0;f=w[c+8>>2];if(f){continue}break}}w[114256]=0;d=V(22,80)|0;c=w[114256];w[114256]=0;n:{if((c|0)!=1){w[114256]=0;c=Q(1331,k|0,k+4|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break n}w[114256]=0;a=da(1334,d|0,a|0,b|0,c|0,j+40|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break h}break n}c=W(0)|0;break i}c=W(0)|0;zb(d)}ke(j+40|0,w[j+44>>2]);$(c|0)|0;w[114256]=0;Y(1333,10637,k|0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break g}w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break f}a=w[k+24>>2];if(a){zb(kg(a))}i=0;w[k+24>>2]=0;a=w[k+20>>2];if(a){zb(a);w[k+20>>2]=0}zb(k);break d}w[k+24>>2]=a;ke(j+40|0,w[j+44>>2]);i=k;break d}c=W(0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){break e}break b}c=W(0)|0}$(c|0)|0;i=0;w[114256]=0;na(1314,10637,0,0,0,0,0,0,g|0,h|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=j+80|0;return i|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}W(0)|0;Eb()}M()}function hz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=jb-32|0;a:{b:{c:{i=w[a+12>>2];n=w[a+8>>2];d:{if((i|0)<=1&n>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&n>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&n>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&n>>>0>2147483648|i>>>0>1){break b}}y=b+196648|0;break a}y=b+131112|0;break a}y=b+262184|0}A=w[a+16>>2];l=w[a+44>>2];w[f+12>>2]=l;o=w[a+48>>2];w[f+16>>2]=o;p=w[a+52>>2];w[f+20>>2]=p;e=w[a+56>>2];w[f+24>>2]=e;q=w[a>>2];m=w[a+4>>2];r=w[a+40>>2];s=w[a+36>>2];e:{if(!d){b=r>>12;j=s>>12;break e}B=w[a+32>>2];D=w[a+28>>2];E=w[a+72>>2];b=w[a+68>>2];F=b;G=b>>31;b=w[a+64>>2];H=b;I=b>>31;b=w[a+60>>2];J=b;K=b>>31;while(1){k=(((m&2147483647)<<1|q>>>31)&-2)+A|0;b=(q>>>16&65520)+y|0;L=v[b+14>>1];M=v[b+12>>1];z=v[b+10>>1];g=v[b+8>>1];t=v[b+6>>1];h=v[b+4>>1];x=v[b+2>>1];j=v[b>>1];l=0;p=1;o=1;b=0;while(1){w[(b<<2)+f>>2]=(((((((C(u[k+(b|-4)|0],x)+C(u[k+(b|-6)|0],j)|0)+C(u[k+(b|-2)|0],h)|0)+C(u[b+k|0],t)|0)+C(u[k+(b|2)|0],g)|0)+C(u[k+(b|4)|0],z)|0)+C(u[k+(b|6)|0],M)|0)+C(L,u[k+(b|8)|0])<<8)/32768;e=o&1;o=0;b=1;if(e){continue}break}while(1){g=(f+8|0)+(l<<3)|0;t=w[g+8>>2];h=w[g+4>>2];w[g+8>>2]=h;x=(l<<2)+f|0;j=w[x>>2]<<8;b=j;b=BV(J,K,b,b>>31);e=nb;z=g;g=b;b=(h|0)>=16776704?16776704:h;b=(b|0)<=-16777216?-16777216:b;b=BV(b,b>>31,H,I);h=g+b|0;g=nb+e|0;g=b>>>0>h>>>0?g+1|0:g;b=(t|0)>=16776704?16776704:t;b=(b|0)<=-16777216?-16777216:b;e=BV(b,b>>31,F,G);h=e+h|0;b=nb+g|0;b=e>>>0>h>>>0?b+1|0:b;e=h+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[z+4>>2]=b-(j&E);w[x>>2]=(b|0)/256;l=1;b=p&1;p=0;if(b){continue}break}s=s+D|0;j=s>>12;w[c>>2]=w[c>>2]+C(j,w[f>>2]);r=r+B|0;b=r>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[f+4>>2]);m=i+m|0;e=n+q|0;m=e>>>0<n>>>0?m+1|0:m;q=e;c=c+8|0;d=d-1|0;if(d){continue}break}e=w[f+24>>2];p=w[f+20>>2];o=w[f+16>>2];l=w[f+12>>2]}w[a+36>>2]=s;w[a>>2]=q;w[a+4>>2]=m;w[a+40>>2]=r;w[a+20>>2]=j;w[a+56>>2]=e;w[a+52>>2]=p;w[a+48>>2]=o;w[a+44>>2]=l;w[a+24>>2]=b}function Js(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!Yf(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}jc(j+16|0,b,c,d,e,f,g,h,i);e=w[j+16>>2];d=w[j+20>>2];c=w[j+24>>2];b=w[j+28>>2];Ks(j,e,d,c,b,e,d,c,b);d=w[j+8>>2];e=w[j+12>>2];h=w[j>>2];i=w[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((Yf(b,c,l,p,f,g,h,k)|0)<=0){if(Yf(b,c,l,p,f,g,m,k)){h=b;i=c;break a}jc(j+112|0,b,c,d,e,0,0,0,0);d=w[j+120>>2];e=w[j+124>>2];h=w[j+112>>2];i=w[j+116>>2];break a}if(o){i=c;h=b}else{jc(j+96|0,b,c,l,p,0,0,0,1081540608);h=w[j+108>>2];p=h;l=w[j+104>>2];o=(h>>>16|0)-120|0;i=w[j+100>>2];h=w[j+96>>2]}if(!q){jc(j+80|0,f,g,m,k,0,0,0,1081540608);f=w[j+92>>2];k=f;m=w[j+88>>2];q=(k>>>16|0)-120|0;g=w[j+84>>2];f=w[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){jc(j+32|0,b,c,d,e,0,0,0,0);d=w[j+40>>2];e=w[j+44>>2];h=w[j+32>>2];i=w[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}jc(j+48|0,b,c,d,e,0,0,0,0);d=w[j+56>>2];e=w[j+60>>2];h=w[j+48>>2];i=w[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){jc(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=w[j+72>>2];e=w[j+76>>2];h=w[j+64>>2];i=w[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}w[a>>2]=h;w[a+4>>2]=i;w[a+8>>2]=d;w[a+12>>2]=e;jb=j+128|0}function wn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=jb-560|0;jb=g;a:{b:{if((b-256&65535)>>>0<65281){break b}e=((b<<2)+a|0)+900380|0;d=w[e>>2];c:{if(d){c=Eo(g,c);e=w[c+4>>2];w[d>>2]=w[c>>2];w[d+4>>2]=e;e=x[c+11|0]|x[c+12|0]<<8|(x[c+13|0]<<16|x[c+14|0]<<24);f=x[c+7|0]|x[c+8|0]<<8|(x[c+9|0]<<16|x[c+10|0]<<24);u[d+7|0]=f;u[d+8|0]=f>>>8;u[d+9|0]=f>>>16;u[d+10|0]=f>>>24;u[d+11|0]=e;u[d+12|0]=e>>>8;u[d+13|0]=e>>>16;u[d+14|0]=e>>>24;u[d+15|0]=x[c+15|0];e=w[c+44>>2];w[d+40>>2]=w[c+40>>2];w[d+44>>2]=e;e=w[c+36>>2];w[d+32>>2]=w[c+32>>2];w[d+36>>2]=e;e=w[c+28>>2];w[d+24>>2]=w[c+24>>2];w[d+28>>2]=e;e=w[c+20>>2];w[d+16>>2]=w[c+16>>2];w[d+20>>2]=e;e=w[d+48>>2];if(e){w[d+52>>2]=e;zb(e);w[d+56>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0}w[d+48>>2]=w[c+48>>2];w[d+52>>2]=w[c+52>>2];w[d+56>>2]=w[c+56>>2];e=0;w[c+56>>2]=0;w[c+48>>2]=0;w[c+52>>2]=0;u[d+60|0]=x[c+60|0];f=x[c+61|0]|x[c+62|0]<<8|(x[c+63|0]<<16|x[c+64|0]<<24);u[d+61|0]=f;u[d+62|0]=f>>>8;u[d+63|0]=f>>>16;u[d+64|0]=f>>>24;u[d+65|0]=x[c+65|0];f=w[d+68>>2];if(f){w[d+72>>2]=f;zb(f);w[d+76>>2]=0;w[d+68>>2]=0;w[d+72>>2]=0}w[d+68>>2]=w[c+68>>2];w[d+72>>2]=w[c+72>>2];w[d+76>>2]=w[c+76>>2];w[c+76>>2]=0;w[c+68>>2]=0;w[c+72>>2]=0;u[d+80|0]=x[c+80|0];f=x[c+81|0]|x[c+82|0]<<8|(x[c+83|0]<<16|x[c+84|0]<<24);u[d+81|0]=f;u[d+82|0]=f>>>8;u[d+83|0]=f>>>16;u[d+84|0]=f>>>24;u[d+85|0]=x[c+85|0];f=w[d+88>>2];if(f){w[d+92>>2]=f;zb(f);w[d+96>>2]=0;w[d+88>>2]=0;w[d+92>>2]=0;e=w[c+68>>2]}w[d+88>>2]=w[c+88>>2];w[d+92>>2]=w[c+92>>2];w[d+96>>2]=w[c+96>>2];w[c+96>>2]=0;w[c+88>>2]=0;w[c+92>>2]=0;u[d+100|0]=x[c+100|0];u[d+105|0]=x[c+105|0];f=x[c+101|0]|x[c+102|0]<<8|(x[c+103|0]<<16|x[c+104|0]<<24);u[d+101|0]=f;u[d+102|0]=f>>>8;u[d+103|0]=f>>>16;u[d+104|0]=f>>>24;Fb(d+108|0,c+108|0,448);if(e){w[c+72>>2]=e;zb(e)}e=w[c+48>>2];if(!e){break c}w[c+52>>2]=e;zb(e);break c}f=Gd(556);if(!f){d=0;w[e>>2]=0;break b}w[114256]=0;d=Q(839,f|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[e>>2]=d}c=a;a=y[a+480192>>1];v[c+480192>>1]=a>>>0>b>>>0?a:b}jb=g+560|0;return d|0}a=P()|0;zb(f);R(a|0);M()}function BB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;g=w[c+4>>2];e=w[a+4>>2];f=w[b+4>>2];c=w[c>>2];h=w[b>>2];b=(g+(e-f|0)|0)+(c-h<<3)|0;w[a+4>>2]=b;if(!((b-1^e-1)>>>0<32?e:0)){w[w[a>>2]+((b>>>0>=33?b-1>>>5|0:0)<<2)>>2]=0}a=w[a>>2]+(e>>>3&536870908)|0;b=e&31;a:{if((b|0)==(f|0)){w[d+28>>2]=f;w[d+24>>2]=h;w[d+20>>2]=g;w[d+16>>2]=c;w[d+12>>2]=f;w[d+8>>2]=a;b=w[d+28>>2];c=w[d+24>>2];a=(w[d+20>>2]-b|0)+(w[d+16>>2]-c<<3)|0;b:{if((a|0)<=0){b=w[d+8>>2];break b}if(b){f=32-b|0;e=(a|0)<(f|0)?a:f;g=w[d+8>>2];b=-1<<b&-1>>>f-e;w[g>>2]=w[g>>2]&(b^-1)|b&w[c>>2];b=e+w[d+12>>2]|0;w[d+12>>2]=b&31;w[d+8>>2]=g+(b>>>3&536870908);c=w[d+24>>2]+4|0;w[d+24>>2]=c;a=a-e|0}b=c;e=(a|0)/32|0;c=e<<2;hc(w[d+8>>2],b,c);b=c+w[d+8>>2]|0;w[d+8>>2]=b;a=a-(e<<5)|0;if((a|0)<=0){break b}c=c+w[d+24>>2]|0;w[d+24>>2]=c;b=w[d+8>>2];e=-1>>>32-a|0;w[b>>2]=w[b>>2]&(e^-1)|e&w[c>>2];w[d+12>>2]=a}w[d>>2]=b;w[d+4>>2]=w[d+12>>2];break a}w[d+28>>2]=f;w[d+24>>2]=h;w[d+20>>2]=g;w[d+16>>2]=c;w[d+12>>2]=b;w[d+8>>2]=a;a=w[d+28>>2];b=w[d+24>>2];c=(w[d+20>>2]-a|0)+(w[d+16>>2]-b<<3)|0;c:{if((c|0)<=0){a=w[d+12>>2];break c}d:{if(!a){a=w[d+12>>2];break d}e=w[d+12>>2];h=32-e|0;i=32-a|0;f=(c|0)<(i|0)?c:i;g=f>>>0>h>>>0?h:f;j=w[d+8>>2];k=w[j>>2]&(-1<<e&-1>>>h-g^-1);h=w[b>>2]&(-1<<a&-1>>>i-f);w[j>>2]=k|(a>>>0<e>>>0?h<<e-a:h>>>a-e|0);b=e+g|0;a=b&31;w[d+12>>2]=a;e=j+(b>>>3&536870908)|0;w[d+8>>2]=e;b=f-g|0;if((b|0)>0){w[e>>2]=w[e>>2]&(-1>>>32-b^-1)|h>>>g+w[d+28>>2];w[d+12>>2]=b;a=b}c=c-f|0;b=w[d+24>>2]+4|0;w[d+24>>2]=b}g=-1<<a;e=32-a|0;if((c|0)>=32){h=g^-1;while(1){f=w[d+8>>2];b=w[b>>2];w[f>>2]=h&w[f>>2]|b<<a;w[d+8>>2]=f+4;w[f+4>>2]=g&w[f+4>>2]|b>>>e;b=w[d+24>>2]+4|0;w[d+24>>2]=b;f=c>>>0>63;c=c-32|0;if(f){continue}break}}if((c|0)<=0){break c}f=w[d+8>>2];h=e;e=(c|0)>(e|0)?e:c;h=w[f>>2]&(g&-1>>>h-e^-1);g=w[b>>2]&-1>>>32-c;w[f>>2]=h|g<<a;b=a+e|0;a=b&31;w[d+12>>2]=a;f=f+(b>>>3&536870908)|0;w[d+8>>2]=f;b=c-e|0;if((b|0)<=0){break c}w[f>>2]=w[f>>2]&(-1>>>32-b^-1)|g>>>e;w[d+12>>2]=b;a=b}b=w[d+8>>2];w[d+4>>2]=a;w[d>>2]=b}jb=d+32|0}function Po(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-128|0;jb=g;a:{if(!x[83496]){if(!x[83372]){w[20837]=0;w[20838]=0;w[20842]=0;w[20839]=0;w[20840]=0;u[83364]=0;w[114256]=0;d=V(22,1)|0;a=w[114256];w[114256]=0;b:{c:{d:{e:{if((a|0)!=1){w[114256]=0;b=V(55,d|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){b=ja(74720,74672)|0;a=kb;zb(d);break e}Mk(b);u[83364]=0;e=0;break d}b=ja(74720,74672)|0;a=kb}if((fa(74720)|0)==(a|0)){$(b|0)|0;w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)==1){b=P()|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){break c}W(0)|0;Eb()}M()}if((fa(74672)|0)!=(a|0)){break c}$(b|0)|0;u[83364]=0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){b=P()|0;break c}e=x[83364]}if(e&255){break b}w[114256]=0;X(57,83344);a=w[114256];w[114256]=0;if((a|0)!=1){break b}b=P()|0}a=w[20842];w[20842]=0;if(a){zb(a)}Mk(0);if(u[83359]<0){zb(w[20837])}R(b|0);M()}u[83372]=1}c=jb+-64|0;jb=c;while(1){j=(c+16|0)+(h<<2)|0;f:{g:{h:{i:{a=w[20840];j:{if(a){w[114256]=0;a=V(64,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break j}a=W(74672)|0;if((kb|0)!=(fa(74672)|0)){break h}$(a|0)|0;a=0;u[83364]=0;w[114256]=0;X(57,83344);b=w[114256];w[114256]=0;if((b|0)==1){break i}aa();break j}a=0;u[83364]=0}if(!x[83364]){f=w[20842];b=w[f+2496>>2];e=w[((b+397>>>0)%624<<2)+f>>2];i=(b+1>>>0)%624|0;d=w[(i<<2)+f>>2];b=(b<<2)+f|0;d=e^(d&2147483646|w[b>>2]&-2147483648)>>>1^0-(d&1)&-1727483681;w[b>>2]=d;w[f+2496>>2]=i;e=a;a=d^d>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;a=e^(a>>>18^a)}break f}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break g}}R(a|0);M()}W(0)|0;Eb();M()}w[j>>2]=a;h=h+1|0;if((h|0)!=12){continue}break}w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[114256]=0;U(67,c|0,c+16|0,c- -64|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}w[114256]=0;b=g+8|0;T(66,b|0,c|0);a=w[114256];w[114256]=0;k:{if((a|0)!=1){w[b+112>>2]=0;a=w[c>>2];if(a){w[c+4>>2]=a;zb(a)}jb=c- -64|0;break k}break a}Fb(83376,b,116);u[83496]=1}jb=g+128|0;return 83376}a=P()|0;b=w[c>>2];if(b){w[c+4>>2]=b;zb(b)}R(a|0);M()}function Ru(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;h=w[c+4>>2];a:{if(!h){break a}g=w[c>>2];e=h-1|0;i=x[g+e|0];if((i|0)==33){d=1}else{if((i|0)!=63){break a}d=0}w[c>>2]=g;w[c+4>>2]=e>>>0>h>>>0?h:e}e=82096;g=w[c+4>>2];i=g;h=w[c>>2];b:{c:{d:{e:{f:{g:{while(1){h:{j=w[e>>2];if((ec(j)|0)==(g|0)){if(!g){break h}if(!Jb(j,h,g)){break h}}e=e+8|0;if((e|0)!=82200){continue}break g}break}if((e|0)!=82200){break f}}if(!i){b=ba(8)|0;w[114256]=0;a=Q(5,f+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}e=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}if(d){d=ba(8)|0;w[114256]=0;b=Q(1447,f|0,c|0)|0;a=w[114256];w[114256]=0;i:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[f+24>>2]=w[a+8>>2];c=w[a+4>>2];w[f+16>>2]=w[a>>2];w[f+20>>2]=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(d,f+16|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}e=P()|0;if(u[f+27|0]<0){zb(w[f+16>>2])}if(u[b+11|0]>=0){break c}zb(w[b>>2]);break c}e=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2]);break i}e=P()|0}ca(d|0);break c}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break e}j:{k:{if((g|0)!=11){if((g|0)==35){break k}if(g){break j}b=ba(8)|0;w[114256]=0;a=Q(5,f+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}e=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}e=P()|0;ca(b|0);break c}if(Jb(h,8127,11)){break j}l:{switch(w[b+52>>2]){case 0:Hb(a,2087);break e;case 1:Hb(a,7124);break e;case 2:Hb(a,5136);break e;default:break l}}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break e}if(Jb(h,7361,g)){break j}m:{switch(w[b+56>>2]){case 0:Hb(a,11534);break e;case 1:Hb(a,11539);break e;case 2:Hb(a,8386);break e;case 3:Hb(a,5200);break e;default:break m}}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break e}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0}jb=f+32|0;return}e=P()|0;ca(b|0)}R(e|0)}M()}function Vg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=jb-96|0;jb=c;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{b:{e=w[b+24>>2];if(w[e+484364>>2]-w[e+484360>>2]&8160){n=a+8|0;while(1){w[c+48>>2]=1;w[114256]=0;d=w[c+44>>2];w[c+16>>2]=w[c+40>>2];w[c+20>>2]=d;d=w[c+52>>2];w[c+24>>2]=w[c+48>>2];w[c+28>>2]=d;u[c+38|0]=k;v[c+36>>1]=0;w[c+32>>2]=0;d=w[c+36>>2];w[c+8>>2]=w[c+32>>2];w[c+12>>2]=d;Y(1441,c+56|0,e|0,0,c+8|0);e=w[114256];w[114256]=0;c:{d:{e:{if((e|0)!=1){e=w[c+56>>2];l=w[c+60>>2];if((e|0)==(l|0)){break c}while(1){f:{g=y[e+24>>1];i=w[e+16>>2];m=B[e>>3];d=w[a+4>>2];f=w[a+8>>2];g:{if(d>>>0<f>>>0){w[d+16>>2]=k;w[d+12>>2]=g;w[d+8>>2]=i;B[d>>3]=m;w[a+4>>2]=d+24;break g}h=w[a>>2];j=(d-h|0)/24|0;d=j+1|0;if(d>>>0>=178956971){w[114256]=0;X(1442,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}break b}w[114256]=0;f=(f-h|0)/24|0;h=f<<1;d=Z(1443,c+72|0,(f>>>0>=89478485?178956970:d>>>0<h>>>0?h:d)|0,j|0,n|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}f=w[c+80>>2];w[f+16>>2]=k;w[f+12>>2]=g;w[f+8>>2]=i;B[f>>3]=m;i=f+24|0;w[c+80>>2]=i;h=w[a+4>>2];f=w[a>>2];j=h-f|0;g=w[c+76>>2]+C((j|0)/-24|0,24)|0;w[c+76>>2]=g;if((j|0)>0){Fb(g,f,j);h=w[a+4>>2];i=w[c+80>>2];g=w[c+76>>2];f=w[a>>2]}w[a>>2]=g;w[c+76>>2]=f;w[a+4>>2]=i;w[c+80>>2]=h;g=w[a+8>>2];w[a+8>>2]=w[c+84>>2];w[c+84>>2]=g;w[d>>2]=f;f=w[d+8>>2];g=w[d+4>>2];if((f|0)!=(g|0)){g=(f-g|0)-24|0;w[d+8>>2]=(f+(((g>>>0)%24|0)-g|0)|0)-24}d=w[d>>2];if(d){zb(d)}}e=e+32|0;if((l|0)!=(e|0)){continue}break d}break}e=P()|0;b=w[c+56>>2];if(!b){break e}w[c+60>>2]=b;zb(b);break e}e=P()|0}b=w[a>>2];if(!b){break a}w[a+4>>2]=b;zb(b);break a}e=w[c+56>>2]}if(e){w[c+60>>2]=e;zb(e)}k=k+1|0;e=w[b+24>>2];if(k>>>0<(w[e+484364>>2]-w[e+484360>>2]>>>5&255)>>>0){continue}break}jb=c+96|0;return}b=ba(8)|0;w[114256]=0;a=Q(5,c+72|0,3534)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}e=P()|0;if(u[a+11|0]>=0){break a}zb(w[a>>2]);break a}e=P()|0;ca(b|0);break a}M()}R(e|0);M()}function Hy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;y=w[a+16>>2];z=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];q=w[a+12>>2];k=w[a>>2];l=w[a+4>>2];r=0;break a}l=w[a+4>>2];f=w[a+76>>2];k=w[a>>2];o=w[a+8>>2];q=w[a+12>>2];e=BV(o,q,d,0);i=k+e|0;b=nb+l|0;t=f>>>0<(e>>>0>i>>>0?b+1|0:b)>>>0?d:0;s=CV(o,q,n,n>>31);r=nb}g=w[a+48>>2];b=w[a+44>>2];b:{c:{if(!d){i=g;break c}j=a+112|0;A=w[a+24>>2];B=w[a+20>>2];D=(n|0)>0;while(1){i=b;t=t-1|0;b=t;s=b?s:0;r=b?r:0;e=0;p=k;m=(l<<1)+y|0;b=n;d:{if(!D){break d}while(1){e:{f=v[(e<<1)+m>>1];w[114256]=0;T(604,j|0,(f|0)/4<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,j|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+r|0;p=p+s|0;e=p>>>0<s>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}h=w[a+120>>2];b=h+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<h>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=v[(e<<1)+m>>1];w[114256]=0;T(604,j|0,(e|0)/4<<16>>16);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,z|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}p=w[a+72>>2];e=w[c>>2];f=w[a+60>>2];u=f;h=f>>31;f=b<<8;b=f;b=BV(u,h,b,b>>31);m=nb;u=e;e=b;b=w[a+64>>2];h=b;x=b>>31;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;h=BV(h,x,b,b>>31);b=e+h|0;e=nb+m|0;e=b>>>0<h>>>0?e+1|0:e;h=b;b=w[a+68>>2];m=b;x=b>>31;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(m,x,b,b>>31);b=h+g|0;e=nb+e|0;e=b>>>0<g>>>0?e+1|0:e;b=b+8388608|0;e=b>>>0<8388608?e+1|0:e;b=(e&16777215)<<8|b>>>24;e=(b|0)/256|0;w[c>>2]=u+C(e,B);w[c+4>>2]=w[c+4>>2]+C(e,A);b=b-(f&p)|0;e=l+q|0;g=k+o|0;e=g>>>0<o>>>0?e+1|0:e;k=g;l=e;c=c+8|0;g=i;d=d-1|0;if(d){continue}break}}w[a+48>>2]=i;w[a+44>>2]=b;w[a>>2]=k;w[a+4>>2]=l;return}b=P()|0;w[a+48>>2]=g;w[a+44>>2]=i;R(b|0);M()}function No(a,b,c){var d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{switch(b|0){case 0:w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;e=x[c+11|0];b=e<<24>>24<0;e=b?w[c+4>>2]:e;if(!e){break e}b=b?w[c>>2]:c;g=e+b|0;e=0;while(1){c=x[b|0];g:{h:{if(!d){if(c<<24>>24>=0){d=0;w[114256]=0;T(69,a|0,c|0);c=w[114256];w[114256]=0;if((c|0)!=1){break g}break c}if((c&224)==192){e=c&31;d=1;break g}if((c&240)==224){e=c&15;d=2;break g}f=65533;if((c&248)!=240){break h}e=c&7;d=3;break g}if((c&192)!=128){w[114256]=0;T(69,a|0,65533);d=w[114256];w[114256]=0;if((d|0)==1){break c}e=c&63;d=-1;break g}f=c&63|e<<6;e=f;d=d-1|0;if(d){break g}}e=0;w[114256]=0;T(69,a|0,f|0);c=w[114256];w[114256]=0;d=0;if((c|0)==1){break c}}b=b+1|0;if((g|0)!=(b|0)){continue}break};if(!d){break e}w[114256]=0;T(69,a|0,65533);b=w[114256];w[114256]=0;if((b|0)!=1){break e}break c;case 1:w[a>>2]=0;w[a+4>>2]=0;b=0;w[a+8>>2]=0;e=w[c+4>>2];d=x[c+11|0];w[114256]=0;T(70,a|0,(d<<24>>24<0?e:d)|0);d=w[114256];w[114256]=0;if((d|0)!=1){i:{e=x[c+11|0];d=e<<24>>24<0;if(!(d?w[c+4>>2]:e)){break e}while(1){d=x[(d&1?w[c>>2]:c)+b|0];w[114256]=0;T(69,a|0,(d<<24>>24<0?65533:d)|0);d=w[114256];w[114256]=0;if((d|0)==1){break i}e=x[c+11|0];d=e<<24>>24<0;b=b+1|0;if(b>>>0<(d?w[c+4>>2]:e)>>>0){continue}break}break e}}c=P()|0;if(u[a+11|0]<0){break b}break a;case 2:w[a>>2]=0;w[a+4>>2]=0;b=0;w[a+8>>2]=0;e=w[c+4>>2];d=x[c+11|0];w[114256]=0;T(70,a|0,(d<<24>>24<0?e:d)|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}e=x[c+11|0];d=e<<24>>24<0;if(!(d?w[c+4>>2]:e)){break e}while(1){j:{d=x[(d&1?w[c>>2]:c)+b|0];w[114256]=0;T(69,a|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break j}e=x[c+11|0];d=e<<24>>24<0;b=b+1|0;if(b>>>0<(d?w[c+4>>2]:e)>>>0){continue}break e}break};break d;case 3:qh(a,c,17472);return;case 4:qh(a,c,18496);return;case 5:qh(a,c,19520);return;case 6:qh(a,c,20544);return;case 7:qh(a,c,21568);return;default:break f}}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0}return}c=P()|0;if(u[a+11|0]<0){break b}break a}c=P()|0;if(u[a+11|0]>=0){break a}}zb(w[a>>2])}R(c|0);M()}function og(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=w[b+88>>2];w[b+88>>2]=d|524288;g=w[a+480208>>2];a:{b:{if(!(g&8)){if(x[a+1074313|0]&128|w[a+480180>>2]==268435456){break b}break a}if(w[a+480180>>2]!=268435456){break a}}c=c?c:x[b+831|0];u[b+832|0]=c;u[b+831|0]=c}if(c){w[b+776>>2]=c}c:{d:{e:{c=w[b+656>>2];if(!c){break e}h=w[c+44>>2];if(!h){break e}c=w[b+776>>2];if(!c){break d}e=w[a+1074392>>2];f=w[b+708>>2];if(!(!((c|0)<0&(f|0)>0)&((c|0)<=0|(f|0)>=0))){c=0-c|0;w[b+776>>2]=c}g=w[b+880>>2];j=(+(e>>>0)+1)*+(c|0)/+z[a+1074416>>2];f:{if(E(j)<2147483648){a=~~j;break f}a=-2147483648}w[b+880>>2]=a;if(d&1048576){a=C(w[h+36>>2]+1|0,a);w[b+880>>2]=a}a=a-(e?g:0)|0;c=a>>31;e=f>>31;if((e^f)-e>>>0<=(a^c)-c>>>0){if(!f){break d}w[b+708>>2]=0;w[b+876>>2]=f+w[b+876>>2];break c}w[b+708>>2]=f-a;w[b+876>>2]=a+w[b+876>>2];break c}h=u[b+872|0]&1;e=w[a+480180>>2];d=1;g:{if(!h|e&524352|(x[a+1074312|0]&64?w[a+1074416>>2]==1:0)){break g}d=0;if((e|0)!=8){break g}e=8;d=(g&2)>>>1|0}c=w[b+700>>2];h:{if(!c){f=w[b+708>>2];c=0;break h}f=w[b+708>>2];if(!f){break h}k=h;i=d;d=w[b+776>>2];h=(e|0)==268435456&(d|0)>239;if(!(h?k:i)){break h}d=h?d-240|0:d;d=(e|0)==64?C(d,10):d;i:{if((c|0)<(f|0)){j:{if(!(!(g&16)|(e|0)==4)){e=w[((d>>>0>=255?255:d)<<2)+30256>>2];d=BV(e,e>>31,c,c>>31)+32768|0;e=nb;d=CV(d,d>>>0<32768?e+1|0:e,65536,0);i=d;e=nb;d=(e|0)>=0&d>>>0>=2147483647|(e|0)>0;g=d?2147483647:i;e=d?0:e;e=((e|0)<0&g>>>0<=2147483648|(e|0)<-1?-2147483648:g)-c|0;d=(e|0)<=1?1:e;break j}d=d<<2}c=d+c|0;c=(c|0)<(f|0)?c:f;break i}if((c|0)<=(f|0)){break h}k:{if(!(!(g&16)|(e|0)==4)){e=w[((d>>>0>=255?255:d)<<2)+31280>>2];d=BV(e,e>>31,c,c>>31)+32768|0;e=nb;d=CV(d,d>>>0<32768?e+1|0:e,65536,0);i=d;e=nb;d=(e|0)>=0&d>>>0>=2147483647|(e|0)>0;g=d?2147483647:i;e=d?0:e;e=((e|0)<0&g>>>0<=2147483648|(e|0)<-1?-2147483648:g)-c|0;d=(e|0)>=-1?-1:e;break k}d=0-(d<<2)|0}c=d+c|0;c=(c|0)>(f|0)?c:f}w[b+700>>2]=c}if(!(x[a+1074315|0]&2)&w[a+480180>>2]!=1|(c|0)!=(f|0)){break d}w[b+708>>2]=0}return}u[b+872|0]=x[b+872|0]|16}function NI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-1072|0;jb=j;w[j+16>>2]=f;w[j+20>>2]=g;w[j+24>>2]=h;w[j+28>>2]=i;a=j+960|0;w[j+956>>2]=a;k=$l(a,100,6990,j+16|0);w[j+48>>2]=1708;a=j+48|0;n=vc(j+536|0,0,a);w[j+48>>2]=1708;l=vc(j+528|0,0,a);m=j+544|0;a:{b:{c:{d:{if(k>>>0>=100){w[114256]=0;a=ea(1732)|0;k=w[114256];w[114256]=0;if((k|0)==1){break d}w[j>>2]=f;w[j+4>>2]=g;w[114256]=0;w[j+8>>2]=h;w[j+12>>2]=i;k=Z(1753,j+956|0,a|0,6990,j|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){Hc(n,w[j+956>>2]);Hc(l,fc(k<<2));if(!qf(l)){break e}}w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break a}m=w[l>>2]}w[114256]=0;Sb(j+520|0,d);a=w[114256];w[114256]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){w[114256]=0;p=V(1735,j+520|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break k}w[114256]=0;a=w[j+956>>2];Z(1749,p|0,a|0,a+k|0,m|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break k}o=(k|0)>0?x[w[j+956>>2]]==45:o;h=Wb(j+488|0);f=Wb(j+472|0);g=Wb(j+456|0);w[114256]=0;oa(1789,c|0,o|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);a=w[114256];w[114256]=0;if((a|0)==1){break j}w[j+36>>2]=1708;i=vc(j+40|0,0,j+36|0);c=j+48|0;a=w[j+452>>2];l:{if((a|0)<(k|0)){a=(((Db(g)+(k-a<<1)|0)+Db(f)|0)+w[j+452>>2]|0)+1|0;break l}a=((Db(g)+Db(f)|0)+w[j+452>>2]|0)+2|0}if(a>>>0<101){break i}Hc(i,fc(a<<2));c=w[i>>2];if(c){break i}w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break a}break h}k=P()|0;break b}k=P()|0;break f}k=P()|0;break g}a=w[d+4>>2];w[114256]=0;ta(1790,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,p|0,o|0,j+512|0,w[j+508>>2],w[j+504>>2],h|0,f|0,g|0,w[j+452>>2]);a=w[114256];w[114256]=0;if((a|0)!=1){w[114256]=0;a=la(1765,b|0,c|0,w[j+36>>2],w[j+32>>2],d|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}}}k=P()|0;Ub(i)}$b(g);$b(f);Gb(h)}Ab(j+520|0);break b}k=P()|0;break b}Ub(i);$b(g);$b(f);Gb(h);Ab(j+520|0);Ub(l);Ub(n);jb=j+1072|0;return a|0}Ub(l);Ub(n);R(k|0);M()}M()}function Vb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;d=d-(((b|0)==1|(b|0)==4)&(d|0)!=0)|0;a:{b:{c:{d:{if((b-1&255)>>>0<=1){b=c;e:{if(!d){break e}d=c+d|0;while(1){if(!x[b|0]){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}w[114256]=0;S(75,a|0,c|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;break d}if((b-3&255)>>>0>1){break a}w[114256]=0;S(75,a|0,c|0,c+d|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){d=x[a+11|0];b=d<<24>>24;c=(b|0)<0;d=c?w[a+4>>2]:d;if(d){b=c?w[a>>2]:a;c=d+b|0;while(1){d=x[b|0];u[b|0]=d?d:32;b=b+1|0;if((c|0)!=(b|0)){continue}break}b=x[a+11|0]}f:{g:{if(b<<24>>24>=0){w[e+24>>2]=w[a+8>>2];b=w[a+4>>2];w[e+16>>2]=w[a>>2];w[e+20>>2]=b;break g}b=w[a+4>>2];c=w[a>>2];w[114256]=0;U(76,e+16|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}}w[114256]=0;f=Q(5,e|0,13546)|0;b=w[114256];w[114256]=0;h:{if((b|0)!=1){c=x[f+11|0];b=c<<24>>24<0;d=b?w[f+4>>2]:c;i=b?w[f>>2]:f;b=x[e+27|0];g=b<<24>>24<0;c=g?w[e+16>>2]:e+16|0;h=g?w[e+20>>2]:b;g=c+h|0;b=g;i:{while(1){if((b|0)==(c|0)){break i}b=b-1|0;if(d){if(uc(i,x[b|0],d)){continue}}break}b=b-c|0;if((b|0)==-1){break i}w[114256]=0;b=(b+c|0)+1|0;S(77,e+16|0,b-c|0,g-b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}b=P()|0;if(u[f+11|0]>=0){break h}zb(w[f>>2]);break h}if(!h|!d){break c}h=d+i|0;d=c;while(1){j=x[d|0];b=i;j:{while(1){if(x[b|0]!=(j|0)){b=b+1|0;if((h|0)!=(b|0)){continue}break j}break}if((d|0)==(g|0)){break c}b=e+32|0;if((c|0)==(d|0)){break b}break c}d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}b=P()|0}if(u[e+27|0]>=0){break d}zb(w[e+16>>2]);break d}b=P()|0;break d}b=P()|0}if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}w[e+40>>2]=w[e+24>>2];b=w[e+20>>2];w[e+32>>2]=w[e+16>>2];w[e+36>>2]=b;b=e+16|0}w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;if(u[a+11|0]<0){zb(w[a>>2])}b=w[e+36>>2];w[a>>2]=w[e+32>>2];w[a+4>>2]=b;w[a+8>>2]=w[e+40>>2];if(u[f+11|0]<0){zb(w[f>>2])}if(u[e+27|0]>=0){break a}zb(w[e+16>>2])}jb=e+48|0}function Zl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=w[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=w[d>>2];if(!g){break l}if(!a){d=c;break j}w[d>>2]=0;d=c;break k}m:{if(!w[w[114126]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=u[e|0];if(d){w[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}w[a>>2]=0;w[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return ec(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=x[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((x[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((x[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=x[e|0];o:{if(e&3|g-1>>>0>126){break o}g=w[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=w[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=w[(f<<2)+61280>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=x[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=w[e>>2];if((g|g-16843009)&-2139062144){break s}w[a>>2]=g&255;w[a+4>>2]=x[e+1|0];w[a+8>>2]=x[e+2|0];w[a+12>>2]=x[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=x[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}w[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=w[(f<<2)+61280>>2];f=1;continue}i=x[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=x[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=x[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;w[a>>2]=f;d=d-1|0;a=a+4|0;break t}w[114084]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=x[e|0]}if(g&255){break d}if(a){w[a>>2]=0;w[b>>2]=0}return c-d|0}w[114084]=25;if(!a){break b}}w[b>>2]=e}return-1}w[b>>2]=e;return c|0}function Iy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0;y=w[a+16>>2];z=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];q=w[a+12>>2];k=w[a>>2];l=w[a+4>>2];r=0;break a}l=w[a+4>>2];f=w[a+76>>2];k=w[a>>2];o=w[a+8>>2];q=w[a+12>>2];e=BV(o,q,d,0);i=k+e|0;b=nb+l|0;t=f>>>0<(e>>>0>i>>>0?b+1|0:b)>>>0?d:0;s=CV(o,q,n,n>>31);r=nb}g=w[a+48>>2];b=w[a+44>>2];b:{c:{if(!d){i=g;break c}j=a+112|0;A=w[a+24>>2];B=w[a+20>>2];D=(n|0)>0;while(1){i=b;t=t-1|0;b=t;s=b?s:0;r=b?r:0;e=0;p=k;m=l+y|0;b=n;d:{if(!D){break d}while(1){e:{f=u[e+m|0];w[114256]=0;T(604,j|0,f<<6);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,j|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+r|0;p=p+s|0;e=p>>>0<s>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}h=w[a+120>>2];b=h+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<h>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=u[e+m|0];w[114256]=0;T(604,j|0,e<<6);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,j|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[j>>2]=w[j>>2];w[j+4>>2]=0}w[114256]=0;b=Q(606,j|0,z|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}p=w[a+72>>2];e=w[c>>2];f=w[a+60>>2];v=f;h=f>>31;f=b<<8;b=f;b=BV(v,h,b,b>>31);m=nb;v=e;e=b;b=w[a+64>>2];h=b;x=b>>31;b=(i|0)>=16776704?16776704:i;b=(b|0)<=-16777216?-16777216:b;h=BV(h,x,b,b>>31);b=e+h|0;e=nb+m|0;e=b>>>0<h>>>0?e+1|0:e;h=b;b=w[a+68>>2];m=b;x=b>>31;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(m,x,b,b>>31);b=h+g|0;e=nb+e|0;e=b>>>0<g>>>0?e+1|0:e;b=b+8388608|0;e=b>>>0<8388608?e+1|0:e;b=(e&16777215)<<8|b>>>24;e=(b|0)/256|0;w[c>>2]=v+C(e,B);w[c+4>>2]=w[c+4>>2]+C(e,A);b=b-(f&p)|0;e=l+q|0;g=k+o|0;e=g>>>0<o>>>0?e+1|0:e;k=g;l=e;c=c+8|0;g=i;d=d-1|0;if(d){continue}break}}w[a+48>>2]=i;w[a+44>>2]=b;w[a>>2]=k;w[a+4>>2]=l;return}b=P()|0;w[a+48>>2]=g;w[a+44>>2]=i;R(b|0);M()}function RI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-464|0;jb=j;w[j+16>>2]=f;w[j+20>>2]=g;w[j+24>>2]=h;w[j+28>>2]=i;a=j+352|0;w[j+348>>2]=a;k=$l(a,100,6990,j+16|0);w[j+48>>2]=1708;a=j+48|0;n=vc(j+232|0,0,a);w[j+48>>2]=1708;l=vc(j+224|0,0,a);m=j+240|0;a:{b:{c:{d:{if(k>>>0>=100){w[114256]=0;a=ea(1732)|0;k=w[114256];w[114256]=0;if((k|0)==1){break d}w[j>>2]=f;w[j+4>>2]=g;w[114256]=0;w[j+8>>2]=h;w[j+12>>2]=i;k=Z(1753,j+348|0,a|0,6990,j|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){Hc(n,w[j+348>>2]);Hc(l,fc(k));if(!qf(l)){break e}}w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break a}m=w[l>>2]}w[114256]=0;Sb(j+216|0,d);a=w[114256];w[114256]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){w[114256]=0;p=V(1561,j+216|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break k}w[114256]=0;a=w[j+348>>2];Z(1728,p|0,a|0,a+k|0,m|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break k}o=(k|0)>0?x[w[j+348>>2]]==45:o;h=Wb(j+192|0);f=Wb(j+176|0);g=Wb(j+160|0);w[114256]=0;oa(1787,c|0,o|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);a=w[114256];w[114256]=0;if((a|0)==1){break j}w[j+36>>2]=1708;i=vc(j+40|0,0,j+36|0);c=j+48|0;a=w[j+156>>2];l:{if((a|0)<(k|0)){a=(((Db(g)+(k-a<<1)|0)+Db(f)|0)+w[j+156>>2]|0)+1|0;break l}a=((Db(g)+Db(f)|0)+w[j+156>>2]|0)+2|0}if(a>>>0<101){break i}Hc(i,fc(a));c=w[i>>2];if(c){break i}w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break a}break h}k=P()|0;break b}k=P()|0;break f}k=P()|0;break g}a=w[d+4>>2];w[114256]=0;ta(1788,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,p|0,o|0,j+208|0,u[j+207|0],u[j+206|0],h|0,f|0,g|0,w[j+156>>2]);a=w[114256];w[114256]=0;if((a|0)!=1){w[114256]=0;a=la(15,b|0,c|0,w[j+36>>2],w[j+32>>2],d|0,e|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}}}k=P()|0;Ub(i)}Gb(g);Gb(f);Gb(h)}Ab(j+216|0);break b}k=P()|0;break b}Ub(i);Gb(g);Gb(f);Gb(h);Ab(j+216|0);Ub(l);Ub(n);jb=j+464|0;return a|0}Ub(l);Ub(n);R(k|0);M()}M()}function Tu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;f=w[b+4>>2];a:{if(!f){break a}g=w[b>>2];d=f-1|0;h=x[g+d|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}w[b>>2]=g;w[b+4>>2]=d>>>0>f>>>0?f:d}d=82096;g=w[b+4>>2];h=g;f=w[b>>2];b:{c:{d:{e:{f:{g:{while(1){h:{i=w[d>>2];if((ec(i)|0)==(g|0)){if(!g){break h}if(!Jb(i,f,g)){break h}}d=d+8|0;if((d|0)!=82200){continue}break g}break}if((d|0)!=82200){break f}}if(!h){b=ba(8)|0;w[114256]=0;a=Q(5,e+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=0;h=0;if(!c){break e}c=ba(8)|0;w[114256]=0;b=Q(1447,e|0,b|0)|0;a=w[114256];w[114256]=0;i:{if((a|0)!=1){w[114256]=0;a=S(1436,b|0,0,13399)|0;f=w[114256];w[114256]=0;if((f|0)!=1){w[e+24>>2]=w[a+8>>2];f=w[a+4>>2];w[e+16>>2]=w[a>>2];w[e+20>>2]=f;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a=Pb(c,e+16|0);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break b}d=P()|0;if(u[e+27|0]<0){zb(w[e+16>>2])}if(u[b+11|0]>=0){break c}zb(w[b>>2]);break c}d=P()|0;if(u[b+11|0]>=0){break i}zb(w[b>>2]);break i}d=P()|0}ca(c|0);break c}if(w[d+4>>2]!=1){b=ba(8)|0;w[114256]=0;a=Q(5,e+16|0,7423)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=P()|0;ca(b|0);break c}d=0;h=0;j:{switch(g-6|0){default:if(g){break e}b=ba(8)|0;w[114256]=0;a=Q(5,e+16|0,6422)|0;c=w[114256];w[114256]=0;if((c|0)!=1){b=Pb(b,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break b}d=P()|0;if(u[a+11|0]>=0){break c}zb(w[a>>2]);break c}d=P()|0;ca(b|0);break c;case 1:if(Jb(f,6873,7)){break e}a=w[a+8>>2];d=a;h=a>>31;break e;case 0:break j}}if(Jb(f,4783,g)){break e}a=w[w[a+32>>2]+40>>2];d=a;h=a>>31}jb=e+32|0;nb=h;return d|0}d=P()|0;ca(b|0)}R(d|0)}M()}function bT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=D(0),f=D(0),g=0,h=0,i=0,j=0,k=0,l=0,m=D(0),n=0,o=D(0),p=D(0),q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,B=0,C=D(0),F=0,G=D(0),H=0,I=D(0);a:{if(!w[a+4276>>2]){break a}q=w[a+56>>2];r=w[a+44>>2];if((0-(w[a+60>>2]-q>>11)|0)==w[a+48>>2]-r>>11){break a}F=ob[w[w[a>>2]+188>>2]](a)|0;f=D(ob[w[w[a>>2]+196>>2]](a));C=D(ob[w[w[a>>2]+184>>2]](a));s=ob[w[w[a>>2]+208>>2]](a)|0;if(d){G=D(f*D(.009999999776482582));H=s&1;t=r+2048|0;u=q+2048|0;v=w[a+4292>>2];i=w[a+4288>>2];k=w[a+4284>>2];g=w[a+4280>>2];j=w[a+4272>>2];n=w[a+4260>>2];x=w[a+4256>>2];y=d;while(1){h=w[a+4276>>2];l=h<<12;z=((((l&j>>31)+j|0)/4096|0)%(h|0)<<2)+n|0;B=l;l=j+x|0;o=A[t>>2];p=A[r>>2];A[z>>2]=D(G*A[((((B&l>>31)+l|0)/4096|0)%(h|0)<<2)+n>>2])+D(D(o+p)*D(.5));b:{if(F){e=A[a+4244>>2];f=D(A[a+4236>>2]+e);A[a+4236>>2]=f;e=D(e+A[a+4240>>2]);A[a+4240>>2]=e;if(!(f<=D(1))){f=D(f+D(-2));A[a+4236>>2]=f}if(!(e<=D(1))){e=D(e+D(-2));A[a+4240>>2]=e}e=D(E(e));e=D(D(e+e)+D(-1));f=D(E(f));f=D(D(f+f)+D(-1));break b}e=A[a+4244>>2];m=A[a+4240>>2];f=D(D(e*m)+A[a+4236>>2]);A[a+4236>>2]=f;e=D(m-D(f*e));A[a+4240>>2]=e}h=g+j|0;B=h;z=h>>31;h=w[a+4276>>2];l=h<<12;m=A[(((B+(z&l)|0)/4096|0)%(h|0)<<2)+n>>2];I=D(D(g&4095)*D(.000244140625));g=j+k|0;A[q>>2]=D(D(D(m-p)+D(I*D(A[((((l&g>>31)+g|0)/4096|0)%(h|0)<<2)+n>>2]-m)))*C)+p;g=w[a+4276>>2];h=g<<12;k=j+i|0;p=A[((((h&k>>31)+k|0)/4096|0)%(g|0)<<2)+n>>2];m=D(D(i&4095)*D(.000244140625));i=j+v|0;A[u>>2]=D(D(D(p-o)+D(m*D(A[((((h&i>>31)+i|0)/4096|0)%(g|0)<<2)+n>>2]-p)))*C)+o;k=s>>>0<4;t=t+4|0;r=r+4|0;o=A[a+4248>>2];e=D(o*(H?e:f));c:{if(D(E(e))<D(2147483648)){i=~~e;break c}i=-2147483648}i=(s>>>0>1?i:0-i|0)+x|0;v=i+4096|0;f=D(o*f);d:{if(D(E(f))<D(2147483648)){g=~~f;break d}g=-2147483648}g=(k?g:0-g|0)+x|0;k=g+4096|0;j=(((j|0)<=0?h:0)+j|0)-4096|0;u=u+4|0;q=q+4|0;y=y-1|0;if(y){continue}break}w[a+4292>>2]=v;w[a+4288>>2]=i;w[a+4284>>2]=k;w[a+4280>>2]=g;w[a+4272>>2]=j}g=a;a=w[a+56>>2];ye(g,b,c,a,a+2048|0,d)}}function kz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=jb-32|0;a:{b:{c:{j=w[a+12>>2];l=w[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}t=w[a+16>>2];b=w[a+44>>2];w[h+12>>2]=b;e=w[a+48>>2];w[h+16>>2]=e;g=w[a+52>>2];w[h+20>>2]=g;i=w[a+56>>2];w[h+24>>2]=i;m=w[a>>2];k=w[a+4>>2];if(d){u=w[a+24>>2];x=w[a+20>>2];y=w[a+72>>2];b=w[a+68>>2];z=b;A=b>>31;b=w[a+64>>2];B=b;D=b>>31;b=w[a+60>>2];E=b;F=b>>31;while(1){b=1;f=((((k&2147483647)<<1|m>>>31)&2147483646)<<1)+t|0;e=(m>>>16&65520)+q|0;o=v[e+14>>1];p=v[e+12>>1];r=v[e+10>>1];G=v[e+8>>1];H=v[e+6>>1];I=v[e+4>>1];J=v[e+2>>1];s=v[e>>1];g=0;i=1;e=0;while(1){n=(e<<2)+h|0;e=e<<1;w[n>>2]=(((((((C(v[f+(e|-8)>>1],J)+C(v[f+(e|-12)>>1],s)|0)+C(v[f+(e|-4)>>1],I)|0)+C(v[e+f>>1],H)|0)+C(v[f+(e|4)>>1],G)|0)+C(v[f+(e|8)>>1],r)|0)+C(v[f+(e|12)>>1],p)|0)+C(v[f+(e|16)>>1],o)|0)/32768;n=i&1;i=0;e=1;if(n){continue}break}while(1){f=(h+8|0)+(g<<3)|0;e=w[f+8>>2];i=w[f+4>>2];w[f+8>>2]=i;o=(g<<2)+h|0;p=w[o>>2]<<8;g=p;g=BV(E,F,g,g>>31);r=nb;s=f;f=(i|0)>=16776704?16776704:i;f=(f|0)<=-16777216?-16777216:f;i=BV(f,f>>31,B,D);g=i+g|0;f=nb+r|0;f=g>>>0<i>>>0?f+1|0:f;n=g;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,z,A);e=n+g|0;f=nb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;w[s+4>>2]=f-(p&y);w[o>>2]=(f|0)/256;g=1;f=b;b=0;if(f){continue}break}w[c>>2]=w[c>>2]+C(w[h>>2],x);w[c+4>>2]=w[c+4>>2]+C(w[h+4>>2],u);k=j+k|0;b=l+m|0;k=b>>>0<l>>>0?k+1|0:k;m=b;c=c+8|0;d=d-1|0;if(d){continue}break}i=w[h+24>>2];g=w[h+20>>2];e=w[h+16>>2];b=w[h+12>>2]}w[a+56>>2]=i;w[a+52>>2]=g;w[a+48>>2]=e;w[a+44>>2]=b;w[a>>2]=m;w[a+4>>2]=k}function MR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=D(0),f=D(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=D(0),q=D(0),r=0,s=0,t=0,u=0,v=0,x=D(0),y=D(0),z=0,B=0,C=0,E=0,F=0,G=0,H=D(0),I=0,J=0,K=0,L=0,M=0,N=0,O=D(0),P=D(0),Q=D(0),R=D(0),S=D(0);r=w[a+56>>2];n=w[a+44>>2];if((0-(w[a+60>>2]-r>>11)|0)!=w[a+48>>2]-n>>11){I=r+2048|0;k=w[a+4300>>2];o=w[a+4296>>2];if(d){j=a+4304|0;i=o+1|0;s=i+w[a+4272>>2]&4095;l=j+(s<<4)|0;t=i+w[a+4276>>2]&4095;g=((t<<4)+j|0)+4|0;u=i+w[a+4280>>2]&4095;z=((u<<4)+j|0)+8|0;v=i+w[a+4284>>2]&4095;B=((v<<4)+j|0)+12|0;C=n+2048|0;h=w[a+4288>>2]+k|0;m=w[a+4292>>2]+k|0;J=a+69840|0;K=a+78032|0;E=I;F=r;G=d;while(1){t=t-1&4095;i=((t<<4)+j|0)+4|0;e=A[i>>2];L=h&1023;h=(L<<3)+J|0;f=A[h>>2];O=A[B>>2];P=A[z>>2];Q=A[g>>2];R=A[l>>2];x=A[C>>2];S=A[n>>2];M=k<<3;g=M+J|0;y=A[a+4232>>2];s=s-1&4095;l=(s<<4)+j|0;p=A[l>>2];q=D(D(A[h+4>>2]*y)-D(p*D(.6180340051651001)));A[g>>2]=D(q*D(.6180340051651001))+p;H=e;e=D(D(y*f)+D(e*D(.6180340051651001)));A[g+4>>2]=H-D(e*D(.6180340051651001));A[l>>2]=e;A[i>>2]=q;N=m&1023;g=(N<<3)+K|0;y=A[g+4>>2];u=u-1&4095;m=(u<<4)+j|0;z=m+8|0;f=A[z>>2];p=A[a+4236>>2];e=D(p*A[g>>2]);v=v-1&4095;g=(v<<4)+j|0;B=g+12|0;q=A[B>>2];e=D(e+D(q*D(.6180340051651001)));h=K+M|0;A[h+4>>2]=q-D(e*D(.6180340051651001));H=f;f=D(D(y*p)-D(f*D(.6180340051651001)));A[h>>2]=H+D(f*D(.6180340051651001));A[m+8>>2]=e;A[g+12>>2]=f;f=D(A[l>>2]+e);e=D(S+D(1.0000000031710769e-30));A[F>>2]=f+D(A[a+4224>>2]*e);f=D(x+D(1.0000000031710769e-30));A[E>>2]=D(D(A[a+4224>>2]*f)+A[i>>2])+A[g+12>>2];h=(o<<4)+j|0;x=A[a+4228>>2];e=D(x*e);A[h>>2]=D(D(A[a+4240>>2]*A[l>>2])+e)+D(R*A[a+4244>>2]);f=D(x*f);A[h+4>>2]=D(D(A[a+4248>>2]*A[i>>2])+f)+D(Q*A[a+4252>>2]);A[h+8>>2]=D(D(A[a+4256>>2]*A[m+8>>2])-f)+D(P*A[a+4260>>2]);A[h+12>>2]=D(D(A[a+4264>>2]*A[g+12>>2])+e)+D(O*A[a+4268>>2]);E=E+4|0;F=F+4|0;C=C+4|0;n=n+4|0;m=N-1|0;h=L-1|0;k=k-1&1023;o=o-1&4095;g=i;G=G-1|0;if(G){continue}break}}w[a+4300>>2]=k;w[a+4296>>2]=o;ye(a,b,c,r,I,d)}}function xE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=jb-48|0;jb=k;e=w[a>>2];i=b-e>>1;a:{d=w[a+4>>2];g=w[a+8>>2];if(d>>>0<g>>>0){if((b|0)==(d|0)){c=x[c|0]|x[c+1|0]<<8;u[b|0]=c;u[b+1|0]=c>>>8;w[a+4>>2]=b+2;break a}g=d;f=d-2|0;if(f>>>0<d>>>0){h=f;while(1){j=x[h|0]|x[h+1|0]<<8;u[g|0]=j;u[g+1|0]=j>>>8;g=g+2|0;h=h+2|0;if(h>>>0<d>>>0){continue}break}}w[a+4>>2]=g;h=b>>>0<=c>>>0;if((b+2|0)!=(d|0)){while(1){d=d-2|0;f=f-2|0;u[d|0]=x[f|0];u[d+1|0]=x[f+1|0];if((b|0)!=(f|0)){continue}break}g=w[a+4>>2]}a=((c>>>0<g>>>0&h)<<1)+c|0;u[b|0]=x[a|0];u[(e+(i<<1)|0)+1|0]=x[a+1|0];break a}d=d-e|0;if((d|0)>-3){g=g-e|0;d=(d>>1)+1|0;e=Vf(k,g>>>0>=2147483646?2147483647:d>>>0<g>>>0?g:d,i,a+8|0);h=w[e+8>>2];b:{c:{if((h|0)!=w[e+12>>2]){d=h;break c}f=w[e+4>>2];d=w[e>>2];if(f>>>0>d>>>0){g=(((f-d>>1)+1|0)/-2<<1)+f|0;d=g;if((f|0)!=(h|0)){d=g;while(1){u[d|0]=x[f|0];u[d+1|0]=x[f+1|0];d=d+2|0;f=f+2|0;if((h|0)!=(f|0)){continue}break}}w[e+4>>2]=g;w[e+8>>2]=d;break c}g=w[e+16>>2];w[114256]=0;d=(d|0)==(h|0)?1:h-d|0;i=Z(288,k+24|0,d|0,d>>>2|0,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}h=w[i+8>>2];f=w[e+4>>2];d=w[e+8>>2];d:{if((f|0)==(d|0)){d=h;g=f;break d}d=(d-f|0)+h|0;while(1){g=x[f|0]|x[f+1|0]<<8;u[h|0]=g;u[h+1|0]=g>>>8;f=f+2|0;h=h+2|0;if((h|0)!=(d|0)){continue}break}f=w[e+8>>2];g=w[e+4>>2]}j=w[e>>2];w[e>>2]=w[i>>2];w[i>>2]=j;w[e+4>>2]=w[i+4>>2];w[i+4>>2]=g;w[e+8>>2]=d;w[i+8>>2]=f;h=w[e+12>>2];w[e+12>>2]=w[i+12>>2];w[i+12>>2]=h;if((f|0)!=(g|0)){w[i+8>>2]=((g-f|0)+1&-2)+f}if(!j){break c}zb(j);d=w[e+8>>2]}c=x[c|0]|x[c+1|0]<<8;u[d|0]=c;u[d+1|0]=c>>>8;w[e+8>>2]=w[e+8>>2]+2;w[114256]=0;b=S(289,a|0,e|0,b|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break b}c=w[e+8>>2];a=w[e+4>>2];if((c|0)!=(a|0)){w[e+8>>2]=c+((a-c|0)+1&-2)}a=w[e>>2];if(!a){break a}zb(a);break a}b=P()|0;c=w[e+8>>2];a=w[e+4>>2];if((c|0)!=(a|0)){w[e+8>>2]=c+((a-c|0)+1&-2)}a=w[e>>2];if(a){zb(a)}R(b|0);M()}Mb(a);M()}jb=k+48|0;return b|0}function Hj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return fc(b)}if(b>>>0>=4294967232){w[114084]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=w[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=w[114252]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}w[f+4>>2]=j&1|g|2;c=f+g|0;w[c+4>>2]=d|3;w[h+4>>2]=w[h+4>>2]|1;Gj(c,d);break b}if(w[114138]==(h|0)){e=e+w[114135]|0;if(e>>>0<=g>>>0){break a}w[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;w[d+4>>2]=c|1;w[114135]=c;w[114138]=d;break b}if(w[114137]==(h|0)){d=e+w[114134]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){w[f+4>>2]=j&1|g|2;e=f+g|0;w[e+4>>2]=c|1;d=d+f|0;w[d>>2]=c;w[d+4>>2]=w[d+4>>2]&-2;break c}w[f+4>>2]=d|j&1|2;c=d+f|0;w[c+4>>2]=w[c+4>>2]|1;c=0;e=0}w[114137]=e;w[114134]=c;break b}d=w[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=w[h+8>>2];c=d>>>3|0;d=w[h+12>>2];if((d|0)==(e|0)){n=456528,o=w[114132]&FV(-2,c),w[n>>2]=o;break d}w[e+12>>2]=d;w[d+8>>2]=e;break d}l=w[h+24>>2];i=w[h+12>>2];e:{if((i|0)!=(h|0)){c=w[h+8>>2];w[c+12>>2]=i;w[i+8>>2]=c;break e}f:{e=h+20|0;c=w[e>>2];if(c){break f}e=h+16|0;c=w[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=w[e>>2];if(c){continue}e=i+16|0;c=w[i+16>>2];if(c){continue}break}w[d>>2]=0}if(!l){break d}d=w[h+28>>2];c=(d<<2)+456832|0;g:{if(w[c>>2]==(h|0)){w[c>>2]=i;if(i){break g}n=456532,o=w[114133]&FV(-2,d),w[n>>2]=o;break d}w[(w[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}w[i+24>>2]=l;c=w[h+16>>2];if(c){w[i+16>>2]=c;w[c+24>>2]=i}c=w[h+20>>2];if(!c){break d}w[i+20>>2]=c;w[c+24>>2]=i}if(m>>>0<=15){w[f+4>>2]=j&1|k|2;c=f+k|0;w[c+4>>2]=w[c+4>>2]|1;break b}w[f+4>>2]=j&1|g|2;d=f+g|0;w[d+4>>2]=m|3;c=f+k|0;w[c+4>>2]=w[c+4>>2]|1;Gj(d,m)}c=f}if(c){return c+8|0}f=fc(b);if(!f){return 0}c=w[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;Fb(f,a,b>>>0>c>>>0?c:b);zb(a);return f}function ye(a,b,c,d,e,f){var g=0,h=0,i=0,j=D(0),k=D(0),l=0,m=0,n=D(0),o=D(0),p=0;l=ob[w[w[a>>2]+132>>2]](a)|0;h=w[a+20>>2];g=l?g:x[h+25|0];j=A[h+144>>2];k=D(1);if(!(ob[w[w[a>>2]+132>>2]](a)|0)){k=A[w[a+20>>2]+144>>2]}j=D(D(1)-j);if(!((ob[w[w[a>>2]+148>>2]](a)|0)<=0|!(x[w[a+20>>2]+24|0]&8))){j=D(D(j+j)+D(-1));k=D(-j)}l=w[a+44>>2];m=l+2048|0;n=A[a+4196>>2];k=D(n*k);j=D(n*j);a:{b:{switch(g|0){case 4:if(!f){break a}h=0;while(1){g=h<<2;i=g+b|0;p=i;k=D(A[g+l>>2]+A[i>>2]);i=c+g|0;A[p>>2]=D(k-D(A[g+m>>2]+D(k+A[i>>2])))+D(A[d+g>>2]*j);A[i>>2]=D(A[e+g>>2]*j)-k;h=h+1|0;if((h|0)!=(f|0)){continue}break};break a;case 3:if(!f){break a}h=0;while(1){g=h<<2;i=g+b|0;A[i>>2]=D(D(A[g+l>>2]*j)-A[d+g>>2])+A[i>>2];i=c+g|0;A[i>>2]=D(D(A[g+m>>2]*j)-A[e+g>>2])+A[i>>2];h=h+1|0;if((h|0)!=(f|0)){continue}break};break a;case 2:if(!f){break a}h=0;while(1){g=h<<2;i=g+b|0;A[i>>2]=D(A[i>>2]+A[d+g>>2])-D(A[g+l>>2]*k);i=c+g|0;A[i>>2]=D(A[i>>2]+A[e+g>>2])-D(A[g+m>>2]*k);h=h+1|0;if((h|0)!=(f|0)){continue}break};break a;case 1:if(!f){break a}h=0;while(1){g=h<<2;i=g+b|0;A[i>>2]=D(A[i>>2]+A[g+l>>2])-D(A[d+g>>2]*j);i=c+g|0;A[i>>2]=D(A[i>>2]+A[g+m>>2])-D(A[e+g>>2]*j);h=h+1|0;if((h|0)!=(f|0)){continue}break};break a;case 0:if(!f){break a}h=0;while(1){g=h<<2;i=g+b|0;A[i>>2]=D(D(A[g+l>>2]*k)+D(A[d+g>>2]*j))+A[i>>2];i=c+g|0;A[i>>2]=D(D(A[g+m>>2]*k)+D(A[e+g>>2]*j))+A[i>>2];h=h+1|0;if((h|0)!=(f|0)){continue}break};break a;case 5:break b;default:break a}}if(!f){break a}h=x[w[a+20>>2]+24|0]&8;j=h?D(j*D(.5)):j;k=h?D(k*D(.5)):k;h=0;while(1){g=h<<2;i=g+b|0;n=D(A[d+g>>2]-A[g+l>>2]);o=D(A[g+m>>2]-A[e+g>>2]);A[i>>2]=D(A[i>>2]+D(n*j))+D(o*k);g=c+g|0;A[g>>2]=D(D(o*j)+D(n*k))+A[g>>2];h=h+1|0;if((h|0)!=(f|0)){continue}break}}c:{if(!(x[w[a+20>>2]+24|0]&4)){break c}if(ob[w[w[a>>2]+132>>2]](a)|!f){break c}d=0;while(1){a=d<<2;e=a+b|0;A[e>>2]=A[e>>2]+A[a+l>>2];e=a+c|0;A[e>>2]=A[e>>2]+A[a+m>>2];d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function Co(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=jb-48|0;jb=k;a:{if(!w[a+20>>2]|!w[a>>2]){break a}tg(a);if(w[a+20>>2]!=0&w[a>>2]!=0?c:0){q=b+1304360|0;d=b+1074984|0;c=y[a+34>>1];l=c&4;r=c&2;s=c&16;t=c&8;f=w[a+8>>2];n=w[a+4>>2];g=w[a+16>>2];o=w[a+12>>2];while(1){b:{if(w[d+104>>2]!=(a|0)){break b}e=w[d+76>>2];if(!e){break b}c:{d:{e:{f:{m=w[a>>2];if(!t|(m>>>0<g>>>0|g>>>0<=o>>>0)){break f}j=w[d+88>>2];if(j&2048){break f}w[d+84>>2]=g;w[d+80>>2]=o;e=g;c=s;break e}if(!r|(f>>>0<=n>>>0|f>>>0>m>>>0)){break d}w[d+84>>2]=f;w[d+80>>2]=n;j=w[d+88>>2];e=f;c=l}w[d+76>>2]=e;i=j|2;p=d+88|0;j=(c|0)!=0;c=1;break c}p=d+88|0;i=w[d+88>>2]&-3;j=0;c=0}i=i&-5|(j?c?4:0:0);w[d+88>>2]=i;if(z[d+4>>2]>e>>>0){i=i&-129;w[d+88>>2]=i;e=w[d+80>>2];w[d>>2]=0;w[d+4>>2]=e}if(!j){w[p>>2]=i&-129}if(c){break b}w[d+76>>2]=m}d=d+896|0;if((q|0)!=(d|0)){continue}break}}c=y[a+34>>1];e=c&64?2:1;if(c&1){d=w[a+20>>2];f=d+(C(e,w[a>>2])<<1)|0;while(1){g=C(e,h);l=C(e,h^-1);c=0;while(1){v[f+(c+g<<1)>>1]=y[f+(c-e<<1)>>1];v[d+(c+l<<1)>>1]=y[d+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}h=h+1|0;if((h|0)!=16){continue}break}f=f+(e<<5)|0;c=y[a+34>>1];if(c&2){g=w[a+4>>2];Bo(k+24|0,f,d+(C(g,e)<<1)|0,w[a+8>>2]-g|0,e,(c&4)>>>2|0,(w[b+1074316>>2]&2)>>>1|0);c=y[a+34>>1]}if(!(c&8)){break a}g=f+(e<<7)|0;f=w[a+12>>2];Bo(k,g,d+(C(f,e)<<1)|0,w[a+16>>2]-f|0,e,(c&16)>>>4|0,(w[b+1074316>>2]&2)>>>1|0);break a}d=w[a+20>>2];f=d+C(e,w[a>>2])|0;while(1){g=C(e,h);l=C(e,h^-1);c=0;while(1){u[f+(c+g|0)|0]=x[f+(c-e|0)|0];u[d+(c+l|0)|0]=x[c+d|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}h=h+1|0;if((h|0)!=16){continue}break}f=f+(e<<4)|0;c=y[a+34>>1];if(c&2){g=w[a+4>>2];Ao(k+24|0,f,d+C(g,e)|0,w[a+8>>2]-g|0,e,(c&4)>>>2|0,(w[b+1074316>>2]&2)>>>1|0);c=y[a+34>>1]}if(!(c&8)){break a}g=f+(e<<6)|0;f=w[a+12>>2];Ao(k,g,d+C(f,e)|0,w[a+16>>2]-f|0,e,(c&16)>>>4|0,(w[b+1074316>>2]&2)>>>1|0)}jb=k+48|0}function lz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=jb-32|0;a:{b:{c:{i=w[a+12>>2];k=w[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=w[a+16>>2];b=w[a+44>>2];w[g+12>>2]=b;l=w[a+48>>2];w[g+16>>2]=l;f=w[a+52>>2];w[g+20>>2]=f;h=w[a+56>>2];w[g+24>>2]=h;m=w[a>>2];j=w[a+4>>2];if(d){x=w[a+24>>2];y=w[a+20>>2];z=w[a+72>>2];b=w[a+68>>2];A=b;B=b>>31;b=w[a+64>>2];D=b;E=b>>31;b=w[a+60>>2];F=b;G=b>>31;while(1){e=(((j&2147483647)<<1|m>>>31)&-2)+t|0;b=(m>>>16&65520)+p|0;n=v[b+14>>1];o=v[b+12>>1];q=v[b+10>>1];H=v[b+8>>1];I=v[b+6>>1];J=v[b+4>>1];K=v[b+2>>1];r=v[b>>1];f=0;l=1;h=1;b=0;while(1){w[(b<<2)+g>>2]=(((((((C(u[e+(b|-4)|0],K)+C(u[e+(b|-6)|0],r)|0)+C(u[e+(b|-2)|0],J)|0)+C(u[b+e|0],I)|0)+C(u[e+(b|2)|0],H)|0)+C(u[e+(b|4)|0],q)|0)+C(u[e+(b|6)|0],o)|0)+C(u[e+(b|8)|0],n)<<8)/32768;s=h&1;h=0;b=1;if(s){continue}break}while(1){b=(g+8|0)+(f<<3)|0;e=w[b+8>>2];h=w[b+4>>2];w[b+8>>2]=h;n=(f<<2)+g|0;o=w[n>>2]<<8;f=o;f=BV(F,G,f,f>>31);q=nb;r=b;b=(h|0)>=16776704?16776704:h;b=(b|0)<=-16777216?-16777216:b;h=BV(b,b>>31,D,E);f=h+f|0;b=nb+q|0;b=f>>>0<h>>>0?b+1|0:b;s=f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;f=BV(e,e>>31,A,B);e=s+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[r+4>>2]=b-(o&z);w[n>>2]=(b|0)/256;f=1;b=l;l=0;if(b){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],y);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],x);j=i+j|0;b=k+m|0;j=b>>>0<k>>>0?j+1|0:j;m=b;c=c+8|0;d=d-1|0;if(d){continue}break}h=w[g+24>>2];f=w[g+20>>2];l=w[g+16>>2];b=w[g+12>>2]}w[a+56>>2]=h;w[a+52>>2]=f;w[a+48>>2]=l;w[a+44>>2]=b;w[a>>2]=m;w[a+4>>2]=j}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=jb-32|0;jb=i;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;d=w[b+4>>2];if(d){$i(a,d);d=w[b>>2];w[i+28>>2]=0;w[i+24>>2]=d;b=w[b+4>>2];w[i+20>>2]=b&31;w[i+16>>2]=d+(b>>>3&536870908);b=w[i+28>>2];w[i+8>>2]=w[i+24>>2];w[i+12>>2]=b;b=w[i+20>>2];w[i>>2]=w[i+16>>2];w[i+4>>2]=b;c=jb+-64|0;jb=c;g=w[i+4>>2];f=w[a+4>>2];e=w[i+12>>2];j=e;d=w[i>>2];b=w[i+8>>2];h=(g+(f-e|0)|0)+(d-b<<3)|0;w[a+4>>2]=h;if(!((h-1^f-1)>>>0<32?f:0)){w[w[a>>2]+((h>>>0>=33?h-1>>>5|0:0)<<2)>>2]=0}h=w[a>>2]+(f>>>3&536870908)|0;f=f&31;a:{if((f|0)==(j|0)){w[c+48>>2]=d;w[c+52>>2]=g;w[c+56>>2]=b;w[c+60>>2]=e;w[c+44>>2]=j;w[c+40>>2]=h;w[c+8>>2]=b;w[c+12>>2]=e;w[c>>2]=d;w[c+4>>2]=g;np(c+32|0,c+8|0,c,c+40|0);break a}w[c+48>>2]=d;w[c+52>>2]=g;w[c+56>>2]=b;w[c+60>>2]=e;w[c+44>>2]=f;w[c+40>>2]=h;w[c+24>>2]=b;w[c+28>>2]=e;w[c+16>>2]=d;w[c+20>>2]=g;e=w[c+28>>2];f=w[c+24>>2];g=(w[c+20>>2]-e|0)+(w[c+16>>2]-f<<3)|0;b:{if((g|0)<=0){b=w[c+44>>2];break b}c:{if(!e){b=w[c+44>>2];break c}b=w[c+44>>2];d=32-b|0;l=32-e|0;h=(g|0)<(l|0)?g:l;j=d>>>0<h>>>0?d:h;k=w[c+40>>2];l=w[f>>2]&(-1<<e&-1>>>l-h);w[k>>2]=w[k>>2]&(-1<<b&-1>>>d-j^-1)|(b>>>0>e>>>0?l<<b-e:l>>>e-b|0);b=b+j|0;d=b&31;w[c+44>>2]=d;k=k+(b>>>3&536870908)|0;w[c+40>>2]=k;g=g-h|0;f=f+4|0;b=h-j|0;if((b|0)>0){w[k>>2]=w[k>>2]&(-1>>>32-b^-1)|l>>>e+j;w[c+44>>2]=b}else{b=d}}h=-1<<b;e=32-b|0;if((g|0)>=32){l=h^-1;d=w[c+40>>2];j=w[d>>2];while(1){k=j&l;j=w[f>>2];w[d>>2]=k|j<<b;j=h&w[d+4>>2]|j>>>e;w[d+4>>2]=j;f=f+4|0;d=d+4|0;k=g>>>0>63;g=g-32|0;if(k){continue}break}w[c+40>>2]=d}if((g|0)<=0){break b}d=w[c+40>>2];j=e;e=(e|0)<(g|0)?e:g;j=w[d>>2]&(h&-1>>>j-e^-1);h=w[f>>2]&-1>>>32-g;w[d>>2]=j|h<<b;f=b+e|0;b=f&31;w[c+44>>2]=b;f=d+(f>>>3&536870908)|0;w[c+40>>2]=f;d=g-e|0;if((d|0)<=0){break b}w[f>>2]=w[f>>2]&(-1>>>32-d^-1)|h>>>e;w[c+44>>2]=d;b=d}d=w[c+40>>2];w[c+36>>2]=b;w[c+32>>2]=d}jb=c- -64|0}jb=i+32|0;return a|0}function wA(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;Cb(a+3|0,0,4893);u[a+2|0]=x[9857];b=x[9855]|x[9856]<<8;u[a|0]=b;u[a+1|0]=b>>>8;b=x[9909]|x[9910]<<8;u[a+32|0]=b;u[a+33|0]=b>>>8;u[a+34|0]=x[9911];b=x[1982]|x[1983]<<8|(x[1984]<<16|x[1985]<<24);u[a+96|0]=b;u[a+97|0]=b>>>8;u[a+98|0]=b>>>16;u[a+99|0]=b>>>24;b=x[1985]|x[1986]<<8|(x[1987]<<16|x[1988]<<24);u[a+99|0]=b;u[a+100|0]=b>>>8;u[a+101|0]=b>>>16;u[a+102|0]=b>>>24;b=x[11606]|x[11607]<<8|(x[11608]<<16|x[11609]<<24);u[a+128|0]=b;u[a+129|0]=b>>>8;u[a+130|0]=b>>>16;u[a+131|0]=b>>>24;b=x[11609]|x[11610]<<8|(x[11611]<<16|x[11612]<<24);u[a+131|0]=b;u[a+132|0]=b>>>8;u[a+133|0]=b>>>16;u[a+134|0]=b>>>24;u[a+260|0]=x[5199];b=x[5195]|x[5196]<<8|(x[5197]<<16|x[5198]<<24);u[a+256|0]=b;u[a+257|0]=b>>>8;u[a+258|0]=b>>>16;u[a+259|0]=b>>>24;b=jb-80|0;jb=b;c=Hb(b+56|0,1439);w[114256]=0;w[b+44>>2]=32;w[b+40>>2]=a+288;Q(200,b+40|0,c|0)|0;d=w[114256];w[114256]=0;a:{if((d|0)!=1){if(u[c+11|0]>=0){break a}zb(w[c>>2]);break a}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}jb=b+80|0;d=a+800|0;b=0;a=jb-80|0;jb=a;b:{c:{d:{e:{f:{g:{while(1){w[a+52>>2]=b;w[a+52>>2]=b<<3;e=a+56|0;c=Hb(e,b>>>0<16?11334:17256);w[a+32>>2]=w[c+8>>2];f=w[c+4>>2];c=w[c>>2];w[114256]=0;w[a+24>>2]=c;w[a+28>>2]=f;u[a+72|0]=44;w[a+64>>2]=-1;w[a+68>>2]=0;w[a+56>>2]=1058;w[a+60>>2]=2;U(280,a+8|0,a+52|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break g}w[114256]=0;U(281,a+40|0,a+24|0,a+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break f}w[114256]=0;w[a+60>>2]=32;w[a+56>>2]=d+(b<<5);Q(200,a+56|0,a+40|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}if(u[a+51|0]<0){zb(w[a+40>>2])}if(u[a+19|0]<0){zb(w[a+8>>2])}if(u[a+35|0]<0){zb(w[a+24>>2])}b=b+1|0;if((b|0)!=128){continue}break}jb=a+80|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;if(u[a+51|0]>=0){break d}zb(w[a+40>>2])}if(u[a+19|0]>=0){break c}zb(w[a+8>>2])}if(u[a+35|0]<0){zb(w[a+24>>2])}R(b|0);M()}}function Ry(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;t=w[a+16>>2];h=jb-32|0;f=w[a+44>>2];w[h+12>>2]=f;g=w[a+48>>2];w[h+16>>2]=g;j=w[a+52>>2];w[h+20>>2]=j;k=w[a+56>>2];w[h+24>>2]=k;l=w[a>>2];i=w[a+4>>2];m=w[a+40>>2];n=w[a+36>>2];a:{if(!d){e=m>>12;b=n>>12;break a}u=b+24|0;k=w[a+8>>2];x=w[a+12>>2];y=w[a+32>>2];z=w[a+28>>2];A=w[a+72>>2];b=w[a+68>>2];B=b;D=b>>31;b=w[a+64>>2];E=b;F=b>>31;b=w[a+60>>2];G=b;H=b>>31;while(1){j=1;e=((((i&2147483647)<<1|l>>>31)&2147483646)<<1)+t|0;b=(((l>>>16|0)+4&131064)<<1)+u|0;o=v[b+14>>1];p=v[b+12>>1];q=v[b+10>>1];r=v[b+8>>1];I=v[b+6>>1];J=v[b+4>>1];K=v[b+2>>1];L=v[b>>1];f=0;g=1;b=0;while(1){s=(b<<2)+h|0;b=b<<1;w[s>>2]=(((((C(v[e+(b|8)>>1],q)+C(v[e+(b|4)>>1],r)|0)+C(v[e+(b|12)>>1],p)|0)+C(o,v[e+(b|16)>>1])|0)/2|0)+((((C(v[e+(b|-8)>>1],K)+C(v[e+(b|-12)>>1],L)|0)+C(v[e+(b|-4)>>1],J)|0)+C(v[b+e>>1],I)|0)/2|0)|0)/16384;s=g&1;g=0;b=1;if(s){continue}break}while(1){b=(h+8|0)+(f<<3)|0;e=w[b+8>>2];g=w[b+4>>2];w[b+8>>2]=g;o=(f<<2)+h|0;p=w[o>>2]<<8;f=p;f=BV(G,H,f,f>>31);q=nb;r=b;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(b,b>>31,E,F);f=g+f|0;b=nb+q|0;b=f>>>0<g>>>0?b+1|0:b;g=f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;f=BV(e,e>>31,B,D);e=g+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[r+4>>2]=b-(p&A);w[o>>2]=(b|0)/256;f=1;b=j&1;j=0;if(b){continue}break}n=n+z|0;b=n>>12;w[c>>2]=w[c>>2]+C(b,w[h>>2]);m=m+y|0;e=m>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[h+4>>2]);i=i+x|0;f=k+l|0;i=f>>>0<k>>>0?i+1|0:i;l=f;c=c+8|0;d=d-1|0;if(d){continue}break}k=w[h+24>>2];j=w[h+20>>2];g=w[h+16>>2];f=w[h+12>>2]}w[a+36>>2]=n;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=m;w[a+20>>2]=b;w[a+56>>2]=k;w[a+52>>2]=j;w[a+48>>2]=g;w[a+44>>2]=f;w[a+24>>2]=e}function aO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb+-64|0;jb=d;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=y[w[b+24>>2]+480192>>1];w[114256]=0;T(918,a|0,c|0);c=w[114256];w[114256]=0;a:{if((c|0)!=1){b:{c:{d:{e:{f=w[b+24>>2];if(y[f+480192>>1]){k=a+8|0;i=1;while(1){w[114256]=0;c=Q(1466,f|0,i&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}w[114256]=0;j=Q(5,d+8|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}c=w[w[b+24>>2]+1304496>>2];w[114256]=0;Y(229,d+24|0,0,c|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break d}c=w[a+4>>2];e=w[a+8>>2];f:{if(c>>>0<e>>>0){e=w[d+28>>2];w[c>>2]=w[d+24>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+32>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;w[a+4>>2]=c+12;break f}f=w[a>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}M()}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;g=Z(921,d+40|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,k|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}e=w[d+28>>2];c=w[d+48>>2];w[c>>2]=w[d+24>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+32>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;h=w[d+48>>2]+12|0;w[d+48>>2]=h;f=w[d+44>>2];e=w[a+4>>2];c=w[a>>2];g:{if((e|0)==(c|0)){e=c;break g}while(1){e=e-12|0;h=w[e+4>>2];f=f-12|0;w[f>>2]=w[e>>2];w[f+4>>2]=h;w[f+8>>2]=w[e+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;f=w[d+44>>2]-12|0;w[d+44>>2]=f;if((c|0)!=(e|0)){continue}break}c=w[a+4>>2];h=w[d+48>>2];e=w[a>>2]}w[a>>2]=f;w[d+44>>2]=e;w[a+4>>2]=h;w[d+48>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+52>>2];w[d+52>>2]=c;w[g>>2]=e;sc(g);if(u[d+35|0]>=0){break f}zb(w[d+24>>2])}if(u[d+19|0]<0){zb(w[j>>2])}f=w[b+24>>2];i=i+1|0;if(y[f+480192>>1]>=(i&65535)>>>0){continue}break}}jb=d- -64|0;return}e=P()|0;break a}e=P()|0;break b}e=P()|0;if(u[d+35|0]>=0){break b}zb(w[d+24>>2])}if(u[d+19|0]>=0){break a}zb(w[j>>2]);break a}e=P()|0}bc(a);R(e|0);M()}function $N(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb+-64|0;jb=d;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=y[w[b+24>>2]+480190>>1];w[114256]=0;T(918,a|0,c|0);c=w[114256];w[114256]=0;a:{if((c|0)!=1){b:{c:{d:{e:{f=w[b+24>>2];if(y[f+480190>>1]){k=a+8|0;i=1;while(1){w[114256]=0;c=Q(1467,f|0,i&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}w[114256]=0;j=Q(5,d+8|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}c=w[w[b+24>>2]+1304496>>2];w[114256]=0;Y(229,d+24|0,0,c|0,j|0);c=w[114256];w[114256]=0;if((c|0)==1){break d}c=w[a+4>>2];e=w[a+8>>2];f:{if(c>>>0<e>>>0){e=w[d+28>>2];w[c>>2]=w[d+24>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+32>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;w[a+4>>2]=c+12;break f}f=w[a>>2];g=(c-f|0)/12|0;c=g+1|0;if(c>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}M()}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;g=Z(921,d+40|0,(e>>>0>=178956970?357913941:c>>>0<f>>>0?f:c)|0,g|0,k|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}e=w[d+28>>2];c=w[d+48>>2];w[c>>2]=w[d+24>>2];w[c+4>>2]=e;w[c+8>>2]=w[d+32>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;h=w[d+48>>2]+12|0;w[d+48>>2]=h;f=w[d+44>>2];e=w[a+4>>2];c=w[a>>2];g:{if((e|0)==(c|0)){e=c;break g}while(1){e=e-12|0;h=w[e+4>>2];f=f-12|0;w[f>>2]=w[e>>2];w[f+4>>2]=h;w[f+8>>2]=w[e+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;f=w[d+44>>2]-12|0;w[d+44>>2]=f;if((c|0)!=(e|0)){continue}break}c=w[a+4>>2];h=w[d+48>>2];e=w[a>>2]}w[a>>2]=f;w[d+44>>2]=e;w[a+4>>2]=h;w[d+48>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+52>>2];w[d+52>>2]=c;w[g>>2]=e;sc(g);if(u[d+35|0]>=0){break f}zb(w[d+24>>2])}if(u[d+19|0]<0){zb(w[j>>2])}f=w[b+24>>2];i=i+1|0;if(y[f+480190>>1]>=(i&65535)>>>0){continue}break}}jb=d- -64|0;return}e=P()|0;break a}e=P()|0;break b}e=P()|0;if(u[d+35|0]>=0){break b}zb(w[d+24>>2])}if(u[d+19|0]>=0){break a}zb(w[j>>2]);break a}e=P()|0}bc(a);R(e|0);M()}function Bw(){var a=0,b=0,c=0,d=0,e=0,f=0;if(!x[460149]){c=w[15126];b=jb-16|0;jb=b;a=Fj(459796);w[a+40>>2]=459852;w[a+32>>2]=c;w[a>>2]=60520;u[a+52|0]=0;w[a+48>>2]=-1;d=b+8|0;xj(d,a);e=w[w[a>>2]+8>>2];w[114256]=0;T(e|0,a|0,d|0);d=w[114256];w[114256]=0;a:{if((d|0)!=1){Ab(b+8|0);jb=b+16|0;break a}c=P()|0;Ab(b+8|0);wc(a);R(c|0);M()}a=Ys(459120);w[114778]=59020;w[a>>2]=59040;w[114779]=0;w[114256]=0;T(1676,a|0,459796);b=w[114256];w[114256]=0;b:{c:{if((b|0)==1){break c}d=w[15127];_s(459860,d,459908);fm(459288,459860);e=w[14612];_s(459916,e,459964);fm(459456,459916);fm(459624,w[(w[w[114864]-12>>2]+459456|0)+24>>2]);pj(w[w[114778]-12>>2]+459112|0,459288);Ws(w[w[114864]-12>>2]+459456|0);pj(w[w[114864]-12>>2]+459456|0,459288);b=jb-16|0;jb=b;a=wt(459972);w[a+40>>2]=460028;w[a+32>>2]=c;w[a>>2]=60724;u[a+52|0]=0;w[a+48>>2]=-1;c=b+8|0;xj(c,a);f=w[w[a>>2]+8>>2];w[114256]=0;T(f|0,a|0,c|0);c=w[114256];w[114256]=0;d:{if((c|0)!=1){Ab(b+8|0);jb=b+16|0;break d}c=P()|0;Ab(b+8|0);Uh(a);R(c|0);M()}a=Vs(459208);w[114800]=59180;w[a>>2]=59200;w[114801]=0;w[114256]=0;T(1678,a|0,459972);b=w[114256];w[114256]=0;if((b|0)==1){break c}Zs(460036,d,460084);em(459372,460036);Zs(460092,e,460140);em(459540,460092);em(459708,w[(w[w[114885]-12>>2]+459540|0)+24>>2]);pj(w[w[114800]-12>>2]+459200|0,459372);Ws(w[w[114885]-12>>2]+459540|0);pj(w[w[114885]-12>>2]+459540|0,459372);break b}b=P()|0;pc(a);R(b|0);M()}u[460149]=1}a=jb-16|0;jb=a;e:{if(Ta(a+12|0,a+8|0)|0){break e}b=fc((w[a+12>>2]<<2)+4|0);w[115039]=b;if(!b){break e}b=fc(w[a+8>>2]);if(b){w[w[115039]+(w[a+12>>2]<<2)>>2]=0;if(!(Sa(w[115039],b|0)|0)){break e}}w[115039]=0}jb=a+16|0;if(!x[455304]){u[455280]=3;w[21655]=0;u[86616]=7;w[21652]=1889785610;w[21653]=1072630333;u[86600]=3;w[113825]=0;u[455296]=7;w[113822]=1889785610;w[113823]=1072630333;Zj(86600,1);u[455304]=1}w[114126]=456392;w[114108]=42}function Ty(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;s=w[a+16>>2];h=jb-32|0;f=w[a+44>>2];w[h+12>>2]=f;g=w[a+48>>2];w[h+16>>2]=g;j=w[a+52>>2];w[h+20>>2]=j;k=w[a+56>>2];w[h+24>>2]=k;l=w[a>>2];i=w[a+4>>2];m=w[a+40>>2];n=w[a+36>>2];a:{if(!d){e=m>>12;b=n>>12;break a}t=b+24|0;k=w[a+8>>2];x=w[a+12>>2];y=w[a+32>>2];z=w[a+28>>2];A=w[a+72>>2];b=w[a+68>>2];B=b;D=b>>31;b=w[a+64>>2];E=b;F=b>>31;b=w[a+60>>2];G=b;H=b>>31;while(1){b=(((i&2147483647)<<1|l>>>31)&-2)+s|0;j=1;e=t+(((l>>>16|0)+4&131064)<<1)|0;o=v[e+14>>1];p=v[e+12>>1];q=v[e+10>>1];r=v[e+8>>1];I=v[e+6>>1];J=v[e+4>>1];K=v[e+2>>1];L=v[e>>1];f=0;g=1;e=0;while(1){w[(e<<2)+h>>2]=(((((C(u[b+(e|4)|0],q)+C(u[b+(e|2)|0],r)|0)+C(u[b+(e|6)|0],p)|0)+C(u[b+(e|8)|0],o)<<8)/2|0)+((((C(u[b+(e|-4)|0],K)+C(u[b+(e|-6)|0],L)|0)+C(u[b+(e|-2)|0],J)|0)+C(u[b+e|0],I)<<8)/2|0)|0)/16384;M=g&1;g=0;e=1;if(M){continue}break}while(1){b=(h+8|0)+(f<<3)|0;e=w[b+8>>2];g=w[b+4>>2];w[b+8>>2]=g;o=(f<<2)+h|0;p=w[o>>2]<<8;f=p;f=BV(G,H,f,f>>31);q=nb;r=b;b=(g|0)>=16776704?16776704:g;b=(b|0)<=-16777216?-16777216:b;g=BV(b,b>>31,E,F);f=g+f|0;b=nb+q|0;b=f>>>0<g>>>0?b+1|0:b;g=f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;f=BV(e,e>>31,B,D);e=g+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;w[r+4>>2]=b-(p&A);w[o>>2]=(b|0)/256;f=1;b=j&1;j=0;if(b){continue}break}n=n+z|0;b=n>>12;w[c>>2]=w[c>>2]+C(b,w[h>>2]);m=m+y|0;e=m>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[h+4>>2]);i=i+x|0;f=k+l|0;i=f>>>0<k>>>0?i+1|0:i;l=f;c=c+8|0;d=d-1|0;if(d){continue}break}k=w[h+24>>2];j=w[h+20>>2];g=w[h+16>>2];f=w[h+12>>2]}w[a+36>>2]=n;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=m;w[a+20>>2]=b;w[a+56>>2]=k;w[a+52>>2]=j;w[a+48>>2]=g;w[a+44>>2]=f;w[a+24>>2]=e}function fJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-1072|0;jb=e;g=Kb(16);w[g+4>>2]=0;w[g+8>>2]=0;w[g+12>>2]=75696;w[g>>2]=75656;w[a+4>>2]=g;w[a>>2]=g+12;w[g+4>>2]=w[g+4>>2]+1;Cb(a+8|0,0,1048);h=w[g+4>>2];w[g+4>>2]=h-1;if(!h){ob[w[w[g>>2]+8>>2]](g);Ib(g)}i=a+16|0;w[a+1060>>2]=0;w[a+1064>>2]=0;w[a+1056>>2]=c;u[a+1080|0]=d;d=a+1068|0;w[d>>2]=0;w[d+4>>2]=0;w[a+1076>>2]=0;j=a+1060|0;k=e+32|0;d=c;h=1;g=0;a:{b:{while(1){w[a+1060>>2]=0;w[a+1064>>2]=0;l=h;if(w[c>>2]){while(1){c:{d=w[b+8>>2];f=w[b>>2];h=w[w[f>>2]+36>>2];w[114256]=0;d=S(h|0,f|0,d|0,2)|0;f=w[114256];w[114256]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break c}w[114256]=0;d=Q(197,b|0,e+16|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(!d){break d}d=y[e+16>>1];if(!d){break d}w[114256]=0;U(188,e|0,b|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break f}w[e+16>>2]=w[e>>2];d=w[e+4>>2];w[e+20>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[e+12>>2];w[e+24>>2]=w[e+8>>2];w[e+28>>2]=d;d=Cb(k,0,1040);he(a,e+16|0);f=w[e+28>>2];w[a+8>>2]=w[e+24>>2];w[a+12>>2]=f;Fb(i,d,1040);d=w[e+20>>2];h:{if(!d){break h}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break h}ob[w[w[d>>2]+8>>2]](d);Ib(d)}d=w[e+4>>2];i:{if(!d){break i}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){break i}ob[w[w[d>>2]+8>>2]](d);Ib(d)}w[a+1072>>2]=0;w[a+1076>>2]=0;f=w[a+1056>>2];d=w[f+20>>2];if(u[f+34|0]&1){w[114256]=0;T(198,a|0,d+(g<<1)|0);d=w[114256];w[114256]=0;if((d|0)!=1){break d}break e}w[114256]=0;T(199,a|0,d+g|0);d=w[114256];w[114256]=0;if((d|0)==1){break e}break d}d=P()|0;break a}d=P()|0;break a}d=P()|0;break a}d=W(75512)|0;if((kb|0)!=(fa(75512)|0)){break a}$(d|0)|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;if((d|0)==1){break b}}if(z[j>>2]<z[c>>2]){continue}}break}d=w[a+1056>>2]}f=l&(x[d+34|0]&64)>>>6;g=1;h=0;if(f){continue}break}jb=e+1072|0;return a|0}d=P()|0}Bb(a);R(d|0);M()}function UO(a,b){a=a|0;b=b|0;var c=D(0),d=D(0),e=0,f=D(0),g=0,h=0,i=D(0),k=D(0),m=D(0);h=jb-80|0;jb=h;a:{b:{c:{d:{e:{switch(b-1|0){case 0:c=A[a+48>>2];a=w[a+48>>2];f:{g:{h:{if((a|0)<=8388607){d=D(D(-1)/D(c*c));if(!(a&2147483647)){break f}d=D(D(c-c)/D(0));if((a|0)<0){break f}a=(p(D(c*D(33554432))),j(2));b=-152;break h}if(a>>>0>2139095039){break g}b=-127;c=D(0);if((a|0)==1065353216){break g}}a=a+4913933|0;m=D((a>>>23|0)+b|0);i=D((l(2,(a&8388607)+1060439283|0),q())+D(-1));k=D(i*D(i*D(.5)));c=D(i/D(i+D(2)));f=D(c*c);d=D(f*f);d=D(c*D(k+D(D(f*D(D(d*D(.2849878668785095))+D(.6666666269302368)))+D(d*D(D(d*D(.24279078841209412))+D(.40000972151756287))))));c=(l(2,(p(D(i-k)),j(2))&-4096),q());f=D(d+D(D(i-c)-k));c=D(D(m*D(.3010292053222656))+D(D(c*D(.434326171875))+D(D(f*D(.434326171875))+D(D(m*D(7.903415166765626e-7))+D(D(f+c)*D(-3168997136526741e-20))))))}d=c}f=D(d*D(2e3));if(D(E(f))<D(2147483648)){g=~~f;break c}g=-2147483648;break c;case 1:g=(C(w[w[a+24>>2]+24604>>2],100)|0)/128|0;break c;case 2:a=u[w[a+24>>2]+24648|0];if(a>>>0<6){break d}b=ba(8)|0;w[114256]=0;e=Q(5,h+40|0,1613)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=Pb(b,e);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}a=P()|0;ca(b|0);break b;case 3:b=w[a+24>>2];a=w[b+24640>>2];e=w[b+24636>>2];if((e|0)==w[ph(h+40|0)+32>>2]){g=-1;if(w[b+24640>>2]==w[ph(h)+36>>2]){break c}}a=(a|0)<(e|0)?e:a;g=0;if((a|0)<=0){break c}g=(a+500>>>0)/1e3|0;break c;default:break e}}b=ba(8)|0;w[114256]=0;e=Q(5,h+40|0,6325)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=Pb(b,e);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}a=P()|0;ca(b|0);break b}g=w[(a<<2)+37504>>2]}a=g;jb=h+80|0;return a|0}R(a|0)}M()}function gT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{c=w[b+1304396>>2];if(!c){c=Kb(12);w[114256]=0;d=V(1086,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}c=b+1304396|0;kk(c,d);c=w[c>>2]}d=jb+-64|0;jb=d;e=Hb(d+32|0,a+80|0);w[114256]=0;T(959,d+48|0,e|0);f=w[114256];w[114256]=0;b:{c:{d:{e:{f:{g:{h:{if((f|0)!=1){if(u[e+11|0]<0){zb(w[e>>2])}i=w[c>>2];n=w[c+4>>2];if((i|0)!=(n|0)){break h}c=0;break g}c=P()|0;if(u[e+11|0]<0){break d}break c}f=0;while(1){m=0;c=w[i>>2];if(w[c+32>>2]==w[a+16>>2]){m=w[c+36>>2]==w[a+20>>2]}i:{j:{k:{l:{m:{if(u[c+19|0]>=0){w[d+8>>2]=w[c+16>>2];e=w[c+12>>2];w[d>>2]=w[c+8>>2];w[d+4>>2]=e;break m}e=w[c+12>>2];c=w[c+8>>2];w[114256]=0;U(76,d|0,c|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break l}}w[114256]=0;T(959,d+16|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break k}g=0;h=x[d+27|0];k=h<<24>>24;e=x[d+59|0];c=e<<24>>24;l=(c|0)<0?w[d+52>>2]:e;e=(k|0)<0?w[d+20>>2]:h;n:{o:{p:{if((l|0)!=(e|0)){break p}c=(c|0)<0?w[d+48>>2]:d+48|0;q:{g=(k|0)<0;if(!g){e=d+16|0;if(k){break q}g=1;break n}h=w[d+16>>2];if(!e){g=1;break o}g=!Jb(g?h:d+16|0,c,e);break o}while(1){l=x[e|0];o=x[c|0];g=(l|0)==(o|0);if((l|0)!=(o|0)){break p}c=c+1|0;e=e+1|0;h=h-1|0;if(h){continue}break}}if((k|0)>=0){break n}h=w[d+16>>2]}zb(h)}if(u[d+11|0]<0){zb(w[d>>2])}if(!(g&m)){break j}f=w[i>>2];j=3;break i}c=P()|0;break e}c=P()|0;if(u[d+11|0]>=0){break e}zb(w[d>>2]);break e}if((j|0)<2&m){f=w[i>>2];j=2;break i}c=(j|0)<=0&g;f=c?w[i>>2]:f;j=c?1:j}i=i+4|0;if((n|0)!=(i|0)){continue}break}c=0;if(!f){break g}j=w[f+4>>2];if(!j){break g}w[114256]=0;a=S(j|0,f|0,b|0,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}c=(a|0)!=0}if(u[d+59|0]<0){zb(w[d+48>>2])}jb=d- -64|0;break b}c=P()|0}e=d+48|0;if(u[d+59|0]>=0){break c}}zb(w[e>>2])}R(c|0);M()}return c|0}a=P()|0;zb(c);R(a|0);M()}function wu(a){var b=0,c=0,d=0,e=0,f=0;if(!w[a+80>>2]){zb(w[a+20>>2])}c=w[a+24>>2];if((c|0)>0){while(1){if(!w[a+80>>2]){zb(w[w[a+28>>2]+(b<<2)>>2]);c=w[a+24>>2]}b=b+1|0;if((c|0)>(b|0)){continue}break}}if(!w[a+80>>2]){zb(w[a+28>>2])}if(!(!w[a+396>>2]|w[a+264>>2]<=0)){while(1){d=w[a+396>>2]+C(f,24)|0;a:{if(w[d+16>>2]){c=w[a+124>>2];e=x[d+13|0];if(w[(c+C(e,2096)|0)+4>>2]>0){b=0;while(1){if(!w[a+80>>2]){zb(w[w[d+16>>2]+(b<<2)>>2]);e=x[d+13|0];c=w[a+124>>2]}b=b+1|0;if((b|0)<w[(C(e,2096)+c|0)+4>>2]){continue}break}}if(w[a+80>>2]){break a}zb(w[d+16>>2])}if(w[a+80>>2]){break a}zb(w[d+20>>2])}f=f+1|0;if((f|0)<w[a+264>>2]){continue}break}}b:{if(w[a+124>>2]){if(w[a+120>>2]>0){b=0;while(1){c:{if(w[a+80>>2]){break c}c=w[a+124>>2]+C(b,2096)|0;zb(w[c+8>>2]);if(w[a+80>>2]){break c}zb(w[c+28>>2]);if(w[a+80>>2]){break c}zb(w[c+32>>2]);if(w[a+80>>2]){break c}zb(w[c+2084>>2]);if(w[a+80>>2]){break c}c=w[c+2088>>2];zb(c?c-4|0:0)}b=b+1|0;if((b|0)<w[a+120>>2]){continue}break}}if(w[a+80>>2]){break b}zb(w[a+124>>2])}if(w[a+80>>2]){break b}zb(w[a+260>>2]);if(w[a+80>>2]){break b}zb(w[a+396>>2])}d:{if(!w[a+404>>2]){break d}c=w[a+400>>2];if((c|0)>0){b=0;while(1){if(!w[a+80>>2]){zb(w[(w[a+404>>2]+C(b,40)|0)+4>>2]);c=w[a+400>>2]}b=b+1|0;if((c|0)>(b|0)){continue}break}}if(w[a+80>>2]){break d}zb(w[a+404>>2])}c=1;e:{if(w[a+4>>2]<=0){break e}b=0;while(1){f:{if(w[a+80>>2]){break f}d=(b<<2)+a|0;zb(w[d+800>>2]);if(w[a+80>>2]){break f}zb(w[d+928>>2]);if(w[a+80>>2]){break f}zb(w[d+996>>2])}if(b>>>0>14){break e}b=b+1|0;if((b|0)<w[a+4>>2]){continue}break}}e=0;while(1){g:{if(w[a+80>>2]){break g}b=(e<<2)+a|0;zb(w[b+1068>>2]);if(w[a+80>>2]){break g}zb(w[b+1076>>2]);if(w[a+80>>2]){break g}zb(w[b+1084>>2]);if(w[a+80>>2]){break g}zb(w[b+1092>>2]);if(w[a+80>>2]){break g}zb(w[b+1100>>2])}e=1;b=c&1;c=0;if(b){continue}break}}function SB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a|0]=0;c=x[b|0];if(c){u[a|0]=c>>>0>96?-1:c+12|0}u[a+1|0]=x[b+1|0];c=x[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){u[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:u[a+2|0]=4;c=c&15;break b;case 1:u[a+2|0]=3;c=c&15;break b;case 2:u[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}u[a+2|0]=5;c=c&15}u[a+4|0]=c}c=x[b+6|0];e=x[b+4|0];d=x[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}u[a+2|0]=15;u[a+3|0]=20;u[a+4|0]=c>>>3;c=x[b+5|0];u[a+5|0]=(c>>>0>=15?15:c)|208;break d}u[a+5|0]=d;u[a+3|0]=c;We(a);f=x[b+6|0]==15;break d}u[a+3|0]=2;c=c<<4|(d&240)>>>4;u[a+5|0]=(c|0)>=255?255:c;break d}u[a+3|0]=3;c=c<<4|(d&240)>>>4;u[a+5|0]=(c|0)>=255?255:c;break d}u[a+3|0]=4;c=c<<4|(d&240)>>>4;u[a+5|0]=(c|0)>=255?255:c;break d}u[a+3|0]=5;u[a+5|0]=c&240|(d&240)>>>4;break d}if(d){u[a+5|0]=d;u[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}u[a+5|0]=145;u[a+3|0]=20;break d}u[a+3|0]=13;u[a+5|0]=c>>>1;break d}if(c){u[a+5|0]=c;u[a+3|0]=17;break d}u[a+3|0]=16;u[a+5|0]=d&15;break d}u[a+5|0]=d;u[a+3|0]=c;Lk(a,1);f=(x[a+3|0]&254)==16;break d}u[a+5|0]=d;u[a+3|0]=18;break d}u[a+3|0]=31;u[a+5|0]=c>>>1;break d}u[a+3|0]=31;u[a+5|0]=c>>>1&120;break d}u[a+5|0]=159;u[a+3|0]=20;break d}u[a+3|0]=21;u[a+5|0]=c>>>2}b=x[b+3|0];t:{if(!b){break t}if(!x[a+3|0]){u[a+5|0]=b;u[a+3|0]=9;return f|0}if(x[a+2|0]){break t}u[a+2|0]=2;u[a+4|0]=b>>>2}return f|0}function VM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;d=-2;a:{if(!a){break a}c=w[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=w[c+11e3>>2];k=w[a+4>>2];w[c+11e3>>2]=0;b:{if(w[c+43780>>2]<0){break b}h=(b|0)==4;g=w[c+11004>>2];if(!(g?h:1)){break a}d=w[c+11008>>2]>0?9:8;w[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){w[e+12>>2]=w[a+4>>2];w[e+8>>2]=w[a+16>>2];b=w[a+12>>2];b=Bu(c,w[a>>2],e+12|0,b,b,e+8|0,d|4);w[c+43780>>2]=b;d=w[e+12>>2];w[a>>2]=d+w[a>>2];w[a+4>>2]=w[a+4>>2]-d;w[a+8>>2]=d+w[a+8>>2];w[a+48>>2]=w[c+28>>2];d=w[e+8>>2];w[a+12>>2]=d+w[a+12>>2];w[a+16>>2]=w[a+16>>2]-d;w[a+20>>2]=d+w[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}w[c+43780>>2]=-1;d=-5;break a}f=w[c+10996>>2];if(!f){j=(b|0)!=4;l=j?d|2:d;h=c+11012|0;g=w[c+10992>>2];while(1){b=w[a+4>>2];w[e+8>>2]=32768-g;w[e+12>>2]=b;f=Bu(c,w[a>>2],e+12|0,h,h+g|0,e+8|0,l);w[c+43780>>2]=f;b=w[e+12>>2];w[a>>2]=b+w[a>>2];w[a+4>>2]=w[a+4>>2]-b;w[a+8>>2]=b+w[a+8>>2];w[a+48>>2]=w[c+28>>2];b=w[e+8>>2];w[c+10996>>2]=b;d=w[a+16>>2];b=b>>>0<d>>>0?b:d;Fb(w[a+12>>2],h+w[c+10992>>2]|0,b);w[a+12>>2]=b+w[a+12>>2];w[a+16>>2]=w[a+16>>2]-b;w[a+20>>2]=b+w[a+20>>2];i=w[c+10996>>2];w[c+10996>>2]=i-b;g=b+w[c+10992>>2]&32767;w[c+10992>>2]=g;if((f|0)<0){break b}d=-5;if(!k&(f|0)==1){break a}if(!j){if(!f){d=(b|0)==(i|0)?1:-5;break a}if(w[a+16>>2]){continue}break a}if(f){d=0;if(!w[a+4>>2]|!w[a+16>>2]){break a}if((b|0)==(i|0)){continue}break a}break}d=(b|0)==(i|0);break a}b=w[a+16>>2];b=b>>>0>f>>>0?f:b;Fb(w[a+12>>2],(w[c+10992>>2]+c|0)+11012|0,b);w[a+12>>2]=b+w[a+12>>2];w[a+16>>2]=w[a+16>>2]-b;w[a+20>>2]=b+w[a+20>>2];a=w[c+10996>>2];w[c+10996>>2]=a-b;w[c+10992>>2]=b+w[c+10992>>2]&32767;d=0;if(w[c+43780>>2]){break a}d=(a|0)==(b|0);break a}d=-3}jb=e+16|0;return d|0}function Jy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0;u=w[a+16>>2];x=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];p=w[a+12>>2];j=w[a>>2];h=w[a+4>>2];q=0;break a}h=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];o=w[a+8>>2];p=w[a+12>>2];k=BV(o,p,d,0);e=j+k|0;b=nb+h|0;t=f>>>0<(e>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(o,p,n,n>>31);q=nb}l=w[a+40>>2];m=w[a+36>>2];b:{c:{if(!d){b=l>>12;e=m>>12;break c}i=a+112|0;y=(n|0)>0;while(1){t=t-1|0;b=t;k=b?k:0;q=b?q:0;e=0;g=j;r=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+u|0;b=n;d:{if(!y){break d}while(1){e:{f=(e&2147483647)<<1|g>>>31;s=v[(f<<1|2)+r>>1];f=v[r+((f&2147483646)<<1)>>1];w[114256]=0;T(604,i|0,(f+s|0)/8<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,i|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+q|0;g=g+k|0;e=g>>>0<k>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}s=w[a+120>>2];b=s+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<s>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=(e&2147483647)<<1|g>>>31;g=v[(e<<1|2)+r>>1];e=v[r+((e&2147483646)<<1)>>1];w[114256]=0;T(604,i|0,(e+g|0)/8<<16>>16);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,i|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[i>>2]=w[i>>2];w[i+4>>2]=0}w[114256]=0;g=Q(606,i|0,x|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a+32>>2];m=w[a+28>>2]+m|0;e=m>>12;w[c>>2]=w[c>>2]+C(g,e);l=b+l|0;b=l>>12;w[c+4>>2]=w[c+4>>2]+C(g,b);h=h+p|0;j=j+o|0;h=j>>>0<o>>>0?h+1|0:h;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=m;w[a>>2]=j;w[a+4>>2]=h;w[a+40>>2]=l;w[a+20>>2]=e;w[a+24>>2]=b;return}b=P()|0;w[a+40>>2]=l;w[a+36>>2]=m;w[a+20>>2]=m>>12;w[a+24>>2]=l>>12;R(b|0);M()}function Du(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0;k=jb-16|0;jb=k;a:{b:{c:{f=a+8|0;d:{if(jg(f)){f=jg(f);break d}f=Rj(f)}if(!((f|0)>(b|0)&(b|0)>=0)){c=ba(8)|0;w[114256]=0;a=Q(5,k|0,2427)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(c,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}if(c>>>0>=120){c=ba(8)|0;w[114256]=0;a=Q(5,k|0,7157)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=Pb(c,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}b=P()|0;ca(c|0);break b}f=pk(w[a+32>>2],65535);j=(f|0)==65535?255:f;h=w[a+32>>2];f=C(j,896)+h|0;i=f+1074984|0;ug(i,7,h,65535,1024);c=c+1|0;u[f+1075808|0]=c;u[f+1075805|0]=c;v[f+1075792>>1]=0;g=f+1075736|0;w[g>>2]=0;w[g+4>>2]=-1;g=f+1075724|0;w[g>>2]=0;w[g+4>>2]=-1;g=f+1075712|0;w[g>>2]=0;w[g+4>>2]=-1;fh(w[a+32>>2],i,b+1|0,0,1,1);w[f+1075680>>2]=65536;qi(w[a+32>>2],i,c,0,1,1,65535);b=2147483647;f=f+1075676|0;e=Tb(H(G(e*128,128),-128)+128);c=2147483647;e:{if(e>=2147483647){break e}c=-2147483648;if(e<=-2147483648){break e}c=~~e;if(E(e)<2147483648){break e}c=-2147483648}w[f>>2]=c;d=Tb(H(G(d*256,256),0));f:{if(d>=2147483647){break f}b=-2147483648;if(d<=-2147483648){break f}b=E(d)<2147483648?~~d:b}w[(h+C(j,896)|0)+1075672>>2]=b;h=w[a+32>>2];f=h+1074466|0;a=y[h+480212>>1];c=f+(a<<1)|0;b=f;g:{h:{if(!a){break h}while(1){if(y[b>>1]==(j|0)){break h}b=b+2|0;if((c|0)!=(b|0)){continue}break}b=c;break g}if((b|0)==(c|0)){break g}a=b+2|0;if((c|0)==(a|0)){break g}while(1){i=y[a>>1];if((i|0)!=(j|0)){v[b>>1]=i;b=b+2|0}a=a+2|0;if((c|0)!=(a|0)){continue}break}}v[h+480212>>1]=b-f>>>1;jb=k+16|0;return j|0}b=P()|0;ca(c|0)}R(b|0)}M()}function yJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=jb-432|0;jb=i;w[i+424>>2]=37;w[i+428>>2]=0;m=ij(i+424|1,9605,w[c+4>>2]);w[i+380>>2]=i+384;a=Cc();a:{if(m){k=w[c+8>>2];j=i- -64|0;w[j>>2]=g;w[j+4>>2]=h;w[i+56>>2]=e;w[i+60>>2]=f;w[i+48>>2]=k;a=Xc(i+384|0,30,a,i+424|0,i+48|0);break a}w[i+80>>2]=e;w[i+84>>2]=f;w[i+88>>2]=g;w[i+92>>2]=h;a=Xc(i+384|0,30,a,i+424|0,i+80|0)}w[i+128>>2]=1708;k=vc(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){w[114256]=0;a=ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break d}j=w[c+8>>2];w[i+16>>2]=g;w[i+20>>2]=h;w[i>>2]=j;w[114256]=0;w[i+8>>2]=e;w[i+12>>2]=f;a=Z(1753,i+380|0,a|0,i+424|0,i|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break f}break d}w[114256]=0;a=ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break d}w[i+32>>2]=e;w[i+36>>2]=f;w[114256]=0;w[i+40>>2]=g;w[i+44>>2]=h;a=Z(1753,i+380|0,a|0,i+424|0,i+32|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}}if((a|0)==-1){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break e}Hc(k,w[i+380>>2]);j=w[i+380>>2]}f=a+j|0;g=yd(j,f,c);w[i+116>>2]=1708;e=vc(i+120|0,0,i+116|0);g:{h:{if(w[i+380>>2]==(i+384|0)){a=i+128|0;break h}a=fc(a<<3);if(!a){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break e}b=P()|0;break g}Hc(e,a);l=w[i+380>>2]}w[114256]=0;Sb(i+104|0,c);h=w[114256];w[114256]=0;i:{j:{if((h|0)!=1){w[114256]=0;ma(1764,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=w[114256];w[114256]=0;if((f|0)==1){break j}Ab(i+104|0);w[114256]=0;a=la(1765,b|0,a|0,w[i+116>>2],w[i+112>>2],c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break i}Ub(e);Ub(k);jb=i+432|0;break b}b=P()|0;break g}b=P()|0;Ab(i+104|0);break g}b=P()|0}Ub(e);break c}M()}b=P()|0}Ub(k);R(b|0);M()}return a|0}function IJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=jb-256|0;jb=i;w[i+248>>2]=37;w[i+252>>2]=0;m=ij(i+248|1,9605,w[c+4>>2]);w[i+204>>2]=i+208;a=Cc();a:{if(m){k=w[c+8>>2];j=i- -64|0;w[j>>2]=g;w[j+4>>2]=h;w[i+56>>2]=e;w[i+60>>2]=f;w[i+48>>2]=k;a=Xc(i+208|0,30,a,i+248|0,i+48|0);break a}w[i+80>>2]=e;w[i+84>>2]=f;w[i+88>>2]=g;w[i+92>>2]=h;a=Xc(i+208|0,30,a,i+248|0,i+80|0)}w[i+128>>2]=1708;k=vc(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){w[114256]=0;a=ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break d}j=w[c+8>>2];w[i+16>>2]=g;w[i+20>>2]=h;w[i>>2]=j;w[114256]=0;w[i+8>>2]=e;w[i+12>>2]=f;a=Z(1753,i+204|0,a|0,i+248|0,i|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break f}break d}w[114256]=0;a=ea(1732)|0;j=w[114256];w[114256]=0;if((j|0)==1){break d}w[i+32>>2]=e;w[i+36>>2]=f;w[114256]=0;w[i+40>>2]=g;w[i+44>>2]=h;a=Z(1753,i+204|0,a|0,i+248|0,i+32|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}}if((a|0)==-1){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break e}Hc(k,w[i+204>>2]);j=w[i+204>>2]}f=a+j|0;g=yd(j,f,c);w[i+116>>2]=1708;e=vc(i+120|0,0,i+116|0);g:{h:{if(w[i+204>>2]==(i+208|0)){a=i+128|0;break h}a=fc(a<<1);if(!a){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break e}b=P()|0;break g}Hc(e,a);l=w[i+204>>2]}w[114256]=0;Sb(i+104|0,c);h=w[114256];w[114256]=0;i:{j:{if((h|0)!=1){w[114256]=0;ma(1754,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=w[114256];w[114256]=0;if((f|0)==1){break j}Ab(i+104|0);w[114256]=0;a=la(15,b|0,a|0,w[i+116>>2],w[i+112>>2],c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break i}Ub(e);Ub(k);jb=i+256|0;break b}b=P()|0;break g}b=P()|0;Ab(i+104|0);break g}b=P()|0}Ub(e);break c}M()}b=P()|0}Ub(k);R(b|0);M()}return a|0}function Fk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;d=c&4;a:{b:{if(!(b&4)){if(!d){break b}u[a+15|0]=x[a+16|0];b=x[a+12|0];u[a+12|0]=b&247;d=!(b&2);b=x[a+14|0];if(d|b>>>0<=x[a+13|0]){break b}d=w[a>>2];e=w[a+4>>2]-d>>2;if(e>>>0<=b>>>0){break b}while(1){g=d+(b<<2)|0;v[g>>1]=y[g>>1]+1;b=b+1|0;if((e|0)!=(b|0)){continue}break}break b}if(d){break b}b=x[a+14|0];c:{if(b>>>0>=x[a+15|0]){break c}d=x[a+12|0];if(!(d&2)){break c}u[a+12|0]=d&251}if(!(x[a+12|0]&2)|b>>>0<=x[a+13|0]){break b}d=w[a>>2];e=w[a+4>>2]-d>>2;if(e>>>0<=b>>>0){break b}f=e;e=b-1|0;if(f>>>0<=e>>>0){break a}e=y[d+(e<<2)>>1];d=y[d+(b<<2)>>1];if((e|0)<(d-1|0)){b=d-1|0;d=oh(a,b&65535,64,64);e=w[a>>2];g=x[a+14|0];u[h+10|0]=d;v[h+8>>1]=b;e=e+(g<<2)|0;g=h+8|0;j=jb-32|0;jb=j;d:{b=w[a+4>>2];f=w[a+8>>2];if(b>>>0<f>>>0){if((b|0)==(e|0)){b=y[g>>1]|y[g+2>>1]<<16;v[e>>1]=b;v[e+2>>1]=b>>>16;w[a+4>>2]=e+4;break d}d=b;f=b-4|0;if(b>>>0>f>>>0){while(1){i=y[f>>1]|y[f+2>>1]<<16;v[d>>1]=i;v[d+2>>1]=i>>>16;d=d+4|0;f=f+4|0;if(b>>>0>f>>>0){continue}break}}w[a+4>>2]=d;d=e+4|0;if((d|0)!=(b|0)){f=b;b=b-d|0;hc(f-(b&-4)|0,e,b)}v[e>>1]=y[g>>1];u[e+2|0]=x[g+2|0];break d}d=b;b=w[a>>2];d=(d-b>>2)+1|0;if(d>>>0<1073741824){f=f-b|0;i=f>>1;b=ud(j+8|0,f>>>0>=2147483644?1073741823:d>>>0<i>>>0?i:d,e-b>>2,a+8|0);w[114256]=0;T(703,b|0,g|0);d=w[114256];w[114256]=0;e:{if((d|0)==1){break e}w[114256]=0;S(704,a|0,b|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}d=w[b+8>>2];e=w[b+4>>2];if((d|0)!=(e|0)){w[b+8>>2]=d+((e-d|0)+3&-4)}b=w[b>>2];if(!b){break d}zb(b);break d}c=P()|0;a=w[b+8>>2];d=w[b+4>>2];if((a|0)!=(d|0)){w[b+8>>2]=a+((d-a|0)+3&-4)}a=w[b>>2];if(a){zb(a)}R(c|0);M()}Mb(a);M()}jb=j+32|0;break b}u[a+14|0]=b-1}if((c|0)!=16777216){u[a+17|0]=255}jb=h+16|0;return}Bc(a);M()}function py(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=w[a>>2];b:{if(w[a+8>>2]-d>>5>>>0>=b>>>0){l=w[a+4>>2]-d>>5;f=b>>>0>l>>>0?l:b;if(f){while(1){if((c|0)!=(d|0)){c:{j=w[c+4>>2];h=w[c>>2];e=j-h|0;k=e>>1;g=w[d+8>>2];i=w[d>>2];if(k>>>0<=g-i>>1>>>0){e=w[d+4>>2]-i|0;g=e+h|0;e=e>>1;m=e>>>0<k>>>0?g:j;n=m-h|0;if((h|0)!=(m|0)){hc(i,h,n)}if(e>>>0<k>>>0){h=w[d+4>>2];if((j|0)!=(m|0)){while(1){v[h>>1]=y[g>>1];h=h+2|0;g=g+2|0;if((j|0)!=(g|0)){continue}break}}w[d+4>>2]=h;break c}w[d+4>>2]=i+n;break c}if(i){w[d+4>>2]=i;zb(i);w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;g=0}if((e|0)>=0){sh(d,g>>>0>=2147483646?2147483647:g>>>0>k>>>0?g:k);g=w[d+4>>2];if((h|0)!=(j|0)){while(1){v[g>>1]=y[h>>1];g=g+2|0;h=h+2|0;if((j|0)!=(h|0)){continue}break}}w[d+4>>2]=g;break c}Mb(d);M()}Wm(d+12|0,c+12|0);v[d+28>>1]=y[c+28>>1]}d=d+32|0;f=f-1|0;if(f){continue}break}}if(b>>>0>l>>>0){f=w[a+4>>2];b=f+(b-l<<5)|0;d:{while(1){w[114256]=0;d=Q(709,f|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}f=d+32|0;if((f|0)!=(b|0)){continue}break}break a}break b}b=w[a>>2]+(b<<5)|0;d=w[a+4>>2];if((b|0)!=(d|0)){while(1){d=d-32|0;mh(d);if((b|0)!=(d|0)){continue}break}}break a}e=w[a>>2];if(e){d=e;f=w[a+4>>2];if((d|0)!=(f|0)){while(1){f=f-32|0;mh(f);if((e|0)!=(f|0)){continue}break}d=w[a>>2]}w[a+4>>2]=e;zb(d);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0}e:{if(b>>>0<134217728){d=w[a+8>>2]-w[a>>2]|0;e=d>>4;e=d>>>0>=2147483616?134217727:b>>>0<e>>>0?e:b;if(e>>>0>=134217728){Mb(a);M()}e=e<<5;d=Kb(e);w[a>>2]=d;w[a+4>>2]=d;w[a+8>>2]=d+e;f=w[a+4>>2];b=f+(b<<5)|0;while(1){w[114256]=0;d=Q(709,f|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}f=d+32|0;if((f|0)!=(b|0)){continue}break}break a}Mb(a);M()}}b=P()|0;w[a+4>>2]=f;R(b|0);M()}w[a+4>>2]=b}function fd(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=w[a+8>>2]+(C(y[a+14>>1],(x[a+80|0]?c:0)+b|0)>>>1|0)|0;w[a+8>>2]=i;j=x[a+79|0]?y[w[a>>2]+3836>>1]:j;g=y[a+20>>1];l=y[a+22>>1];m=y[a+70>>1];a:{b:{c:{d:{switch(w[a+16>>2]){case 1:b=y[w[a>>2]+3832>>1];c=y[a+26>>1]?y[a+48>>1]>>>y[w[a+52>>2]+((b>>>y[a+44>>1]&7)<<1)>>1]|0:0;h=b;b=y[a+46>>1];f=g+(b?h&b?0:c:c)|0;v[a+20>>1]=f;b=2;c=y[a+28>>1];if((c|0)<=f<<16>>16){break c}break b;case 2:if(x[a+78|0]){break b}case 3:b=0;c=y[w[a>>2]+3832>>1];f=y[a+30>>1]?y[a+60>>1]>>>y[w[a+64>>2]+((c>>>y[a+56>>1]&7)<<1)>>1]|0:0;h=c;c=y[a+58>>1];c=g+(c?h&c?0:f:f)|0;v[a+20>>1]=c;if(c<<16>>16<511){break b}w[a+16>>2]=-1;v[a+20>>1]=511;w[a+72>>2]=0;break a;default:b=0;w[a+72>>2]=0;break a;case 0:break d}}b=1;c=0;f=y[w[a>>2]+3832>>1];h=y[a+24>>1]?C((g^-1)<<16>>16,y[a+36>>1]>>>y[w[a+40>>2]+((f>>>y[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;k=y[a+34>>1];f=g+(k?f&k?0:h:h)|0;v[a+20>>1]=f;if(f<<16>>16>0){break b}}w[a+16>>2]=b;v[a+20>>1]=c}g=((g+l|0)+m|0)+j<<3;if(e){d=(v[a+74>>1]+v[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(y[a+12>>1]){case 0:d=(b&512)>>>9|0;b=y[((b&256?c^255:c)<<1)+24800>>1];break e;case 1:d=0;b=y[((b&512?0:b&256?c^255:c)<<1)+24800>>1];break e;case 2:d=0;b=y[((b&256?c^255:c)<<1)+24800>>1];break e;case 3:d=0;b=y[((b&256?0:c)<<1)+24800>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=y[(e<<1)+24800>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=y[(b<<1)+24800>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}v[a+74>>1]=y[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^y[((a&255)<<1)+24288>>1]+1024>>>(a>>>8)<<1;v[c+72>>1]=b}return b<<16>>16}function Pd(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;a:{if((b|0)==189){u[a+3843|0]=c>>>7;u[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=C(b>>>0<3?b:b+6|0,44)+a|0;g=c&d;u[e+188|0]=!g;w[e+52>>2]=g?e+148|0:0;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}u[a+3842|0]=c>>>6&1;b=0;while(1){yk((C(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if(d-160>>>0<=32){d=b&15;if(d>>>0>8){break a}e=b&256?d+9|0:d;d=C(e,44)+a|0;w[f+8>>2]=d+16;d=w[d+52>>2];w[f+12>>2]=d;d=d?2:1;b:{b=b&240;if((b|0)!=160){if((b|0)==192){break b}if((b|0)!=176){break a}g=(c&3)<<8;e=c>>>2&7;a=0;c=(c&32)!=0;while(1){b=w[(f+8|0)+(a<<2)>>2];so(w[b>>2],c);so(w[b+4>>2],c);v[b+22>>1]=e;w[b+24>>2]=y[b+20>>1]<<e;yk(b);h=g|x[b+20|0];v[b+20>>1]=h;w[b+24>>2]=h<<y[b+22>>1];yk(b);a=a+1|0;if((d|0)!=(a|0)){continue}break}break a}a=0;while(1){b=w[(f+8|0)+(a<<2)>>2];e=y[b+20>>1]&768|c;v[b+20>>1]=e;w[b+24>>2]=e<<y[b+22>>1];a=a+1|0;if((d|0)!=(a|0)){continue}break}break a}a=C(e,44)+a|0;u[a+57|0]=c>>>4&1;u[a+58|0]=c>>>5&1;v[a+48>>1]=c&1;b=a;a=c>>>1&7;v[b+46>>1]=a?9-a|0:0;break a}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=u[(b&31)+25392|0];a=e+C(b&256?a+18|0:a,84)|0;b=a+808|0;c:{switch(d-32>>>5|0){case 0:u[a+888|0]=c>>>6&1;u[a+887|0]=c>>>7;u[a+886|0]=c>>>5&1;u[a+885|0]=c>>>4&1;sg(b);v[a+822>>1]=y[((c&15)<<1)+25424>>1];break a;case 1:b=x[(c>>>6|0)+17253|0];v[a+876>>1]=b;d=w[a+812>>2];e=y[d+20>>1];d=y[d+22>>1];v[a+830>>1]=c<<2&252;v[a+878>>1]=x[((d<<4|e>>>6)&65535)+25456|0]>>>b;break a;case 2:v[a+832>>1]=c>>>4;sg(b);v[a+834>>1]=c&15;sg(b);break a;case 3:v[a+838>>1]=c&15;v[a+836>>1]=c>>>0>239?496:c&240;sg(b);break a;case 6:break c;default:break a}}v[a+820>>1]=c&7}jb=f+16|0}function sU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb+-64|0;jb=c;u[c+8|0]=0;g=c+9|0;w[c+28>>2]=g;w[c+24>>2]=c+8;Ob(a,c+24|0);e=x[c+8|0];i=(e&252)>>>2|0;e=e&3;if(e){e=-1<<e;h=(e>>>0>=4294967294?-2:e)^-1;while(1){u[c+8|0]=0;w[c+28>>2]=g;w[c+24>>2]=c+8;Ob(a,c+24|0);k=x[c+8|0];e=f;f=l+1|0;e=f?e:e+1|0;l=f;f=e;e=(l<<3)-2|0;m=e&31;if((e&63)>>>0>=32){e=k<<m;n=0}else{e=(1<<m)-1&k>>>32-m;n=k<<m}i=n|i;j=e|j;if((h|0)!=(l|0)|f){continue}break}f=!j&i>>>0>=256|(j|0)!=0;i=f?256:i;j=f?0:j}a:{b:{c:{d:{e:{if(j|i){k=c+57|0;m=c+10|0;l=0;f=0;while(1){v[c+8>>1]=0;w[c+28>>2]=m;e=c+8|0;w[c+24>>2]=e;Ob(a,c+24|0);v[c+38>>1]=y[c+8>>1];w[c+32>>2]=0;w[114256]=0;w[c+24>>2]=0;w[c+28>>2]=0;u[c+56|0]=0;w[c+12>>2]=k;w[c+8>>2]=c+56;e=kc(a,e);g=nb;h=w[114256];w[114256]=0;if((h|0)==1){break d}f:{if((e|0)!=1|g){break f}e=0;g=x[c+56|0];if(!g){break f}while(1){w[114256]=0;u[c+56|0]=0;w[c+12>>2]=k;w[c+8>>2]=c+56;h=kc(a,c+8|0);o=nb;n=w[114256];w[114256]=0;if((n|0)==1){break e}if((h|0)!=1|o){break f}h=u[c+56|0];w[114256]=0;T(71,c+24|0,h|0);h=w[114256];w[114256]=0;if((h|0)==1){break e}e=e+1|0;if((e&255)!=(g|0)){continue}break}}w[114256]=0;U(6,c+8|0,d|0,c+24|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;e=c+38|0;w[c+48>>2]=e;ia(970,c+56|0,b|0,e|0,35814,c+48|0,c+40|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}e=w[c+56>>2];if(u[e+31|0]<0){zb(w[e+20>>2])}g=w[c+12>>2];w[e+20>>2]=w[c+8>>2];w[e+24>>2]=g;w[e+28>>2]=w[c+16>>2];if(u[c+35|0]<0){zb(w[c+24>>2])}e=l+1|0;f=e?f:f+1|0;l=e;if((i|0)!=(e|0)|(f|0)!=(j|0)){continue}break}}jb=c- -64|0;return}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;if(u[c+19|0]>=0){break a}zb(w[c+8>>2])}if(u[c+35|0]<0){zb(w[c+24>>2])}R(a|0);M()}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=jb-176|0;jb=c;a=mg(c+48|0,a);w[114256]=0;d=Q(5,c+32|0,35808)|0;f=w[114256];w[114256]=0;a:{b:{c:{d:{if((f|0)!=1){w[114256]=0;w[c+152>>2]=19469585;w[c+156>>2]=0;U(397,a|0,d|0,c+152|0);f=w[114256];w[114256]=0;if((f|0)==1){break d}if(u[d+11|0]<0){zb(w[d>>2])}if(!(x[a+3|0]&64)){break c}break a}b=P()|0;break b}b=P()|0;if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}f=w[b>>2];g=w[b+4>>2];w[114256]=0;v[c+30>>1]=65535;d=Q(5,c+16|0,6045)|0;e=w[114256];w[114256]=0;f=(g-f|0)/52|0;e:{f:{g:{if((e|0)!=1){w[114256]=0;g=S(715,a|0,c+30|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}if(u[d+11|0]<0){zb(w[d>>2])}d=((g|0)==1?f:y[c+30>>1])&65535;f=y[w[19467]+10>>1];f=d>>>0<f>>>0?d:f;if(f>>>0<=((w[b+4>>2]-w[b>>2]|0)/52&65535)>>>0){break f}w[114256]=0;T(215,b|0,f|0);d=w[114256];w[114256]=0;if((d|0)!=1){break e}b=P()|0;break b}b=P()|0;break b}b=P()|0;if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}if(!f){break a}}d=0;while(1){h:{h=w[b>>2];w[114256]=0;u[c+11|0]=2;w[c>>2]=d;g=Q(399,a|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}e=w[a+28>>2];w[114256]=0;T(400,c+152|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}e=w[c+164>>2];w[c+168>>2]=w[c+160>>2];w[c+172>>2]=e;i:{j:{if(!g){e=-1;if(!(x[a+24|0]&32)){break j}break i}e=w[g+8>>2]}i=w[a+28>>2];w[114256]=0;U(957,i|0,h+C(d,52)|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break h}}w[114256]=0;Z(402,a|0,g|0,c|0,c+168|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break h}if(u[c+11|0]<0){zb(w[c>>2])}d=d+1|0;if((f|0)!=(d|0)){continue}break a}break}b=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2])}Mf(a);R(b|0);M()}b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}b=w[a+32>>2];if(b){w[a+36>>2]=b;zb(b)}jb=c+176|0}function Wy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;r=w[a+16>>2];i=jb-32|0;e=w[a+44>>2];w[i+12>>2]=e;f=w[a+48>>2];w[i+16>>2]=f;g=w[a+52>>2];w[i+20>>2]=g;h=w[a+56>>2];w[i+24>>2]=h;k=w[a>>2];j=w[a+4>>2];if(d){s=b+24|0;q=w[a+8>>2];t=w[a+12>>2];u=w[a+24>>2];x=w[a+20>>2];y=w[a+72>>2];b=w[a+68>>2];z=b;A=b>>31;b=w[a+64>>2];B=b;D=b>>31;b=w[a+60>>2];E=b;F=b>>31;while(1){b=1;e=((((j&2147483647)<<1|k>>>31)&2147483646)<<1)+r|0;f=(((k>>>16|0)+4&131064)<<1)+s|0;l=v[f+14>>1];m=v[f+12>>1];n=v[f+10>>1];o=v[f+8>>1];G=v[f+6>>1];H=v[f+4>>1];I=v[f+2>>1];J=v[f>>1];g=0;h=1;f=0;while(1){p=(f<<2)+i|0;f=f<<1;w[p>>2]=(((((C(v[e+(f|8)>>1],n)+C(v[e+(f|4)>>1],o)|0)+C(v[e+(f|12)>>1],m)|0)+C(v[e+(f|16)>>1],l)|0)/2|0)+((((C(v[e+(f|-8)>>1],I)+C(v[e+(f|-12)>>1],J)|0)+C(v[e+(f|-4)>>1],H)|0)+C(v[e+f>>1],G)|0)/2|0)|0)/16384;p=h&1;h=0;f=1;if(p){continue}break}while(1){e=(i+8|0)+(g<<3)|0;f=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;l=(g<<2)+i|0;m=w[l>>2]<<8;g=m;g=BV(E,F,g,g>>31);n=nb;o=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,B,D);g=h+g|0;e=nb+n|0;e=g>>>0<h>>>0?e+1|0:e;h=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(f,f>>31,z,A);f=h+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[o+4>>2]=e-(m&y);w[l>>2]=(e|0)/256;g=1;e=b&1;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[i>>2],x);w[c+4>>2]=w[c+4>>2]+C(w[i+4>>2],u);j=j+t|0;b=k+q|0;j=b>>>0<q>>>0?j+1|0:j;k=b;c=c+8|0;d=d-1|0;if(d){continue}break}h=w[i+24>>2];g=w[i+20>>2];f=w[i+16>>2];e=w[i+12>>2]}w[a+56>>2]=h;w[a+52>>2]=g;w[a+48>>2]=f;w[a+44>>2]=e;w[a>>2]=k;w[a+4>>2]=j}function BO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;a:{if(u[b+11|0]>=0){w[d+8>>2]=w[b+8>>2];e=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=e;break a}me(d,w[b>>2],w[b+4>>2])}f=x[c+11|0];k=f<<24>>24;l=w[c+4>>2];m=w[c>>2];b:{b=x[d+11|0];e=b<<24>>24<0;h=e?w[d+4>>2]:b;c:{d:{if(!h){break d}g=(k|0)<0;j=g?m:c;e=e?w[d>>2]:d;i=e+h|0;b=e;e:{f:{g=g?l:f;if(!g){break f}while(1){if(!uc(j,x[b|0],g)){break f}b=b+1|0;if((i|0)!=(b|0)){continue}break}break e}b=b-e|0;if((b|0)==-1){break e}w[114256]=0;S(4,d|0,0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){l=w[c+4>>2];m=w[c>>2];f=x[c+11|0];k=f;break d}b=P()|0;break b}b=-1;g:{if(!g){break g}while(1){if((e|0)==(i|0)){break g}i=i-1|0;if(!uc(j,x[i|0],g)){continue}break}b=i-e|0}e=d+16|0;if((h-1|0)==(b|0)){break c}}w[d+24>>2]=w[d+8>>2];b=w[d+4>>2];w[d+16>>2]=w[d>>2];w[d+20>>2]=b;e=d}w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;b=k<<24>>24<0;g=b?l:f;c=b?m:c;f=x[d+27|0];b=f<<24>>24<0;e=b?w[d+16>>2]:d+16|0;f=b?w[d+20>>2]:f;h=e+f|0;b=h;h:{i:{j:{while(1){if((b|0)==(e|0)){break j}b=b-1|0;if(g){if(uc(c,x[b|0],g)){continue}}break}b=b-e|0;if((b|0)==-1){break j}w[114256]=0;b=(b+e|0)+1|0;S(4,d+16|0,b-e|0,h-b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break i}b=P()|0;if(u[d+27|0]>=0){break b}zb(w[d+16>>2]);break b}if(!f|!g){break i}j=c+g|0;f=e;while(1){g=x[f|0];b=c;k:{while(1){if((g|0)!=x[b|0]){b=b+1|0;if((j|0)!=(b|0)){continue}break k}break}if((f|0)==(h|0)|(e|0)!=(f|0)){break i}break h}f=f+1|0;if((h|0)!=(f|0)){continue}break}}b=w[d+20>>2];w[a>>2]=w[d+16>>2];w[a+4>>2]=b;w[a+8>>2]=w[d+24>>2];a=d+16|0}w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;if(u[d+27|0]<0){zb(w[d+16>>2])}if(u[d+11|0]<0){zb(w[d>>2])}jb=d+32|0;return}if(u[d+11|0]<0){zb(w[d>>2])}R(b|0);M()}function Zv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;a:{b:{if(w[(w[w[b>>2]-12>>2]+b|0)+16>>2]|w[a+4>>2]-w[a>>2]>>>0>2044){break b}d=jb-16|0;jb=d;f=Kb(64);w[114256]=0;e=V(836,f|0)|0;h=w[114256];w[114256]=0;c:{d:{if((h|0)!=1){w[114256]=0;w[d+8>>2]=e;f=S(982,e|0,b|0,c|0)|0;h=w[114256];w[114256]=0;e:{f:{if((h|0)!=1){if((f|0)!=1){break f}break e}a=P()|0;w[d+8>>2]=0;od(e);break d}w[d+8>>2]=0;od(e);e=0}jb=d+16|0;break c}a=P()|0;zb(f)}R(a|0);M()}w[g>>2]=e;g:{if(e){break g}d=jb-16|0;jb=d;f=Kb(64);w[114256]=0;e=V(836,f|0)|0;h=w[114256];w[114256]=0;h:{i:{if((h|0)!=1){w[114256]=0;w[d+8>>2]=e;b=S(983,e|0,b|0,c|0)|0;c=w[114256];w[114256]=0;j:{k:{if((c|0)!=1){if((b|0)!=1){break k}b=e;break j}a=P()|0;w[d+8>>2]=0;od(e);break i}w[d+8>>2]=0;od(e);b=0}jb=d+16|0;break h}a=P()|0;zb(f)}R(a|0);M()}e=b;w[g>>2]=b;if(b){break g}e=0;break b}b=w[a+4>>2];c=w[a+8>>2];l:{if(b>>>0<c>>>0){w[g>>2]=0;w[b>>2]=e;w[a+4>>2]=b+4;break l}d=w[a>>2];f=b-d>>2;b=f+1|0;if(b>>>0>=1073741824){w[114256]=0;X(980,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}M()}w[114256]=0;c=c-d|0;d=c>>1;d=Z(981,g+8|0,(c>>>0>=2147483644?1073741823:b>>>0<d>>>0?d:b)|0,f|0,a+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}b=w[d+8>>2];c=w[g>>2];w[g>>2]=0;w[b>>2]=c;h=b+4|0;w[d+8>>2]=h;f=w[d+4>>2];b=w[a+4>>2];c=w[a>>2];m:{if((b|0)==(c|0)){b=c;break m}while(1){b=b-4|0;h=w[b>>2];w[b>>2]=0;w[f-4>>2]=h;f=w[d+4>>2]-4|0;w[d+4>>2]=f;if((b|0)!=(c|0)){continue}break}h=w[d+8>>2];c=w[a+4>>2];b=w[a>>2]}w[a>>2]=f;w[d+4>>2]=b;w[a+4>>2]=h;w[d+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=c;Yv(d)}a=w[g>>2];w[g>>2]=0;if(!a){break b}od(a)}jb=g+32|0;return e|0}b=P()|0;a=w[g>>2];w[g>>2]=0;if(a){od(a)}R(b|0);M()}function Ky(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0;v=w[a+16>>2];x=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];p=w[a+12>>2];j=w[a>>2];h=w[a+4>>2];q=0;break a}h=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];o=w[a+8>>2];p=w[a+12>>2];k=BV(o,p,d,0);e=j+k|0;b=nb+h|0;t=f>>>0<(e>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(o,p,n,n>>31);q=nb}l=w[a+40>>2];m=w[a+36>>2];b:{c:{if(!d){b=l>>12;e=m>>12;break c}i=a+112|0;y=(n|0)>0;while(1){t=t-1|0;b=t;k=b?k:0;q=b?q:0;e=0;g=j;r=(((h&2147483647)<<1|g>>>31)&-2)+v|0;b=n;d:{if(!y){break d}while(1){e:{f=(e&2147483647)<<1|g>>>31;s=u[(f|1)+r|0];f=u[r+(f&-2)|0];w[114256]=0;T(604,i|0,f+s<<5);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,i|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+q|0;g=g+k|0;e=g>>>0<k>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}s=w[a+120>>2];b=s+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<s>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=(e&2147483647)<<1|g>>>31;g=u[(e|1)+r|0];e=u[r+(e&-2)|0];w[114256]=0;T(604,i|0,e+g<<5);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,i|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[i>>2]=w[i>>2];w[i+4>>2]=0}w[114256]=0;g=Q(606,i|0,x|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a+32>>2];m=w[a+28>>2]+m|0;e=m>>12;w[c>>2]=w[c>>2]+C(g,e);l=b+l|0;b=l>>12;w[c+4>>2]=w[c+4>>2]+C(g,b);h=h+p|0;j=j+o|0;h=j>>>0<o>>>0?h+1|0:h;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=m;w[a>>2]=j;w[a+4>>2]=h;w[a+40>>2]=l;w[a+20>>2]=e;w[a+24>>2]=b;return}b=P()|0;w[a+40>>2]=l;w[a+36>>2]=m;w[a+20>>2]=m>>12;w[a+24>>2]=l>>12;R(b|0);M()}function dO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{b:{c:{d:{e:{f=w[b+24>>2];if(y[f+480188>>1]){j=a+8|0;while(1){w[114256]=0;w[c+36>>2]=20;w[c+32>>2]=((i<<5)+f|0)+480289;T(451,c|0,c+32|0);d=w[114256];w[114256]=0;if((d|0)==1){break e}d=w[w[b+24>>2]+1304496>>2];w[114256]=0;Y(229,c+16|0,0,d|0,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}d=w[a+4>>2];e=w[a+8>>2];f:{if(d>>>0<e>>>0){e=w[c+20>>2];w[d>>2]=w[c+16>>2];w[d+4>>2]=e;w[d+8>>2]=w[c+24>>2];w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;w[a+4>>2]=d+12;break f}f=w[a>>2];g=(d-f|0)/12|0;d=g+1|0;if(d>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}M()}w[114256]=0;e=(e-f|0)/12|0;f=e<<1;g=Z(921,c+40|0,(e>>>0>=178956970?357913941:d>>>0<f>>>0?f:d)|0,g|0,j|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}e=w[c+20>>2];d=w[c+48>>2];w[d>>2]=w[c+16>>2];w[d+4>>2]=e;w[d+8>>2]=w[c+24>>2];w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;h=w[c+48>>2]+12|0;w[c+48>>2]=h;f=w[c+44>>2];e=w[a+4>>2];d=w[a>>2];g:{if((e|0)==(d|0)){e=d;break g}while(1){e=e-12|0;h=w[e+4>>2];f=f-12|0;w[f>>2]=w[e>>2];w[f+4>>2]=h;w[f+8>>2]=w[e+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;f=w[c+44>>2]-12|0;w[c+44>>2]=f;if((d|0)!=(e|0)){continue}break}d=w[a+4>>2];h=w[c+48>>2];e=w[a>>2]}w[a>>2]=f;w[c+44>>2]=e;w[a+4>>2]=h;w[c+48>>2]=d;d=w[a+8>>2];w[a+8>>2]=w[c+52>>2];w[c+52>>2]=d;w[g>>2]=e;sc(g);if(u[c+27|0]>=0){break f}zb(w[c+16>>2])}if(u[c+11|0]<0){zb(w[c>>2])}i=i+1|0;f=w[b+24>>2];if(i>>>0<y[f+480188>>1]){continue}break}}jb=c- -64|0;return}e=P()|0;break a}e=P()|0;break b}e=P()|0;if(u[c+27|0]>=0){break b}zb(w[c+16>>2])}if(u[c+11|0]>=0){break a}zb(w[c>>2])}bc(a);R(e|0);M()}function dK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;h=Wb(a+208|0);w[114256]=0;Sb(a+16|0,d);b=w[114256];w[114256]=0;a:{b:{c:{d:{if((b|0)!=1){w[114256]=0;b=V(1561,a+16|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}w[114256]=0;Z(1728,b|0,64768,64794,a+224|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}Ab(a+16|0);c=Wb(a+192|0);b=Yb(c);w[114256]=0;T(1592,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Rb(c,0);w[a+188>>2]=b;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){e:{w[114256]=0;d=Q(1710,a+264|0,a+256|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}if(!d){break c}if(w[a+188>>2]==(Db(c)+b|0)){d=Db(c);b=Db(c);w[114256]=0;T(1592,c|0,b<<1);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Yb(c);w[114256]=0;T(1592,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Rb(c,0);w[a+188>>2]=d+b}w[114256]=0;d=V(1712,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}w[114256]=0;d=kf(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break e}if(d){break c}w[114256]=0;V(1714,a+264|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;break a}b=P()|0;Ab(a+16|0);break a}w[114256]=0;T(1592,c|0,w[a+188>>2]-b|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}b=Qb(c);w[114256]=0;d=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break f}w[a>>2]=f;w[114256]=0;b=Z(1733,b|0,d|0,5192,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if((b|0)!=1){w[e>>2]=4}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(c);Gb(h);jb=a+272|0;return b|0}}b=P()|0;Gb(c)}Gb(h);R(b|0);M()}function TJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;h=Wb(a+208|0);w[114256]=0;Sb(a+16|0,d);b=w[114256];w[114256]=0;a:{b:{c:{d:{if((b|0)!=1){w[114256]=0;b=V(1735,a+16|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}w[114256]=0;Z(1749,b|0,64768,64794,a+224|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}Ab(a+16|0);c=Wb(a+192|0);b=Yb(c);w[114256]=0;T(1592,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Rb(c,0);w[a+188>>2]=b;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){e:{w[114256]=0;d=Q(1740,a+344|0,a+336|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}if(!d){break c}if(w[a+188>>2]==(Db(c)+b|0)){d=Db(c);b=Db(c);w[114256]=0;T(1592,c|0,b<<1);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Yb(c);w[114256]=0;T(1592,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=Rb(c,0);w[a+188>>2]=d+b}w[114256]=0;d=V(1742,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}w[114256]=0;d=jf(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break e}if(d){break c}w[114256]=0;V(1744,a+344|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;break a}b=P()|0;Ab(a+16|0);break a}w[114256]=0;T(1592,c|0,w[a+188>>2]-b|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}b=Qb(c);w[114256]=0;d=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break f}w[a>>2]=f;w[114256]=0;b=Z(1733,b|0,d|0,5192,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if((b|0)!=1){w[e>>2]=4}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(c);Gb(h);jb=a+352|0;return b|0}}b=P()|0;Gb(c)}Gb(h);R(b|0);M()}function Xy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;q=w[a+16>>2];i=jb-32|0;e=w[a+44>>2];w[i+12>>2]=e;k=w[a+48>>2];w[i+16>>2]=k;g=w[a+52>>2];w[i+20>>2]=g;h=w[a+56>>2];w[i+24>>2]=h;l=w[a>>2];j=w[a+4>>2];if(d){r=b+24|0;k=w[a+8>>2];s=w[a+12>>2];t=w[a+24>>2];x=w[a+20>>2];y=w[a+72>>2];b=w[a+68>>2];z=b;A=b>>31;b=w[a+64>>2];B=b;D=b>>31;b=w[a+60>>2];E=b;F=b>>31;while(1){f=(((j&2147483647)<<1|l>>>31)&-2)+q|0;b=1;e=(((l>>>16|0)+4&131064)<<1)+r|0;m=v[e+14>>1];n=v[e+12>>1];o=v[e+10>>1];p=v[e+8>>1];G=v[e+6>>1];H=v[e+4>>1];I=v[e+2>>1];J=v[e>>1];g=0;h=1;e=0;while(1){w[(e<<2)+i>>2]=(((((C(u[f+(e|4)|0],o)+C(u[f+(e|2)|0],p)|0)+C(u[f+(e|6)|0],n)|0)+C(u[f+(e|8)|0],m)<<8)/2|0)+((((C(u[f+(e|-4)|0],I)+C(u[f+(e|-6)|0],J)|0)+C(u[f+(e|-2)|0],H)|0)+C(u[e+f|0],G)<<8)/2|0)|0)/16384;K=h&1;h=0;e=1;if(K){continue}break}while(1){e=(i+8|0)+(g<<3)|0;f=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;m=(g<<2)+i|0;n=w[m>>2]<<8;g=n;g=BV(E,F,g,g>>31);o=nb;p=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,B,D);g=h+g|0;e=nb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(f,f>>31,z,A);f=h+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[p+4>>2]=e-(n&y);w[m>>2]=(e|0)/256;g=1;e=b&1;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[i>>2],x);w[c+4>>2]=w[c+4>>2]+C(w[i+4>>2],t);j=j+s|0;b=k+l|0;j=b>>>0<k>>>0?j+1|0:j;l=b;c=c+8|0;d=d-1|0;if(d){continue}break}h=w[i+24>>2];g=w[i+20>>2];k=w[i+16>>2];e=w[i+12>>2]}w[a+56>>2]=h;w[a+52>>2]=g;w[a+48>>2]=k;w[a+44>>2]=e;w[a>>2]=l;w[a+4>>2]=j}function nj(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;w[i+120>>2]=b;k=ss(c,d);w[i+4>>2]=1708;m=vc(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=fc(k);if(!j){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;break b}Hc(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{w[114256]=0;h=Q(1710,a|0,i+120|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){w[114256]=0;b=Q(1711,a|0,i+120|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}if(!b){break d}w[f>>2]=w[f>>2]|2;break d}w[114256]=0;n=V(1712,a|0)|0;b=w[114256];w[114256]=0;g:{if((b|0)!=1){if(g){break g}w[114256]=0;n=Q(1713,e|0,n|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break g}}a=P()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}w[114256]=0;V(1714,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(x[h|0]!=2){break h}if((Db(b)|0)==(o|0)){break h}u[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(x[h|0]!=1){break i}p=u[Rb(b,q)|0];j:{if(g){break j}w[114256]=0;p=Q(1713,e|0,p<<24>>24)|0;s=w[114256];w[114256]=0;if((s|0)!=1){break j}a=P()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Db(b)|0)!=(o|0)){break i}u[h|0]=2;l=l+1|0;break k}u[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(x[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}w[f>>2]=w[f>>2]|4}Ub(m);jb=i+128|0;return d|0}a=P()|0}else{n:{if(!Id(b)){u[h|0]=1;break n}u[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Ub(m);R(a|0)}M()}function YI(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;w[a+608>>2]=c;w[a+616>>2]=b;w[a+16>>2]=1769;b=vc(a+200|0,a+208|0,a+16|0);w[114256]=0;Sb(a+192|0,e);h=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){w[114256]=0;h=V(1735,a+192|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break j}u[a+191|0]=0;e=w[e+4>>2];w[114256]=0;c=ua(1779,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(!c){break f}c=x[10104]|x[10105]<<8|(x[10106]<<16|x[10107]<<24);u[a+183|0]=c;u[a+184|0]=c>>>8;u[a+185|0]=c>>>16;u[a+186|0]=c>>>24;c=x[10101]|x[10102]<<8|(x[10103]<<16|x[10104]<<24);w[a+176>>2]=x[10097]|x[10098]<<8|(x[10099]<<16|x[10100]<<24);w[a+180>>2]=c;w[114256]=0;Z(1749,h|0,a+176|0,a+186|0,a+128|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}w[a+4>>2]=1708;d=vc(a+8|0,0,a+4|0);e=a+16|0;if((w[a+196>>2]-w[b>>2]|0)<393){break g}Hc(d,fc((w[a+196>>2]-w[b>>2]>>2)+2|0));if(w[d>>2]){break h}w[114256]=0;_(1709);c=w[114256];w[114256]=0;if((c|0)==1){break d}break a}c=P()|0;break b}c=P()|0;break c}c=P()|0;break c}e=w[d>>2]}if(x[a+191|0]){u[e|0]=45;e=e+1|0}c=w[b>>2];while(1){if(z[a+196>>2]<=c>>>0){u[e|0]=0;w[a>>2]=g;if((Bs(a+16|0,a)|0)!=1){w[114256]=0;X(1771,4185);c=w[114256];w[114256]=0;if((c|0)!=1){break a}break d}Ub(d)}else{h=a+128|0;j=e,k=x[(a+176|0)+(Pl(h,h+40|0,c)-h>>2)|0],u[j|0]=k;e=e+1|0;c=c+4|0;continue}break}}w[114256]=0;c=Q(1741,a+616|0,a+608|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(c){w[f>>2]=w[f>>2]|2}c=w[a+616>>2];Ab(a+192|0);Ub(b);jb=a+624|0;return c|0}c=P()|0;break c}c=P()|0;Ub(d)}Ab(a+192|0)}Ub(b);R(c|0);M()}M()}function wz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0;t=w[a+16>>2];b=jb-32|0;e=w[a+44>>2];w[b+12>>2]=e;h=w[a+48>>2];w[b+16>>2]=h;j=w[a+52>>2];w[b+20>>2]=j;k=w[a+56>>2];w[b+24>>2]=k;l=w[a>>2];i=w[a+4>>2];m=w[a+40>>2];n=w[a+36>>2];a:{if(!d){g=m>>12;f=n>>12;break a}k=w[a+8>>2];u=w[a+12>>2];x=w[a+32>>2];y=w[a+28>>2];z=w[a+72>>2];e=w[a+68>>2];A=e;B=e>>31;e=w[a+64>>2];D=e;E=e>>31;e=w[a+60>>2];F=e;G=e>>31;while(1){j=1;g=((((i&2147483647)<<1|l>>>31)&2147483646)<<1)+t|0;e=(l>>>21&2040)+32832|0;o=v[e+6>>1];p=v[e+4>>1];q=v[e+2>>1];r=v[e>>1];e=0;h=1;f=0;while(1){s=(f<<2)+b|0;f=f<<1;w[s>>2]=(((C(v[f+g>>1],q)+C(v[g+(f|-4)>>1],r)|0)+C(v[g+(f|4)>>1],p)|0)+C(o,v[g+(f|8)>>1])|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){f=(b+8|0)+(e<<3)|0;h=w[f+8>>2];g=w[f+4>>2];w[f+8>>2]=g;o=(e<<2)+b|0;p=w[o>>2]<<8;e=p;e=BV(F,G,e,e>>31);q=nb;r=f;f=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);f=f+g|0;e=nb+q|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,A,B);f=g+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[r+4>>2]=e-(p&z);w[o>>2]=(e|0)/256;e=1;f=j&1;j=0;if(f){continue}break}n=n+y|0;f=n>>12;w[c>>2]=w[c>>2]+C(f,w[b>>2]);m=m+x|0;g=m>>12;w[c+4>>2]=w[c+4>>2]+C(g,w[b+4>>2]);i=i+u|0;e=k+l|0;i=e>>>0<k>>>0?i+1|0:i;l=e;c=c+8|0;d=d-1|0;if(d){continue}break}k=w[b+24>>2];j=w[b+20>>2];h=w[b+16>>2];e=w[b+12>>2]}w[a+36>>2]=n;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=m;w[a+20>>2]=f;w[a+56>>2]=k;w[a+52>>2]=j;w[a+48>>2]=h;w[a+44>>2]=e;w[a+24>>2]=g}function eJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;w[a+272>>2]=c;w[a+280>>2]=b;w[a+16>>2]=1769;b=vc(a+152|0,a+160|0,a+16|0);w[114256]=0;Sb(a+144|0,e);h=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){w[114256]=0;h=V(1561,a+144|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break j}u[a+143|0]=0;e=w[e+4>>2];w[114256]=0;c=ua(1770,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(!c){break f}c=x[10104]|x[10105]<<8|(x[10106]<<16|x[10107]<<24);u[a+135|0]=c;u[a+136|0]=c>>>8;u[a+137|0]=c>>>16;u[a+138|0]=c>>>24;c=x[10101]|x[10102]<<8|(x[10103]<<16|x[10104]<<24);w[a+128>>2]=x[10097]|x[10098]<<8|(x[10099]<<16|x[10100]<<24);w[a+132>>2]=c;w[114256]=0;Z(1728,h|0,a+128|0,a+138|0,a+118|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break i}w[a+4>>2]=1708;d=vc(a+8|0,0,a+4|0);e=a+16|0;if((w[a+148>>2]-w[b>>2]|0)<99){break g}Hc(d,fc((w[a+148>>2]-w[b>>2]|0)+2|0));if(w[d>>2]){break h}w[114256]=0;_(1709);c=w[114256];w[114256]=0;if((c|0)==1){break d}break a}c=P()|0;break b}c=P()|0;break c}c=P()|0;break c}e=w[d>>2]}if(x[a+143|0]){u[e|0]=45;e=e+1|0}c=w[b>>2];while(1){if(z[a+148>>2]<=c>>>0){u[e|0]=0;w[a>>2]=g;if((Bs(a+16|0,a)|0)!=1){w[114256]=0;X(1771,4185);c=w[114256];w[114256]=0;if((c|0)!=1){break a}break d}Ub(d)}else{h=a+118|0;j=e,k=x[((Tl(h,h+10|0,c)-a|0)+a|0)+10|0],u[j|0]=k;e=e+1|0;c=c+1|0;continue}break}}w[114256]=0;c=Q(1711,a+280|0,a+272|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break e}if(c){w[f>>2]=w[f>>2]|2}c=w[a+280>>2];Ab(a+144|0);Ub(b);jb=a+288|0;return c|0}c=P()|0;break c}c=P()|0;Ub(d)}Ab(a+144|0)}Ub(b);R(c|0);M()}M()}function lj(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;w[i+120>>2]=b;k=ss(c,d);w[i+4>>2]=1708;m=vc(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=fc(k);if(!j){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;break b}Hc(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{w[114256]=0;h=Q(1740,a|0,i+120|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){w[114256]=0;b=Q(1741,a|0,i+120|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}if(!b){break d}w[f>>2]=w[f>>2]|2;break d}w[114256]=0;n=V(1742,a|0)|0;b=w[114256];w[114256]=0;g:{if((b|0)!=1){if(g){break g}w[114256]=0;n=Q(1743,e|0,n|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break g}}a=P()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}w[114256]=0;V(1744,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(x[h|0]!=2){break h}if((Db(b)|0)==(o|0)){break h}u[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(x[h|0]!=1){break i}p=w[kj(b,q)>>2];j:{if(g){break j}w[114256]=0;p=Q(1743,e|0,p|0)|0;s=w[114256];w[114256]=0;if((s|0)!=1){break j}a=P()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Db(b)|0)!=(o|0)){break i}u[h|0]=2;l=l+1|0;break k}u[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(x[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}w[f>>2]=w[f>>2]|4}Ub(m);jb=i+128|0;return d|0}a=P()|0}else{n:{if(!Id(b)){u[h|0]=1;break n}u[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Ub(m);R(a|0)}M()}function fT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=jb+-64|0;jb=b;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;T(1087,a|0,11);c=w[114256];w[114256]=0;a:{if((c|0)!=1){c=78512;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){h=Gd(44);if(h){g=w[c>>2];d=w[c+4>>2];w[114256]=0;d=Q(5,b+32|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break k}l:{if(u[b+43|0]>=0){w[b+56>>2]=w[d+8>>2];e=w[d+4>>2];w[b+48>>2]=w[d>>2];w[b+52>>2]=e;break l}e=w[d>>2];w[114256]=0;U(76,b+48|0,e|0,w[b+36>>2]);e=w[114256];w[114256]=0;if((e|0)==1){break j}}e=w[c+8>>2];w[114256]=0;e=Q(5,b|0,e|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break i}m:{if(u[b+11|0]>=0){w[b+24>>2]=w[e+8>>2];f=w[e+4>>2];w[b+16>>2]=w[e>>2];w[b+20>>2]=f;break m}f=w[e>>2];w[114256]=0;U(76,b+16|0,f|0,w[b+4>>2]);f=w[114256];w[114256]=0;if((f|0)==1){break h}}w[114256]=0;g=da(1088,h|0,g|0,1,b+48|0,b+16|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}if(u[b+27|0]<0){zb(w[b+16>>2])}if(u[b+11|0]<0){zb(w[e>>2])}if(u[b+59|0]<0){zb(w[b+48>>2])}if(u[b+43|0]<0){zb(w[d>>2])}w[b+60>>2]=g;d=w[a+4>>2];n:{if((d|0)!=w[a+8>>2]){w[d>>2]=g;w[a+4>>2]=d+4;break n}w[114256]=0;T(1089,a|0,b+60|0);d=w[114256];w[114256]=0;if((d|0)==1){break b}}d=w[b+60>>2];w[d+32>>2]=w[c+12>>2];w[d+36>>2]=w[c+16>>2];u[d+40|0]=x[c+20|0];u[d+41|0]=x[d+41|0]&253|x[c+21|0]<<1}c=c+24|0;if((c|0)!=78776){continue}break}jb=b- -64|0;return a|0}c=P()|0;break c}c=P()|0;break d}c=P()|0;break e}c=P()|0;break f}c=P()|0;if(u[b+27|0]>=0){break f}zb(w[b+16>>2])}if(u[b+11|0]>=0){break e}zb(w[e>>2])}if(u[b+59|0]>=0){break d}zb(w[b+48>>2])}if(u[b+43|0]>=0){break c}zb(w[d>>2])}zb(h);break a}c=P()|0;break a}c=P()|0}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(c|0);M()}function NU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=jb-32|0;jb=k;e=b;b=w[a>>2];i=(e-b|0)/6|0;h=C(i,6)+b|0;a:{b:{c:{if(!c){break c}f=w[a+8>>2];g=w[a+4>>2];if((f-g|0)/6>>>0>=c>>>0){i=g;b=c;f=(g-h|0)/6|0;if(b>>>0>f>>>0){i=g+C(c-f|0,6)|0;e=g;while(1){b=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);u[e|0]=b;u[e+1|0]=b>>>8;u[e+2|0]=b>>>16;u[e+3|0]=b>>>24;b=x[d+4|0]|x[d+5|0]<<8;u[e+4|0]=b;u[e+5|0]=b>>>8;e=e+6|0;if((i|0)!=(e|0)){continue}break}w[a+4>>2]=i;if((g|0)==(h|0)){break c}b=f}e=i;m=C(c,6)+h|0;l=e-m|0;f=C((l|0)/6|0,6)+h|0;if(g>>>0>f>>>0){while(1){j=x[f|0]|x[f+1|0]<<8|(x[f+2|0]<<16|x[f+3|0]<<24);u[e|0]=j;u[e+1|0]=j>>>8;u[e+2|0]=j>>>16;u[e+3|0]=j>>>24;j=x[f+4|0]|x[f+5|0]<<8;u[e+4|0]=j;u[e+5|0]=j>>>8;e=e+6|0;f=f+6|0;if(g>>>0>f>>>0){continue}break}}w[a+4>>2]=e;if((i|0)!=(m|0)){hc(C((l|0)/-6|0,6)+i|0,h,l);e=w[a+4>>2]}a=C(d>>>0>=h>>>0?d>>>0<e>>>0?c:0:0,6)+d|0;e=h;while(1){c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);u[e|0]=c;u[e+1|0]=c>>>8;u[e+2|0]=c>>>16;u[e+3|0]=c>>>24;c=x[a+4|0]|x[a+5|0]<<8;u[e+4|0]=c;u[e+5|0]=c>>>8;e=e+6|0;b=b-1|0;if(b){continue}break}break c}e=((g-b|0)/6|0)+c|0;if(e>>>0>=715827883){break b}b=(f-b|0)/6|0;g=b<<1;b=Np(k+8|0,b>>>0>=357913941?715827882:e>>>0<g>>>0?g:e,i,a+8|0);e=w[b+8>>2];g=e+C(c,6)|0;while(1){c=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);u[e|0]=c;u[e+1|0]=c>>>8;u[e+2|0]=c>>>16;u[e+3|0]=c>>>24;c=x[d+4|0]|x[d+5|0]<<8;u[e+4|0]=c;u[e+5|0]=c>>>8;e=e+6|0;if((g|0)!=(e|0)){continue}break}w[b+8>>2]=g;w[114256]=0;h=S(945,a|0,b|0,h|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}Vk(b)}jb=k+32|0;return h|0}Mb(a);M()}a=P()|0;Vk(b);R(a|0);M()}function xz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0;s=w[a+16>>2];b=jb-32|0;f=w[a+44>>2];w[b+12>>2]=f;h=w[a+48>>2];w[b+16>>2]=h;j=w[a+52>>2];w[b+20>>2]=j;k=w[a+56>>2];w[b+24>>2]=k;l=w[a>>2];i=w[a+4>>2];m=w[a+40>>2];n=w[a+36>>2];a:{if(!d){e=m>>12;g=n>>12;break a}k=w[a+8>>2];t=w[a+12>>2];x=w[a+32>>2];y=w[a+28>>2];z=w[a+72>>2];e=w[a+68>>2];A=e;B=e>>31;e=w[a+64>>2];D=e;E=e>>31;e=w[a+60>>2];F=e;G=e>>31;while(1){g=(((i&2147483647)<<1|l>>>31)&-2)+s|0;e=(l>>>21&2040)+32832|0;o=v[e+6>>1];p=v[e+4>>1];q=v[e+2>>1];r=v[e>>1];f=0;j=1;h=1;e=0;while(1){w[(e<<2)+b>>2]=(((C(u[e+g|0],q)+C(u[g+(e|-2)|0],r)|0)+C(u[g+(e|2)|0],p)|0)+C(o,u[g+(e|4)|0])<<8)/16384;H=h&1;h=0;e=1;if(H){continue}break}while(1){e=(b+8|0)+(f<<3)|0;h=w[e+8>>2];g=w[e+4>>2];w[e+8>>2]=g;o=(f<<2)+b|0;p=w[o>>2]<<8;f=p;f=BV(F,G,f,f>>31);q=nb;r=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,D,E);f=g+f|0;e=nb+q|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,A,B);f=g+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[r+4>>2]=e-(p&z);w[o>>2]=(e|0)/256;f=1;e=j&1;j=0;if(e){continue}break}n=n+y|0;g=n>>12;w[c>>2]=w[c>>2]+C(g,w[b>>2]);m=m+x|0;e=m>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[b+4>>2]);i=i+t|0;f=k+l|0;i=f>>>0<k>>>0?i+1|0:i;l=f;c=c+8|0;d=d-1|0;if(d){continue}break}k=w[b+24>>2];j=w[b+20>>2];h=w[b+16>>2];f=w[b+12>>2]}w[a+36>>2]=n;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=m;w[a+20>>2]=g;w[a+56>>2]=k;w[a+52>>2]=j;w[a+48>>2]=h;w[a+44>>2]=f;w[a+24>>2]=e}function UJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-384|0;jb=a;w[a+368>>2]=c;w[a+376>>2]=b;Ql(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Wb(a+200|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+196>>2]=c;w[a+28>>2]=a+32;w[a+24>>2]=0;u[a+23|0]=1;u[a+22|0]=69;while(1){d:{w[114256]=0;b=Q(1740,a+376|0,a+368|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+196>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+196>>2]=b+c}w[114256]=0;b=V(1742,a+376|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=jj(b,a+23|0,a+22|0,c,a+196|0,w[a+236>>2],w[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1744,a+376|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+216|0)|!x[a+23|0]){break e}b=w[a+28>>2];if((b-(a+32|0)|0)>159){break e}w[a+28>>2]=b+4;w[b>>2]=w[a+24>>2]}w[114256]=0;Y(1731,a|0,c|0,w[a+196>>2],e|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}b=w[a+8>>2];c=w[a+12>>2];g=w[a+4>>2];w[f>>2]=w[a>>2];w[f+4>>2]=g;w[f+8>>2]=b;w[f+12>>2]=c;w[114256]=0;Jc(a+216|0,a+32|0,w[a+28>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+376|0,a+368|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+376>>2];Gb(d);Gb(a+216|0);jb=a+384|0;break a}}b=P()|0;Gb(d);Gb(a+216|0);R(b|0);M()}return b|0}function Ly(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0;t=w[a+16>>2];u=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];p=w[a+12>>2];j=w[a>>2];g=w[a+4>>2];q=0;break a}g=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];o=w[a+8>>2];p=w[a+12>>2];k=BV(o,p,d,0);e=j+k|0;b=nb+g|0;r=f>>>0<(e>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(o,p,n,n>>31);q=nb}l=w[a+40>>2];m=w[a+36>>2];b:{c:{if(!d){b=l>>12;e=m>>12;break c}i=a+112|0;x=(n|0)>0;while(1){r=r-1|0;b=r;k=b?k:0;q=b?q:0;e=0;h=j;s=(g<<1)+t|0;b=n;d:{if(!x){break d}while(1){e:{f=v[(e<<1)+s>>1];w[114256]=0;T(604,i|0,(f|0)/4<<16>>16);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,i|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+q|0;h=h+k|0;e=h>>>0<k>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}h=w[a+120>>2];b=h+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<h>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=v[(e<<1)+s>>1];w[114256]=0;T(604,i|0,(e|0)/4<<16>>16);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,i|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[i>>2]=w[i>>2];w[i+4>>2]=0}w[114256]=0;h=Q(606,i|0,u|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a+32>>2];m=w[a+28>>2]+m|0;e=m>>12;w[c>>2]=w[c>>2]+C(h,e);l=b+l|0;b=l>>12;w[c+4>>2]=w[c+4>>2]+C(h,b);g=g+p|0;j=j+o|0;g=j>>>0<o>>>0?g+1|0:g;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=m;w[a>>2]=j;w[a+4>>2]=g;w[a+40>>2]=l;w[a+20>>2]=e;w[a+24>>2]=b;return}b=P()|0;w[a+40>>2]=l;w[a+36>>2]=m;w[a+20>>2]=m>>12;w[a+24>>2]=l>>12;R(b|0);M()}function fK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-288|0;jb=a;w[a+272>>2]=c;w[a+280>>2]=b;Ul(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Wb(a+208|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+204>>2]=c;w[a+28>>2]=a+32;w[a+24>>2]=0;u[a+23|0]=1;u[a+22|0]=69;while(1){d:{w[114256]=0;b=Q(1710,a+280|0,a+272|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+204>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+204>>2]=b+c}w[114256]=0;b=V(1712,a+280|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=mj(b,a+23|0,a+22|0,c,a+204|0,u[a+239|0],u[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1714,a+280|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+224|0)|!x[a+23|0]){break e}b=w[a+28>>2];if((b-(a+32|0)|0)>159){break e}w[a+28>>2]=b+4;w[b>>2]=w[a+24>>2]}w[114256]=0;Y(1731,a|0,c|0,w[a+204>>2],e|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}b=w[a+8>>2];c=w[a+12>>2];g=w[a+4>>2];w[f>>2]=w[a>>2];w[f+4>>2]=g;w[f+8>>2]=b;w[f+12>>2]=c;w[114256]=0;Jc(a+224|0,a+32|0,w[a+28>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+280|0,a+272|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+280>>2];Gb(d);Gb(a+224|0);jb=a+288|0;break a}}b=P()|0;Gb(d);Gb(a+224|0);R(b|0);M()}return b|0}function $A(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-144|0;jb=e;w[a+12>>2]=0;a:{b:{if(!(ob[w[w[a>>2]+36>>2]](a,0,64)|0)){break b}c:{d:{e:{if(z[a+12>>2]<=59){if(ob[w[w[a>>2]+24>>2]](a)>>>0<60){break e}}w[a+12>>2]=60;if(!Ah(a,9837,4)){break e}d=15;break d}w[a+12>>2]=0;if(!(ob[w[w[a>>2]+36>>2]](a,0,128)|0)){break b}f:{if(z[a+12>>2]<=123){if(ob[w[w[a>>2]+24>>2]](a)>>>0<124){break f}}w[a+12>>2]=124;d=31;if(Ah(a,11109,4)){break c}}c=1;d=0}b=0;if(c){break a}}b=0;w[a+12>>2]=0;g:{while(1){if(_o(a,e+8|0)){c=w[e+8>>2];if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0>131072){break g}}b=b+1|0;if((b&65535)>>>0<d>>>0){continue}break}h:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],4)|0){b=w[a+12>>2]+4|0;break h}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b;if(!(ob[w[w[a>>2]+36>>2]](a,b,2)|0)){break b}b=jb-16|0;jb=b;c=w[a+12>>2];f=e+8|0;w[b+8>>2]=f;w[b+12>>2]=f+2;f=ob[w[w[a>>2]+32>>2]](a,c,b+8|0)|0;if((f|0)==2){i:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],2)|0){c=w[a+12>>2]+2|0;break i}c=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=c}jb=b+16|0;if((f|0)!=2){break g}c=y[e+8>>1];b=0;if(((c<<8|c>>>8)&65535)>>>0<178){break a}d=C(d,30);b=-1;if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],d)|0)){break a}j:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],d)|0){b=d+w[a+12>>2]|0;break j}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b;b=jb-16|0;jb=b;d=w[a+12>>2];c=e+8|0;w[b+8>>2]=c;w[b+12>>2]=c+130;c=ob[w[w[a>>2]+32>>2]](a,d,b+8|0)|0;if((c|0)==130){k:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],130)|0){d=w[a+12>>2]+130|0;break k}d=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=d}jb=b+16|0;b=(c|0)!=130?-1:x[e+8|0]<129;break a}b=0;break a}b=-1}jb=e+144|0;return b|0}function ii(a){a=a|0;var b=D(0),c=0,d=0,e=0,f=D(0),g=0,h=0,i=0,j=0,k=0,l=0,m=D(0),n=0,o=0,p=0,q=D(0);a:{c=w[a+36>>2];if(!c){break a}b:{c:{switch(y[a>>1]){case 3:if(c>>>0>=1001){break a}Fe(a+16|0,c);c=y[a+28>>1];h=c<<16;d=h>>16;e=w[a+4>>2];i=(c+(w[a+8>>2]-e>>>2|0)<<16)-65536>>16;f=D(1);d:{if((c|0)==32767){break d}c=h+65536>>16;f=D(1);if((c|0)>(i|0)){break d}b=A[e+(c-d<<2)>>2];f=b>D(10000000036274937e-31)?b:D(1)}if((d|0)<=(i|0)){b=A[e>>2];b=b>D(10000000036274937e-31)?b:D(1)}else{b=D(1)}c=w[a+36>>2];b=Rg(D(f/b),D(D(1)/D(c+1>>>0)));if(!c){break b}d=w[a+16>>2];a=1;while(1){p=(d+(a<<2)|0)-4|0,q=Rg(b,D(a>>>0)),A[p>>2]=q;e=(a|0)==(c|0);a=a+1|0;if(!e){continue}break};break b;case 1:i=y[a+30>>1];if(i>>>0>1e3/(c>>>0)>>>0){break a}Fe(a+16|0,C(c,i));e=y[a+30>>1];d=v[a+28>>1];e:{if((d|0)>=0){c=(d>>>0)%(e>>>0)|0;break e}c=e+(((d^-1)>>>0)%(e>>>0)^-1)|0}if(!i){break b}j=w[a+4>>2];l=d-1+(w[a+8>>2]-j>>>2)<<16>>16;h=w[a+36>>2];m=D(D(1)/D(h+1>>>0));n=w[a+16>>2];while(1){a=c+k<<16>>16;f:{if((a|0)>=0){a=(a>>>0)%(e>>>0)|0;break f}a=e+(((a^-1)>>>0)%(e>>>0)^-1)|0}g=a<<16;a=g>>16;g=g+65536>>16;f=D(1);g:{if((g|0)<(d|0)){break g}f=D(1);if((g|0)>(l|0)){break g}b=A[j+(g-d<<2)>>2];f=b>D(10000000036274937e-31)?b:D(1)}if((a|0)<(d|0)|(a|0)>(l|0)){b=D(1)}else{b=A[j+(a-d<<2)>>2];b=b>D(10000000036274937e-31)?b:D(1)}b=Rg(D(f/b),m);if(h){o=C(a,h)-1|0;g=1;a=1;while(1){p=(g+o<<2)+n|0,q=Nt(b,a&65535),A[p>>2]=q;a=a+1|0;g=a&65535;if(h>>>0>=g>>>0){continue}break}}k=k+1|0;if(i>>>0>(k&65535)>>>0){continue}break};break b;case 0:break a;default:break c}}w[a+36>>2]=0;w[a+20>>2]=w[a+16>>2]}return}w[a+20>>2]=w[a+16>>2]}function ty(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;j=jb-16|0;jb=j;a:{b:{c:{d:{e:{f:{c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){g:{d=c;if((c|0)==(e|0)){d=e;break g}c=d-2|0;if(y[c>>1]==65535){continue}}break}d=d-e|0;g=d>>>1&65535;h=xo(j,g);if(!(d&131070)){break e}k=w[a>>2];l=w[a+4>>2]-k>>1;i=w[h>>2];c=0;d=0;while(1){h:{e=c<<1;v[e+i>>1]=c-d;if((c|0)==(l|0)){break h}d=(y[e+k>>1]==(b|0))+d|0;c=c+1|0;if((g|0)!=(c|0)){continue}break f}break}w[114256]=0;X(706,a|0);a=w[114256];w[114256]=0;if((a|0)!=1){M()}a=P()|0;b=w[h>>2];if(b){w[h+4>>2]=b;zb(b)}R(a|0);M()}xo(j,0);break e}if(d&65535){break d}}g=w[j>>2];break c}i:{j:{e=w[a>>2];c=e;f=w[a+4>>2];if((c|0)==(f|0)){break j}c=e;while(1){if(y[c>>1]==(b|0)){break j}c=c+2|0;if((f|0)!=(c|0)){continue}break}break i}k:{if((c|0)==(f|0)){break k}d=c+2|0;if((f|0)==(d|0)){break k}while(1){i=y[d>>1];if((i|0)!=(b|0)){v[c>>1]=i;c=c+2|0}d=d+2|0;if((f|0)!=(d|0)){continue}break}}if((c|0)==(f|0)){break i}d=(f-c|0)+c|0;b=f-d|0;if((d|0)!=(f|0)){hc(c,d,b);e=w[a>>2]}f=b+c|0;w[a+4>>2]=f}l:{if((e|0)==(f|0)){g=w[h>>2];break l}g=w[h>>2];b=w[a+24>>2];k=w[b+484344>>2];l=(w[b+484348>>2]-k|0)/52&65535;while(1){b=y[e>>1];m:{if(b>>>0>=l>>>0){break m}b=k+C(b,52)|0;c=w[b>>2];i=w[b+4>>2];if((c|0)==(i|0)){break m}d=w[h+4>>2]-g>>1;while(1){n:{if(x[c+3|0]!=12){break n}b=x[c+5|0];if(b>>>0>=d>>>0){break n}u[c+5|0]=x[(b<<1)+g|0]}c=c+6|0;if((i|0)!=(c|0)){continue}break}}e=e+2|0;if((f|0)!=(e|0)){continue}break}}b=y[a+28>>1];if(b>>>0>=w[h+4>>2]-g>>1>>>0){break c}v[a+28>>1]=y[(b<<1)+g>>1];break b}if(!g){break a}}w[j+4>>2]=g;zb(g)}jb=j+16|0}function jP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=D(0);d=jb-80|0;jb=d;a:{b:{c:{d:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=w[a+24>>2];if((b|0)==w[a+24604>>2]){break c}c=d+40|0;Fb(c,a+24604|0,40);w[d+40>>2]=b;li(a,c);break c;case 2:a=w[a+24>>2];b=a+24664|0;e=w[b+4>>2];w[d+56>>2]=w[b>>2];w[d+60>>2]=e;b=a+24656|0;e=w[b+4>>2];w[d+48>>2]=w[b>>2];w[d+52>>2]=e;b=w[a+24652>>2];w[d+40>>2]=w[a+24648>>2];w[d+44>>2]=b;b=3;e:{if(!c|(c|0)>7){break e}b=2;if((c|0)>2){break e}b=1;if((c|0)==2){break e}b=0;if((c|0)>0){break e}c=ba(8)|0;w[114256]=0;b=Q(5,d|0,6729)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}a=P()|0;ca(c|0);break b}u[d+40|0]=b;if(!(x[a+24648|0]!=(b|0)|B[d+48>>3]!=B[a+24656>>3]|x[d+56|0]!=x[a+24664|0])){if(w[d+60>>2]==w[a+24668>>2]){break c}}dk(a,d+40|0);break c;case 3:f=w[a+24>>2];e=Fb(d,f+24604|0,40);f:{if((c|0)==-1){c=w[ph(e+40|0)+32>>2];w[e+32>>2]=c;b=w[ph(e+40|0)+36>>2];w[e+36>>2]=b;f=w[a+24>>2];break f}b=0;if((c|0)<=0){w[e+32>>2]=0;w[e+36>>2]=0;c=0;break f}b=C(c,1e3);w[e+36>>2]=b;w[e+32>>2]=b;c=b}if(w[f+24636>>2]==(c|0)&w[f+24640>>2]==(b|0)){break c}li(f,e);break c;default:c=ba(8)|0;w[114256]=0;b=Q(5,d+40|0,6325)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}a=P()|0;ca(c|0);break b;case 0:break d}}g=a,h=jd(D(D(c|0)*D(.0016609641024842858))),A[g+48>>2]=h}jb=d+80|0;return}R(a|0)}M()}function yp(a,b){var c=0,d=0;a:{b:{c:{c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);d:{if((c|0)==776678989|(c|0)==558571853){break d}c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);if((c|0)==1414807888|(c|0)==1397576526){break d}if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=1146241356){break c}}v[b+10>>1]=4;w[b>>2]=7839;break b}c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);if(!(!((c|0)==558573133|(c|0)==1414743366)&(x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=777268814)){u[b+12|0]=1;v[b+10>>1]=4;w[b>>2]=4590;return 1}c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);if(!((c|0)!=1096043343&(c|0)!=1096041295)){v[b+10>>1]=8;w[b>>2]=4354;break b}c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);if(!((c|0)!=825771075&(c|0)!=825640003)){w[b>>2]=12862;v[b+10>>1]=u[a+2|0]-48;break b}c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);if(!((c|0)!=77&(c|0)!=56)){w[b+4>>2]=1;w[b>>2]=12668;v[b+10>>1]=x[a|0]==56?8:4;return 1}if(!(Jb(a,11467,3)|(x[a+3|0]-52&255)>>>0>4)){w[b>>2]=4708;a=u[a+3|0];v[b+8>>1]=1088;v[b+10>>1]=a-48;break b}e:{if(Jb(a,9422,3)){if(Jb(a,9531,3)){break e}}if((x[a+3|0]-52&255)>>>0>5){break e}u[b+15|0]=1;u[b+13|0]=1;w[b>>2]=4453;v[b+10>>1]=u[a+3|0]-48;return 1}f:{if((x[a|0]-49&255)>>>0>8){break f}if(!Jb(a+1|0,9539,3)){u[b+14|0]=1;w[b>>2]=4740;v[b+10>>1]=u[a|0]-48;return 1}c=x[a+2|0]|x[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(x[a+1|0]-48&255)>>>0>9){break f}u[b+14|0]=1;w[b>>2]=4740;v[b+10>>1]=(u[a+1|0]+C(u[a|0],10)|0)-528;return 1}if(Jb(a,9254,3)|(x[a+3|0]-52&255)>>>0>5){break a}w[b>>2]=4617;v[b+10>>1]=u[a+3|0]-48}d=1}return d}function fn(a,b,c){var d=0,e=0,f=0,g=0;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=x[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}u[a|0]=1;a=x[b|0];u[b|0]=a>>>0>=64?64:a;break a}d=x[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}u[b|0]=(d&252)>>>2;u[a|0]=12;e=1;break a}d=x[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}u[b|0]=(d&252)>>>2;u[a|0]=13;e=1;break a}f=x[b|0];if(f>>>0<240){d=0;while(1){g=x[d+25776|0];m:{n:{if(c){if(f>>>0<=g>>>0){break n}break m}if((f|0)!=(g|0)){break m}}u[a|0]=11;u[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}u[a|0]=11;u[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=x[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}u[b|0]=0;u[a|0]=0;e=1;break a}u[a|0]=2;u[b|0]=x[b|0]<<2&60|2;e=1;break a}e=0;c=x[b|0];if(!c){break a}d=c&15;if(!d){u[b|0]=c>>>4;u[a|0]=3;e=1;break a}f=c&240;if(!f){u[a|0]=4;e=1;break a}if((d|0)==15){u[b|0]=c>>>4;u[a|0]=5;e=1;break a}if((f|0)!=240){break a}u[b|0]=d;u[a|0]=6;e=1;break a}c=b;b=x[b|0];u[c|0]=(b|0)==255?64:b>>>2|0;u[a|0]=2;break a}r:{if(c){u[b|0]=0;break r}e=0;if(x[b|0]){break a}}u[a|0]=8;e=1;break a}d=x[b|0];s:{if(c){c=d&15;d=c>>>0>=9?9:c;break s}e=0;if((d&255)>>>0>15|(d&14)>>>0>9){break a}}u[b|0]=d;u[a|0]=8;e=1}return e}function AJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-384|0;jb=f;w[f+376>>2]=37;w[f+380>>2]=0;h=ij(f+376|1,17256,w[c+4>>2]);w[f+332>>2]=f+336;a=Cc();a:{if(h){i=w[c+8>>2];B[f+40>>3]=e;w[f+32>>2]=i;a=Xc(f+336|0,30,a,f+376|0,f+32|0);break a}B[f+48>>3]=e;a=Xc(f+336|0,30,a,f+376|0,f+48|0)}w[f+80>>2]=1708;i=vc(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){w[114256]=0;a=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[f>>2]=w[c+8>>2];w[114256]=0;B[f+8>>3]=e;a=Z(1753,f+332|0,a|0,f+376|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){break f}break d}w[114256]=0;a=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}B[f+16>>3]=e;w[114256]=0;a=Z(1753,f+332|0,a|0,f+376|0,f+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}}if((a|0)==-1){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break e}Hc(i,w[f+332>>2]);g=w[f+332>>2]}h=a+g|0;k=yd(g,h,c);w[f+68>>2]=1708;g=vc(f+72|0,0,f+68|0);g:{h:{if(w[f+332>>2]==(f+336|0)){a=f+80|0;break h}a=fc(a<<3);if(!a){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break e}b=P()|0;break g}Hc(g,a);j=w[f+332>>2]}w[114256]=0;Sb(f+56|0,c);l=w[114256];w[114256]=0;i:{j:{if((l|0)!=1){w[114256]=0;ma(1764,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=w[114256];w[114256]=0;if((h|0)==1){break j}Ab(f+56|0);w[114256]=0;a=la(1765,b|0,a|0,w[f+68>>2],w[f+64>>2],c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break i}Ub(g);Ub(i);jb=f+384|0;break b}b=P()|0;break g}b=P()|0;Ab(f+56|0);break g}b=P()|0}Ub(g);break c}M()}b=P()|0}Ub(i);R(b|0);M()}return a|0}function LJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-208|0;jb=f;w[f+200>>2]=37;w[f+204>>2]=0;h=ij(f+200|1,17256,w[c+4>>2]);w[f+156>>2]=f+160;a=Cc();a:{if(h){i=w[c+8>>2];B[f+40>>3]=e;w[f+32>>2]=i;a=Xc(f+160|0,30,a,f+200|0,f+32|0);break a}B[f+48>>3]=e;a=Xc(f+160|0,30,a,f+200|0,f+48|0)}w[f+80>>2]=1708;i=vc(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){w[114256]=0;a=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[f>>2]=w[c+8>>2];w[114256]=0;B[f+8>>3]=e;a=Z(1753,f+156|0,a|0,f+200|0,f|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){break f}break d}w[114256]=0;a=ea(1732)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}B[f+16>>3]=e;w[114256]=0;a=Z(1753,f+156|0,a|0,f+200|0,f+16|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}}if((a|0)==-1){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)==1){break d}break e}Hc(i,w[f+156>>2]);g=w[f+156>>2]}h=a+g|0;k=yd(g,h,c);w[f+68>>2]=1708;g=vc(f+72|0,0,f+68|0);g:{h:{if(w[f+156>>2]==(f+160|0)){a=f+80|0;break h}a=fc(a<<1);if(!a){w[114256]=0;_(1709);a=w[114256];w[114256]=0;if((a|0)!=1){break e}b=P()|0;break g}Hc(g,a);j=w[f+156>>2]}w[114256]=0;Sb(f+56|0,c);l=w[114256];w[114256]=0;i:{j:{if((l|0)!=1){w[114256]=0;ma(1754,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=w[114256];w[114256]=0;if((h|0)==1){break j}Ab(f+56|0);w[114256]=0;a=la(15,b|0,a|0,w[f+68>>2],w[f+64>>2],c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break i}Ub(g);Ub(i);jb=f+208|0;break b}b=P()|0;break g}b=P()|0;Ab(f+56|0);break g}b=P()|0}Ub(g);break c}M()}b=P()|0}Ub(i);R(b|0);M()}return a|0}function iz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;a:{b:{c:{g=w[a+12>>2];j=w[a+8>>2];d:{if((g|0)<=1&j>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&j>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&j>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&j>>>0>2147483648|g>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}n=w[a+48>>2];o=w[a>>2];h=w[a+4>>2];k=w[a+40>>2];l=w[a+36>>2];e=w[a+44>>2];e:{if(!d){f=k>>12;i=l>>12;break e}q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];b=w[a+68>>2];u=b;x=b>>31;b=w[a+64>>2];y=b;z=b>>31;b=w[a+60>>2];A=b;B=b>>31;b=n;while(1){f=w[c>>2];n=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(y,z,e,e>>31);i=nb;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;m=BV(u,x,b,b>>31);e=m+e|0;b=nb+i|0;b=e>>>0<m>>>0?b+1|0:b;D=f;i=e;e=(h<<1)+q|0;f=(o>>>16&65520)+p|0;m=(((((((C(v[e-4>>1],v[f+2>>1])+C(v[e-6>>1],v[f>>1])|0)+C(v[e-2>>1],v[f+4>>1])|0)+C(v[e>>1],v[f+6>>1])|0)+C(v[e+2>>1],v[f+8>>1])|0)+C(v[e+4>>1],v[f+10>>1])|0)+C(v[e+6>>1],v[f+12>>1])|0)+C(v[e+8>>1],v[f+14>>1])|0)/32768<<8;e=m;f=BV(e,e>>31,A,B);e=i+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;l=l+s|0;i=l>>12;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=D+C(i,e);k=k+r|0;f=k>>12;w[c+4>>2]=w[c+4>>2]+C(e,f);e=b-(m&t)|0;h=g+h|0;b=j+o|0;h=b>>>0<j>>>0?h+1|0:h;o=b;c=c+8|0;b=n;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=o;w[a+4>>2]=h;w[a+40>>2]=k;w[a+20>>2]=i;w[a+48>>2]=n;w[a+44>>2]=e;w[a+24>>2]=f}function My(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0;t=w[a+16>>2];v=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);n=w[a+128>>2];a:{if(!n){o=w[a+8>>2];p=w[a+12>>2];j=w[a>>2];g=w[a+4>>2];q=0;break a}g=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];o=w[a+8>>2];p=w[a+12>>2];k=BV(o,p,d,0);e=j+k|0;b=nb+g|0;r=f>>>0<(e>>>0<k>>>0?b+1|0:b)>>>0?d:0;k=CV(o,p,n,n>>31);q=nb}l=w[a+40>>2];m=w[a+36>>2];b:{c:{if(!d){b=l>>12;e=m>>12;break c}i=a+112|0;x=(n|0)>0;while(1){r=r-1|0;b=r;k=b?k:0;q=b?q:0;e=0;h=j;s=g+t|0;b=n;d:{if(!x){break d}while(1){e:{f=u[e+s|0];w[114256]=0;T(604,i|0,f<<6);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;T(605,i|0,4);f=w[114256];w[114256]=0;if((f|0)==1){break e}e=e+q|0;h=h+k|0;e=h>>>0<k>>>0?e+1|0:e;f=b>>>0>1;b=b-1|0;if(f){continue}break d}break}break b}h=w[a+120>>2];b=h+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<h>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){e=u[e+s|0];w[114256]=0;T(604,i|0,e<<6);e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;T(605,i|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[i>>2]=w[i>>2];w[i+4>>2]=0}w[114256]=0;h=Q(606,i|0,v|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a+32>>2];m=w[a+28>>2]+m|0;e=m>>12;w[c>>2]=w[c>>2]+C(h,e);l=b+l|0;b=l>>12;w[c+4>>2]=w[c+4>>2]+C(h,b);g=g+p|0;j=j+o|0;g=j>>>0<o>>>0?g+1|0:g;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=m;w[a>>2]=j;w[a+4>>2]=g;w[a+40>>2]=l;w[a+20>>2]=e;w[a+24>>2]=b;return}b=P()|0;w[a+40>>2]=l;w[a+36>>2]=m;w[a+20>>2]=m>>12;w[a+24>>2]=l>>12;R(b|0);M()}function Go(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=D(0),m=0,n=D(0);a:{g=w[a+656>>2];if(!g){break a}e=w[g+44>>2];if(!e){break a}m=-1;j=!(x[d+1074316|0]&4);d=x[a+819|0];d=(d-1&255)>>>0<120?d:x[a+821|0];b:{if(j|!(d&255)){break b}f=d&255;if(f>>>0>120){break b}d=x[(g+f|0)+107|0]}n=D(D(b*D(16))*D(w[a+704>>2]));g=((d&255)+c<<16)-3997696>>16;c:{d:{d=w[a+876>>2]+w[a+768>>2]|0;if(d){j=w[e+36>>2];if(j){break d}}b=D(1);f=v[e+28>>1];d=d+g<<16>>16;if((f|0)>(d|0)){break c}c=w[e+4>>2];if((d|0)>(f+(w[e+8>>2]-c>>>2|0)<<16)-65536>>16){break c}b=A[c+(d-f<<2)>>2];b=b>D(10000000036274937e-31)?b:D(1);break c}k=j+1|0;e:{if((d|0)>=0){c=(d|0)/(k|0)|0;d=d-C(k,c)|0;break e}c=((d+1|0)/(k|0)|0)-1|0;d=j-((d^-1)%(k|0)|0)|0}b=D(1);h=c+g<<16>>16;i=v[e+28>>1];if((h|0)<(i|0)){break c}g=w[e+4>>2];f=((w[e+8>>2]-g>>>2|0)+i<<16)-65536>>16;if((f|0)<(h|0)){break c}c=d;if(!d){b=A[g+(h-i<<2)>>2];break c}f:{g:{h:{switch(y[e>>1]-1|0){case 2:d=w[e+16>>2];if((d|0)==w[e+20>>2]){break g}b=A[(d+(c<<2)|0)-4>>2];break f;case 0:break h;default:break g}}d=w[e+16>>2];if((d|0)==w[e+20>>2]){break g}f=y[e+30>>1];if((h|0)>=0){e=(h>>>0)%(f>>>0)|0}else{e=f+(((h^-1)>>>0)%(f>>>0)^-1)|0}b=A[(d+(C(j,e<<16>>16)+c<<2)|0)-4>>2];break f}d=(h<<16)+65536>>16;l=D(1);i:{if((d|0)<(i|0)){break i}l=D(1);if((d|0)>(f|0)){break i}b=A[g+(d-i<<2)>>2];l=b>D(10000000036274937e-31)?b:D(1)}b=A[g+(h-i<<2)>>2];b=Rg(D(l/(b>D(10000000036274937e-31)?b:D(1))),D(D(c|0)/D(k|0)))}b=D(A[g+(h-i<<2)>>2]*b)}b=_b(D(n*b));j:{if(b>=D(4294967296)){break j}m=0;if(b<=D(0)){break j}m=b<D(4294967296)&b>=D(0)?~~b>>>0:m}w[a+700>>2]=m}}function jz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0;a:{b:{c:{g=w[a+12>>2];j=w[a+8>>2];d:{if((g|0)<=1&j>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&j>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&j>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&j>>>0>2147483648|g>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}n=w[a+48>>2];o=w[a>>2];h=w[a+4>>2];k=w[a+40>>2];l=w[a+36>>2];e=w[a+44>>2];e:{if(!d){f=k>>12;i=l>>12;break e}q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];b=w[a+68>>2];x=b;y=b>>31;b=w[a+64>>2];z=b;A=b>>31;b=w[a+60>>2];B=b;D=b>>31;b=n;while(1){f=w[c>>2];n=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(z,A,e,e>>31);i=nb;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;m=BV(x,y,b,b>>31);e=m+e|0;b=nb+i|0;b=e>>>0<m>>>0?b+1|0:b;E=f;i=e;e=h+q|0;f=(o>>>16&65520)+p|0;m=(((((((C(u[e-2|0],v[f+2>>1])+C(u[e-3|0],v[f>>1])|0)+C(u[e-1|0],v[f+4>>1])|0)+C(u[e|0],v[f+6>>1])|0)+C(u[e+1|0],v[f+8>>1])|0)+C(u[e+2|0],v[f+10>>1])|0)+C(u[e+3|0],v[f+12>>1])|0)+C(u[e+4|0],v[f+14>>1])<<8)/32768<<8;e=m;f=BV(e,e>>31,B,D);e=i+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;l=l+s|0;i=l>>12;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=E+C(i,e);k=k+r|0;f=k>>12;w[c+4>>2]=w[c+4>>2]+C(e,f);e=b-(m&t)|0;h=g+h|0;b=j+o|0;h=b>>>0<j>>>0?h+1|0:h;o=b;c=c+8|0;b=n;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=o;w[a+4>>2]=h;w[a+40>>2]=k;w[a+20>>2]=i;w[a+48>>2]=n;w[a+44>>2]=e;w[a+24>>2]=f}function Mz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0;r=w[a+16>>2];b=jb-32|0;k=w[a+44>>2];w[b+12>>2]=k;h=w[a+48>>2];w[b+16>>2]=h;l=w[a+52>>2];w[b+20>>2]=l;g=w[a+56>>2];w[b+24>>2]=g;m=w[a>>2];i=w[a+4>>2];n=w[a+40>>2];o=w[a+36>>2];a:{if(!d){e=n>>12;f=o>>12;break a}k=w[a+8>>2];s=w[a+12>>2];t=w[a+32>>2];u=w[a+28>>2];x=w[a+72>>2];e=w[a+68>>2];y=e;z=e>>31;e=w[a+64>>2];A=e;B=e>>31;e=w[a+60>>2];D=e;E=e>>31;while(1){p=m>>>18|0;l=1;g=((((i&2147483647)<<1|m>>>31)&2147483646)<<1)+r|0;e=0;h=1;f=0;while(1){q=f<<1;j=v[q+g>>1];w[(f<<2)+b>>2]=j+((C(v[g+(q|4)>>1]-j|0,p)|0)/16384|0);j=h&1;h=0;f=1;if(j){continue}break}while(1){f=(b+8|0)+(e<<3)|0;h=w[f+8>>2];g=w[f+4>>2];w[f+8>>2]=g;j=(e<<2)+b|0;p=w[j>>2]<<8;e=p;e=BV(D,E,e,e>>31);q=nb;F=f;f=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,A,B);f=f+g|0;e=nb+q|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,y,z);f=g+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[F+4>>2]=e-(p&x);w[j>>2]=(e|0)/256;e=1;f=l&1;l=0;if(f){continue}break}o=o+u|0;f=o>>12;w[c>>2]=w[c>>2]+C(f,w[b>>2]);n=n+t|0;e=n>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[b+4>>2]);i=i+s|0;m=m+k|0;i=m>>>0<k>>>0?i+1|0:i;c=c+8|0;d=d-1|0;if(d){continue}break}g=w[b+24>>2];l=w[b+20>>2];h=w[b+16>>2];k=w[b+12>>2]}w[a+36>>2]=o;w[a>>2]=m;w[a+4>>2]=i;w[a+40>>2]=n;w[a+20>>2]=f;w[a+56>>2]=g;w[a+52>>2]=l;w[a+48>>2]=h;w[a+44>>2]=k;w[a+24>>2]=e}function Nz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0;r=w[a+16>>2];b=jb-32|0;j=w[a+44>>2];w[b+12>>2]=j;h=w[a+48>>2];w[b+16>>2]=h;k=w[a+52>>2];w[b+20>>2]=k;g=w[a+56>>2];w[b+24>>2]=g;l=w[a>>2];i=w[a+4>>2];n=w[a+40>>2];o=w[a+36>>2];a:{if(!d){e=n>>12;f=o>>12;break a}j=w[a+8>>2];s=w[a+12>>2];t=w[a+32>>2];v=w[a+28>>2];x=w[a+72>>2];e=w[a+68>>2];y=e;z=e>>31;e=w[a+64>>2];A=e;B=e>>31;e=w[a+60>>2];D=e;E=e>>31;while(1){p=l>>>10&4194048;g=(((i&2147483647)<<1|l>>>31)&-2)+r|0;f=0;k=1;h=1;e=0;while(1){m=(e<<2)+b|0;q=u[g+(e|2)|0];e=u[e+g|0];w[m>>2]=((C(q-e|0,p)|0)/16384|0)+(e<<8);m=h&1;h=0;e=1;if(m){continue}break}while(1){e=(b+8|0)+(f<<3)|0;h=w[e+8>>2];g=w[e+4>>2];w[e+8>>2]=g;p=(f<<2)+b|0;m=w[p>>2]<<8;f=m;f=BV(D,E,f,f>>31);F=nb;q=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,A,B);f=g+f|0;e=nb+F|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,y,z);f=g+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[q+4>>2]=e-(m&x);w[p>>2]=(e|0)/256;f=1;e=k&1;k=0;if(e){continue}break}o=o+v|0;f=o>>12;w[c>>2]=w[c>>2]+C(f,w[b>>2]);n=n+t|0;e=n>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[b+4>>2]);i=i+s|0;l=l+j|0;i=l>>>0<j>>>0?i+1|0:i;c=c+8|0;d=d-1|0;if(d){continue}break}g=w[b+24>>2];k=w[b+20>>2];h=w[b+16>>2];j=w[b+12>>2]}w[a+36>>2]=o;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=n;w[a+20>>2]=f;w[a+56>>2]=g;w[a+52>>2]=k;w[a+48>>2]=h;w[a+44>>2]=j;w[a+24>>2]=e}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=w[a+484360>>2]+(x[a+484376|0]<<5)|0;d=w[c+4>>2]-w[c>>2]>>1;a:{if(d>>>0<=b>>>0){c=b;break a}b:{if(nh(c,b)){c=b;break b}while(1){b=b+1|0;c=b&65535;e=w[a+484360>>2]+(x[a+484376|0]<<5)|0;d=w[e+4>>2]-w[e>>2]>>1;if(c>>>0>=d>>>0){break a}if(!nh(e,b&65535)){continue}break}}d=w[a+484360>>2]+(x[a+484376|0]<<5)|0;d=w[d+4>>2]-w[d>>2]>>1}if(c>>>0<d>>>0){d=a+1304360|0;c=a+1074984|0;e=w[a+1074312>>2]&8388608;while(1){u[c+819|0]=0;w[c+700>>2]=0;u[c+861|0]=0;u[c+827|0]=0;w[c+708>>2]=0;u[c+841|0]=0;w[c+804>>2]=0;u[c+839|0]=0;u[c+840|0]=0;if(e){v[c+798>>1]=0;v[c+800>>1]=1}u[c+859|0]=0;c=c+896|0;if((d|0)!=(c|0)){continue}break}e=a+946300|0;c=a+906300|0;while(1){d=w[c>>2];c:{if(!d){break c}if(!(ob[w[w[d>>2]+112>>2]](d)|0)){break c}ob[w[w[d>>2]+92>>2]](d)}c=c+160|0;if((e|0)!=(c|0)){continue}break}d:{if(!(b&65535)){b=0;while(1){ug((C(b,896)+a|0)+1074984|0,7,a,b&65535,1024);b=b+1|0;if((b|0)!=256){continue}break}Te(a+1304360|0,1);b=a+1074448|0;w[b>>2]=0;w[b+4>>2]=0;v[a+1074440>>1]=0;w[a+1074392>>2]=-2;b=a+1074428|0;w[b>>2]=0;w[b+4>>2]=0;b=a+1074396|0;w[b>>2]=0;w[b+4>>2]=0;w[a+1074376>>2]=0;w[a+1074380>>2]=0;b=w[a+480200>>2];w[a+1074444>>2]=b;w[a+1074416>>2]=w[a+480196>>2];w[a+1074420>>2]=w[a+480204>>2];w[a+1074456>>2]=b;w[a+480208>>2]=w[a+480208>>2]&-769;w[a+1074460>>2]=b<<12;break d}v[a+1074440>>1]=b;v[a+1074436>>1]=0;b=a+1074424|0;w[b>>2]=0;w[b+4>>2]=0;w[a+1074392>>2]=-2;w[a+1074432>>2]=0;b=a+1074396|0;w[b>>2]=0;w[b+4>>2]=0;w[a+1074380>>2]=0}w[a+480208>>2]=w[a+480208>>2]&-769}}function WJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=D(0);a=jb-368|0;jb=a;w[a+352>>2]=c;w[a+360>>2]=b;Ql(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+180>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;u[a+7|0]=1;u[a+6|0]=69;while(1){d:{w[114256]=0;b=Q(1740,a+360|0,a+352|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+180>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+180>>2]=b+c}w[114256]=0;b=V(1742,a+360|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=jj(b,a+7|0,a+6|0,c,a+180|0,w[a+220>>2],w[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1744,a+360|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+200|0)|!x[a+7|0]){break e}b=w[a+12>>2];if((b-(a+16|0)|0)>159){break e}w[a+12>>2]=b+4;w[b>>2]=w[a+8>>2]}w[114256]=0;h=D(xa(1727,c|0,w[a+180>>2],e|0));b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}A[f>>2]=h;w[114256]=0;Jc(a+200|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+360|0,a+352|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+360>>2];Gb(d);Gb(a+200|0);jb=a+368|0;break a}}b=P()|0;Gb(d);Gb(a+200|0);R(b|0);M()}return b|0}function Te(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;d=w[a+24>>2];i=w[d+484360>>2];c=x[a+30|0];if(c>>>0>=(w[d+484364>>2]-i>>>5&255)>>>0){c=x[d+484376|0]}k=i+((c&255)<<5)|0;i=If(k);d=i;c=w[a+4>>2];f=w[a>>2];e=(c-f|0)/12|0;a:{if(d>>>0>e>>>0){f=jb-32|0;jb=f;b:{c:{d=d-e|0;h=w[a+8>>2];c=w[a+4>>2];d:{if(d>>>0<=(h-c|0)/12>>>0){if(d){e=c;c=C(d,12)-12|0;c=(c-((c>>>0)%12|0)|0)+12|0;c=Cb(e,0,c)+c|0}w[a+4>>2]=c;break d}e=w[a>>2];g=(c-e|0)/12|0;c=d+g|0;if(c>>>0>=357913942){break c}e=(h-e|0)/12|0;h=e<<1;c=Re(f+8|0,e>>>0>=178956970?357913941:c>>>0<h>>>0?h:c,g,a+8|0);d=C(d,12)-12|0;d=(d-((d>>>0)%12|0)|0)+12|0;m=c,n=Cb(w[c+8>>2],0,d)+d|0,w[m+8>>2]=n;w[114256]=0;T(733,a|0,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break b}go(c)}jb=f+32|0;break a}Mb(a);M()}a=P()|0;go(c);R(a|0);M()}if(d>>>0<e>>>0){d=f+C(d,12)|0;if((d|0)!=(c|0)){while(1){c=c-12|0;e=w[c>>2];if(e){zb(e)}if((c|0)!=(d|0)){continue}break}}w[a+4>>2]=d}}e:{if(!b){break e}c=w[a+12>>2];w[a+16>>2]=c;if(w[a+20>>2]-c>>>0>4095){break e}d=0;e=w[a+24>>2];c=w[e+484344>>2];e=w[e+484348>>2];if((c|0)!=(e|0)){while(1){f=w[c+12>>2];d=d>>>0>f>>>0?d:f;c=c+52|0;if((e|0)!=(c|0)){continue}break}}Qh(a+12|0,d)}if(i){d=0;while(1){f=C(d,12);h=w[a>>2];g=w[a+24>>2];e=w[g+484344>>2];l=(w[g+484348>>2]-e|0)/52&65535;g=y[w[k>>2]+(d<<1)>>1];c=1;f:{if(l>>>0<=g>>>0){break f}e=e+C(g,52)|0;c=1;if(w[e>>2]==w[e+4>>2]){break f}c=w[e+12>>2]}e=f+h|0;g:{if(b){u[j+15|0]=0;lo(e,c,j+15|0);break g}op(e,c,0)}d=d+1|0;if((i|0)!=(d|0)){continue}break}}jb=j+16|0}function DO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-80|0;jb=d;a:{b:{c:{d:{e:{f:{c=w[a+40>>2];e=w[a+36>>2];g:{if((c|0)!=(e|0)){w[d+72>>2]=0;break g}Vg(d+56|0,a);w[114256]=0;g=V(22,12)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}w[g>>2]=w[d+56>>2];w[g+4>>2]=w[d+60>>2];w[g+8>>2]=w[d+64>>2];w[d+72>>2]=g;c=w[a+40>>2];e=w[a+36>>2]}f=(c|0)==(e|0)?g:a+36|0;c=w[a+8>>2];if((c|0)!=-1){break c}e=w[f+4>>2];c=e-24|0;h=w[f>>2];if((h|0)!=(e|0)){break e}break d}e=P()|0;a=w[d+56>>2];if(!a){break a}w[d+60>>2]=a;zb(a);break a}f=(e-h|0)/24|0;i=f>>>0<=1?1:f;e=0;while(1){f=h+C(e,24)|0;if(B[f>>3]+k>b){c=f;break d}k=B[c>>3]+k;e=e+1|0;if((i|0)!=(e|0)){continue}break}}b=b-k;break b}c=w[f>>2]+C(c,24)|0}f=y[c+12>>1];e=w[a+24>>2];w[114256]=0;T(1463,e|0,f|0);f=w[114256];w[114256]=0;if((f|0)!=1){h:{f=w[a+24>>2];e=x[a+64|0];h=w[c+8>>2];i=w[c+12>>2];c=w[c+16>>2];B[d+40>>3]=b;w[d+48>>2]=b<0?0:3;w[114256]=0;j=w[d+44>>2];w[d+16>>2]=w[d+40>>2];w[d+20>>2]=j;j=w[d+52>>2];w[d+24>>2]=w[d+48>>2];w[d+28>>2]=j;u[d+38|0]=c;v[d+36>>1]=i;w[d+32>>2]=h;c=w[d+36>>2];w[d+8>>2]=w[d+32>>2];w[d+12>>2]=c;Y(1441,d+56|0,f|0,(e?7:1)|0,d+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break h}c=w[d+60>>2]-32|0;b=B[c>>3];f=x[c+26|0];e=y[c+22>>1];h=y[c+20>>1];i=w[c+12>>2];j=w[c+8>>2];c=w[d+56>>2];if(c){w[d+60>>2]=c;zb(c)}c=w[a+24>>2];f=f&1;e=f?h:e;v[c+1074440>>1]=e;v[c+1074438>>1]=e;w[c+1074428>>2]=f?j:i;w[c+1074392>>2]=-2;b=b+k;B[a+16>>3]=b;w[d+72>>2]=0;if(g){kd(g)}jb=d+80|0;return+b}}e=P()|0;w[d+72>>2]=0;if(!g){break a}kd(g)}R(e|0);M()}function kK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=D(0);a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;Ul(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;u[a+7|0]=1;u[a+6|0]=69;while(1){d:{w[114256]=0;b=Q(1710,a+264|0,a+256|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+188>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=b+c}w[114256]=0;b=V(1712,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=mj(b,a+7|0,a+6|0,c,a+188|0,u[a+223|0],u[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1714,a+264|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)|!x[a+7|0]){break e}b=w[a+12>>2];if((b-(a+16|0)|0)>159){break e}w[a+12>>2]=b+4;w[b>>2]=w[a+8>>2]}w[114256]=0;h=D(xa(1727,c|0,w[a+188>>2],e|0));b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}A[f>>2]=h;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function Zw(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;c=a+12|0;qg(a+8|0,w[c>>2]);w[a+32>>2]=0;w[a+36>>2]=0;w[a+8>>2]=c;w[a+12>>2]=0;w[a+16>>2]=0;c=w[a+4>>2];w[c>>2]=0;b=w[a>>2];w[c+40>>2]=w[b+480196>>2];w[c+44>>2]=w[b+480204>>2];w[c+68>>2]=w[b+480200>>2];f=y[b+480188>>1];w[d+24>>2]=0;w[d+28>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;w[d+8>>2]=0;w[d+12>>2]=0;u[d+29|0]=255;e=a+20|0;c=w[e+8>>2];b=w[e>>2];a:{b:{if(f>>>0<=(c-b|0)/24>>>0){h=(w[e+4>>2]-b|0)/24|0;c=f>>>0>h>>>0?h:f;if(c){while(1){g=w[d+12>>2];w[b>>2]=w[d+8>>2];w[b+4>>2]=g;g=y[d+26>>1]|y[d+28>>1]<<16;i=y[d+22>>1]|y[d+24>>1]<<16;v[b+14>>1]=i;v[b+16>>1]=i>>>16;v[b+18>>1]=g;v[b+20>>1]=g>>>16;g=w[d+20>>2];w[b+8>>2]=w[d+16>>2];w[b+12>>2]=g;b=b+24|0;c=c-1|0;if(c){continue}break}}if(f>>>0>h>>>0){b=w[e+4>>2];c=b+C(f-h|0,24)|0;break b}w[e+4>>2]=w[e>>2]+C(f,24);break a}if(b){w[e+4>>2]=b;zb(b);w[e+8>>2]=0;w[e>>2]=0;w[e+4>>2]=0;c=0}c=(c|0)/24|0;b=c<<1;c=c>>>0>=89478485?178956970:b>>>0>f>>>0?b:f;if(c>>>0>=178956971){Mb(e);M()}b=C(c,24);c=Kb(b);w[e>>2]=c;w[e+4>>2]=c;w[e+8>>2]=b+c;b=w[e+4>>2];c=b+C(f,24)|0}while(1){f=w[d+12>>2];w[b>>2]=w[d+8>>2];w[b+4>>2]=f;f=w[d+28>>2];w[b+16>>2]=w[d+24>>2];w[b+20>>2]=f;f=w[d+20>>2];w[b+8>>2]=w[d+16>>2];w[b+12>>2]=f;b=b+24|0;if((c|0)!=(b|0)){continue}break}w[e+4>>2]=c}b=w[a>>2];if(y[b+480188>>1]){c=w[a+4>>2];e=0;while(1){f=C(e,896);ug((f+c|0)+608|0,7,b,e&65535,1024);c=w[a+4>>2];b=f+c|0;v[b+1444>>1]=0;u[b+1432|0]=0;u[b+1429|0]=0;u[b+1427|0]=0;e=e+1|0;b=w[a>>2];if(e>>>0<y[b+480188>>1]){continue}break}}jb=d+32|0}function VJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-368|0;jb=a;w[a+352>>2]=c;w[a+360>>2]=b;Ql(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+180>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;u[a+7|0]=1;u[a+6|0]=69;while(1){d:{w[114256]=0;b=Q(1740,a+360|0,a+352|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+180>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+180>>2]=b+c}w[114256]=0;b=V(1742,a+360|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=jj(b,a+7|0,a+6|0,c,a+180|0,w[a+220>>2],w[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1744,a+360|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+200|0)|!x[a+7|0]){break e}b=w[a+12>>2];if((b-(a+16|0)|0)>159){break e}w[a+12>>2]=b+4;w[b>>2]=w[a+8>>2]}w[114256]=0;h=+ra(1730,c|0,w[a+180>>2],e|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}B[f>>3]=h;w[114256]=0;Jc(a+200|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+360|0,a+352|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+360>>2];Gb(d);Gb(a+200|0);jb=a+368|0;break a}}b=P()|0;Gb(d);Gb(a+200|0);R(b|0);M()}return b|0}function hK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;Ul(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Yb(d);w[114256]=0;T(1592,d|0,b|0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;u[a+7|0]=1;u[a+6|0]=69;while(1){d:{w[114256]=0;b=Q(1710,a+264|0,a+256|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(!b){break c}if(w[a+188>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=b+c}w[114256]=0;b=V(1712,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;b=mj(b,a+7|0,a+6|0,c,a+188|0,u[a+223|0],u[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=w[114256];w[114256]=0;if((g|0)==1){break d}if(b){break c}w[114256]=0;V(1714,a+264|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)|!x[a+7|0]){break e}b=w[a+12>>2];if((b-(a+16|0)|0)>159){break e}w[a+12>>2]=b+4;w[b>>2]=w[a+8>>2]}w[114256]=0;h=+ra(1730,c|0,w[a+188>>2],e|0);b=w[114256];w[114256]=0;f:{if((b|0)==1){break f}B[f>>3]=h;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function LI(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,v=0,y=0,z=0,A=0,B=0,C=0,D=0;t=jb-16|0;jb=t;w[c>>2]=a;z=d&512;A=h<<2;while(1){if((v|0)==4){if(Db(n)>>>0>1){C=t,D=zd(n),w[C+8>>2]=D;C=c,D=cj(Pr(t+8|0,1),ff(n),w[c>>2]),w[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=w[c>>2]}w[b>>2]=a}jb=t+16|0}else{a:{b:{switch(u[i+v|0]){case 0:w[b>>2]=w[c>>2];break a;case 1:w[b>>2]=w[c>>2];h=tj(g,32);p=w[c>>2];w[c>>2]=p+4;w[p>>2]=h;break a;case 3:if(Id(n)){break a}h=w[kj(n,0)>>2];p=w[c>>2];w[c>>2]=p+4;w[p>>2]=h;break a;case 2:if(Id(m)|!z){break a}C=c,D=cj(zd(m),ff(m),w[c>>2]),w[C>>2]=D;break a;case 4:break b;default:break a}}B=w[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!pf(g,64,w[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=w[c>>2];r=o;while(1){if(!(!r|e>>>0>=h>>>0)){h=h-4|0;s=w[h>>2];q=p+4|0;w[c>>2]=q;w[p>>2]=s;r=r-1|0;p=q;continue}break}d:{if(!r){q=0;break d}q=tj(g,48);p=w[c>>2]}while(1){s=p+4|0;if((r|0)>0){w[p>>2]=q;r=r-1|0;p=s;continue}break}w[c>>2]=s;w[p>>2]=j}e:{if((e|0)==(h|0)){p=tj(g,48);q=w[c>>2];h=q+4|0;w[c>>2]=h;w[q>>2]=p;break e}if(Id(l)){q=-1}else{q=u[Rb(l,0)|0]}p=0;r=0;while(1){if((e|0)!=(h|0)){f:{if((p|0)!=(q|0)){s=p;break f}q=w[c>>2];w[c>>2]=q+4;w[q>>2]=k;s=0;r=r+1|0;if(Db(l)>>>0<=r>>>0){q=p;break f}if(x[Rb(l,r)|0]==127){q=-1;break f}q=u[Rb(l,r)|0]}h=h-4|0;p=w[h>>2];y=w[c>>2];w[c>>2]=y+4;w[y>>2]=p;p=s+1|0;continue}break}h=w[c>>2]}Nh(B,h)}v=v+1|0;continue}break}}function ro(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];a:{if(!c){f=Kb(3848);c=f+808|0;d=f+16|0;while(1){w[d+16>>2]=0;w[d+20>>2]=0;w[d+36>>2]=0;u[d+42|0]=1;v[d+40>>1]=257;w[d+24>>2]=0;w[d+28>>2]=0;v[d+32>>1]=0;d=d+44|0;if((d|0)!=(c|0)){continue}break}d=f+3832|0;while(1){w[c>>2]=0;w[c+4>>2]=0;w[c+68>>2]=0;w[c+72>>2]=0;w[c+24>>2]=0;w[c+28>>2]=0;v[c+20>>1]=511;w[c+16>>2]=-1;v[c+14>>1]=1;v[c+6>>1]=0;v[c+8>>1]=0;v[c+10>>1]=0;v[c+12>>1]=0;u[c+73|0]=0;u[c+74|0]=0;u[c+75|0]=0;u[c+76|0]=0;u[c+77|0]=0;u[c+78|0]=0;u[c+79|0]=0;u[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}c=0;d=0;w[f+3832>>2]=0;w[f+3836>>2]=0;e=f+3837|0;u[e|0]=0;u[e+1|0]=0;u[e+2|0]=0;u[e+3|0]=0;u[e+4|0]=0;u[e+5|0]=0;u[e+6|0]=0;u[e+7|0]=0;while(1){w[(C(d,84)+f|0)+808>>2]=f;d=d+1|0;if((d|0)!=36){continue}break}while(1){w[(C(c,44)+f|0)+32>>2]=f;c=c+1|0;if((c|0)!=18){continue}break}d=0;while(1){c=w[(d<<2)+25312>>2];e=C(d,44)+f|0;h=e+16|0;b:{if(!(!(1<<d&3591)|d>>>0>11)){g=C(c,84)+f|0;w[e+28>>2]=g+1564;w[e+24>>2]=g+1312;w[e+20>>2]=g+1060;w[e+16>>2]=g+808;w[g+1064>>2]=h;w[g+812>>2]=h;e=c+9|0;c=c+6|0;break b}w[e+24>>2]=0;w[e+28>>2]=0;g=C(c,84)+f|0;w[e+20>>2]=g+1060;w[e+16>>2]=g+808;e=c+3|0}g=C(c,84);c=f+808|0;w[(g+c|0)+4>>2]=h;w[(c+C(e,84)|0)+4>>2]=h;d=d+1|0;if((d|0)!=18){continue}break}c=0;while(1){sg((C(c,84)+f|0)+808|0);c=c+1|0;if((c|0)!=36){continue}break}w[f+4>>2]=0;w[f+8>>2]=0;w[f>>2]=b?b:49716;w[f+12>>2]=0;b=w[a>>2];w[a>>2]=f;if(!b){break a}zb(b);break a}w[c+4>>2]=0;w[c+8>>2]=0;w[c>>2]=b?b:49716;w[c+12>>2]=0}qo(a)}function Az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0;r=w[a+16>>2];g=jb-32|0;b=w[a+44>>2];w[g+12>>2]=b;e=w[a+48>>2];w[g+16>>2]=e;f=w[a+52>>2];w[g+20>>2]=f;i=w[a+56>>2];w[g+24>>2]=i;k=w[a>>2];j=w[a+4>>2];if(d){q=w[a+8>>2];s=w[a+12>>2];t=w[a+24>>2];u=w[a+20>>2];x=w[a+72>>2];b=w[a+68>>2];y=b;z=b>>31;b=w[a+64>>2];A=b;B=b>>31;b=w[a+60>>2];D=b;E=b>>31;while(1){b=1;h=((((j&2147483647)<<1|k>>>31)&2147483646)<<1)+r|0;e=(k>>>21&2040)+32832|0;l=v[e+6>>1];m=v[e+4>>1];n=v[e+2>>1];o=v[e>>1];f=0;i=1;e=0;while(1){p=(e<<2)+g|0;e=e<<1;w[p>>2]=(((C(v[e+h>>1],n)+C(v[h+(e|-4)>>1],o)|0)+C(v[h+(e|4)>>1],m)|0)+C(v[h+(e|8)>>1],l)|0)/16384;p=i&1;i=0;e=1;if(p){continue}break}while(1){e=(g+8|0)+(f<<3)|0;i=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;l=(f<<2)+g|0;m=w[l>>2]<<8;f=m;f=BV(D,E,f,f>>31);n=nb;o=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,A,B);f=h+f|0;e=nb+n|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=(i|0)>=16776704?16776704:i;f=(f|0)<=-16777216?-16777216:f;i=BV(f,f>>31,y,z);f=h+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[o+4>>2]=e-(m&x);w[l>>2]=(e|0)/256;f=1;e=b;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],u);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],t);j=j+s|0;b=k+q|0;j=b>>>0<q>>>0?j+1|0:j;k=b;c=c+8|0;d=d-1|0;if(d){continue}break}i=w[g+24>>2];f=w[g+20>>2];e=w[g+16>>2];b=w[g+12>>2]}w[a+56>>2]=i;w[a+52>>2]=f;w[a+48>>2]=e;w[a+44>>2]=b;w[a>>2]=k;w[a+4>>2]=j}function ou(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=D(0),j=0,k=0,l=D(0),m=0,n=0,o=0,p=0,q=0,r=0,s=D(0);d=(b<<2)+a|0;e=d+1068|0;k=c<<1&-4;q=e,r=yc(a,k),w[q>>2]=r;h=d+1076|0;q=h,r=yc(a,k),w[q>>2]=r;f=yc(a,c&-4);w[d+1084>>2]=f;a:{b:{j=w[e>>2];if(!j){break b}h=w[h>>2];if(!h|!f){break b}c:{if((c|0)<4){break c}p=c>>>2|0;l=D(c|0);i=D(D(1)/l);d=0;e=0;while(1){m=d<<2;g=+D(D(D(e<<2)*D(3.1415927410125732))*i);q=j+m|0,s=D(Fc(g)),A[q>>2]=s;n=d|1;o=n<<2;q=j+o|0,s=D(-D(ee(g))),A[q>>2]=s;g=+D(D(D(n|0)*D(1.5707963705062866))*i);q=h+m|0,s=D(D(Fc(g))*D(.5)),A[q>>2]=s;q=h+o|0,s=D(D(ee(g))*D(.5)),A[q>>2]=s;d=d+2|0;e=e+1|0;if((p|0)!=(e|0)){continue}break}if((c|0)<8){break c}d=c>>3;j=(d|0)<=1?1:d;i=D(D(1)/l);d=0;e=0;while(1){h=d|1;g=+D(D(D(h<<1)*D(3.1415927410125732))*i);q=f+(d<<2)|0,s=D(Fc(g)),A[q>>2]=s;q=f+(h<<2)|0,s=D(-D(ee(g))),A[q>>2]=s;d=d+2|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}}e=yc(a,k);w[((b<<2)+a|0)+1092>>2]=e;if(!e){break b}if((c|0)>=2){f=c>>>1|0;g=1/+(f|0);d=0;while(1){i=D(ee((+(d|0)*1.5707963705062866+.7853981852531433)*g));q=e+(d<<2)|0,s=D(ee(+D(i*i)*1.5707963705062866)),A[q>>2]=s;d=d+1|0;if((f|0)!=(d|0)){continue}break}}d=((b<<2)+a|0)+1100|0;b=yc(a,c>>2&-2);w[d>>2]=b;if(!b){break b}e=1;if((c|0)<8){break a}a=c>>>3|0;c=36-ig(c)|0;d=0;while(1){f=d<<8&16711680|d<<24|(d>>>8&65280|d>>>24);f=f>>>4&252645135|(f&252645135)<<4;f=f>>>2&858993459|(f&858993459)<<2;v[b+(d<<1)>>1]=(f>>>1&1431655765|(f&1431655765)<<1)>>>c<<2;d=d+1|0;if((a|0)!=(d|0)){continue}break}break a}w[a+100>>2]=3;e=0}return e}function tD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;c=w[b>>2];a:{if(!(ob[w[w[c>>2]+36>>2]](c,w[b+8>>2],9)|0)){break a}h=a+484344|0;i=a+480280|0;while(1){vh(b,d+20|0);c=Nc(b,d);b:{e=x[d+20|0]|x[d+21|0]<<8|(x[d+22|0]<<16|x[d+23|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=x[d+20|0]|x[d+21|0]<<8|(x[d+22|0]<<16|x[d+23|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}e=w[b>>2];c=c?w[d>>2]:0;if(ob[w[w[e>>2]+36>>2]](e,w[b+8>>2],c)|0){break b}}c=b;a=w[b+8>>2];b=a-8|0;w[c+8>>2]=a>>>0>=b>>>0?b:0;break a}oc(d,b,c);c=i;d:{e:{f:{if((x[d+20|0]|x[d+21|0]<<8|(x[d+22|0]<<16|x[d+23|0]<<24))==1481001027){while(1){w[114256]=0;e=Q(232,d|0,d+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}u[c+8|0]=e?x[d+24|0]:0;c=c+32|0;if((h|0)!=(c|0)){continue}break d}}if(x[d+20|0]!=70){break e}e=x[d+21|0];g=(e|0)==88;g:{if(!g){if((e-48&255)>>>0>9){break e}c=u[d+22|0];if((c|0)>47){break g}break e}c=u[d+22|0];if((c|0)<48){break e}}if(c>>>0>57){break e}f=u[d+23|0];if((f|0)<48|(f|0)>57){break e}c=(f+(g?-16:C(e,100)+48|0)|0)+C(c,10)&255;if(c>>>0>249){break d}w[114256]=0;T(386,d|0,(C(c,160)+a|0)+906300|0);c=w[114256];w[114256]=0;if((c|0)!=1){break d}}a=P()|0;Bb(d);R(a|0);M()}if((x[d+20|0]|x[d+21|0]<<8|(x[d+22|0]<<16|x[d+23|0]<<24))!=1430540109){break d}w[a+1074308>>2]=0;j=1}c=w[d+4>>2];h:{if(!c){break h}e=w[c+4>>2];w[c+4>>2]=e-1;if(e){break h}ob[w[w[c>>2]+8>>2]](c);Ib(c)}c=w[b>>2];if(ob[w[w[c>>2]+36>>2]](c,w[b+8>>2],9)|0){continue}break}}jb=d+32|0;return j|0}function Rk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=jb-32|0;jb=g;if(!vp(a,b)){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+22|0]=0;u[b+23|0]=0;u[b+24|0]=0;u[b+25|0]=0;u[b+26|0]=0;u[b+27|0]=0;u[b+28|0]=0;u[b+29|0]=0;u[b+16|0]=0;u[b+17|0]=0;u[b+18|0]=0;u[b+19|0]=0;u[b+20|0]=0;u[b+21|0]=0;u[b+22|0]=0;u[b+23|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0}lc(c,1);f=x[b+22|0]|x[b+23|0]<<8;i=((f<<8|f>>>8)&65535)<<1;w[c>>2]=i;u[c+37|0]=x[b+24|0]<<4;a=x[b+25|0];v[c+30>>1]=(a>>>0>=64?64:a)<<2;a=x[b+26|0]|x[b+27|0]<<8;h=(a<<8|a>>>8)&65535;a=h<<1;j=h;h=x[b+28|0]|x[b+29|0]<<8;k=(h<<8|h>>>8)&65535;h=k<<1;a=k>>>0>=2?a+h>>>0<=i>>>0?a:j+h>>>0>i>>>0?a:j:a;a:{if(!f){break a}if((f|0)==256){w[c>>2]=0;break a}w[c+4>>2]=a;f=a+h|0;w[c+8>>2]=f;if(a>>>0>=i>>>0){a=i-1|0;w[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){w[c+4>>2]=0;w[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=i>>>0))){w[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}v[c+34>>1]=y[c+34>>1]|2}a=g+8|0;Vb(a,3,b,22);w[114256]=0;w[g+28>>2]=32;w[g+24>>2]=d;Q(200,g+24|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+19|0]<0){zb(w[g+8>>2])}e=0;c=d;while(1){if((x[c|0]-1&255)>>>0<=30){u[c|0]=32}e=e+1|0;c=e+d|0;if((e|0)!=32){continue}break}jb=g+32|0;a=x[b+26|0]|x[b+27|0]<<8;c=(a<<8|a>>>8)&65535;a=x[b+22|0]|x[b+23|0]<<8;return((x[b+24|0]>15)+(x[b+25|0]>64)|0)+(c>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}a=P()|0;if(u[g+19|0]<0){zb(w[g+8>>2])}R(a|0);M()}function Lw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;c=y[a+480190>>1];u[e+31|0]=0;lo(b,c+1|0,e+31|0);a:{if(!y[a+480192>>1]){break a}w[e+24>>2]=0;w[e+16>>2]=0;w[e+20>>2]=0;f=w[a+484344>>2];k=w[a+484348>>2];if((f|0)!=(k|0)){while(1){b:{if(w[f>>2]==w[f+4>>2]){break b}c=y[a+480188>>1];w[114256]=0;u[e+15|0]=0;U(834,e+16|0,c|0,e+15|0);c=w[114256];w[114256]=0;if((c|0)!=1){d=w[f+12>>2];if(!d){break b}c=y[a+480188>>1];h=w[f>>2];j=0;while(1){c:{if(c&65535){i=0;while(1){d:{if((x[h|0]-1&255)>>>0>119){break d}e:{f:{c=x[h+1|0];if(c){d=y[a+480192>>1];g=w[e+16>>2];break f}d=y[a+480192>>1];g=w[e+16>>2];c=x[i+g|0];if(c){break f}c=1;break e}u[g+i|0]=c;d=d&65535;g=d>>>0<c>>>0;d=g?d:c;c=g?1:c}g=d&65535;if(c>>>0>g>>>0){break d}n=w[b>>2];o=y[a+480190>>1];while(1){d=w[(((c&65535)<<2)+a|0)+900380>>2];g:{if(!d){break g}d=y[(d+(x[h|0]<<1)|0)+234>>1];if(o>>>0<d>>>0){break g}l=(d>>>3&8188)+n|0;w[l>>2]=w[l>>2]|1<<d}c=c+1|0;if((c&65535)>>>0<=g>>>0){continue}break}}h=h+6|0;c=y[a+480188>>1];i=i+1|0;if(c>>>0>i>>>0){continue}break}d=w[f+12>>2];break c}c=0}j=j+1|0;if(j>>>0<d>>>0){continue}break}break b}b=P()|0;a=w[e+16>>2];if(a){w[e+20>>2]=a;zb(a)}R(b|0);M()}f=f+52|0;if((k|0)!=(f|0)){continue}break}}c=y[a+480190>>1];if(c){b=w[b>>2];d=c;while(1){if(!(w[b+(c>>>3&536870908)>>2]>>>c&1)){f=C(c,104)+a|0;m=(w[f+484400>>2]!=0&w[f+484380>>2]!=0)+m|0}c=c-1|0;d=d-1|0;if(d&65535){continue}break}}a=w[e+16>>2];if(!a){break a}w[e+20>>2]=a;zb(a)}jb=e+32|0;return m&65535}function Dk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;a:{b:{c:{if(!b){b=x[c+11|0];f=b<<24>>24<0;d=f?w[c+4>>2]:b;if(d>>>0>=4294967280){break b}g=w[c>>2];d:{e:{if(d>>>0>=11){h=(d|15)+1|0;b=Kb(h);w[a+8>>2]=h|-2147483648;w[a>>2]=b;w[a+4>>2]=d;a=b;break e}u[a+11|0]=d;if(!d){break d}}c=f?g:c;b=d+c|0;while(1){u[a|0]=x[c|0];a=a+1|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}}u[a|0]=0;break c}No(e+8|0,b,c);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;d=x[e+19|0];b=d<<24>>24;c=(b|0)<0;if(c?w[e+12>>2]:d){while(1){c=w[(f<<2)+(c&1?w[e+8>>2]:e+8|0)>>2];f:{if(c>>>0>=2097152){w[114256]=0;T(74,a|0,63);b=w[114256];w[114256]=0;if((b|0)!=1){break f}break a}b=0;g:{h:{while(1){g=c&63;u[(e+26|0)+b|0]=g;if(c>>>0<64){break h}c=c>>>6|0;b=b+1|0;if((b|0)!=6){continue}break}d=7;b=6;break g}if(b){d=b+1|0;if((d|0)!=2){break g}b=1;d=2;if((g|0)!=1){break g}b=x[e+26|0]|64}else{b=x[e+26|0]}w[114256]=0;T(74,a|0,b<<24>>24);b=w[114256];w[114256]=0;if((b|0)!=1){break f}break a}g=(-1<<d^-1)<<7-b;b=d-1|0;h=b+(e+26|0)|0;c=d;while(1){i:{if((c|0)==(d|0)){c=x[h|0];w[114256]=0;T(74,a|0,(c|g)<<24>>24);i=w[114256];w[114256]=0;c=b;if((i|0)!=1){break i}break a}w[114256]=0;c=c-1|0;T(74,a|0,u[c+(e+26|0)|0]|-128);i=w[114256];w[114256]=0;if((i|0)==1){break a}}if(c){continue}break}}d=x[e+19|0];b=d<<24>>24;c=(b|0)<0;f=f+1|0;if(f>>>0<(c?w[e+12>>2]:d)>>>0){continue}break}}if((b|0)>=0){break c}zb(w[e+8>>2])}jb=e+32|0;return}zc(a);M()}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}if(u[e+19|0]<0){zb(w[e+8>>2])}R(b|0);M()}function XJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Ch(1725,c,w[a+188>>2],e,b);c=nb;h=w[114256];w[114256]=0;f:{if((h|0)==1){break f}w[f>>2]=b;w[f+4>>2]=c;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function $J(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Ch(1721,c,w[a+188>>2],e,b);c=nb;h=w[114256];w[114256]=0;f:{if((h|0)==1){break f}w[f>>2]=b;w[f+4>>2]=c;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function Bz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0;q=w[a+16>>2];g=jb-32|0;e=w[a+44>>2];w[g+12>>2]=e;b=w[a+48>>2];w[g+16>>2]=b;f=w[a+52>>2];w[g+20>>2]=f;i=w[a+56>>2];w[g+24>>2]=i;k=w[a>>2];j=w[a+4>>2];if(d){p=w[a+8>>2];r=w[a+12>>2];s=w[a+24>>2];t=w[a+20>>2];x=w[a+72>>2];b=w[a+68>>2];y=b;z=b>>31;b=w[a+64>>2];A=b;B=b>>31;b=w[a+60>>2];D=b;E=b>>31;while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+q|0;b=(k>>>21&2040)+32832|0;l=v[b+6>>1];m=v[b+4>>1];n=v[b+2>>1];o=v[b>>1];f=0;b=1;i=1;e=0;while(1){w[(e<<2)+g>>2]=(((C(u[e+h|0],n)+C(u[h+(e|-2)|0],o)|0)+C(u[h+(e|2)|0],m)|0)+C(u[h+(e|4)|0],l)<<8)/16384;F=i&1;i=0;e=1;if(F){continue}break}while(1){e=(g+8|0)+(f<<3)|0;i=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;l=(f<<2)+g|0;m=w[l>>2]<<8;f=m;f=BV(D,E,f,f>>31);n=nb;o=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,A,B);f=h+f|0;e=nb+n|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=(i|0)>=16776704?16776704:i;f=(f|0)<=-16777216?-16777216:f;i=BV(f,f>>31,y,z);f=h+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[o+4>>2]=e-(m&x);w[l>>2]=(e|0)/256;f=1;e=b;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],t);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],s);j=j+r|0;b=k+p|0;j=b>>>0<p>>>0?j+1|0:j;k=b;c=c+8|0;d=d-1|0;if(d){continue}break}i=w[g+24>>2];f=w[g+20>>2];e=w[g+12>>2];b=w[g+16>>2]}w[a+56>>2]=i;w[a+52>>2]=f;w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=k;w[a+4>>2]=j}function CO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=jb-160|0;jb=e;d=Hb(e,7439);w[114256]=0;b=d+12|0;Q(5,b|0,6904)|0;c=w[114256];w[114256]=0;a:{if((c|0)==1){break a}w[114256]=0;b=d+24|0;Q(5,b|0,7269)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+36|0;Q(5,b|0,6896)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+48|0;Q(5,b|0,4428)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+60|0;Q(5,b|0,6881)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+72|0;Q(5,b|0,4494)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+84|0;Q(5,b|0,2106)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+96|0;Q(5,b|0,7807)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+108|0;Q(5,b|0,7212)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+120|0;Q(5,b|0,7998)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+132|0;Q(5,b|0,1958)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;b=d+144|0;Q(5,b|0,3559)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;T(1464,a|0,13);b=w[114256];w[114256]=0;b:{if((b|0)==1){break b}w[114256]=0;b=d+156|0;Y(1465,a|0,d|0,b|0,13);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=b-12|0;if(u[b-1|0]<0){zb(w[a>>2])}b=a;if((d|0)!=(b|0)){continue}break}jb=e+160|0;return}b=d+156|0}e=P()|0;while(1){a=b-12|0;if(u[b-1|0]<0){zb(w[a>>2])}b=a;if((d|0)!=(b|0)){continue}break}R(e|0);M()}function aK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Z(1717,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function _J(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Z(1722,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}v[f>>1]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function ZJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Z(1723,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function YJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;w[a+336>>2]=c;w[a+344>>2]=b;b=Sd(d);h=Gg(d,a+224|0);Fg(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1740,a+344|0,a+336|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1742,a+344|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[114256]=0;g=jf(g,b,c,a+188|0,a+8|0,w[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=w[114256];w[114256]=0;if((i|0)==1){break d}if(g){break c}w[114256]=0;V(1744,a+344|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=w[a+12>>2];if((h-(a+16|0)|0)>159){break e}w[a+12>>2]=h+4;w[h>>2]=w[a+8>>2]}w[114256]=0;b=Z(1724,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1741,a+344|0,a+336|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+344>>2];Gb(d);Gb(a+208|0);jb=a+352|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function sK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Ch(1721,c,w[a+188>>2],e,b);c=nb;g=w[114256];w[114256]=0;f:{if((g|0)==1){break f}w[f>>2]=b;w[f+4>>2]=c;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function mK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Ch(1725,c,w[a+188>>2],e,b);c=nb;g=w[114256];w[114256]=0;f:{if((g|0)==1){break f}w[f>>2]=b;w[f+4>>2]=c;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function PI(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,v=0,y=0,z=0,A=0,B=0,C=0,D=0;v=jb-16|0;jb=v;w[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(Db(n)>>>0>1){C=v,D=zd(n),w[C+8>>2]=D;C=c,D=cj(Vr(v+8|0,1),hf(n),w[c>>2]),w[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=w[c>>2]}w[b>>2]=a}jb=v+16|0;return}a:{b:{switch(u[i+y|0]){case 0:w[b>>2]=w[c>>2];break a;case 1:w[b>>2]=w[c>>2];q=$f(g,32);p=w[c>>2];w[c>>2]=p+1;u[p|0]=q;break a;case 3:if(Id(n)){break a}q=x[Rb(n,0)|0];p=w[c>>2];w[c>>2]=p+1;u[p|0]=q;break a;case 2:if(Id(m)|!A){break a}C=c,D=cj(zd(m),hf(m),w[c>>2]),w[C>>2]=D;break a;case 4:break b;default:break a}}B=w[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Ld(g,64,u[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=x[r|0];s=w[c>>2];w[c>>2]=s+1;u[s|0]=p;q=q-1|0;continue}break}if(q){p=$f(g,48)}else{p=0}while(1){s=w[c>>2];w[c>>2]=s+1;if((q|0)>0){u[s|0]=p;q=q-1|0;continue}break}u[s|0]=j}d:{if((e|0)==(r|0)){q=$f(g,48);p=w[c>>2];w[c>>2]=p+1;u[p|0]=q;break d}if(Id(l)){p=-1}else{p=u[Rb(l,0)|0]}q=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=w[c>>2];w[c>>2]=p+1;u[p|0]=k;s=0;t=t+1|0;if(Db(l)>>>0<=t>>>0){p=q;break e}if(x[Rb(l,t)|0]==127){p=-1;break e}p=u[Rb(l,t)|0]}r=r-1|0;q=x[r|0];z=w[c>>2];w[c>>2]=z+1;u[z|0]=q;q=s+1|0;continue}}ef(B,w[c>>2])}y=y+1|0;continue}}function uK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Z(1717,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function qK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Z(1722,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}v[f>>1]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function oK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Z(1723,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function nK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;w[a+256>>2]=c;w[a+264>>2]=b;b=Sd(d);Hg(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){c=Rb(d,0);w[a+188>>2]=c;w[a+12>>2]=a+16;w[a+8>>2]=0;while(1){d:{w[114256]=0;g=Q(1710,a+264|0,a+256|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}if(!g){break c}if(w[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);w[114256]=0;T(1592,d|0,c<<1);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Yb(d);w[114256]=0;T(1592,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}c=Rb(d,0);w[a+188>>2]=g+c}w[114256]=0;g=V(1712,a+264|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;g=kf(g,b,c,a+188|0,a+8|0,u[a+255|0],a+208|0,a+16|0,a+12|0,64768);h=w[114256];w[114256]=0;if((h|0)==1){break d}if(g){break c}w[114256]=0;V(1714,a+264|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=w[a+12>>2];if((g-(a+16|0)|0)>159){break e}w[a+12>>2]=g+4;w[g>>2]=w[a+8>>2]}w[114256]=0;b=Z(1724,c|0,w[a+188>>2],e|0,b|0)|0;c=w[114256];w[114256]=0;f:{if((c|0)==1){break f}w[f>>2]=b;w[114256]=0;Jc(a+208|0,a+16|0,w[a+12>>2],e);b=w[114256];w[114256]=0;if((b|0)==1){break f}w[114256]=0;b=Q(1711,a+264|0,a+256|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}if(b){w[e>>2]=w[e>>2]|2}b=w[a+264>>2];Gb(d);Gb(a+208|0);jb=a+272|0;break a}}b=P()|0;Gb(d);Gb(a+208|0);R(b|0);M()}return b|0}function bA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0;q=w[a+16>>2];b=jb-32|0;k=w[a+44>>2];w[b+12>>2]=k;f=w[a+48>>2];w[b+16>>2]=f;h=w[a+52>>2];w[b+20>>2]=h;i=w[a+56>>2];w[b+24>>2]=i;n=w[a>>2];j=w[a+4>>2];l=w[a+40>>2];m=w[a+36>>2];a:{if(!d){e=l>>12;g=m>>12;break a}k=w[a+8>>2];r=w[a+12>>2];s=w[a+32>>2];t=w[a+28>>2];u=w[a+72>>2];e=w[a+68>>2];x=e;y=e>>31;e=w[a+64>>2];z=e;A=e>>31;e=w[a+60>>2];B=e;D=e>>31;while(1){e=((((j&2147483647)<<1|n>>>31)&2147483646)<<1)+q|0;w[b>>2]=v[e>>1];w[b+4>>2]=v[e+2>>1];e=0;h=1;while(1){f=(b+8|0)+(e<<3)|0;i=w[f+8>>2];g=w[f+4>>2];w[f+8>>2]=g;o=(e<<2)+b|0;p=w[o>>2]<<8;e=p;e=BV(B,D,e,e>>31);E=nb;F=f;f=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,z,A);f=f+g|0;e=nb+E|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(i|0)>=16776704?16776704:i;f=(f|0)<=-16777216?-16777216:f;i=BV(f,f>>31,x,y);f=g+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[F+4>>2]=e-(u&p);w[o>>2]=(e|0)/256;f=h&1;h=0;e=1;if(f){continue}break}m=m+t|0;g=m>>12;w[c>>2]=w[c>>2]+C(g,w[b>>2]);l=l+s|0;e=l>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[b+4>>2]);j=j+r|0;h=k+n|0;j=h>>>0<k>>>0?j+1|0:j;n=h;c=c+8|0;d=d-1|0;if(d){continue}break}i=w[b+24>>2];h=w[b+20>>2];f=w[b+16>>2];k=w[b+12>>2]}w[a+36>>2]=m;w[a>>2]=n;w[a+4>>2]=j;w[a+40>>2]=l;w[a+20>>2]=g;w[a+56>>2]=i;w[a+52>>2]=h;w[a+48>>2]=f;w[a+44>>2]=k;w[a+24>>2]=e}function cA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0;q=w[a+16>>2];b=jb-32|0;k=w[a+44>>2];w[b+12>>2]=k;f=w[a+48>>2];w[b+16>>2]=f;h=w[a+52>>2];w[b+20>>2]=h;i=w[a+56>>2];w[b+24>>2]=i;n=w[a>>2];j=w[a+4>>2];l=w[a+40>>2];m=w[a+36>>2];a:{if(!d){e=l>>12;g=m>>12;break a}k=w[a+8>>2];r=w[a+12>>2];s=w[a+32>>2];t=w[a+28>>2];v=w[a+72>>2];e=w[a+68>>2];x=e;y=e>>31;e=w[a+64>>2];z=e;A=e>>31;e=w[a+60>>2];B=e;D=e>>31;while(1){e=(((j&2147483647)<<1|n>>>31)&-2)+q|0;w[b>>2]=u[e|0]<<8;w[b+4>>2]=u[e+1|0]<<8;e=0;h=1;while(1){f=(b+8|0)+(e<<3)|0;i=w[f+8>>2];g=w[f+4>>2];w[f+8>>2]=g;o=(e<<2)+b|0;p=w[o>>2]<<8;e=p;e=BV(B,D,e,e>>31);E=nb;F=f;f=e;e=(g|0)>=16776704?16776704:g;e=(e|0)<=-16777216?-16777216:e;g=BV(e,e>>31,z,A);f=f+g|0;e=nb+E|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=(i|0)>=16776704?16776704:i;f=(f|0)<=-16777216?-16777216:f;i=BV(f,f>>31,x,y);f=g+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[F+4>>2]=e-(v&p);w[o>>2]=(e|0)/256;f=h&1;h=0;e=1;if(f){continue}break}m=m+t|0;g=m>>12;w[c>>2]=w[c>>2]+C(g,w[b>>2]);l=l+s|0;e=l>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[b+4>>2]);j=j+r|0;h=k+n|0;j=h>>>0<k>>>0?j+1|0:j;n=h;c=c+8|0;d=d-1|0;if(d){continue}break}i=w[b+24>>2];h=w[b+20>>2];f=w[b+16>>2];k=w[b+12>>2]}w[a+36>>2]=m;w[a>>2]=n;w[a+4>>2]=j;w[a+40>>2]=l;w[a+20>>2]=g;w[a+56>>2]=i;w[a+52>>2]=h;w[a+48>>2]=f;w[a+44>>2]=k;w[a+24>>2]=e}function Oo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{if((b|0)==(c|0)){break a}d=c-b|0;if((d|0)>0){Cb(b,139,((d>>>2|0)-(d>>>0>3)<<2)+4|0)}i=w[a+4>>2];g=w[a>>2];f=i-g>>2;c=d>>2;h=w[b>>2]^w[((c<<2)+b|0)-4>>2];a=11;b:{if(d>>>0>2488){break b}a=7;if(d>>>0>268){break b}a=5;if(d>>>0>152){break b}a=3;if(d>>>0>24){break b}a=c-1>>>1|0}k=c-a>>>1|0;j=(k<<2)+b|0;e=w[j>>2];d=h^e;d=C(d>>>27^d,1664525);w[j>>2]=d+e;j=a+k|0;a=(j<<2)+b|0;e=a;h=w[a>>2];a=d+f|0;w[e>>2]=h+a;w[b>>2]=a;a=f+1|0;e=c>>>0<a>>>0;if((g|0)!=(i|0)){i=a>>>0<=2?2:a;d=1;while(1){l=((d+k>>>0)%(c>>>0)<<2)+b|0;m=w[l>>2];h=(d>>>0)%(c>>>0)|0;n=(h<<2)+b|0;o=d-1|0;f=m^(w[n>>2]^w[((o>>>0)%(c>>>0)<<2)+b>>2]);f=C(f>>>27^f,1664525);w[l>>2]=f+m;l=((d+j>>>0)%(c>>>0)<<2)+b|0;f=f+(h+w[g+(o<<2)>>2]|0)|0;w[l>>2]=f+w[l>>2];w[n>>2]=f;d=d+1|0;if((i|0)!=(d|0)){continue}break}}d=e?a:c;if(a>>>0<c>>>0){while(1){e=((a+k>>>0)%(c>>>0)<<2)+b|0;h=w[e>>2];f=(a>>>0)%(c>>>0)|0;i=(f<<2)+b|0;g=h^(w[i>>2]^w[((a-1>>>0)%(c>>>0)<<2)+b>>2]);g=C(g>>>27^g,1664525);w[e>>2]=g+h;e=((a+j>>>0)%(c>>>0)<<2)+b|0;g=f+g|0;w[e>>2]=g+w[e>>2];w[i>>2]=g;a=a+1|0;if((d|0)!=(a|0)){continue}break}}g=c+d|0;if(g>>>0<=d>>>0){break a}while(1){e=((d+k>>>0)%(c>>>0)<<2)+b|0;h=w[e>>2];f=(d>>>0)%(c>>>0)|0;i=(f<<2)+b|0;a=w[((d-1>>>0)%(c>>>0)<<2)+b>>2]+(h+w[i>>2]|0)|0;a=C(a>>>27^a,1566083941);w[e>>2]=a^h;e=((d+j>>>0)%(c>>>0)<<2)+b|0;a=a-f|0;w[e>>2]=a^w[e>>2];w[i>>2]=a;d=d+1|0;if((g|0)!=(d|0)){continue}break}}}function mz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0;a:{b:{c:{h=w[a+12>>2];j=w[a+8>>2];d:{if((h|0)<=1&j>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&j>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&j>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&j>>>0>2147483648|h>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}b=w[a+48>>2];k=w[a>>2];i=w[a+4>>2];e=w[a+44>>2];e:{if(!d){g=b;break e}n=w[a+16>>2];o=w[a+24>>2];p=w[a+20>>2];q=w[a+72>>2];g=w[a+68>>2];r=g;s=g>>31;g=w[a+64>>2];t=g;u=g>>31;g=w[a+60>>2];x=g;y=g>>31;while(1){f=w[c>>2];g=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,u,e,e>>31);l=nb;z=f;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;f=BV(r,s,b,b>>31);e=f+e|0;b=nb+l|0;b=e>>>0<f>>>0?b+1|0:b;A=e;e=(i<<1)+n|0;f=(k>>>16&65520)+m|0;f=(((((((C(v[e-4>>1],v[f+2>>1])+C(v[e-6>>1],v[f>>1])|0)+C(v[e-2>>1],v[f+4>>1])|0)+C(v[e>>1],v[f+6>>1])|0)+C(v[e+2>>1],v[f+8>>1])|0)+C(v[e+4>>1],v[f+10>>1])|0)+C(v[e+6>>1],v[f+12>>1])|0)+C(v[e+8>>1],v[f+14>>1])|0)/32768<<8;e=f;l=BV(e,e>>31,x,y);e=A+l|0;b=nb+b|0;b=e>>>0<l>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=z+C(e,p);w[c+4>>2]=w[c+4>>2]+C(e,o);e=b-(f&q)|0;i=h+i|0;b=j+k|0;i=b>>>0<j>>>0?i+1|0:i;k=b;c=c+8|0;b=g;d=d-1|0;if(d){continue}break}}w[a+48>>2]=g;w[a+44>>2]=e;w[a>>2]=k;w[a+4>>2]=i}function Dv(a){var b=D(0),c=0,d=0,e=D(0),f=0,g=0,h=0,i=D(0),k=D(0),l=0,m=D(0);c=w[w[a+16>>2]+24620>>2];b=D(D(A[a+4212>>2]*D(29))+D(2));a:{if(b<D(4294967296)&b>=D(0)){d=~~b>>>0;break a}d=0}u[a+4272|0]=d;b=D(c>>>0);e=D(ai(D(D(G(D(D(D(A[a+4216>>2]*D(7900))+D(100))/b),D(.5)))*D(6.2831854820251465)))*D(.4000000059604645));A[a+4240>>2]=L(D(D(.3999999761581421)-e));A[a+4236>>2]=L(D(e+D(.6000000238418579)));c=2;b:{if(d>>>0<4){break b}c=3;if(d>>>0<8){break b}c=d>>>0<16?4:5}u[a+4273|0]=c;e=ai(D(D(G(D(D(D(A[a+4220>>2]*D(7900))+D(100))/b),D(.5)))*D(6.2831854820251465)));i=A[a+4224>>2];k=A[a+4208>>2];A[a+4264>>2]=-e;h=jb-16|0;jb=h;b=D(D(G(D(D(D(i*D(7900))+D(100))/b),D(.5)))*D(3.1415927410125732));f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Qg(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=Qg(((f|0)<0?1.5707963267948966:-1.5707963267948966)+g,1);break c}b=Qg(((f|0)<0?3.141592653589793:-3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=Qg(((f|0)<0?4.71238898038469:-4.71238898038469)+g,1);break c}b=Qg(((f|0)<0?6.283185307179586:-6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=D(b-b);break c}c=Fm(b,h+8|0);b=Qg(B[h+8>>3],c&1)}jb=h+16|0;b=D(D(D(1)-b)/D(b+D(1)));A[a+4268>>2]=b;l=a,m=D(D(D(A[(d<<2)+35968>>2]*jd(D(D(k*D(9.965784072875977))+D(-9.965784072875977))))*D(L(D(D(1)-D(b*b)))))*D(L(D(D(1)-D(e*e))))),A[l+4260>>2]=m}function TN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-48|0;jb=c;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;T(918,a|0,13);b=w[114256];w[114256]=0;a:{if((b|0)!=1){j=a+8|0;b:{c:{while(1){w[114256]=0;f=Q(5,c+8|0,w[(i<<3)+82096>>2])|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[a+4>>2];d=w[a+8>>2];d:{if(b>>>0<d>>>0){d=w[f+4>>2];w[b>>2]=w[f>>2];w[b+4>>2]=d;w[b+8>>2]=w[f+8>>2];w[a+4>>2]=b+12;break d}e=w[a>>2];g=(b-e|0)/12|0;b=g+1|0;if(b>>>0>=357913942){w[114256]=0;X(920,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}M()}w[114256]=0;d=(d-e|0)/12|0;e=d<<1;g=Z(921,c+24|0,(d>>>0>=178956970?357913941:b>>>0<e>>>0?e:b)|0,g|0,j|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}d=w[f+4>>2];b=w[c+32>>2];w[b>>2]=w[f>>2];w[b+4>>2]=d;w[b+8>>2]=w[f+8>>2];w[f>>2]=0;w[f+4>>2]=0;w[f+8>>2]=0;h=w[c+32>>2]+12|0;w[c+32>>2]=h;e=w[c+28>>2];b=w[a+4>>2];d=w[a>>2];e:{if((b|0)==(d|0)){b=d;break e}while(1){b=b-12|0;h=w[b+4>>2];e=e-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=h;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[c+28>>2]-12|0;w[c+28>>2]=e;if((b|0)!=(d|0)){continue}break}d=w[a+4>>2];h=w[c+32>>2];b=w[a>>2]}w[a>>2]=e;w[c+28>>2]=b;w[a+4>>2]=h;w[c+32>>2]=d;d=w[a+8>>2];w[a+8>>2]=w[c+36>>2];w[c+36>>2]=d;w[g>>2]=b;sc(g);if(u[c+19|0]>=0){break d}zb(w[f>>2])}i=i+1|0;if((i|0)!=13){continue}break}jb=c+48|0;return}b=P()|0;break a}b=P()|0;if(u[c+19|0]>=0){break a}zb(w[f>>2]);break a}b=P()|0}bc(a);R(b|0);M()}function nz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0;a:{b:{c:{h=w[a+12>>2];j=w[a+8>>2];d:{if((h|0)<=1&j>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&j>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&j>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&j>>>0>2147483648|h>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}b=w[a+48>>2];k=w[a>>2];i=w[a+4>>2];e=w[a+44>>2];e:{if(!d){g=b;break e}n=w[a+16>>2];o=w[a+24>>2];p=w[a+20>>2];q=w[a+72>>2];g=w[a+68>>2];r=g;s=g>>31;g=w[a+64>>2];t=g;x=g>>31;g=w[a+60>>2];y=g;z=g>>31;while(1){f=w[c>>2];g=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,x,e,e>>31);l=nb;A=f;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;f=BV(r,s,b,b>>31);e=f+e|0;b=nb+l|0;b=e>>>0<f>>>0?b+1|0:b;B=e;e=i+n|0;f=(k>>>16&65520)+m|0;f=(((((((C(u[e-2|0],v[f+2>>1])+C(u[e-3|0],v[f>>1])|0)+C(u[e-1|0],v[f+4>>1])|0)+C(u[e|0],v[f+6>>1])|0)+C(u[e+1|0],v[f+8>>1])|0)+C(u[e+2|0],v[f+10>>1])|0)+C(u[e+3|0],v[f+12>>1])|0)+C(u[e+4|0],v[f+14>>1])<<8)/32768<<8;e=f;l=BV(e,e>>31,y,z);e=B+l|0;b=nb+b|0;b=e>>>0<l>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=A+C(e,p);w[c+4>>2]=w[c+4>>2]+C(e,o);e=b-(f&q)|0;i=h+i|0;b=j+k|0;i=b>>>0<j>>>0?i+1|0:i;k=b;c=c+8|0;b=g;d=d-1|0;if(d){continue}break}}w[a+48>>2]=g;w[a+44>>2]=e;w[a>>2]=k;w[a+4>>2]=i}function tB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-48|0;jb=f;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;j=a+8|0;k=f+8|0;a:{b:{c:{d:{e:{f:{while(1){e=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;e=S(h|0,g|0,e|0,8)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}if(e){w[114256]=0;U(548,f|0,b|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break f}e=w[a+4>>2];g=w[a+8>>2];g:{if(e>>>0<g>>>0){g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];w[e+12>>2]=w[f+12>>2];g=w[f+20>>2];w[e+16>>2]=w[f+16>>2];w[e+20>>2]=g;w[a+4>>2]=e+24;break g}h=w[a>>2];i=(e-h|0)/24|0;e=i+1|0;if(e>>>0>=178956971){w[114256]=0;X(549,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}M()}w[114256]=0;g=(g-h|0)/24|0;h=g<<1;g=Z(550,f+24|0,(g>>>0>=89478485?178956970:e>>>0<h>>>0?h:e)|0,i|0,j|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}h=w[f+4>>2];e=w[f+32>>2];w[e>>2]=w[f>>2];w[e+4>>2]=h;w[e+8>>2]=w[f+8>>2];w[e+12>>2]=w[f+12>>2];w[f+8>>2]=0;w[f+12>>2]=0;h=w[f+20>>2];w[e+16>>2]=w[f+16>>2];w[e+20>>2]=h;w[114256]=0;w[f+32>>2]=w[f+32>>2]+24;T(551,a|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){b=P()|0;pd(g);break c}pd(g);e=w[f+12>>2];if(!e){break g}g=w[e+4>>2];w[e+4>>2]=g-1;if(g){break g}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[a+4>>2]-24|0;if((x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24))!=(d|0)){continue}}break}jb=f+48|0;return}b=P()|0;break a}b=P()|0;break c}b=P()|0}Bb(k);break a}b=P()|0}Ac(a);R(b|0);M()}function dV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-48|0;jb=f;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;j=a+8|0;k=f+8|0;a:{b:{c:{d:{e:{f:{while(1){e=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;e=S(h|0,g|0,e|0,8)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}if(e){w[114256]=0;U(937,f|0,b|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break f}e=w[a+4>>2];g=w[a+8>>2];g:{if(e>>>0<g>>>0){g=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=g;w[e+8>>2]=w[f+8>>2];w[e+12>>2]=w[f+12>>2];g=w[f+20>>2];w[e+16>>2]=w[f+16>>2];w[e+20>>2]=g;w[a+4>>2]=e+24;break g}h=w[a>>2];i=(e-h|0)/24|0;e=i+1|0;if(e>>>0>=178956971){w[114256]=0;X(938,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}M()}w[114256]=0;g=(g-h|0)/24|0;h=g<<1;g=Z(939,f+24|0,(g>>>0>=89478485?178956970:e>>>0<h>>>0?h:e)|0,i|0,j|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break e}h=w[f+4>>2];e=w[f+32>>2];w[e>>2]=w[f>>2];w[e+4>>2]=h;w[e+8>>2]=w[f+8>>2];w[e+12>>2]=w[f+12>>2];w[f+8>>2]=0;w[f+12>>2]=0;h=w[f+20>>2];w[e+16>>2]=w[f+16>>2];w[e+20>>2]=h;w[114256]=0;w[f+32>>2]=w[f+32>>2]+24;T(940,a|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){b=P()|0;pd(g);break c}pd(g);e=w[f+12>>2];if(!e){break g}g=w[e+4>>2];w[e+4>>2]=g-1;if(g){break g}ob[w[w[e>>2]+8>>2]](e);Ib(e)}e=w[a+4>>2]-24|0;if((x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24))!=(d|0)){continue}}break}jb=f+48|0;return}b=P()|0;break a}b=P()|0;break c}b=P()|0}Bb(k);break a}b=P()|0}Ac(a);R(b|0);M()}function PD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb+-64|0;jb=h;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}b:{f=w[a>>2];if(ob[w[w[f>>2]+36>>2]](f,w[a+8>>2],1)|0){e=w[a+8>>2];c:{d:{e:{f:{g:{h:{while(1){d=w[a>>2];f=w[w[d>>2]+28>>2];w[114256]=0;d=Z(f|0,d|0,h|0,e|0,64)|0;f=w[114256];w[114256]=0;if((f|0)==1){break e}f=x[b+11|0];e=f<<24>>24<0;g=e?w[b+4>>2]:f;f=c-g|0;d=d>>>0>f>>>0?f:d;if(!d){break c}f=d+h|0;d=h;i:{while(1){if(!x[d|0]){break i}d=d+1|0;if((f|0)!=(d|0)){continue}break}d=f}i=w[b>>2];w[114256]=0;Z(337,b|0,g+(e?i:b)|0,h|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}e=w[a+8>>2];g=w[a>>2];i=w[w[g>>2]+36>>2];w[114256]=0;j=e;e=d-h|0;g=S(i|0,g|0,j|0,e|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break g}j:{if(g){e=e+w[a+8>>2]|0;break j}e=w[a>>2];g=w[w[e>>2]+24>>2];w[114256]=0;e=V(g|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break g}}w[a+8>>2]=e;if(d>>>0>=f>>>0){continue}break}c=w[a>>2];d=w[w[c>>2]+36>>2];w[114256]=0;c=S(d|0,c|0,e|0,1)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}k:{if(c){d=w[a+8>>2]+1|0;break k}c=w[a>>2];d=w[w[c>>2]+24>>2];w[114256]=0;d=V(d|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}}w[a+8>>2]=d;break c}a=W(74720)|0;break d}a=W(74720)|0;break d}a=W(74720)|0;break d}a=W(74720)|0}if((kb|0)!=(fa(74720)|0)){break b}$(a|0)|0;aa()}a=x[b+11|0];d=((a<<24>>24<0?w[b+4>>2]:a)|0)!=0}jb=h- -64|0;return d|0}R(a|0);M()}function HT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if(!x[a+4242|0]){w[a+32>>2]=0;w[a+28>>2]=w[a+28>>2]&-7|2;a:{if(!x[a+4240|0]){break a}e=Cn(w[a+16>>2]);if(e==B[a+4288>>3]){break a}B[a+4288>>3]=e;f=B[a+4248>>3]/+z[w[a+16>>2]+24620>>2];B[a+4264>>3]=f;if(!x[a+4240|0]){break a}B[a+4264>>3]=e*.016666666666666666*f}e=B[a+4256>>3];b:{c:{if(x[a+4244|0]){f=1;if(e>1){break c}break b}g=(w[a+4232>>2]&-2)!=4;if(E(e)<2147483648){h=~~e}else{h=-2147483648}if(!(g|(h|0)<=0)){Wj(a);e=B[a+4256>>3]}f=e-+(h|0)}e=f;B[a+4256>>3]=e}f=0;d:{e:{switch(w[a+4232>>2]){case 0:f=ee(e*6.283185307179586);break d;case 1:f=E(e+-.5)*-4+1;break d;case 2:f=e+e+-1;break d;case 3:f=e<.5?-1:1;break d;case 4:f=B[a+4272>>3];break d;case 5:break e;default:break d}}f=B[a+4272>>3];f=e*e*e*(B[a+4280>>3]-f)*((e*6+-15)*e+10)+f}e=(x[a+4241|0]?-f:f)*+A[a+4220>>2]+ +A[a+4224>>2];f:{if(!(e<0)){i=1;if(e<=1){break f}}e=i}h=w[w[a+20>>2]+28>>2];h=h>>>0<=127?-1:h^-128;g=h&255;g:{if(g>>>0<=x[a+4200|0]|g>>>0>249){break g}h=w[(w[a+16>>2]+C(h&255,160)|0)+906300>>2];if(!h){break g}g=w[a+4236>>2];if(x[a+4243|0]){j=(g>>>8&15|(g&127)<<8|176)&65471;e=Tb(e*127);g=255;h:{if(e>=255){break h}g=0;if(e<=0){break h}g=~~e>>>0;if(e<4294967296&e>=0){break h}g=0}ob[w[w[h>>2]+68>>2]](h,j|g<<16)|0;break g}if((g|0)<0){break g}ob[w[w[h>>2]+44>>2]](h,g,D(e))}B[a+4256>>3]=B[a+4256>>3]+B[a+4264>>3]*+(d>>>0)}h=a;a=w[a+44>>2];ye(h,b,c,a,a+2048|0,d)}function Rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;p=w[a+16>>2];g=jb-32|0;f=w[a+44>>2];w[g+12>>2]=f;e=w[a+48>>2];w[g+16>>2]=e;b=w[a+52>>2];w[g+20>>2]=b;h=w[a+56>>2];w[g+24>>2]=h;l=w[a>>2];j=w[a+4>>2];if(d){o=w[a+8>>2];q=w[a+12>>2];r=w[a+24>>2];s=w[a+20>>2];t=w[a+72>>2];b=w[a+68>>2];u=b;x=b>>31;b=w[a+64>>2];y=b;z=b>>31;b=w[a+60>>2];A=b;B=b>>31;while(1){m=l>>>18|0;b=1;i=((((j&2147483647)<<1|l>>>31)&2147483646)<<1)+p|0;f=0;h=1;e=0;while(1){n=e<<1;k=v[n+i>>1];w[(e<<2)+g>>2]=k+((C(v[i+(n|4)>>1]-k|0,m)|0)/16384|0);k=h&1;h=0;e=1;if(k){continue}break}while(1){e=(g+8|0)+(f<<3)|0;h=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;k=(f<<2)+g|0;m=w[k>>2]<<8;f=m;f=BV(A,B,f,f>>31);n=nb;D=e;e=(i|0)>=16776704?16776704:i;e=(e|0)<=-16777216?-16777216:e;i=BV(e,e>>31,y,z);f=i+f|0;e=nb+n|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,u,x);f=i+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[D+4>>2]=e-(m&t);w[k>>2]=(e|0)/256;f=1;e=b;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],s);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],r);j=j+q|0;b=l+o|0;j=b>>>0<o>>>0?j+1|0:j;l=b;c=c+8|0;d=d-1|0;if(d){continue}break}h=w[g+24>>2];e=w[g+16>>2];f=w[g+12>>2];b=w[g+20>>2]}w[a+56>>2]=h;w[a+52>>2]=b;w[a+48>>2]=e;w[a+44>>2]=f;w[a>>2]=l;w[a+4>>2]=j}function Sz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0;p=w[a+16>>2];g=jb-32|0;e=w[a+44>>2];w[g+12>>2]=e;f=w[a+48>>2];w[g+16>>2]=f;b=w[a+52>>2];w[g+20>>2]=b;h=w[a+56>>2];w[g+24>>2]=h;l=w[a>>2];j=w[a+4>>2];if(d){o=w[a+8>>2];q=w[a+12>>2];r=w[a+24>>2];s=w[a+20>>2];t=w[a+72>>2];b=w[a+68>>2];v=b;x=b>>31;b=w[a+64>>2];y=b;z=b>>31;b=w[a+60>>2];A=b;B=b>>31;while(1){m=l>>>10&4194048;i=(((j&2147483647)<<1|l>>>31)&-2)+p|0;f=0;b=1;h=1;e=0;while(1){k=(e<<2)+g|0;n=u[i+(e|2)|0];e=u[e+i|0];w[k>>2]=((C(n-e|0,m)|0)/16384|0)+(e<<8);k=h&1;h=0;e=1;if(k){continue}break}while(1){e=(g+8|0)+(f<<3)|0;h=w[e+8>>2];i=w[e+4>>2];w[e+8>>2]=i;m=(f<<2)+g|0;k=w[m>>2]<<8;f=k;f=BV(A,B,f,f>>31);D=nb;n=e;e=(i|0)>=16776704?16776704:i;e=(e|0)<=-16777216?-16777216:e;i=BV(e,e>>31,y,z);f=i+f|0;e=nb+D|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=(h|0)>=16776704?16776704:h;f=(f|0)<=-16777216?-16777216:f;h=BV(f,f>>31,v,x);f=i+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[n+4>>2]=e-(k&t);w[m>>2]=(e|0)/256;f=1;e=b;b=0;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],s);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],r);j=j+q|0;b=l+o|0;j=b>>>0<o>>>0?j+1|0:j;l=b;c=c+8|0;d=d-1|0;if(d){continue}break}h=w[g+24>>2];f=w[g+16>>2];e=w[g+12>>2];b=w[g+20>>2]}w[a+56>>2]=h;w[a+52>>2]=b;w[a+48>>2]=f;w[a+44>>2]=e;w[a>>2]=l;w[a+4>>2]=j}function Ve(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if(!b){b=x[c+11|0];f=b<<24>>24<0;d=f?w[c+4>>2]:b;if(d>>>0>=4294967280){break d}g=w[c>>2];e:{f:{if(d>>>0>=11){h=(d|15)+1|0;b=Kb(h);w[a+8>>2]=h|-2147483648;w[a>>2]=b;w[a+4>>2]=d;a=b;break f}u[a+11|0]=d;if(!d){break e}}c=f?g:c;b=d+c|0;while(1){u[a|0]=x[c|0];a=a+1|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}}u[a|0]=0;break a}w[e+8>>2]=0;w[e>>2]=0;w[e+4>>2]=0;g=x[c+11|0];f=g<<24>>24<0;g:{h=f?w[c+4>>2]:g;if(!h){break g}g=f?w[c>>2]:c;i=h+g|0;f=0;while(1){c=x[g|0];h:{i:{if(!d){if(c<<24>>24>=0){d=0;w[114256]=0;T(69,e|0,c|0);c=w[114256];w[114256]=0;if((c|0)!=1){break h}break c}if((c&224)==192){f=c&31;d=1;break h}if((c&240)==224){f=c&15;d=2;break h}h=65533;if((c&248)!=240){break i}f=c&7;d=3;break h}if((c&192)!=128){w[114256]=0;T(69,e|0,65533);d=w[114256];w[114256]=0;if((d|0)==1){break c}f=c&63;d=-1;break h}h=c&63|f<<6;f=h;d=d-1|0;if(d){break h}}f=0;w[114256]=0;T(69,e|0,h|0);c=w[114256];w[114256]=0;d=0;if((c|0)==1){break c}}g=g+1|0;if((i|0)!=(g|0)){continue}break}if(!d){break g}w[114256]=0;T(69,e|0,65533);c=w[114256];w[114256]=0;if((c|0)!=1){break g}break c}w[114256]=0;U(73,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}c=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}zc(a);M()}c=P()|0;if(u[e+11|0]>=0){break b}zb(w[e>>2])}R(c|0);M()}jb=e+16|0}function EJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=nm(g);g=Rl(g);Ad(k,g);a:{b:{if(Id(k)){w[114256]=0;Z(1749,l|0,a|0,c|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;w[f>>2]=g;break a}w[f>>2]=d;c:{d:{j=a;h=x[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}w[114256]=0;j=Q(1761,l|0,h<<24>>24)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}h=w[f>>2];w[f>>2]=h+4;w[h>>2]=j;j=a+1|0}if(!(x[j|0]!=48|(c-j|0)<2|(x[j+1|0]|32)!=120)){w[114256]=0;h=Q(1761,l|0,48)|0;i=w[114256];w[114256]=0;if((i|0)==1){break b}i=w[f>>2];w[f>>2]=i+4;w[i>>2]=h;h=u[j+1|0];w[114256]=0;h=Q(1761,l|0,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break b}i=w[f>>2];w[f>>2]=i+4;w[i>>2]=h;j=j+2|0}i=0;w[114256]=0;ef(j,c);h=w[114256];w[114256]=0;if((h|0)==1){break b}w[114256]=0;o=V(1746,g|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=w[f>>2];w[114256]=0;Nh((j-a<<2)+d|0,g);g=w[114256];w[114256]=0;if((g|0)==1){break e}g=w[f>>2];break a}f:{if(!x[Rb(k,h)|0]){break f}if(u[Rb(k,h)|0]!=(i|0)){break f}i=w[f>>2];w[f>>2]=i+4;w[i>>2]=o;h=(Db(k)-1>>>0>h>>>0)+h|0;i=0}n=u[g|0];w[114256]=0;n=Q(1761,l|0,n|0)|0;m=w[114256];w[114256]=0;if((m|0)!=1){m=w[f>>2];w[f>>2]=m+4;w[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;Gb(k);R(a|0);M()}w[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;Gb(k);jb=k+16|0}function sH(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))==1397771593){lc(b,32);c=d+8|0;Vb(c,1,a+4|0,13);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=b+43;Q(200,d+24|0,c|0)|0;c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}c=x[a+19|0]<<2;v[b+30>>1]=c>>>0>=256?256:c;c=x[a+17|0];v[b+32>>1]=c>>>0>=64?64:c;c=(x[a+47|0]&127)<<2;v[b+28>>1]=c>>>0>=256?256:c;if(u[a+47|0]<0){v[b+34>>1]=y[b+34>>1]|32}c=x[a+18|0];if(c&16){v[b+34>>1]=y[b+34>>1]|2;c=x[a+18|0]}if(c&32){v[b+34>>1]=y[b+34>>1]|8;c=x[a+18|0]}if(c&64){v[b+34>>1]=y[b+34>>1]|4;c=x[a+18|0]}if(c<<24>>24<0){v[b+34>>1]=y[b+34>>1]|16}c=x[a+60|0]|x[a+61|0]<<8|(x[a+62|0]<<16|x[a+63|0]<<24);w[b+24>>2]=c?c>>>0<=256?256:c:8363;w[b>>2]=x[a+48|0]|x[a+49|0]<<8|(x[a+50|0]<<16|x[a+51|0]<<24);w[b+4>>2]=x[a+52|0]|x[a+53|0]<<8|(x[a+54|0]<<16|x[a+55|0]<<24);w[b+8>>2]=x[a+56|0]|x[a+57|0]<<8|(x[a+58|0]<<16|x[a+59|0]<<24);w[b+12>>2]=x[a+64|0]|x[a+65|0]<<8|(x[a+66|0]<<16|x[a+67|0]<<24);w[b+16>>2]=x[a+68|0]|x[a+69|0]<<8|(x[a+70|0]<<16|x[a+71|0]<<24);tg(b);u[b+38|0]=x[(x[a+79|0]&7)+32816|0];u[b+41|0]=x[a+76|0];u[b+40|0]=x[a+77|0]&127;u[b+39|0]=x[a+78|0];c=x[a+46|0];if((c|0)!=64){break c}c=512;break b}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}if((c|0)!=128){break a}c=16384}v[b+34>>1]=c|y[b+34>>1]}c=x[a+72|0]|x[a+73|0]<<8|(x[a+74|0]<<16|x[a+75|0]<<24)}jb=d+32|0;return c|0}function PJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=rm(g);g=Wl(g);Ad(k,g);a:{b:{if(Id(k)){w[114256]=0;Z(1728,l|0,a|0,c|0,d|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;w[f>>2]=g;break a}w[f>>2]=d;c:{d:{j=a;h=x[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}w[114256]=0;j=Q(1578,l|0,h<<24>>24)|0;h=w[114256];w[114256]=0;if((h|0)==1){break b}h=w[f>>2];w[f>>2]=h+1;u[h|0]=j;j=a+1|0}if(!(x[j|0]!=48|(c-j|0)<2|(x[j+1|0]|32)!=120)){w[114256]=0;h=Q(1578,l|0,48)|0;i=w[114256];w[114256]=0;if((i|0)==1){break b}i=w[f>>2];w[f>>2]=i+1;u[i|0]=h;h=u[j+1|0];w[114256]=0;h=Q(1578,l|0,h|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break b}i=w[f>>2];w[f>>2]=i+1;u[i|0]=h;j=j+2|0}i=0;w[114256]=0;ef(j,c);h=w[114256];w[114256]=0;if((h|0)==1){break b}w[114256]=0;o=V(1719,g|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=w[f>>2];w[114256]=0;ef((j-a|0)+d|0,g);g=w[114256];w[114256]=0;if((g|0)==1){break e}g=w[f>>2];break a}f:{if(!x[Rb(k,h)|0]){break f}if(u[Rb(k,h)|0]!=(i|0)){break f}i=w[f>>2];w[f>>2]=i+1;u[i|0]=o;h=(Db(k)-1>>>0>h>>>0)+h|0;i=0}n=u[g|0];w[114256]=0;n=Q(1578,l|0,n|0)|0;m=w[114256];w[114256]=0;if((m|0)!=1){m=w[f>>2];w[f>>2]=m+1;u[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;Gb(k);R(a|0);M()}w[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;Gb(k);jb=k+16|0}function mn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{switch(c-1|0){default:h=b+724|0;break a;case 0:h=b+736|0;break a;case 1:break b}}h=b+748|0}d=w[b+656>>2];c:{if(!d){break c}k=x[h|0];if(!(k&1)){break c}d:{e:{switch(c-1|0){default:d=d+48|0;break d;case 0:d=d+68|0;break d;case 1:break e}}d=d+88|0}i=w[d+4>>2];e=w[d>>2];if((i|0)==(e|0)){break c}j=w[a+1074312>>2];f=w[h+4>>2]+((j^-1)>>>31|0)|0;g=x[d+12|0];f:{g:{if((j|0)>=0){h:{if(!(g&2)){g=g&4;break h}l=x[d+14|0];g=g&4;if((f|0)!=(y[e+(l<<2)>>1]+!(w[a+480180>>2]&1048580)|0)|(!(x[b+89|0]&8)|(!g|x[d+16|0]!=(l|0))?m:(x[a+1074320|0]&64)>>>6|0)){break h}f=y[e+(x[d+13|0]<<2)>>1]}if(!(!g|x[b+89|0]&8)){if((y[e+(x[d+16|0]<<2)>>1]+1|0)!=(f|0)){break f}f=y[e+(x[d+15|0]<<2)>>1];if(!(w[a+1074320>>2]&536870912)|(c|0)!=1){break f}u[h|0]=k&254;break f}e=1;d=y[i-4>>1];if(f>>>0>d>>>0){break g}break f}i:{if(!(!(x[a+1074324|0]&2)&w[h+8>>2]!=-1|(!(g&4)|x[b+669|0]&8))){g=y[e+(x[d+16|0]<<2)>>1]+1|0;d=y[e+(x[d+15|0]<<2)>>1];e=0;break i}if(g&2){g=y[e+(x[d+14|0]<<2)>>1]+1|0;d=y[e+(x[d+13|0]<<2)>>1];e=0;break i}d=y[i-4>>1];e=f>>>0>d>>>0;g=d}d=f>>>0<g>>>0?f:d}j:{if(!e|c){break j}f=w[a+480180>>2];c=w[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;w[b+88>>2]=c}if(x[i-2|0]|!(y[b+808>>1]|w[a+480180>>2]&16777248)){break j}w[b+696>>2]=0;w[b+720>>2]=0;w[b+680>>2]=0;w[b+88>>2]=c|4096}f=d}w[h+4>>2]=(j>>>31|0)+f}}function wp(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;n=jb-16|0;jb=n;i=w[b>>2];while(1){o=y[i+(h<<1)>>1];p=o+1|0;l=(j&65535)>>>0>o>>>0|o>>>0>127;k=l?k:c>>>0>h>>>0?p:k;m=(m&65535)>>>0>o>>>0?m:p;j=l?j:p;h=h+1|0;if((h|0)!=128){continue}break}v[n+14>>1]=65535;$d(b,c,n+14|0);i=w[a+8>>2];l=i+d|0;h=y[e>>1];a:{b:{c:{if(!f){break c}d=j&65535;c=w[a>>2];if((i+((d<<11)+f|0)|0)!=(ob[w[w[c>>2]+24>>2]](c)&-2)){break c}d=i+(d<<10)|0;d:{if(d>>>0>z[a+8>>2]){c=w[a>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<d>>>0){break d}}w[a+8>>2]=d}if(Pk(a,16,1)){v[e>>1]=8}if(i>>>0<=z[a+8>>2]){break b}c=w[a>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0>=i>>>0){break b}break a}if((j&65535)==(k&65535)){j=k;break a}d=k<<8&16776960;if(!g){c=w[a>>2];if((ob[w[w[c>>2]+24>>2]](c)|0)!=(l+C(d,h)|0)){break a}}d=i+C(d,y[e>>1])|0;e:{if(d>>>0>z[a+8>>2]){c=w[a>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<d>>>0){break e}}w[a+8>>2]=d}j=Pk(a,64,1)?j:k;if(i>>>0<=z[a+8>>2]){break b}c=w[a>>2];if(ob[w[w[c>>2]+24>>2]](c)>>>0<i>>>0){break a}}w[a+8>>2]=i}c=m&65535;f:{if(c>>>0>(j&65535)>>>0){a=w[a>>2];if((l+(C(c,y[e>>1])<<8)|0)==(ob[w[w[a>>2]+24>>2]](a)|0)){break f}}g:{if(c>>>0<255){break g}h=w[b>>2];b=w[b+4>>2];if((h|0)==(b|0)){break g}a=h;while(1){if(y[a>>1]==254){v[a>>1]=65534}a=a+2|0;if((b|0)!=(a|0)){continue}break}while(1){if(y[h>>1]==255){v[h>>1]=65535}h=h+2|0;if((b|0)!=(h|0)){continue}break}}m=j}jb=n+16|0;return m&65535}function tU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-32|0;jb=c;w[c+24>>2]=0;w[114256]=0;w[c+16>>2]=0;w[c+20>>2]=0;u[c+31|0]=0;w[c+4>>2]=c+32;w[c>>2]=c+31;kc(a,c);e=w[114256];w[114256]=0;if((e|0)!=1){a:{g=x[c+31|0];k=(g&252)>>>2|0;b:{e=g&3;if(e){e=-1<<e;h=(e>>>0>=4294967294?-2:e)^-1;i=c+32|0;while(1){w[114256]=0;u[c+31|0]=0;w[c+4>>2]=i;w[c>>2]=c+31;kc(a,c);e=w[114256];w[114256]=0;if((e|0)==1){break b}g=x[c+31|0];e=f;f=j+1|0;e=f?e:e+1|0;j=f;f=e;e=(j<<3)-2|0;l=e&31;if((e&63)>>>0>=32){e=g<<l;g=0}else{e=(1<<l)-1&g>>>32-l;g=g<<l}k=g|k;m=e|m;if((h|0)!=(j|0)|f){continue}break}}w[114256]=0;u[c+27|0]=0;u[c+16|0]=0;i=!m&k>>>0>=255|m?255:k;U(969,c+16|0,i|0,0);f=w[114256];w[114256]=0;if((f|0)==1){break a}if(i){j=c+32|0;h=0;while(1){w[114256]=0;g=w[c+16>>2];e=u[c+27|0];u[c+31|0]=0;w[c+4>>2]=j;w[c>>2]=c+31;kc(a,c);f=w[114256];w[114256]=0;if((f|0)==1){break a}u[((e|0)<0?g:c+16|0)+h|0]=x[c+31|0];h=h+1|0;if((i|0)!=(h|0)){continue}break}}if((Qq(c+16|0)|0)!=-1){f=c+16|0;a=Qq(f);w[114256]=0;U(969,f|0,a|0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}}w[114256]=0;U(6,c|0,d|0,c+16|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}if(u[b+11|0]<0){zb(w[b>>2])}a=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=a;w[b+8>>2]=w[c+8>>2];if(u[c+27|0]<0){zb(w[c+16>>2])}jb=c+32|0;return}}}a=P()|0;if(u[c+27|0]<0){zb(w[c+16>>2])}R(a|0);M()}function GN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;i=w[a+4>>2];e=d+16|0;a=b-1|0;if(a>>>0>4){a=5613}else{a=w[(a<<2)+82604>>2]}f=Hb(e,a);w[114256]=0;a=Q(1,d|0,13499)|0;b=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((b|0)!=1){e=w[a>>2];g=w[a+4>>2];b=x[a+11|0];w[114256]=0;h=e;e=b<<24>>24<0;b=S(2,f|0,(e?h:a)|0,(e?g:b)|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}w[d+40>>2]=w[b+8>>2];e=w[b+4>>2];w[d+32>>2]=w[b>>2];w[d+36>>2]=e;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[c>>2];g=w[c+4>>2];b=x[c+11|0];w[114256]=0;h=c;c=b<<24>>24<0;b=S(2,d+32|0,(c?e:h)|0,(c?g:b)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break g}w[d+56>>2]=w[b+8>>2];c=w[b+4>>2];w[d+48>>2]=w[b>>2];w[d+52>>2]=c;w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[114256]=0;U(9,d- -64|0,0,d+48|0);b=w[114256];w[114256]=0;if((b|0)==1){break f}b=w[w[i>>2]+8>>2];w[114256]=0;T(b|0,i|0,d- -64|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}if(u[d+75|0]<0){zb(w[d+64>>2])}if(u[d+59|0]<0){zb(w[d+48>>2])}if(u[d+43|0]<0){zb(w[d+32>>2])}if(u[a+11|0]<0){zb(w[a>>2])}if(u[f+11|0]<0){zb(w[f>>2])}jb=d+80|0;return}c=P()|0;break a}c=P()|0;break b}c=P()|0;break c}c=P()|0;break d}c=P()|0;if(u[d+75|0]>=0){break d}zb(w[d+64>>2])}if(u[d+59|0]>=0){break c}zb(w[d+48>>2])}if(u[d+43|0]>=0){break b}zb(w[d+32>>2])}if(u[a+11|0]>=0){break a}zb(w[a>>2])}if(u[f+11|0]<0){zb(w[f>>2])}R(c|0);M()}function qr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=jb-16|0;jb=a;w[a+12>>2]=c;w[a+8>>2]=f;w[a+12>>2]=c;w[a+8>>2]=f;a:{b:{c:{while(1){d:{c=w[a+12>>2];if(c>>>0>=d>>>0){break d}j=w[a+8>>2];if(j>>>0>=g>>>0){break d}b=2;f=x[c|0];e:{if(f<<24>>24>=0){v[j>>1]=f;b=c+1|0;break e}if(f>>>0<194){break b}if(f>>>0<=223){if((d-c|0)<2){break c}i=x[c+1|0];if((i&192)!=128){break a}v[j>>1]=i&63|f<<6&1984;b=c+2|0;break e}if(f>>>0<=239){if((d-c|0)<3){break c}k=x[c+2|0];i=x[c+1|0];f:{g:{if((f|0)!=237){if((f|0)!=224){break g}if((i&224)==160){break f}break a}if((i&224)==128){break f}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}v[j>>1]=k&63|((i&63)<<6|f<<12);b=c+3|0;break e}if(f>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=x[c+3|0];i=x[c+2|0];c=x[c+1|0];h:{i:{switch(f-240|0){case 0:if((c+112&255)>>>0>=48){break b}break h;case 4:if((c&240)!=128){break b}break h;default:break i}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-j|0)<4){break a}b=2;k=k&63;l=i<<6;f=f&7;if((k|(l&4032|(c<<12&258048|f<<18)))>>>0>1114111){break a}b=c<<2;v[j>>1]=(i>>>4&3|(b&192|f<<8|b&60))+16320|55296;w[a+8>>2]=j+2;v[j+2>>1]=k|l&960|56320;b=w[a+12>>2]+4|0}w[a+12>>2]=b;w[a+8>>2]=w[a+8>>2]+2;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}w[e>>2]=w[a+12>>2];w[h>>2]=w[a+8>>2];jb=a+16|0;return b|0}function Uy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;l=w[a+48>>2];m=w[a>>2];g=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];e=w[a+44>>2];a:{if(!d){f=i>>12;h=j>>12;break a}o=b+24|0;n=w[a+8>>2];p=w[a+12>>2];q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];b=w[a+68>>2];u=b;x=b>>31;b=w[a+64>>2];y=b;z=b>>31;b=w[a+60>>2];A=b;B=b>>31;b=l;while(1){f=w[c>>2];l=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(y,z,e,e>>31);h=nb;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;k=BV(u,x,b,b>>31);e=k+e|0;b=nb+h|0;b=e>>>0<k>>>0?b+1|0:b;D=f;h=e;e=(g<<1)+q|0;f=(((m>>>16|0)+4&131064)<<1)+o|0;k=(((((C(v[e+4>>1],v[f+10>>1])+C(v[e+2>>1],v[f+8>>1])|0)+C(v[e+6>>1],v[f+12>>1])|0)+C(v[e+8>>1],v[f+14>>1])|0)/2|0)+((((C(v[e-4>>1],v[f+2>>1])+C(v[e-6>>1],v[f>>1])|0)+C(v[e-2>>1],v[f+4>>1])|0)+C(v[e>>1],v[f+6>>1])|0)/2|0)|0)/16384<<8;e=k;f=BV(e,e>>31,A,B);e=h+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;j=j+s|0;h=j>>12;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=D+C(h,e);i=i+r|0;f=i>>12;w[c+4>>2]=w[c+4>>2]+C(e,f);e=b-(k&t)|0;g=g+p|0;b=m+n|0;g=b>>>0<n>>>0?g+1|0:g;m=b;c=c+8|0;b=l;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=m;w[a+4>>2]=g;w[a+40>>2]=i;w[a+20>>2]=h;w[a+48>>2]=l;w[a+44>>2]=e;w[a+24>>2]=f}function rr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=jb-16|0;jb=a;w[a+12>>2]=c;w[a+8>>2]=f;w[a+12>>2]=c;w[a+8>>2]=f;c=w[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;c:{b=y[c>>1];d:{if(b>>>0<=127){f=1;c=w[a+8>>2];if((g-c|0)<=0){break a}w[a+8>>2]=c+1;u[c|0]=b;break d}if(b>>>0<=2047){c=w[a+8>>2];if((g-c|0)<2){break b}w[a+8>>2]=c+1;u[c|0]=b>>>6|192;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128;break d}if(b>>>0<=55295){c=w[a+8>>2];if((g-c|0)<3){break b}w[a+8>>2]=c+1;u[c|0]=b>>>12|224;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b>>>6&63|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=y[c+2>>1];if((i&64512)!=56320){break c}if((g-w[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))>>>0>1048575){break c}w[a+12>>2]=c+2;c=w[a+8>>2];w[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;u[j|0]=c>>>2|240;f=w[a+8>>2];w[a+8>>2]=f+1;u[f|0]=c<<4&48|b>>>2&15|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=i>>>6&15|b<<4&48|128;b=w[a+8>>2];w[a+8>>2]=b+1;u[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=w[a+8>>2];if((g-c|0)<3){break b}w[a+8>>2]=c+1;u[c|0]=b>>>12|224;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b>>>6&63|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128}c=w[a+12>>2]+2|0;w[a+12>>2]=c;continue}break}f=2;break a}f=1}w[e>>2]=w[a+12>>2];w[h>>2]=w[a+8>>2];jb=a+16|0;return f|0}function pD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;k=e+8|0;i=jb-160|0;jb=i;g=Od(i+8|0);f=w[w[g>>2]-12>>2];w[114256]=0;j=ea(79)|0;h=w[114256];w[114256]=0;a:{b:{c:{d:{if((h|0)==1){break d}w[114256]=0;f=g+f|0;T(10,i|0,f|0);h=w[114256];w[114256]=0;if((h|0)==1){break d}w[114256]=0;U(80,i+152|0,f|0,j|0);h=w[114256];w[114256]=0;if((h|0)==1){break c}Ab(i+152|0);f=w[f+24>>2];if(f){h=w[w[f>>2]+8>>2];w[114256]=0;T(h|0,f|0,j|0);h=w[114256];w[114256]=0;if((h|0)==1){break c}f=f+4|0;h=Ic(i+144|0,f);Wc(f,j);Ab(h)}Ab(i);c=w[c>>2];w[114256]=0;Q(88,g|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}w[114256]=0;c=g+4|0;T(82,k|0,c|0);j=w[114256];w[114256]=0;if((j|0)==1){break d}j=w[15e3];w[g>>2]=j;w[w[j-12>>2]+g>>2]=w[15003];w[g+4>>2]=59272;if(u[g+47|0]<0){zb(w[g+36>>2])}wc(c);pc(g+56|0);jb=i+160|0;break a}a=P()|0;break b}a=P()|0;Ab(i)}nd(g);R(a|0);M()}w[114256]=0;T(387,e+20|0,d|0);c=w[114256];w[114256]=0;e:{f:{if((c|0)!=1){w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(290,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break e}zb(w[e+8>>2]);break e}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function sB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;i=a+8|0;j=e+8|0;a:{b:{c:{d:{e:{f:{while(1){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,8)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(!d){break c}w[114256]=0;U(548,e|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=w[a+4>>2];f=w[a+8>>2];if(d>>>0<f>>>0){f=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];f=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=f;w[a+4>>2]=d+24;continue}g=w[a>>2];h=(d-g|0)/24|0;d=h+1|0;if(d>>>0>=178956971){w[114256]=0;X(549,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}M()}w[114256]=0;f=(f-g|0)/24|0;g=f<<1;f=Z(550,e+24|0,(f>>>0>=89478485?178956970:d>>>0<g>>>0?g:d)|0,h|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}g=w[e+4>>2];d=w[e+32>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=g;w[114256]=0;w[e+32>>2]=w[e+32>>2]+24;T(551,a|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;pd(f);break d}pd(f);d=w[e+12>>2];if(!d){continue}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){continue}ob[w[w[d>>2]+8>>2]](d);Ib(d);continue}break}b=P()|0;break a}b=P()|0;break d}b=P()|0}Bb(j);break a}jb=e+48|0;return}b=P()|0}Ac(a);R(b|0);M()}function cV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;i=a+8|0;j=e+8|0;a:{b:{c:{d:{e:{f:{while(1){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,8)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(!d){break c}w[114256]=0;U(937,e|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=w[a+4>>2];f=w[a+8>>2];if(d>>>0<f>>>0){f=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];f=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=f;w[a+4>>2]=d+24;continue}g=w[a>>2];h=(d-g|0)/24|0;d=h+1|0;if(d>>>0>=178956971){w[114256]=0;X(938,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}M()}w[114256]=0;f=(f-g|0)/24|0;g=f<<1;f=Z(939,e+24|0,(f>>>0>=89478485?178956970:d>>>0<g>>>0?g:d)|0,h|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}g=w[e+4>>2];d=w[e+32>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=g;w[114256]=0;w[e+32>>2]=w[e+32>>2]+24;T(940,a|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;pd(f);break d}pd(f);d=w[e+12>>2];if(!d){continue}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){continue}ob[w[w[d>>2]+8>>2]](d);Ib(d);continue}break}b=P()|0;break a}b=P()|0;break d}b=P()|0}Bb(j);break a}jb=e+48|0;return}b=P()|0}Ac(a);R(b|0);M()}function VD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;i=a+8|0;j=e+8|0;a:{b:{c:{d:{e:{f:{while(1){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,8)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(!d){break c}w[114256]=0;U(332,e|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=w[a+4>>2];f=w[a+8>>2];if(d>>>0<f>>>0){f=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];f=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=f;w[a+4>>2]=d+24;continue}g=w[a>>2];h=(d-g|0)/24|0;d=h+1|0;if(d>>>0>=178956971){w[114256]=0;X(333,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}M()}w[114256]=0;f=(f-g|0)/24|0;g=f<<1;f=Z(334,e+24|0,(f>>>0>=89478485?178956970:d>>>0<g>>>0?g:d)|0,h|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}g=w[e+4>>2];d=w[e+32>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=g;w[114256]=0;w[e+32>>2]=w[e+32>>2]+24;T(335,a|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;pd(f);break d}pd(f);d=w[e+12>>2];if(!d){continue}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){continue}ob[w[w[d>>2]+8>>2]](d);Ib(d);continue}break}b=P()|0;break a}b=P()|0;break d}b=P()|0}Bb(j);break a}jb=e+48|0;return}b=P()|0}Ac(a);R(b|0);M()}function CE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;i=a+8|0;j=e+8|0;a:{b:{c:{d:{e:{f:{while(1){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,8)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(!d){break c}w[114256]=0;U(282,e|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=w[a+4>>2];f=w[a+8>>2];if(d>>>0<f>>>0){f=w[e+4>>2];w[d>>2]=w[e>>2];w[d+4>>2]=f;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];f=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=f;w[a+4>>2]=d+24;continue}g=w[a>>2];h=(d-g|0)/24|0;d=h+1|0;if(d>>>0>=178956971){w[114256]=0;X(283,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}M()}w[114256]=0;f=(f-g|0)/24|0;g=f<<1;f=Z(284,e+24|0,(f>>>0>=89478485?178956970:d>>>0<g>>>0?g:d)|0,h|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}g=w[e+4>>2];d=w[e+32>>2];w[d>>2]=w[e>>2];w[d+4>>2]=g;w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=g;w[114256]=0;w[e+32>>2]=w[e+32>>2]+24;T(285,a|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;pd(f);break d}pd(f);d=w[e+12>>2];if(!d){continue}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){continue}ob[w[w[d>>2]+8>>2]](d);Ib(d);continue}break}b=P()|0;break a}b=P()|0;break d}b=P()|0}Bb(j);break a}jb=e+48|0;return}b=P()|0}Ac(a);R(b|0);M()}function Vy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0;l=w[a+48>>2];m=w[a>>2];g=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];e=w[a+44>>2];a:{if(!d){f=i>>12;h=j>>12;break a}o=b+24|0;n=w[a+8>>2];p=w[a+12>>2];q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];b=w[a+68>>2];x=b;y=b>>31;b=w[a+64>>2];z=b;A=b>>31;b=w[a+60>>2];B=b;D=b>>31;b=l;while(1){f=w[c>>2];l=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(z,A,e,e>>31);h=nb;b=(b|0)>=16776704?16776704:b;b=(b|0)<=-16777216?-16777216:b;k=BV(x,y,b,b>>31);e=k+e|0;b=nb+h|0;b=e>>>0<k>>>0?b+1|0:b;E=f;h=e;e=g+q|0;f=(((m>>>16|0)+4&131064)<<1)+o|0;k=(((((C(u[e+2|0],v[f+10>>1])+C(u[e+1|0],v[f+8>>1])|0)+C(u[e+3|0],v[f+12>>1])|0)+C(u[e+4|0],v[f+14>>1])<<8)/2|0)+((((C(u[e-2|0],v[f+2>>1])+C(u[e-3|0],v[f>>1])|0)+C(u[e-1|0],v[f+4>>1])|0)+C(u[e|0],v[f+6>>1])<<8)/2|0)|0)/16384<<8;e=k;f=BV(e,e>>31,B,D);e=h+f|0;b=nb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;j=j+s|0;h=j>>12;b=(b&16777215)<<8|e>>>24;e=(b|0)/256|0;w[c>>2]=E+C(h,e);i=i+r|0;f=i>>12;w[c+4>>2]=w[c+4>>2]+C(e,f);e=b-(k&t)|0;g=g+p|0;b=m+n|0;g=b>>>0<n>>>0?g+1|0:g;m=b;c=c+8|0;b=l;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=m;w[a+4>>2]=g;w[a+40>>2]=i;w[a+20>>2]=h;w[a+48>>2]=l;w[a+44>>2]=e;w[a+24>>2]=f}function Ux(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb+-64|0;jb=e;lc(b,2);d=e+40|0;Vb(d,2,a+1|0,12);w[114256]=0;w[e+60>>2]=22;w[e+56>>2]=b+43;Q(200,e+56|0,d|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{d:{if((d|0)!=1){if(u[e+51|0]<0){zb(w[e+40>>2])}e:{switch(x[a|0]){case 2:break b;case 0:break d;case 1:break e;default:break a}}d=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);w[b>>2]=d;f=d-1|0;g=x[a+20|0]|x[a+21|0]<<8|(x[a+22|0]<<16|x[a+23|0]<<24);f=f>>>0<g>>>0?f:g;w[b+4>>2]=f;g=x[a+24|0]|x[a+25|0]<<8|(x[a+26|0]<<16|x[a+27|0]<<24);d=d>>>0<g>>>0?d:g;w[b+8>>2]=d;v[b+34>>1]=y[b+34>>1]&65533|x[a+31|0]<<1&2;break c}a=P()|0;if(u[e+51|0]<0){zb(w[e+40>>2])}R(a|0);M()}f=w[b+4>>2];d=w[b+8>>2]}if(d>>>0>f>>>0&d>>>0>=2){break a}v[b+34>>1]=0;w[b+4>>2]=0;w[b+8>>2]=0;break a}d=x[a+20|0]|x[a+21|0]<<8|(x[a+22|0]<<16|x[a+23|0]<<24);f=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);g=x[a+24|0]|x[a+25|0]<<8|(x[a+26|0]<<16|x[a+27|0]<<24);w[e+32>>2]=g;w[e+16>>2]=g;w[e+24>>2]=f;w[e+28>>2]=d;w[e+8>>2]=f;w[e+12>>2]=d;Ai(b,1,e+8|0)}d=x[a+28|0];v[b+30>>1]=(d>>>0>=64?64:d)<<2;d=x[a+32|0]|x[a+33|0]<<8|(x[a+34|0]<<16|x[a+35|0]<<24);w[b+24>>2]=d;f:{g:{h:{if(!c){break h}if(x[a|0]==2){d=d&65535;w[b+24>>2]=d;break h}a=65535;if(d>>>0>65535){break g}}if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}w[b+24>>2]=a}jb=e- -64|0}function WC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;i=a+8|0;j=e+8|0;a:{b:{c:{d:{e:{f:{while(1){d=w[b+8>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;d=S(g|0,f|0,d|0,6)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}if(!d){break c}w[114256]=0;U(427,e|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)!=1){d=w[a+4>>2];f=w[a+8>>2];if(d>>>0<f>>>0){w[d>>2]=w[e>>2];v[d+4>>1]=y[e+4>>1];w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];f=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=f;w[a+4>>2]=d+24;continue}g=w[a>>2];h=(d-g|0)/24|0;d=h+1|0;if(d>>>0>=178956971){w[114256]=0;X(428,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break e}M()}w[114256]=0;f=(f-g|0)/24|0;g=f<<1;f=Z(429,e+24|0,(f>>>0>=89478485?178956970:d>>>0<g>>>0?g:d)|0,h|0,i|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}d=w[e+32>>2];w[d>>2]=w[e>>2];v[d+4>>1]=y[e+4>>1];w[d+8>>2]=w[e+8>>2];w[d+12>>2]=w[e+12>>2];w[e+8>>2]=0;w[e+12>>2]=0;g=w[e+20>>2];w[d+16>>2]=w[e+16>>2];w[d+20>>2]=g;w[114256]=0;w[e+32>>2]=w[e+32>>2]+24;T(430,a|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;pd(f);break d}pd(f);d=w[e+12>>2];if(!d){continue}f=w[d+4>>2];w[d+4>>2]=f-1;if(f){continue}ob[w[w[d>>2]+8>>2]](d);Ib(d);continue}break}b=P()|0;break a}b=P()|0;break d}b=P()|0}Bb(j);break a}jb=e+48|0;return}b=P()|0}Ac(a);R(b|0);M()}function ru(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=0;a:{if(x[b+21|0]){o=1;j=w[e>>2];l=w[f>>2];b:{if((h|0)>0){p=C(d,g);m=w[b>>2];while(1){g=w[a+1396>>2];c:{if((g|0)>9){break c}if(!g){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break c}k=Dc(a);if((k|0)==-1){break c}g=w[a+1396>>2];w[a+1396>>2]=g+8;w[a+1392>>2]=w[a+1392>>2]+(k<<g);if((g|0)<17){continue}break}}g=w[a+1392>>2];k=v[(((g&1023)<<1)+b|0)+36>>1];d:{if((k|0)>=0){i=g;k=k&65535;g=x[k+w[b+8>>2]|0];w[a+1392>>2]=i>>>g;g=w[a+1396>>2]-g|0;w[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:k;break d}g=hg(a,b)}if((g|0)>=w[b+2092>>2]?x[b+23|0]:0){break a}if((g|0)<0){if(!x[a+1376|0]){o=0;if(w[a+1384>>2]){break b}}w[a+100>>2]=21;return 0}k=C(d,l);m=((k+m|0)+j|0)>(p|0)?(p-k|0)+j|0:m;k=C(g,w[b>>2]);e:{if(x[b+22|0]){g=0;n=D(0);if((m|0)<=0){break e}while(1){n=D(A[w[b+28>>2]+(g+k<<2)>>2]+n);i=w[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;A[i>>2]=A[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break e}g=0;if((m|0)<=0){break e}while(1){i=w[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;A[i>>2]=A[i>>2]+A[w[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}w[e>>2]=j;w[f>>2]=l}return o}w[a+100>>2]=21;return 0}ha(3764,9008,1887,2880);M()}function wk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{g=b;b:{c:{k=a+58|0;i=k+b|0;d=u[i|0];if((d|0)==-1){break c}if((d|0)>=0){b=d;break b}b=d&127;h=(b<<1)+a|0;e=y[h+22>>1];if((e|0)!=65535&(e|0)!=(g|0)){break c}v[h+22>>1]=g;u[i|0]=b;break b}m=a+4|0;l=a+22|0;j=255;b=0;e=255;while(1){f=(b<<1)+l|0;h=y[f>>1];if((h|0)==65535){v[f>>1]=g;u[i|0]=b;break b}if(!(x[b+m|0]&32)){j=u[h+k|0]<0?b:j;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){d=(j&255)==255?e:j;b=((d&255)<<1)+l|0;u[y[b>>1]+k|0]=255;v[b>>1]=g;u[i|0]=d}b=d<<24>>24;b=(b|0)<0?-1:b}f=b&255;if(!w[a>>2]|(f|0)==255){break a}e=C(f,12)+a|0;b=x[c+8|0]|x[c+9|0]<<8|(x[c+10|0]<<16|x[c+11|0]<<24);u[e+322|0]=b;u[e+323|0]=b>>>8;u[e+324|0]=b>>>16;u[e+325|0]=b>>>24;b=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);d=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[e+314|0]=d;u[e+315|0]=d>>>8;u[e+316|0]=d>>>16;u[e+317|0]=d>>>24;u[e+318|0]=b;u[e+319|0]=b>>>8;u[e+320|0]=b>>>16;u[e+321|0]=b>>>24;if(f>>>0<=8){g=x[f+25584|0]}else{g=x[f+25575|0]|256}h=g+3|0;b=0;d=1;while(1){e=d;d=e?g:h;Pd(w[a>>2],d|32,x[b+c|0]);Pd(w[a>>2],d|64,x[(b|2)+c|0]);Pd(w[a>>2],d|96,x[(b|4)+c|0]);Pd(w[a>>2],d|128,x[(b|6)+c|0]);Pd(w[a>>2],d|224,x[(b|8)+c|0]);d=0;b=1;if(e){continue}break}Pd(w[a>>2],((f>>>0<9?f:f-9|256)|192)&65535,x[c+10|0])}}function fA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;o=w[a+16>>2];g=jb-32|0;f=w[a+44>>2];w[g+12>>2]=f;b=w[a+48>>2];w[g+16>>2]=b;e=w[a+52>>2];w[g+20>>2]=e;j=w[a+56>>2];w[g+24>>2]=j;l=w[a>>2];i=w[a+4>>2];if(d){j=w[a+8>>2];p=w[a+12>>2];q=w[a+24>>2];r=w[a+20>>2];s=w[a+72>>2];b=w[a+68>>2];t=b;u=b>>31;b=w[a+64>>2];x=b;y=b>>31;b=w[a+60>>2];z=b;A=b>>31;while(1){b=((((i&2147483647)<<1|l>>>31)&2147483646)<<1)+o|0;w[g>>2]=v[b>>1];w[g+4>>2]=v[b+2>>1];f=0;b=1;while(1){e=(g+8|0)+(f<<3)|0;k=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;m=(f<<2)+g|0;n=w[m>>2]<<8;f=n;f=BV(z,A,f,f>>31);B=nb;D=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,x,y);f=h+f|0;e=nb+B|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=(k|0)>=16776704?16776704:k;f=(f|0)<=-16777216?-16777216:f;k=BV(f,f>>31,t,u);f=h+k|0;e=nb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[D+4>>2]=e-(s&n);w[m>>2]=(e|0)/256;e=b;b=0;f=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],r);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],q);i=i+p|0;b=j+l|0;i=b>>>0<j>>>0?i+1|0:i;l=b;c=c+8|0;d=d-1|0;if(d){continue}break}j=w[g+24>>2];e=w[g+20>>2];f=w[g+12>>2];b=w[g+16>>2]}w[a+56>>2]=j;w[a+52>>2]=e;w[a+48>>2]=b;w[a+44>>2]=f;w[a>>2]=l;w[a+4>>2]=i}function xn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{switch(w[a+480224>>2]-1|0){default:c=w[a+24620>>2];c=BV(c,c>>31,5e4,0);b=w[b+44>>2]<<1;b=b?b:1;b=CV(c,nb,b,b>>31);c=b;d=nb;b=(d|0)>=0&b>>>0>=2147483647|(d|0)>0;c=b?2147483647:c;b=b?0:d;c=(b|0)<0&c>>>0<=2147483648|(b|0)<-1?-2147483648:c;break a;case 0:c=w[a+24620>>2];c=BV(c,c>>31,1e4,0);b=w[b+44>>2];b=b>>>0<=1?1:b;b=CV(c,nb,b,b>>31);c=b;d=nb;b=(d|0)>=0&b>>>0>=2147483647|(d|0)>0;c=b?2147483647:c;b=b?0:d;c=(b|0)<0&c>>>0<=2147483648|(b|0)<-1?-2147483648:c;break a;case 1:break b}}g=+z[b+44>>2]*1e-4*(+(BV(w[b+32>>2],0,w[b+40>>2],0)>>>0)+ +(nb>>>0)*4294967296);e=+z[a+24620>>2]*60;c:{d:{d=y[b+60>>1];f=w[a+484344>>2];if(d>>>0>=((w[a+484348>>2]-f|0)/52&65535)>>>0){break d}c=f+C(d,52)|0;if(w[c>>2]==w[c+4>>2]){break d}d=f+C(d,52)|0;c=w[d+24>>2];if((c|0)==w[d+28>>2]){break d}d=d+24|0;break c}c=w[a+480248>>2];d=a+480248|0}e=e/g;d=w[d+4>>2];if((d|0)!=(c|0)){e=e*5.960464477539063e-8*+z[(z[b+48>>2]%(d-c>>2>>>0)<<2)+c>>2]}e:{if(E(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+B[b+8>>3];B[b+8>>3]=e;if(!(e<1)){B[b+8>>3]=e+-1;c=c+1|0;break a}if(B[a+1074384>>3]>-1){break a}B[b+8>>3]=e+1;c=c-1|0}a=BV(w[a+480244>>2],0,c,0)+32768|0;b=nb;b=a>>>0<32768?b+1|0:b;c=b>>>16|0;b=(b&65535)<<16|a>>>16;a=!c&(b|0)==-1|c?-1:b;return(a?a:1)|0}function gA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0;o=w[a+16>>2];g=jb-32|0;f=w[a+44>>2];w[g+12>>2]=f;b=w[a+48>>2];w[g+16>>2]=b;e=w[a+52>>2];w[g+20>>2]=e;j=w[a+56>>2];w[g+24>>2]=j;l=w[a>>2];i=w[a+4>>2];if(d){j=w[a+8>>2];p=w[a+12>>2];q=w[a+24>>2];r=w[a+20>>2];s=w[a+72>>2];b=w[a+68>>2];t=b;v=b>>31;b=w[a+64>>2];x=b;y=b>>31;b=w[a+60>>2];z=b;A=b>>31;while(1){b=(((i&2147483647)<<1|l>>>31)&-2)+o|0;w[g>>2]=u[b|0]<<8;w[g+4>>2]=u[b+1|0]<<8;f=0;b=1;while(1){e=(g+8|0)+(f<<3)|0;k=w[e+8>>2];h=w[e+4>>2];w[e+8>>2]=h;m=(f<<2)+g|0;n=w[m>>2]<<8;f=n;f=BV(z,A,f,f>>31);B=nb;D=e;e=(h|0)>=16776704?16776704:h;e=(e|0)<=-16777216?-16777216:e;h=BV(e,e>>31,x,y);f=h+f|0;e=nb+B|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=(k|0)>=16776704?16776704:k;f=(f|0)<=-16777216?-16777216:f;k=BV(f,f>>31,t,v);f=h+k|0;e=nb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;w[D+4>>2]=e-(s&n);w[m>>2]=(e|0)/256;e=b;b=0;f=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[g>>2],r);w[c+4>>2]=w[c+4>>2]+C(w[g+4>>2],q);i=i+p|0;b=j+l|0;i=b>>>0<j>>>0?i+1|0:i;l=b;c=c+8|0;d=d-1|0;if(d){continue}break}j=w[g+24>>2];e=w[g+20>>2];f=w[g+12>>2];b=w[g+16>>2]}w[a+56>>2]=j;w[a+52>>2]=e;w[a+48>>2]=b;w[a+44>>2]=f;w[a>>2]=l;w[a+4>>2]=i}function SC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;e=w[c+4>>2];c=w[c>>2];if(d>>>0<(e-c|0)/33>>>0){g=jb-16|0;jb=g;u[a+12|0]=0;w[a+4>>2]=w[a>>2];Qh(a,15);h=c+C(d,33)|0;i=0-x[h+1|0]|0;while(1){c=(j<<1)+h|0;d=x[c+1|0];if(d){c=x[c+2|0];i=d+(i<<16>>16)|0;v[g+8>>1]=i;u[g+10|0]=c>>>0>=64?64:c;c=w[a+4>>2];a:{if(c>>>0<z[a+8>>2]){d=w[g+8>>2];v[c>>1]=d;v[c+2>>1]=d>>>16;w[a+4>>2]=c+4;break a}k=jb-32|0;jb=k;b:{d=w[a>>2];e=w[a+4>>2]-d>>2;c=e+1|0;if(c>>>0<1073741824){d=w[a+8>>2]-d|0;f=d>>1;c=ud(k+8|0,d>>>0>=2147483644?1073741823:c>>>0<f>>>0?f:c,e,a+8|0);d=w[c+8>>2];e=y[g+8>>1]|y[g+10>>1]<<16;v[d>>1]=e;v[d+2>>1]=e>>>16;l=w[c+8>>2]+4|0;w[c+8>>2]=l;e=w[a+4>>2];d=w[a>>2];m=e-d|0;f=w[c+4>>2]-m|0;w[c+4>>2]=f;if((m|0)>0){Fb(f,d,m);l=w[c+8>>2];e=w[a+4>>2];f=w[c+4>>2];d=w[a>>2]}w[a>>2]=f;w[c+4>>2]=d;w[a+4>>2]=l;w[c+8>>2]=e;f=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=d;w[c+12>>2]=f;if((d|0)!=(e|0)){w[c+8>>2]=((d-e|0)+3&-4)+e}if(d){zb(d)}jb=k+32|0;break b}Mb(a);M()}}j=j+1|0;if((j|0)!=15){continue}}break}c=x[h+32|0];u[a+14|0]=c>>>4;u[a+13|0]=c&15;c=x[h+31|0];d=c&15;u[a+15|0]=d;u[a+16|0]=d;if(c&16){u[a+12|0]=x[a+12|0]|4}if(c&32){u[a+12|0]=x[a+12|0]|2}jb=g+16|0}c:{if(b<<24>>24>=0){c=x[a+12|0]&-2;a=a+12|0;break c}c=x[a+12|0]&-2|w[a>>2]!=w[a+4>>2];a=a+12|0}u[a|0]=c}function KI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;g=a+488|0;Sb(g,d);w[114256]=0;m=V(1735,g|0)|0;g=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Db(f)){g=w[kj(f,0)>>2];w[114256]=0;h=Q(1761,m|0,45)|0;i=w[114256];w[114256]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Wb(a+456|0);h=Wb(a+440|0);i=Wb(a+424|0);w[114256]=0;oa(1789,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,h|0,i|0,a+420|0);c=w[114256];w[114256]=0;if((c|0)==1){break f}w[a+4>>2]=1708;k=vc(a+8|0,0,a+4|0);c=a+16|0;h:{if((Db(f)|0)>w[a+420>>2]){g=Db(f);l=w[a+420>>2];g=(((Db(i)+(g-l<<1)|0)+Db(h)|0)+w[a+420>>2]|0)+1|0;break h}g=((Db(i)+Db(h)|0)+w[a+420>>2]|0)+2|0}if(g>>>0<101){break e}Hc(k,fc(g<<2));c=w[k>>2];if(c){break e}w[114256]=0;_(1709);b=w[114256];w[114256]=0;if((b|0)==1){break d}M()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}g=w[d+4>>2];l=Qb(f);o=Qb(f);f=Db(f);w[114256]=0;ta(1790,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+480|0,w[a+476>>2],w[a+472>>2],j|0,h|0,i|0,w[a+420>>2]);f=w[114256];w[114256]=0;if((f|0)!=1){w[114256]=0;b=la(1765,b|0,c|0,w[a+4>>2],w[a>>2],d|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}}}f=P()|0;Ub(k)}$b(i);$b(h);Gb(j)}Ab(a+488|0);R(f|0);M()}Ub(k);$b(i);$b(h);Gb(j);Ab(a+488|0);jb=a+496|0;return b|0}function ZB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=jb-528|0;jb=b;d=-1;a:{if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1468)|0)){break a}b:{if(z[a+12>>2]<=1463){if(ob[w[w[a>>2]+24>>2]](a)>>>0<1464){break b}}w[a+12>>2]=1464}zp(a,b+524|0);if((x[b+524|0]|x[b+525|0]<<8|(x[b+526|0]<<16|x[b+527|0]<<24))!=5133389){d=0;if((x[b+524|0]|x[b+525|0]<<8|(x[b+526|0]<<16|x[b+527|0]<<24))!=808539209){break a}}c:{if(z[a+12>>2]<=19){if(ob[w[w[a>>2]+24>>2]](a)>>>0<20){break c}}w[a+12>>2]=20}d=1;while(1){if(!xp(a,b)){d=-1;break a}e=((x[b+25|0]>64)+c|0)+(x[b+24|0]>15)|0;c=y[b+26>>1];f=(c<<8|c>>>8)&65535;c=y[b+22>>1];c=e+(f>>>0>((c<<8|c>>>8)&65535)<<1>>>0)|0;e=d&65535;d=d+1|0;if(e>>>0<31){continue}break}d=0;if(c>>>0>40){break a}c=b+520|0;e=jb-16|0;jb=e;d:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],2)|0){f=w[a+12>>2];w[e+8>>2]=c;w[e+12>>2]=c+2;g=a,h=(ob[w[w[a>>2]+32>>2]](a,f,e+8|0)|0)+w[a+12>>2]|0,w[g+12>>2]=h;break d}u[c|0]=0;u[c+1|0]=0}jb=e+16|0;if(x[b+520|0]>128){break a}d=jb-16|0;jb=d;e:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],512)|0){c=w[a+12>>2];w[d+8>>2]=b;w[d+12>>2]=b+512;g=a,h=(ob[w[w[a>>2]+32>>2]](a,c,d+8|0)|0)+w[a+12>>2]|0,w[g+12>>2]=h;break e}Cb(b,0,512)}jb=d+16|0;c=x[b+521|0];a=0;while(1){if(c>>>0>=x[a+b|0]){d=1;a=a+1|0;if((a|0)!=512){continue}break a}break}d=0}jb=b+528|0;return d|0}function OI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;g=a+184|0;Sb(g,d);w[114256]=0;m=V(1561,g|0)|0;g=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Db(f)){g=x[Rb(f,0)|0];w[114256]=0;h=Q(1578,m|0,45)|0;i=w[114256];w[114256]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Wb(a+160|0);h=Wb(a+144|0);i=Wb(a+128|0);w[114256]=0;oa(1787,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,h|0,i|0,a+124|0);c=w[114256];w[114256]=0;if((c|0)==1){break f}w[a+4>>2]=1708;k=vc(a+8|0,0,a+4|0);c=a+16|0;h:{if((Db(f)|0)>w[a+124>>2]){g=Db(f);l=w[a+124>>2];g=(((Db(i)+(g-l<<1)|0)+Db(h)|0)+w[a+124>>2]|0)+1|0;break h}g=((Db(i)+Db(h)|0)+w[a+124>>2]|0)+2|0}if(g>>>0<101){break e}Hc(k,fc(g));c=w[k>>2];if(c){break e}w[114256]=0;_(1709);b=w[114256];w[114256]=0;if((b|0)==1){break d}M()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}g=w[d+4>>2];l=Qb(f);o=Qb(f);f=Db(f);w[114256]=0;ta(1788,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+176|0,u[a+175|0],u[a+174|0],j|0,h|0,i|0,w[a+124>>2]);f=w[114256];w[114256]=0;if((f|0)!=1){w[114256]=0;b=la(15,b|0,c|0,w[a+4>>2],w[a>>2],d|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}}}f=P()|0;Ub(k)}Gb(i);Gb(h);Gb(j)}Ab(a+184|0);R(f|0);M()}Ub(k);Gb(i);Gb(h);Gb(j);Ab(a+184|0);jb=a+192|0;return b|0}function tV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=1;m=w[a+12>>2];n=1<<m;t=2;d=m;if(d>>>0>=2){e=n;while(1){j=e>>>2|0;if(e>>>0>=4){M=j>>>0<=1?1:j;N=C(l,3);O=l<<1;d=0;while(1){e=d<<t;y=l+e|0;if(e>>>0<y>>>0){c=w[a>>2];o=c+(d<<4)|0;k=B[o>>3];c=c+(d<<5)|0;f=B[c>>3];u=B[o+8>>3];v=B[c+8>>3];z=k*f-u*v;A=u*-f-k*v;while(1){c=w[b>>2];o=e+N<<4;D=c+o|0;g=B[D>>3];E=e+O<<4;F=c+E|0;p=B[F>>3];G=e+l<<4;H=c+G|0;h=B[H>>3];i=B[H+8>>3];c=c+(e<<4)|0;q=B[c+8>>3];r=i+q;s=B[D+8>>3];I=B[F+8>>3];J=s+I;B[c+8>>3]=J+r;K=g+p;L=B[c>>3];x=h+L;B[c>>3]=K+x;c=w[b>>2]+G|0;g=p-g;p=q-i;i=g+p;q=s-I;h=L-h;s=q+h;B[c+8>>3]=i*f-s*v;B[c>>3]=s*f+i*v;c=w[b>>2]+E|0;r=r-J;i=x-K;B[c+8>>3]=r*k-i*u;B[c>>3]=r*u+i*k;c=o+w[b>>2]|0;h=h-q;g=p-g;B[c+8>>3]=h*A+g*z;B[c>>3]=h*z-g*A;e=e+1|0;if((y|0)!=(e|0)){continue}break}}d=d+1|0;if((M|0)!=(d|0)){continue}break}d=w[a+12>>2]}l=l<<2;e=j;t=t+2|0;if(t>>>0<=d>>>0){continue}break}}if(!(!(d&1)|!m)){j=n>>>1|0;m=j>>>0<=1?1:j;a=w[b>>2];e=0;while(1){d=e<<4;n=d+a|0;f=B[n>>3];a=(e+j<<4)+a|0;k=B[a+8>>3];B[a+8>>3]=B[n+8>>3]-k;x=f;f=B[a>>3];B[a>>3]=x-f;a=w[b>>2];d=d+a|0;B[d>>3]=f+B[d>>3];B[d+8>>3]=k+B[d+8>>3];e=e+1|0;if((m|0)!=(e|0)){continue}break}}}function $I(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;w[a+144>>2]=c;w[a+152>>2]=b;w[a+20>>2]=1769;h=vc(a+24|0,a+32|0,a+20|0);w[114256]=0;Sb(a+16|0,e);b=w[114256];w[114256]=0;a:{b:{c:{d:{if((b|0)!=1){w[114256]=0;i=V(1561,a+16|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}u[a+15|0]=0;b=w[e+4>>2];w[114256]=0;b=ua(1770,a+152|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+132|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}if(!b){break c}b=jb-16|0;jb=b;e:{if(dd(g)){c=w[g>>2];u[b+15|0]=0;Sc(c,b+15|0);Yc(g,0);break e}u[b+14|0]=0;Sc(g,b+14|0);Zc(g,0)}jb=b+16|0;if(!x[a+15|0]){break d}w[114256]=0;b=Q(1578,i|0,45)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}w[114256]=0;T(71,g|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break d}break b}c=P()|0;break a}w[114256]=0;b=Q(1578,i|0,48)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}c=w[h>>2];d=w[a+20>>2];e=d-1|0;b=b&255;while(1){if(!((b|0)!=x[c|0]|c>>>0>=e>>>0)){c=c+1|0;continue}break}w[114256]=0;S(1778,g|0,c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}break b}w[114256]=0;b=Q(1711,a+152|0,a+144|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}if(b){w[f>>2]=w[f>>2]|2}b=w[a+152>>2];Ab(a+16|0);Ub(h);jb=a+160|0;return b|0}c=P()|0;Ab(a+16|0)}Ub(h);R(c|0);M()}function UI(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;w[a+432>>2]=c;w[a+440>>2]=b;w[a+20>>2]=1769;h=vc(a+24|0,a+32|0,a+20|0);w[114256]=0;Sb(a+16|0,e);b=w[114256];w[114256]=0;a:{b:{c:{d:{if((b|0)!=1){w[114256]=0;i=V(1735,a+16|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}u[a+15|0]=0;b=w[e+4>>2];w[114256]=0;b=ua(1779,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}if(!b){break c}b=jb-16|0;jb=b;e:{if(dd(g)){c=w[g>>2];w[b+12>>2]=0;xd(c,b+12|0);Yc(g,0);break e}w[b+8>>2]=0;xd(g,b+8|0);Zc(g,0)}jb=b+16|0;if(!x[a+15|0]){break d}w[114256]=0;b=Q(1761,i|0,45)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}w[114256]=0;T(69,g|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break d}break b}c=P()|0;break a}w[114256]=0;b=Q(1761,i|0,48)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}c=w[h>>2];d=w[a+20>>2];e=d-4|0;while(1){if(!((b|0)!=w[c>>2]|c>>>0>=e>>>0)){c=c+4|0;continue}break}w[114256]=0;S(1785,g|0,c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}break b}w[114256]=0;b=Q(1741,a+440|0,a+432|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}if(b){w[f>>2]=w[f>>2]|2}b=w[a+440>>2];Ab(a+16|0);Ub(h);jb=a+448|0;return b|0}c=P()|0;Ab(a+16|0)}Ub(h);R(c|0);M()}function ny(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb+-64|0;jb=b;d=255;a:{b:{c=w[a+4>>2];e=w[a>>2];f=c-e|0;c:{if((f>>>5&255)>>>0>49){break c}d=w[a+12>>2];w[b+24>>2]=0;w[b+28>>2]=0;w[b+16>>2]=0;w[b+20>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;v[b+36>>1]=0;w[b+32>>2]=d;d=w[a+8>>2];d:{if(d>>>0>c>>>0){w[c>>2]=w[b+8>>2];w[c+4>>2]=w[b+12>>2];w[c+8>>2]=w[b+16>>2];d=w[b+24>>2];w[c+12>>2]=w[b+20>>2];w[c+16>>2]=d;w[c+20>>2]=w[b+28>>2];w[c+24>>2]=w[b+32>>2];v[c+28>>1]=y[b+36>>1];w[a+4>>2]=c+32;break d}f=f>>5;c=f+1|0;if(c>>>0>=134217728){w[114256]=0;X(710,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}M()}w[114256]=0;d=d-e|0;e=d>>4;d=Z(711,b+40|0,(d>>>0>=2147483616?134217727:c>>>0<e>>>0?e:c)|0,f|0,a+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}c=w[d+8>>2];w[c>>2]=w[b+8>>2];w[c+4>>2]=w[b+12>>2];w[c+8>>2]=w[b+16>>2];w[b+16>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;w[c+20>>2]=w[b+28>>2];e=w[b+24>>2];w[c+12>>2]=w[b+20>>2];w[c+16>>2]=e;w[b+28>>2]=0;w[b+20>>2]=0;w[b+24>>2]=0;v[c+28>>1]=y[b+36>>1];w[c+24>>2]=w[b+32>>2];w[d+8>>2]=w[d+8>>2]+32;w[114256]=0;T(712,a|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){a=P()|0;xi(d);break a}xi(d)}c=w[a+4>>2]-w[a>>2]|0;d=(c>>>5|0)-1|0;if((d&255)>>>0>=c>>5>>>0){break c}u[a+16|0]=d}jb=b- -64|0;return d&255}a=P()|0}mh(b+8|0);R(a|0);M()}function oz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0;n=jb-16|0;a:{b:{c:{f=w[a+12>>2];j=w[a+8>>2];d:{if((f|0)<=1&j>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&j>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&j>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&j>>>0>2147483648|f>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}k=w[a>>2];h=w[a+4>>2];l=w[a+40>>2];m=w[a+36>>2];e:{if(!d){b=l>>12;i=m>>12;break e}p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];while(1){g=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+p|0;b=(k>>>16&65520)+o|0;s=v[b+14>>1];t=v[b+12>>1];u=v[b+10>>1];x=v[b+8>>1];y=v[b+6>>1];z=v[b+4>>1];A=v[b+2>>1];B=v[b>>1];i=0;b=1;while(1){e=i<<1;w[(n+8|0)+(i<<2)>>2]=(((((((C(v[(e|-8)+g>>1],A)+C(v[(e|-12)+g>>1],B)|0)+C(v[(e|-4)+g>>1],z)|0)+C(v[e+g>>1],y)|0)+C(v[(e|4)+g>>1],x)|0)+C(v[(e|8)+g>>1],u)|0)+C(v[(e|12)+g>>1],t)|0)+C(v[(e|16)+g>>1],s)|0)/32768;e=b;b=0;i=1;if(e){continue}break}m=m+r|0;i=m>>12;w[c>>2]=w[c>>2]+C(i,w[n+8>>2]);l=l+q|0;b=l>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[n+12>>2]);h=f+h|0;e=j+k|0;h=e>>>0<j>>>0?h+1|0:h;k=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=m;w[a>>2]=k;w[a+4>>2]=h;w[a+40>>2]=l;w[a+20>>2]=i;w[a+24>>2]=b}function nr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;w[a+12>>2]=c;w[a+8>>2]=f;w[a+12>>2]=c;w[a+8>>2]=f;a:{b:{while(1){c:{i=w[a+12>>2];if(i>>>0>=d>>>0){break c}l=w[a+8>>2];if(l>>>0>=g>>>0){break c}f=u[i|0];c=f&255;d:{if((f|0)>=0){if(c>>>0<=1114111){f=1;break d}b=2;break a}b=2;if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-i|0)<2){break b}j=x[i+1|0];if((j&192)!=128){break a}f=2;c=j&63|c<<6&1984;break d}if(f>>>0<=4294967279){if((d-i|0)<3){break b}k=x[i+2|0];j=x[i+1|0];e:{f:{if((c|0)!=237){if((c|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}f=3;c=k&63|(c<<12&61440|(j&63)<<6);break d}if(f>>>0>4294967284){break a}if((d-i|0)<4){break b}k=x[i+3|0];m=x[i+2|0];j=x[i+1|0];g:{h:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break g}break a;case 4:if((j&240)==128){break g}break a;default:break h}}if((j&192)!=128){break a}}if((m&192)!=128|(k&192)!=128){break a}f=4;c=k&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}w[l>>2]=c;w[a+12>>2]=f+i;w[a+8>>2]=w[a+8>>2]+4;continue}break}b=d>>>0>i>>>0;break a}b=1}w[e>>2]=w[a+12>>2];w[h>>2]=w[a+8>>2];jb=a+16|0;return b|0}function md(a,b,c,d){var e=0,f=0;if(b-251>>>0>=4294967046){e=b-1|0;f=w[a+480180>>2];if(!(f&740327453)){if(f&17408){a=((e&255)>>>0)/12|0;return y[((e-C(a,12)&255)<<1)+26368>>1]<<4>>>a|0}b=d?d:8363;a:{b:{if(!(x[a+480208|0]&16)){if((f|0)==64){break b}a=((e&255)>>>0)/12|0;c=-1>>>a|0;a=EV(BV(y[((e-C(a,12)&255)<<1)+26368>>1],0,267616,0),nb,(b>>>0<c>>>0?b:c)<<a,0);b=nb;return!b&(a|0)==-1|b?-1:a}if(x[a+1074312|0]&128){break b}if((f|0)!=64){break a}}a=((e&255)>>>0)/12|0;c=BV(w[(e+(a<<2)<<6&960)+30256>>2]<<a,0,b,0);a=nb;b=a>>>21|0;a=(a&2097151)<<11|c>>>21;return!b&(a|0)==-1|b?-1:a}a=((e&255)>>>0)/12|0;return y[((e-C(a,12)&255)<<1)+26368>>1]<<5>>>a|0}if(f&20){d=e>>>0>12;b=(f|0)==16?c<<4:x[a+1074321|0]&16?c&-8:c;d=d?e:12;if(x[a+480208|0]&16){a=(((b|0)/-2|0)-(d<<6)|0)+8448|0;return(a|0)<=1?1:a}c=0;a=d-12|0;d=((a&255)>>>0)/12|0;e=((b|0)/16|0)+(a-C(d,12)<<3&248)|0;c:{if((e|0)>=-8){c=103;a=e+8|0;if(a>>>0<104){break c}}a=c}f=b;c=b>>31;b=c;b=(f^b)-b&15;c=e+(c|1)|0;c=(c|0)<=-8?-8:c;return C(b,y[((((c|0)>=95?95:c)<<1)+26848|0)+16>>1])+C(y[(a<<1)+26848>>1],16-b|0)<<1>>>d|0}a=b-25|0;if(!((c&255)>>>0<16&a>>>0<=83)){a=((e&255)>>>0)/12|0;return y[(C((c&240)>>>4|0,12)+(e-C(a,12)&255)<<1)+25968>>1]<<5>>>a|0}a=y[(a<<1)+25792>>1]<<2}else{a=0}return a}function Hs(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{c=w[a+4>>2];f:{if((c|0)!=w[a+104>>2]){w[a+4>>2]=c+1;c=x[c|0];break f}c=ac(a)}switch(c-43|0){case 0:case 2:break e;default:break d}}f=(c|0)==45;g=!b;c=w[a+4>>2];g:{if((c|0)!=w[a+104>>2]){w[a+4>>2]=c+1;c=x[c|0];break g}c=ac(a)}b=c-58|0;if(g|b>>>0>4294967285){break c}if(w[a+116>>2]<0){break b}w[a+4>>2]=w[a+4>>2]-1;break b}b=c-58|0}if(b>>>0<4294967286){break b}b=c-48|0;if(b>>>0<10){while(1){e=(C(e,10)+c|0)-48|0;d=(e|0)<214748364;c=w[a+4>>2];h:{if((c|0)!=w[a+104>>2]){w[a+4>>2]=c+1;c=x[c|0];break h}c=ac(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}i:{if(b>>>0>=10){break i}while(1){b=BV(e,d,10,0);c=b+c|0;d=nb;d=b>>>0>c>>>0?d+1|0:d;e=c-48|0;d=d-(c>>>0<48)|0;b=w[a+4>>2];j:{if((b|0)!=w[a+104>>2]){w[a+4>>2]=b+1;c=x[b|0];break j}c=ac(a)}b=c-48|0;if(b>>>0>9){break i}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=w[a+4>>2];k:{if((b|0)!=w[a+104>>2]){w[a+4>>2]=b+1;b=x[b|0];break k}b=ac(a)}if(b-48>>>0<10){continue}break}}b=w[a+116>>2];if((b|0)>0|(b|0)>=0){w[a+4>>2]=w[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break a}d=-2147483648;if(w[a+116>>2]<0){break a}w[a+4>>2]=w[a+4>>2]-1;nb=-2147483648;return 0}nb=d;return e}function op(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb+-64|0;jb=d;a:{b:{h=w[a+4>>2];if(h>>>0<b>>>0){i=b-h|0;f=w[a+8>>2];e=f<<5;if(!(i>>>0>e>>>0|e-i>>>0<h>>>0)){w[a+4>>2]=b;e=h&31;f=w[a>>2]+(h>>>3&536870908)|0;break b}w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;c:{if((b|0)<0){w[114256]=0;X(525,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}M()}w[114256]=0;g=d+24|0;if(e>>>0<=1073741822){e=f<<6;f=b+31&-32;e=e>>>0>f>>>0?e:f}else{e=2147483647}T(526,g|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}e=w[a+4>>2];w[d+28>>2]=e+i;f=w[a>>2];w[114256]=0;g=w[d+24>>2];w[d+60>>2]=0;w[d+56>>2]=f;w[d+52>>2]=e&31;w[d+48>>2]=f+(e>>>3&536870908);w[d+44>>2]=0;w[d+40>>2]=g;e=w[d+60>>2];w[d+8>>2]=w[d+56>>2];w[d+12>>2]=e;e=w[d+52>>2];w[d>>2]=w[d+48>>2];w[d+4>>2]=e;Y(527,d+16|0,d+8|0,d|0,d+40|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}f=w[d+16>>2];e=w[d+20>>2];g=w[a>>2];w[a>>2]=w[d+24>>2];w[d+24>>2]=g;j=w[a+4>>2];w[a+4>>2]=w[d+28>>2];w[d+28>>2]=j;j=w[a+8>>2];w[a+8>>2]=w[d+32>>2];w[d+32>>2]=j;if(!g){break b}zb(g);break b}a=P()|0;b=w[d+24>>2];if(b){zb(b)}R(a|0);M()}w[a+4>>2]=b;break a}if((b|0)==(h|0)){break a}if(c){w[d+28>>2]=e;w[d+24>>2]=f;Kl(d+24|0,i);break a}w[d+28>>2]=e;w[d+24>>2]=f;Jh(d+24|0,i)}jb=d- -64|0}function cR(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb+-64|0;jb=g;a:{if(u[c+11|0]>=0){w[g+24>>2]=w[c+8>>2];h=w[c+4>>2];w[g+16>>2]=w[c>>2];w[g+20>>2]=h;break a}me(g+16|0,w[c>>2],w[c+4>>2])}c=g+28|0;b:{c:{d:{e:{if(u[d+11|0]>=0){h=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=h;w[c+8>>2]=w[d+8>>2];break e}h=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,c|0,d|0,h|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}c=g+40|0;f:{if(u[e+11|0]>=0){d=w[e+4>>2];w[c>>2]=w[e>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+8>>2];break f}d=w[e+4>>2];e=w[e>>2];w[114256]=0;U(3,c|0,e|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}c=g+52|0;g:{if(u[f+11|0]>=0){d=w[f+4>>2];w[c>>2]=w[f>>2];w[c+4>>2]=d;w[c+8>>2]=w[f+8>>2];break g}d=w[f+4>>2];e=w[f>>2];w[114256]=0;U(3,c|0,e|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}w[114256]=0;d=g- -64|0;w[g+12>>2]=d;w[g+8>>2]=g+16;U(51,a|0,b|0,g+8|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(g+16|0)){continue}break}jb=g- -64|0;return}e=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(g+16|0)){continue}break}break b}e=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(g+16|0)){continue}break}}R(e|0);M()}function uV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=1;d=w[a+12>>2];h=1<<d;if(d&1){j=h>>>1|0;c=j>>>0<=1?1:j;e=w[b>>2];d=0;while(1){f=d<<4;g=f+e|0;k=B[g>>3];e=(d+j<<4)+e|0;n=B[e+8>>3];B[e+8>>3]=B[g+8>>3]-n;i=k;k=B[e>>3];B[e>>3]=i-k;e=w[b>>2];f=f+e|0;B[f>>3]=k+B[f>>3];B[f+8>>3]=n+B[f+8>>3];d=d+1|0;if((c|0)!=(d|0)){continue}break}d=w[a+12>>2];e=2;h=h>>>3|0}else{h=h>>>2|0}j=d&-2;if(j){while(1){if(e){I=C(h,3);J=h<<1;f=0;while(1){d=f<<j;x=h+d|0;if(d>>>0<x>>>0){c=w[a>>2];g=c+(f<<4)|0;n=B[g+8>>3];c=c+(f<<5)|0;k=B[c>>3];u=B[g>>3];v=B[c+8>>3];y=n*k+u*v;z=u*k-n*v;while(1){c=w[b>>2];g=c+(d<<4)|0;A=d+I<<4;p=c+A|0;i=B[p+8>>3];l=B[p>>3];q=i*z+l*y;p=d+h<<4;o=p+c|0;m=B[o+8>>3];r=B[o>>3];D=m*k+r*v;E=q+D;o=c;c=d+J<<4;o=o+c|0;s=B[o+8>>3];t=B[o>>3];F=s*u+t*n;G=B[g+8>>3];H=F+G;B[g+8>>3]=E+H;i=l*z-i*y;l=r*k-m*v;m=i+l;r=t*u-s*n;s=B[g>>3];t=r+s;B[g>>3]=m+t;g=p+w[b>>2]|0;B[g+8>>3]=H-E;B[g>>3]=t-m;c=c+w[b>>2]|0;i=i-l;l=G-F;B[c+8>>3]=i+l;q=D-q;m=s-r;B[c>>3]=q+m;c=w[b>>2]+A|0;B[c+8>>3]=l-i;B[c>>3]=m-q;d=d+1|0;if((x|0)!=(d|0)){continue}break}}f=f+1|0;if((f|0)!=(e|0)){continue}break}}h=h>>>2|0;e=e<<2;j=j-2|0;if(j){continue}break}}}function yw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{c=C(b,896)+a|0;if(w[c+1075072>>2]&134218752){break a}f=w[c+1075640>>2];if(!f|(x[f+31|0]-1&255)>>>0>16|x[f+15|0]&2){break a}c=Ef(a,b,2,1);if((c-1&255)>>>0>249){break a}g=w[(C(c,160)+a|0)+906140>>2];if(!g){break a}c=C(b,896)+a|0;d=c+1075794|0;b:{if(x[c+1075796|0]==1){c=x[c+1075798|0];e=c>>>0>=64?64:c;break b}e=255;if(x[c+1075797|0]!=13){break b}c=x[(C(b,896)+a|0)+1075799|0];e=c>>>0>=64?64:c}c=x[d|0];j=w[a+1074312>>2];if(j&4){if(c){if((c-1&255)>>>0<=119){c=x[(c+f|0)+107|0]}Ff(a,b,c,y[(C(b,896)+a|0)+1075672>>1]);return}if((e|0)==255){break a}ob[w[w[g>>2]+76>>2]](g,39,e,b);return}i=w[f+4>>2];k=(c|0)!=0;if(c){d=v[(C(b,896)+a|0)+1075772>>1];d=(x[f+35|0]?i<<2:w[(C(b,896)+a|0)+1075672>>2])+(j&268435456?d<<2:d)|0;c:{if((d|0)>=0){h=256;if(d>>>0<257){break c}}d=h}h=c-1&255;if(h>>>0<=119){c=x[(c+f|0)+107|0]}Ff(a,b,c&255,d&65535);d=h>>>0<120}else{d=0}a=x[a+1074324|0]&32?k:d;if(!(!a&(e|0)!=255)&(!a|x[f+35|0]!=1)){break a}d:{switch(x[f+36|0]){case 1:if((e|0)!=255){Rv(g,e<<1);return}Rv(g,i<<1);return;case 0:break d;default:break a}}if((e|0)!=255){a=e<<1&254;ob[w[w[g>>2]+76>>2]](g,7,a>>>0>=127?127:a,b);return}a=i<<1;ob[w[w[g>>2]+76>>2]](g,7,a>>>0>=127?127:a,b)}}function pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0;n=jb-16|0;a:{b:{c:{e=w[a+12>>2];h=w[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}j=w[a>>2];g=w[a+4>>2];k=w[a+40>>2];l=w[a+36>>2];e:{if(!d){b=k>>12;i=l>>12;break e}p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];while(1){f=(((g&2147483647)<<1|j>>>31)&-2)+p|0;b=(j>>>16&65520)+o|0;s=v[b+14>>1];t=v[b+12>>1];x=v[b+10>>1];y=v[b+8>>1];z=v[b+6>>1];A=v[b+4>>1];B=v[b+2>>1];D=v[b>>1];b=0;i=1;while(1){w[(n+8|0)+(b<<2)>>2]=(((((((C(u[(b|-4)+f|0],B)+C(u[(b|-6)+f|0],D)|0)+C(u[(b|-2)+f|0],A)|0)+C(u[b+f|0],z)|0)+C(u[(b|2)+f|0],y)|0)+C(u[(b|4)+f|0],x)|0)+C(u[(b|6)+f|0],t)|0)+C(u[(b|8)+f|0],s)<<8)/32768;m=i;i=0;b=1;if(m){continue}break}l=l+r|0;i=l>>12;w[c>>2]=w[c>>2]+C(i,w[n+8>>2]);k=k+q|0;b=k>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[n+12>>2]);g=e+g|0;m=h+j|0;g=m>>>0<h>>>0?g+1|0:g;j=m;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=j;w[a+4>>2]=g;w[a+40>>2]=k;w[a+20>>2]=i;w[a+24>>2]=b}function zV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=F(f)-F(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;lb=a-C(b,c)|0;mb=0;nb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}lb=a;mb=e&g;a=e>>>AV(f)|0;nb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(F(c)+33|0)-F(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}lb=0;a=(e>>>0)/(f>>>0)|0;mb=e-C(a,f)|0;nb=0;return a}e=F(f)-F(e)|0;if(e>>>0<31){break d}break b}lb=a&f;mb=0;if((c|0)==1){break a}d=a;c=AV(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}nb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}lb=k;mb=f;e=b<<1|a>>>31;a=l|a<<1;nb=e|j;return a}lb=a;mb=b;a=0;b=0}nb=b;return a}function UP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;d=x[b+11|0];f=d<<24>>24;a:{d=(f|0)<0?w[b+4>>2]:d;if(!(w[b+12>>2]?d:0)){w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;break a}w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;b:{c:{e=d+1|0;d:{if(e>>>0>=4294967280){w[114256]=0;X(103,c+16|0);a=w[114256];w[114256]=0;if((a|0)==1){break d}M()}h=w[b>>2];e:{if(e>>>0<=10){u[c+27|0]=d;e=c+16|0;break e}w[114256]=0;g=(e|15)+1|0;e=V(22,g|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break d}w[c+16>>2]=e;w[c+20>>2]=d;w[c+24>>2]=g|-2147483648}j=Fb(e,(f|0)<0?h:b,d)+d|0,k=0,u[j|0]=k;w[114256]=0;S(2,c+16|0,9912,1)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break c}}b=P()|0;if(u[c+27|0]>=0){break b}zb(w[c+16>>2]);break b}w[114256]=0;T(116,c|0,b+12|0);b=w[114256];w[114256]=0;f:{g:{if((b|0)!=1){w[114256]=0;b=x[c+11|0];d=b<<24>>24<0;b=S(2,c+16|0,(d?w[c>>2]:c)|0,(d?w[c+4>>2]:b)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;w[a+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;if(u[c+11|0]<0){zb(w[c>>2])}if(u[c+27|0]>=0){break a}zb(w[c+16>>2]);break a}b=P()|0;break f}b=P()|0;if(u[c+11|0]>=0){break f}zb(w[c>>2])}if(u[c+27|0]>=0){break b}zb(w[c+16>>2])}R(b|0);M()}jb=c+32|0}function Zu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{f:{c=w[a+36>>2];f=w[a+40>>2];g:{if((c|0)!=(f|0)){w[d+24>>2]=0;break g}Vg(d+8|0,a);w[114256]=0;e=V(22,12)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}w[e>>2]=w[d+8>>2];w[e+4>>2]=w[d+12>>2];w[e+8>>2]=w[d+16>>2];w[d+24>>2]=e;f=w[a+40>>2];c=w[a+36>>2]}g=(c|0)==(f|0)?e:a+36|0;if((b|0)==-1){h=w[g>>2];f=4194304;c=0;break d}f=0;if((b|0)>=0){c=b;h=w[g>>2];if(((w[g+4>>2]-h|0)/24|0)>(b|0)){break d}}c=ba(8)|0;w[114256]=0;b=Q(5,d+8|0,6865)|0;a=w[114256];w[114256]=0;if((a|0)==1){break e}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break c}zb(w[b>>2]);break c}a=P()|0;b=w[d+8>>2];if(!b){break b}w[d+12>>2]=b;zb(b);break b}a=P()|0;ca(c|0);break c}w[a+8>>2]=b;b=w[a+24>>2];w[b+480208>>2]=w[b+480208>>2]&-4194305|f;c=C(c,24);f=x[(c+h|0)+16|0];w[114256]=0;T(264,b+484360|0,f|0);b=w[114256];w[114256]=0;h:{if((b|0)==1){break h}b=c+w[g>>2]|0;c=w[b+8>>2];b=w[b+12>>2];w[114256]=0;+ra(1345,a|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){break h}w[a+16>>2]=0;w[a+20>>2]=0;w[d+24>>2]=0;if(e){kd(e)}jb=d+32|0;return}a=P()|0}w[d+24>>2]=0;if(!e){break b}kd(e)}R(a|0)}M()}function hg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=w[a+1396>>2];a:{if((c|0)>24){break a}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break a}f=Dc(a);if((f|0)==-1){break a}c=w[a+1396>>2];w[a+1396>>2]=c+8;w[a+1392>>2]=w[a+1392>>2]+(f<<c);if((c|0)<17){continue}break}}b:{c:{d:{e:{d=w[b+32>>2];f:{if(!d){g=w[b+2084>>2];if(g){break f}return-1}e=w[b+4>>2];if((e|0)<9){break e}g=w[b+2084>>2];if(!g){break e}}f=w[a+1392>>2];c=0;e=w[b+2092>>2];if((e|0)>=2){d=f<<8&16711680|f<<24|(f>>>8&65280|f>>>24);d=d>>>4&252645135|(d&252645135)<<4;d=d>>>2&858993459|(d&858993459)<<2;j=d>>>1&1431655765|(d&1431655765)<<1;while(1){d=e>>>1|0;i=d+c|0;h=j>>>0<z[(i<<2)+g>>2];c=h?c:i;e=h?d:e-d|0;if((e|0)>1){continue}break}}e=w[a+1396>>2];c=x[b+23|0]?c:w[w[b+2088>>2]+(c<<2)>>2];b=x[c+w[b+8>>2]|0];if((e|0)<(b|0)){break d}w[a+1392>>2]=f>>>b;b=e-b|0;break c}if(x[b+23|0]){break b}if((e|0)>0){g=w[b+8>>2];c=0;while(1){g:{f=x[c+g|0];if((f|0)==255){break g}h=w[a+1392>>2];if(w[d+(c<<2)>>2]!=(h&(-1<<f^-1))){break g}e=w[a+1396>>2];if((e|0)<(f|0)){break d}w[a+1392>>2]=h>>>f;b=e-x[w[b+8>>2]+c|0]|0;break c}c=c+1|0;if((e|0)!=(c|0)){continue}break}}w[a+100>>2]=21}c=-1;b=0}w[a+1396>>2]=b;return c}ha(7217,9008,1705,1931);M()}function WO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=jb-2144|0;jb=b;Cb(b+96|0,0,2048);a:{b:{c:{f=w[c+4>>2];if(!f){d=ba(8)|0;w[114256]=0;a=Q(5,b+80|0,6393)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}c=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}g=w[c>>2];d=w[c+12>>2];c=w[c+8>>2];w[b+72>>2]=c;w[b+76>>2]=d;e=w[b+76>>2];w[b+24>>2]=w[b+72>>2];w[b+28>>2]=e;w[b+68>>2]=f;w[b+64>>2]=g;e=w[b+68>>2];w[b+16>>2]=w[b+64>>2];w[b+20>>2]=e;h=_p(b+16|0);if(h){w[b+48>>2]=c;w[b+52>>2]=d;c=w[b+52>>2];w[b+8>>2]=w[b+48>>2];w[b+12>>2]=c;w[b+44>>2]=f;w[b+40>>2]=g;c=w[b+44>>2];w[b>>2]=w[b+40>>2];w[b+4>>2]=c;c=Xp(b)}else{c=0}w[b+56>>2]=c;w[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=ob[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=b+96|0;w[b+36>>2]=c+d;w[b+32>>2]=c;a=hk(a,b+32|0,h?b+56|0:0);if(a+1>>>0>=3){d=ba(8)|0;w[114256]=0;a=Q(5,b+80|0,4242)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}c=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}c=P()|0;ca(d|0);break b}jb=b+2144|0;return a|0}c=P()|0;ca(d|0)}R(c|0)}M()}function tA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-48|0;jb=e;v[a>>1]=0;v[a+2>>1]=0;v[a+4>>1]=0;vh(b,e+44|0);a:{if(x[e+44|0]!=255){break a}d=x[e+45|0];if((d&224)!=224|(d&24)==8|!(d&6)){break a}c=x[e+46|0];if((c&12)==12|(c&240)==240){break a}f=x[e+47|0];u[a+4|0]=1;h=d>>>3&3;g=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;v[a+2>>1]=y[(C(g,6)+24168|0)+(d<<1)>>1]<<f;i=C(C(x[d+(C(g,3)+23944|0)|0],y[((C(g,90)+23952|0)+C(d,30)|0)+(c>>>3&30)>>1]),1e3);c=c>>>1|0;c=C(((i>>>0)/y[(C(h,6)+24144|0)+(c&6)>>1]|0)+(c&1)|0,d?1:4);v[a>>1]=c;d=x[f+((g<<1)+24180|0)|0];if(d+8>>>0>(c&65535)>>>0){break a}f=w[b>>2];g=d+4|0;c=g>>>0>=36?36:g;b:{if(ob[w[w[f>>2]+36>>2]](f,w[b+8>>2],c)|0){f=w[b+8>>2];break b}c=w[b>>2];c=ob[w[w[c>>2]+24>>2]](c)|0;f=w[b+8>>2];c=c-f|0}h=w[b>>2];ob[w[w[h>>2]+28>>2]](h,e,f,c)|0;Cb(c+e|0,0,36-c|0);c=w[b>>2];c:{if(ob[w[w[c>>2]+36>>2]](c,w[b+8>>2],g)|0){c=g+w[b+8>>2]|0;break c}c=w[b>>2];c=ob[w[w[c>>2]+24>>2]](c)|0}w[b+8>>2]=c;b=2;if(d>>>0>2){while(1){if(x[b+e|0]){break a}b=b+1|0;if((d|0)!=(b|0)){continue}break}}b=d+e|0;if((x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24))==1868983881){b=1}else{b=(x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24))==1735289176}u[a+5|0]=b}jb=e+48|0;return a|0}function pH(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!w[i>>2]){break a}i=i+4|0;continue}break}w[h>>2]=f;w[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=w[b+4>>2];w[j+8>>2]=w[b>>2];w[j+12>>2]=k;m=1;l=jb-16|0;jb=l;w[l+12>>2]=w[a+8>>2];n=be(l+8|0,l+12|0);w[114256]=0;k=da(1845,f|0,e|0,i-c>>2,g-f|0,b|0)|0;o=w[114256];w[114256]=0;d:{if((o|0)!=1){Lc(n);jb=l+16|0;break d}a=P()|0;Lc(n);R(a|0);M()}e:{f:{g:{h:{switch(k+1|0){case 0:w[h>>2]=f;while(1){i:{if(w[e>>2]==(c|0)){break i}b=Jl(f,w[c>>2],j+8|0,w[a+8>>2]);if((b|0)==-1){break i}f=b+w[h>>2]|0;w[h>>2]=f;c=c+4|0;continue}break};w[e>>2]=c;break g;case 1:break c;default:break h}}f=k+w[h>>2]|0;w[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=w[e>>2];i=d;continue}i=Jl(j+4|0,0,b,w[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-w[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=x[c|0];k=w[h>>2];w[h>>2]=k+1;u[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=w[e>>2]+4|0;w[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!w[i>>2]){break b}i=i+4|0;continue}}c=w[e>>2]}m=(c|0)!=(d|0)}jb=j+16|0;return m|0}f=w[h>>2];continue}}function Yy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0;f=w[a+48>>2];i=w[a>>2];h=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}l=b+24|0;k=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;u=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){g=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,u,e,e>>31);j=nb;z=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(r,s,f,f>>31);e=g+e|0;f=nb+j|0;f=e>>>0<g>>>0?f+1|0:f;A=e;e=(h<<1)+p|0;g=(((i>>>16|0)+4&131064)<<1)+l|0;g=(((((C(v[e+4>>1],v[g+10>>1])+C(v[e+2>>1],v[g+8>>1])|0)+C(v[e+6>>1],v[g+12>>1])|0)+C(v[e+8>>1],v[g+14>>1])|0)/2|0)+((((C(v[e-4>>1],v[g+2>>1])+C(v[e-6>>1],v[g>>1])|0)+C(v[e-2>>1],v[g+4>>1])|0)+C(v[e>>1],v[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;j=BV(e,e>>31,x,y);e=A+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=z+C(e,o);w[c+4>>2]=w[c+4>>2]+C(e,n);e=f-(g&q)|0;h=h+m|0;f=i+k|0;h=f>>>0<k>>>0?h+1|0:h;i=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=i;w[a+4>>2]=h}function Hv(a){var b=D(0),c=0,d=D(0),e=0,f=0,g=0,h=0,i=0,k=D(0);c=w[w[a+16>>2]+24620>>2];i=a,k=jd(D(D(A[a+4208>>2]*D(19.931568145751953))+D(-9.965784072875977))),A[i+4232>>2]=k;A[a+4248>>2]=D(D(1)/D(D(A[a+4224>>2]*D(-99))+D(-1)))+D(1);b=D(c>>>0);d=D(b*D(.0010000000474974513));i=a,k=jd(D(D(-3.321928024291992)/D(D(D(A[a+4212>>2]*D(499.989990234375))+D(.009999999776482582))*d))),A[i+4236>>2]=k;i=a,k=jd(D(D(-3.321928024291992)/D(D(D(A[a+4216>>2]*D(2950))+D(50))*d))),A[i+4240>>2]=k;b=D(D(D(b*D(.004000000189989805))*A[a+4228>>2])+D(2));a:{if(D(E(b))<D(2147483648)){e=~~b;break a}e=-2147483648}w[a+4252>>2]=e;e=a;d=D(jd(D(D(A[a+4220>>2]*D(9.965784072875977))+D(-9.965784072875977)))*D(2147483648));a=(p(d),j(2));b=D(0);b:{if((a|0)==1065353216){break b}c:{if(a-2139095040>>>0<=2164260863){c=a<<1;if(!c){b=D(Dm(D(-1))/D(0));break b}if((a|0)==2139095040){break c}if(!(c>>>0<4278190080&(a|0)>=0)){b=bu(d);break b}a=(p(D(d*D(8388608))),j(2))-192937984|0}c=a-1060306944|0;g=c>>>15&240;f=+(l(2,a-(c&-8388608)|0),q())*B[g+57832>>3]+-1;h=f*f;d=D((B[7262]*h+(B[7263]*f+B[7264]))*h+(+(c>>23)*B[7261]+B[g+57840>>3]+f))}b=d}A[e+4244>>2]=D(G(D(D(b*D(96817624))+D(67108864)),D(2147483648)))*D(4.656612873077393e-10)}function hP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;c=Kb(1304568);w[114256]=0;d=V(1444,c|0)|0;f=w[114256];w[114256]=0;a:{if((f|0)==1){b=P()|0;zb(c);break a}Tj(a+24|0,d);v[a+28>>1]=0;d=Po();c=Kb(44);w[c+28>>2]=0;w[c+32>>2]=0;w[c+20>>2]=0;w[c+24>>2]=0;w[c+12>>2]=0;w[c+16>>2]=0;w[114256]=0;d=ml(d);f=w[114256];w[114256]=0;if((f|0)==1){b=P()|0;zb(c);break a}w[c+40>>2]=1;w[c+36>>2]=C(d,214013)+2531011;d=w[a+32>>2];w[a+32>>2]=c;if(d){zb(d)}d=w[a>>2];c=Kb(8);w[c+4>>2]=d;w[c>>2]=82380;d=w[a+4>>2];w[a+4>>2]=c;if(d){ob[w[w[d>>2]+4>>2]](d);c=w[a+4>>2]}w[w[a+24>>2]+1304560>>2]=c;w[a+60>>2]=0;w[a+48>>2]=1065353216;w[a+52>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+8>>2]=0;u[a- -64|0]=0;b:{c=w[b>>2];d=b+4|0;if((c|0)!=(d|0)){while(1){c:{if(u[c+27|0]>=0){w[e+8>>2]=w[c+24>>2];b=w[c+20>>2];w[e>>2]=w[c+16>>2];w[e+4>>2]=b;break c}Ge(e,w[c+16>>2],w[c+20>>2])}w[114256]=0;Y(1400,a|0,e|0,c+28|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[e+11|0]<0){zb(w[e>>2])}b=w[c+4>>2];d:{if(b){while(1){c=b;b=w[c>>2];if(b){continue}break d}}while(1){b=c;c=w[c+8>>2];if((b|0)!=w[c>>2]){continue}break}}if((c|0)!=(d|0)){continue}break}}jb=e+16|0;return}b=P()|0;if(u[e+11|0]>=0){break a}zb(w[e>>2])}R(b|0);M()}function dD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=jb-32|0;jb=h;e=h+8|0;w[e+8>>2]=0;w[e+12>>2]=0;w[e+16>>2]=0;d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;a:{b:{if((c|0)==1){break a}c=w[b+8>>2];w[114256]=0;U(253,e|0,b|0,d-c|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}c=w[b+8>>2];d=w[e>>2];f=w[b>>2];g=w[w[f>>2]+36>>2];w[114256]=0;c=S(g|0,f|0,c|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}c:{if(c){d=d+w[b+8>>2]|0;break c}d=w[b>>2];c=w[w[d>>2]+24>>2];w[114256]=0;d=V(c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}}w[b+8>>2]=d;b=e;break b}b=w[b+4>>2];d:{if(b){c=w[e>>2]+b|0;break d}b=w[e+8>>2];c=w[e+12>>2];if((b|0)!=(c|0)){break d}c=0;b=0}e:{f=c-b|0;if(f>>>0>=4294967280){w[114256]=0;X(408,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break e}M()}f:{if(f>>>0<=10){u[a+11|0]=f;break f}w[114256]=0;g=(f|15)+1|0;d=V(22,g|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break e}w[a>>2]=d;w[a+4>>2]=f;w[a+8>>2]=g|-2147483648;a=d}if((b|0)!=(c|0)){while(1){u[a|0]=x[b|0];a=a+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}u[a|0]=0;a=w[e+8>>2];if(a){w[e+12>>2]=a;zb(a)}jb=h+32|0;return}}b=P()|0;a=w[e+8>>2];if(a){w[e+12>>2]=a;zb(a)}R(b|0);M()}function zE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-144|0;jb=f;w[114256]=0;i=Q(261,a|0,f+8|0)|0;g=w[114256];w[114256]=0;if((g|0)!=1){a:{b:{if(!i){break b}i=y[f+8>>1];if(!i){break b}l=b-1|0;m=(i<<8|i>>>8)&65535;i=0;while(1){w[114256]=0;b=Q(286,a|0,f+8|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}c:{if(!b){break c}b=y[f+8>>1];if(!b){break c}b=(b<<8|b>>>8)&65535;if(b>>>0>y[c+480192>>1]){break c}b=w[((b<<2)+c|0)+900380>>2];if(!b){break c}d:{e:{switch(l|0){default:b=b+48|0;break d;case 0:b=b+68|0;break d;case 1:break e}}b=b+88|0}g=x[f+11|0];f:{if(!g){break f}h=x[f+10|0];if(h&1){u[b+12|0]=x[b+12|0]|1}if(h&2){u[b+12|0]=x[b+12|0]|4}if(!(h&4)){break f}u[b+12|0]=x[b+12|0]|2}w[114256]=0;g=(g>>>0>=31?31:g)+1|0;T(287,b|0,g|0);h=w[114256];w[114256]=0;if((h|0)==1){break a}u[b+13|0]=x[f+13|0];u[b+14|0]=x[f+14|0];h=x[f+12|0];u[b+15|0]=h;u[b+16|0]=h;h=w[b>>2];b=0;while(1){e=b<<2;j=e+h|0;e=e+(f+8|0)|0;k=y[e+8>>1];v[j>>1]=k<<8|k>>>8;e=y[e+10>>1];e=e<<8|e>>>8;e=(d?(e&65535)+128>>>2|0:e)&65535;u[j+2|0]=e>>>0>=64?64:e;b=b+1|0;if((g|0)!=(b|0)){continue}break}}i=i+1|0;if((i&65535)>>>0<m>>>0){continue}break}}Bb(a);jb=f+144|0;return}}b=P()|0;Bb(a);R(b|0);M()}function yz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0;b=w[a+48>>2];m=w[a>>2];h=w[a+4>>2];j=w[a+40>>2];k=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=j>>12;i=k>>12;break a}n=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];s=w[a+72>>2];e=w[a+68>>2];t=e;u=e>>31;e=w[a+64>>2];x=e;y=e>>31;e=w[a+60>>2];z=e;A=e>>31;e=b;while(1){g=w[c>>2];b=f;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;f=BV(x,y,f,f>>31);i=nb;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;l=BV(t,u,e,e>>31);f=l+f|0;e=nb+i|0;e=f>>>0<l>>>0?e+1|0:e;B=g;i=f;f=(h<<1)+p|0;g=(m>>>21&2040)+32832|0;l=(((C(v[f>>1],v[g+2>>1])+C(v[f-2>>1],v[g>>1])|0)+C(v[f+2>>1],v[g+4>>1])|0)+C(v[f+4>>1],v[g+6>>1])|0)/16384<<8;f=l;g=BV(f,f>>31,z,A);f=i+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;k=k+r|0;i=k>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=B+C(i,f);j=j+q|0;g=j>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(l&s)|0;h=h+o|0;e=m+n|0;h=e>>>0<n>>>0?h+1|0:h;m=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=k;w[a>>2]=m;w[a+4>>2]=h;w[a+40>>2]=j;w[a+20>>2]=i;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function Zy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0;f=w[a+48>>2];i=w[a>>2];h=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}l=b+24|0;k=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;x=b>>31;b=w[a+60>>2];y=b;z=b>>31;while(1){g=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,x,e,e>>31);j=nb;A=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(r,s,f,f>>31);e=g+e|0;f=nb+j|0;f=e>>>0<g>>>0?f+1|0:f;B=e;e=h+p|0;g=(((i>>>16|0)+4&131064)<<1)+l|0;g=(((((C(u[e+2|0],v[g+10>>1])+C(u[e+1|0],v[g+8>>1])|0)+C(u[e+3|0],v[g+12>>1])|0)+C(u[e+4|0],v[g+14>>1])<<8)/2|0)+((((C(u[e-2|0],v[g+2>>1])+C(u[e-3|0],v[g>>1])|0)+C(u[e-1|0],v[g+4>>1])|0)+C(u[e|0],v[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;j=BV(e,e>>31,y,z);e=B+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=A+C(e,o);w[c+4>>2]=w[c+4>>2]+C(e,n);e=f-(g&q)|0;h=h+m|0;f=i+k|0;h=f>>>0<k>>>0?h+1|0:h;i=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=i;w[a+4>>2]=h}function zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0;b=w[a+48>>2];m=w[a>>2];h=w[a+4>>2];j=w[a+40>>2];k=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=j>>12;i=k>>12;break a}n=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];s=w[a+72>>2];e=w[a+68>>2];t=e;x=e>>31;e=w[a+64>>2];y=e;z=e>>31;e=w[a+60>>2];A=e;B=e>>31;e=b;while(1){g=w[c>>2];b=f;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;f=BV(y,z,f,f>>31);i=nb;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;l=BV(t,x,e,e>>31);f=l+f|0;e=nb+i|0;e=f>>>0<l>>>0?e+1|0:e;D=g;i=f;f=h+p|0;g=(m>>>21&2040)+32832|0;l=(((C(u[f|0],v[g+2>>1])+C(u[f-1|0],v[g>>1])|0)+C(u[f+1|0],v[g+4>>1])|0)+C(u[f+2|0],v[g+6>>1])<<8)/16384<<8;f=l;g=BV(f,f>>31,A,B);f=i+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;k=k+r|0;i=k>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=D+C(i,f);j=j+q|0;g=j>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(l&s)|0;h=h+o|0;e=m+n|0;h=e>>>0<n>>>0?h+1|0:h;m=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=k;w[a>>2]=m;w[a+4>>2]=h;w[a+40>>2]=j;w[a+20>>2]=i;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function Ny(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0;s=w[a+16>>2];t=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);l=w[a+128>>2];a:{if(!l){m=w[a+8>>2];n=w[a+12>>2];j=w[a>>2];g=w[a+4>>2];o=0;break a}g=w[a+4>>2];e=w[a+76>>2];j=w[a>>2];m=w[a+8>>2];n=w[a+12>>2];i=BV(m,n,d,0);f=j+i|0;b=nb+g|0;q=e>>>0<(f>>>0<i>>>0?b+1|0:b)>>>0?d:0;i=CV(m,n,l,l>>31);o=nb}if(d){h=a+112|0;u=w[a+24>>2];x=w[a+20>>2];y=(l|0)>0;while(1){q=q-1|0;b=q;i=b?i:0;o=b?o:0;f=0;k=j;p=((((g&2147483647)<<1|k>>>31)&2147483646)<<1)+s|0;b=l;if(y){while(1){e=(f&2147483647)<<1|k>>>31;Ee(h,(v[(e<<1|2)+p>>1]+v[((e&2147483646)<<1)+p>>1]|0)/8<<16>>16);De(h,4);f=f+o|0;k=i+k|0;f=k>>>0<i>>>0?f+1|0:f;e=b>>>0>1;b=b-1|0;if(e){continue}break}}d=d-1|0;r=w[a+120>>2];b=r+w[a+112>>2]|0;e=w[a+116>>2]+w[a+124>>2]|0;e=b>>>0<r>>>0?e+1|0:e;w[a+112>>2]=b;w[a+116>>2]=e;b=e;if(b){f=(f&2147483647)<<1|k>>>31;Ee(h,(v[(f<<1|2)+p>>1]+v[((f&2147483646)<<1)+p>>1]|0)/8<<16>>16);De(h,b);w[h>>2]=w[h>>2];w[h+4>>2]=0}b=ih(h,t);w[c>>2]=w[c>>2]+C(b,x);w[c+4>>2]=w[c+4>>2]+C(b,u);g=g+n|0;b=j+m|0;g=b>>>0<m>>>0?g+1|0:g;j=b;c=c+8|0;if(d){continue}break}}w[a>>2]=j;w[a+4>>2]=g}function oC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;lc(b,0);f=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);a:{if(c&34){if(d){w[b+24>>2]=f;break a}e=Tb(Ed(+(f+1408|0)*.0006510416666666666)*8363);d=-1;b:{if(e>=4294967295){break b}d=0;if(e<=0){break b}d=~~e>>>0;if(e<4294967296&e>=0){break b}d=0}w[b+24>>2]=d;break a}u[b+37|0]=(c|0)==16?f:f^128;u[b+36|0]=x[a+4|0]}d=x[a+5|0];v[b+30>>1]=(d>>>0>=64?64:d)<<2;d=x[a+6|0]|x[a+7|0]<<8;if(d>>>0<=256){v[b+28>>1]=d;v[b+34>>1]=y[b+34>>1]|32}w[b>>2]=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);w[b+4>>2]=x[a+12|0]|x[a+13|0]<<8|(x[a+14|0]<<16|x[a+15|0]<<24);w[b+8>>2]=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);d=x[a+20|0]|x[a+21|0]<<8;if(d&16){v[b+34>>1]=y[b+34>>1]|2;d=x[a+20|0]|x[a+21|0]<<8}if(d&32){v[b+34>>1]=y[b+34>>1]|4;d=x[a+20|0]|x[a+21|0]<<8}if(d&256){v[b+34>>1]=y[b+34>>1]|8;d=x[a+20|0]|x[a+21|0]<<8}if(d&512){v[b+34>>1]=y[b+34>>1]|16}u[b+38|0]=x[(x[a+22|0]&7)+32816|0];u[b+39|0]=x[a+23|0];u[b+40|0]=x[a+24|0];u[b+41|0]=x[a+25|0];if((c|0)==32){c=x[a+26|0];v[b+32>>1]=c>>>0>=64?64:c}w[b+12>>2]=x[a+27|0]|x[a+28|0]<<8|(x[a+29|0]<<16|x[a+30|0]<<24);w[b+16>>2]=x[a+31|0]|x[a+32|0]<<8|(x[a+33|0]<<16|x[a+34|0]<<24)}function Rg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=D(0),k=0;f=(p(b),j(2));g=au(f);a:{b:{c:{c=(p(a),j(2));d:{if(c-2139095040>>>0>=2164260864){if(g){break d}break b}if(!g){break c}}i=D(1);if((c|0)==1065353216){break a}d=f<<1;if(!d){break a}g=d>>>0<4278190081;d=c<<1;if(!(g&d>>>0<=4278190080)){return D(a+b)}if((d|0)==2130706432){break a}return d>>>0>2130706431^(f|0)>=0?D(0):D(b*b)}if(au(c)){i=D(a*a);if((c|0)<0){i=($t(f)|0)==1?D(-i):i}if((f|0)>=0){break a}return Dm(D(D(1)/i))}if((c|0)<0){d=$t(f);if(!d){return bu(a)}c=c&2147483647;d=((d|0)==1)<<16}if(c>>>0>8388607){break b}c=((p(D(a*D(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;g=f>>>15&240;e=+(l(2,c-(f&-8388608)|0),q())*B[g+58120>>3]+-1;h=e*e;e=((B[7297]*e+B[7298])*(h*h)+((B[7299]*e+B[7300])*h+(B[7301]*e+(B[g+58128>>3]+ +(f>>23)))))*+b;o(+e);c=j(1)|0;j(0)|0;e:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break e}if(e>127.99999995700433){return Cm(d)}if(!(e<=-150)){break e}return Bm(d)}h=B[6420];k=h+e;e=e-(k-h);h=(B[6421]*e+B[6422])*(e*e)+(B[6423]*e+1);o(+k);j(1)|0;g=j(0)|0;f=d+g|0;d=f<<15;f=((g&31)<<3)+51104|0;g=w[f>>2];c=g;d=w[f+4>>2]+d|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=D(h*+n())}return i}function KB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;d=w[b>>2];e=w[b+4>>2]-d>>3;a:{if(e>>>0<c>>>0){l=jb-32|0;jb=l;b:{e=c-e|0;g=w[b+8>>2];d=w[b+4>>2];c:{if(e>>>0<=g-d>>3>>>0){if(e){k=d;d=e<<3;d=Cb(k,0,d)+d|0}w[b+4>>2]=d;break c}i=w[b>>2];k=d-i>>3;f=e+k|0;if(f>>>0>=536870912){break b}d=l+8|0;w[d+12>>2]=0;w[d+16>>2]=b+8;d:{e:{g=g-i|0;i=g>>2;f=g>>>0>=2147483640?536870911:f>>>0<i>>>0?i:f;if(f){if(f>>>0>=536870912){break e}h=Kb(f<<3)}w[d>>2]=h;g=(k<<3)+h|0;w[d+8>>2]=g;w[d+12>>2]=(f<<3)+h;w[d+4>>2]=g;break d}vd();M()}e=e<<3;g=Cb(w[d+8>>2],0,e)+e|0;w[d+8>>2]=g;h=w[b+4>>2];f=w[b>>2];i=h-f|0;e=w[d+4>>2]-i|0;w[d+4>>2]=e;if((i|0)>0){Fb(e,f,i);g=w[d+8>>2];h=w[b+4>>2];f=w[b>>2];e=w[d+4>>2]}w[b>>2]=e;w[d+4>>2]=f;w[b+4>>2]=g;w[d+8>>2]=h;e=w[b+8>>2];w[b+8>>2]=w[d+12>>2];w[d>>2]=f;w[d+12>>2]=e;if((f|0)!=(h|0)){w[d+8>>2]=((f-h|0)+7&-8)+h}if(!f){break c}zb(f)}jb=l+32|0;break a}Mb(b);M()}if(c>>>0<e>>>0){w[b+4>>2]=d+(c<<3)}}d=w[a>>2];d=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],c<<3)|0;if(d){e=w[a+8>>2];c=w[a>>2];f=w[b+4>>2];w[j+8>>2]=w[b>>2];w[j+12>>2]=f;m=a,n=(ob[w[w[c>>2]+32>>2]](c,e,j+8|0)|0)+w[a+8>>2]|0,w[m+8>>2]=n}jb=j+16|0;return d|0}function $u(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;w[a+32>>2]=0;w[a+36>>2]=0;w[a+24>>2]=0;w[a+4>>2]=0;w[a>>2]=c;w[a+68>>2]=0;w[a+72>>2]=0;w[a+56>>2]=3;w[a+40>>2]=0;w[a+44>>2]=0;w[a+76>>2]=0;w[114256]=0;T(1461,a|0,d|0);f=w[114256];w[114256]=0;c=a+24|0;a:{b:{c:{d:{if((f|0)!=1){f=w[b>>2];g=w[b+4>>2];h=w[b+12>>2];b=w[b+8>>2];w[e+8>>2]=b;w[e+12>>2]=h;w[114256]=0;w[e+24>>2]=b;w[e+28>>2]=h;w[e+16>>2]=f;w[e+20>>2]=g;w[e>>2]=f;w[e+4>>2]=g;U(1457,e+32|0,e|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;U(1462,a|0,e+32|0,d|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[e+36>>2];e:{if(!b){break e}d=w[b+4>>2];w[b+4>>2]=d-1;if(d){break e}ob[w[w[b>>2]+8>>2]](b);Ib(b)}w[114256]=0;U(1349,a|0,2,100);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[c>>2];w[114256]=0;T(264,b+484360|0,0);b=w[114256];w[114256]=0;if((b|0)==1){break b}jb=e+48|0;return a|0}d=P()|0;break a}d=P()|0;break a}d=P()|0;Bb(e+32|0);break a}d=P()|0}bc(a+68|0);b=w[a+36>>2];if(b){w[a+40>>2]=b;zb(b)}b=w[a+32>>2];w[a+32>>2]=0;if(b){zb(b)}Tj(c,0);b=w[a+4>>2];w[a+4>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}b=w[a>>2];w[a>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}R(d|0);M()}function us(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-16|0;jb=k;a:{b:{c:{if((c|0)<=36){f=x[a|0];if(f){break c}g=a;break b}w[114084]=28;d=0;e=0;break a}g=a;d:{while(1){if(!mf(f<<24>>24)){break d}f=x[g+1|0];g=g+1|0;if(f){continue}break}break b}e:{f=x[g|0];switch(f-43|0){case 0:case 2:break e;default:break b}}m=(f|0)==45?-1:0;g=g+1|0}f:{if(!((c|16)!=16|x[g|0]!=48)){n=1;if((x[g+1|0]&223)==88){g=g+2|0;l=16;break f}g=g+1|0;l=c?c:8;break f}l=c?c:10}c=0;while(1){g:{f=-48;i=u[g|0];h:{if((i-48&255)>>>0<10){break h}f=-87;if((i-97&255)>>>0<26){break h}f=-55;if((i-65&255)>>>0>25){break g}}i=f+i|0;if((i|0)>=(l|0)){break g}Rc(k,l,0,0,0,j,h,0,0);f=1;i:{if(w[k+8>>2]|w[k+12>>2]){break i}o=BV(j,h,l,0);p=nb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break i}h=p;f=i+o|0;h=f>>>0<i>>>0?h+1|0:h;j=f;n=1;f=c}g=g+1|0;c=f;continue}break}if(b){w[b>>2]=n?g:a}j:{k:{if(c){w[114084]=68;a=d&1;m=a?0:m;j=d;h=e;break k}if((e|0)==(h|0)&d>>>0>j>>>0|e>>>0>h>>>0){break j}a=d&1}if(!(a|m)){w[114084]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(h|0)&d>>>0>=j>>>0|e>>>0>h>>>0){break j}w[114084]=68;break a}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}jb=k+16|0;nb=e;return d}function mP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=jb-32|0;jb=g;a:{c=w[a+4>>2];d=w[a+8>>2];b:{if(c>>>0<d>>>0){w[c>>2]=w[b>>2];w[c+12>>2]=w[b+12>>2];d=w[b+8>>2];w[c+4>>2]=w[b+4>>2];w[c+8>>2]=d;w[b+12>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[a+4>>2]=c+16;break b}e=w[a>>2];f=c-e>>4;c=f+1|0;if(c>>>0>=268435456){break a}d=d-e|0;e=d>>3;d=gi(g+8|0,d>>>0>=2147483632?268435455:c>>>0<e>>>0?e:c,f,a+8|0);c=w[d+8>>2];w[c>>2]=w[b>>2];w[c+12>>2]=w[b+12>>2];e=w[b+8>>2];w[c+4>>2]=w[b+4>>2];w[c+8>>2]=e;w[b+12>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;f=w[d+8>>2]+16|0;w[d+8>>2]=f;e=w[d+4>>2];b=w[a+4>>2];c=w[a>>2];c:{if((b|0)==(c|0)){b=c;break c}while(1){e=e-16|0;b=b-16|0;w[e>>2]=w[b>>2];w[e+12>>2]=w[b+12>>2];f=w[b+8>>2];w[e+4>>2]=w[b+4>>2];w[e+8>>2]=f;w[b+12>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[d+4>>2]-16|0;w[d+4>>2]=e;if((b|0)!=(c|0)){continue}break}f=w[d+8>>2];c=w[a+4>>2];b=w[a>>2]}w[a>>2]=e;w[d+4>>2]=b;w[a+4>>2]=f;w[d+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=c;a=w[d+8>>2];c=w[d+4>>2];if((a|0)!=(c|0)){while(1){b=a-16|0;w[d+8>>2]=b;if(u[a-1|0]<0){zb(w[a-12>>2]);a=w[d+8>>2]}else{a=b}if((c|0)!=(a|0)){continue}break}}a=w[d>>2];if(a){zb(a)}}jb=g+32|0;return}Mb(a);M()}function pV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;w[e+8>>2]=0;w[e>>2]=0;w[e+4>>2]=0;a:{b:{c:{if(c>>>0<=63){break c}w[114256]=0;c=V(917,b|0)|0;d=w[114256];w[114256]=0;d:{if((d|0)!=1){if((c|0)>0){break d}w[114256]=0;Q(5,a|0,17256)|0;a=w[114256];w[114256]=0;if((a|0)!=1){break b}}break a}d=w[b>>2];f=w[w[d>>2]+24>>2];w[114256]=0;d=V(f|0,d|0)|0;f=w[114256];w[114256]=0;if((f|0)!=1){f=w[b+8>>2];w[114256]=0;d=d-f|0;T(72,e|0,(c>>>0>d>>>0?d:c)|0);c=w[114256];w[114256]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{w[114256]=0;c=Q(241,b|0,e+15|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if(!c){break e}c=x[e+15|0];if(!c){break e}w[114256]=0;S(291,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=w[114256];w[114256]=0;if((c|0)!=1){continue}}break}break a}c=w[b+8>>2];d=w[b>>2];f=w[w[d>>2]+36>>2];w[114256]=0;c=S(f|0,d|0,c|0,4)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}g:{if(c){c=w[b+8>>2]+4|0;break g}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}}w[b+8>>2]=c;w[a+8>>2]=w[e+8>>2];b=w[e+4>>2];w[a>>2]=w[e>>2];w[a+4>>2]=b}jb=e+16|0;return}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}function Qv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=D(0);b=jb-32|0;jb=b;a:{c=w[a+20>>2];b:{if(!c){break b}d=w[c+4>>2];e=w[c+8>>2]-d|0;if(e>>>0<4){break b}c=Kb(24);w[c+4>>2]=0;w[c+8>>2]=0;w[c+20>>2]=e;w[c+16>>2]=d;w[c+12>>2]=75592;w[c>>2]=75552;w[114256]=0;w[b+16>>2]=0;w[b+20>>2]=0;w[b+12>>2]=c;w[b+8>>2]=c+12;c=Q(232,b+8|0,b+24|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}c:{if(w[b+24>>2]?c:0){break c}c=w[w[a>>2]+40>>2];w[114256]=0;c=V(c|0,a|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}d=w[a+20>>2];if((w[d+8>>2]-w[d+4>>2]|0)-4>>>0<c<<2>>>0){break c}e=w[w[a>>2]+168>>2];d=0;w[114256]=0;T(e|0,a|0,-1);e=w[114256];w[114256]=0;if((e|0)==1){break a}d:{if(c){while(1){w[114256]=0;e=Q(407,b+8|0,b+24|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break d}g=A[b+24>>2];f=w[w[a>>2]+44>>2];w[114256]=0;Aa(f|0,a|0,d|0,D(e?g:D(0)));e=w[114256];w[114256]=0;if((e|0)==1){break d}d=d+1|0;if((c|0)!=(d|0)){continue}break}}c=w[w[a>>2]+172>>2];w[114256]=0;X(c|0,a|0);a=w[114256];w[114256]=0;if((a|0)!=1){break c}break a}break a}a=w[b+12>>2];if(!a){break b}c=w[a+4>>2];w[a+4>>2]=c-1;if(c){break b}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=b+32|0;return}a=P()|0;Bb(b+8|0);R(a|0);M()}function nS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=0,q=0,r=D(0),s=D(0),t=0;o=w[a+56>>2];f=w[a+44>>2];if((0-(w[a+60>>2]-o>>11)|0)!=w[a+48>>2]-f>>11){q=o+2048|0;if(d){r=A[a+4212>>2];j=f+2048|0;p=w[a+4220>>2];s=D(D(1)/D(p>>>0));g=w[a+4224>>2];t=w[a+4216>>2];h=o;i=q;l=d;while(1){a:{if(g>>>0<p>>>0){e=p-g|0;k=e>>>0<l>>>0?e:l;b:{if(!(r<D(1))){e=0;if(!k){break b}while(1){A[h>>2]=A[f>>2];A[i>>2]=A[j>>2];i=i+4|0;j=j+4|0;h=h+4|0;f=f+4|0;e=e+1|0;if((k|0)!=(e|0)){continue}break}break b}e=g;m=k+e|0;if(e>>>0>=m>>>0){break b}while(1){n=D(s*D(e>>>0));A[h>>2]=n*A[f>>2];A[i>>2]=n*A[j>>2];i=i+4|0;j=j+4|0;h=h+4|0;f=f+4|0;e=e+1|0;if((m|0)!=(e|0)){continue}break}}g=k+g|0;break a}e=t-g|0;k=e>>>0<l>>>0?e:l;c:{d:{e:{if(!(r<D(1))){e=0;if(k){break e}break d}m=e-k|0;if(m>>>0>=e>>>0){break c}while(1){n=D(s*D(e>>>0));A[h>>2]=n*A[f>>2];A[i>>2]=n*A[j>>2];i=i+4|0;j=j+4|0;h=h+4|0;f=f+4|0;e=e-1|0;if(m>>>0<e>>>0){continue}break}break c}while(1){w[h>>2]=0;w[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((k|0)!=(e|0)){continue}break}}e=k<<2;j=e+j|0;f=e+f|0}g=k+g|0;g=g>>>0<t>>>0?g:0}w[a+4224>>2]=g;l=l-k|0;if(l){continue}break}}ye(a,b,c,o,q,d)}}function jD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=w[a>>2];e=(w[a+4>>2]-d|0)/6|0;if(e>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{f=b-e|0;g=w[a+8>>2];d=w[a+4>>2];c:{if(f>>>0<=(g-d|0)/6>>>0){b=a;if(f){a=C(f,6)+d|0;while(1){e=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[d|0]=e;u[d+1|0]=e>>>8;u[d+2|0]=e>>>16;u[d+3|0]=e>>>24;e=x[c+4|0]|x[c+5|0]<<8;u[d+4|0]=e;u[d+5|0]=e>>>8;d=d+6|0;if((a|0)!=(d|0)){continue}break}}else{a=d}w[b+4>>2]=a;break c}b=d;d=w[a>>2];e=(b-d|0)/6|0;b=e+f|0;if(b>>>0>=715827883){break b}d=(g-d|0)/6|0;g=d<<1;e=Np(h+8|0,d>>>0>=357913941?715827882:b>>>0<g>>>0?g:b,e,a+8|0);d=w[e+8>>2];f=d+C(f,6)|0;while(1){b=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;b=x[c+4|0]|x[c+5|0]<<8;u[d+4|0]=b;u[d+5|0]=b>>>8;d=d+6|0;if((f|0)!=(d|0)){continue}break}w[e+8>>2]=f;c=w[a+4>>2];d=w[a>>2];g=c-d|0;b=w[e+4>>2]+C((g|0)/-6|0,6)|0;w[e+4>>2]=b;if((g|0)>0){Fb(b,d,g);c=w[a+4>>2];d=w[a>>2];f=w[e+8>>2];b=w[e+4>>2]}w[a>>2]=b;w[e+4>>2]=d;w[a+4>>2]=f;w[e+8>>2]=c;b=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=d;w[e+12>>2]=b;Vk(e)}jb=h+32|0;break a}Mb(a);M()}return}if(b>>>0<e>>>0){w[a+4>>2]=d+C(b,6)}}function lT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=D(0);d=jb-32|0;jb=d;a:{b=w[a+20>>2];b:{if(!b){break b}w[b+148>>2]=-1;b=ob[w[w[a>>2]+40>>2]](a)|0;f=(b|0)>=1073741822?1073741822:b;c=f<<2;if(!c){break b}e=w[a+20>>2];w[114256]=0;T(279,e+4|0,c+4|0);c=w[114256];w[114256]=0;c:{if((c|0)!=1){c=w[a+20>>2];e=w[c+4>>2];c=w[c+8>>2];w[114256]=0;w[d+8>>2]=0;w[d+12>>2]=0;w[d>>2]=e;w[d+4>>2]=c;w[d+16>>2]=0;c=d+16|0;w[d+28>>2]=c|4;w[d+24>>2]=c;Q(1077,d|0,d+24|0)|0;c=w[114256];w[114256]=0;d:{e:{if((c|0)==1){break e}c=w[w[a>>2]+176>>2];w[114256]=0;T(c|0,a|0,-1);c=w[114256];w[114256]=0;if((c|0)==1){break e}if((b|0)>0){f=(f|0)<=1?1:f;c=d+16|4;b=0;while(1){e=w[w[a>>2]+48>>2];w[114256]=0;g=D(qa(e|0,a|0,b|0));e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;A[d+16>>2]=g;w[d+28>>2]=c;w[d+24>>2]=d+16;Q(1077,d|0,d+24|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}b=b+1|0;if((f|0)!=(b|0)){continue}break}}b=w[w[a>>2]+180>>2];w[114256]=0;X(b|0,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}b=W(74720)|0;break c}b=W(74720)|0;break c}b=W(74720)|0}if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;a=w[a+20>>2];w[a+8>>2]=w[a+4>>2];aa()}jb=d+32|0;return}R(b|0);M()}function DU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=w[a+4>>2];f=w[a>>2];e=(d-f|0)/52|0;if(e>>>0<b>>>0){i=jb-32|0;jb=i;a:{f=b-e|0;g=w[a+8>>2];d=w[a+4>>2];b:{if(f>>>0<=(g-d|0)/52>>>0){c:{if(f){b=C(f,52)+d|0;while(1){w[114256]=0;f=Q(952,d|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break c}d=f+52|0;if((b|0)!=(d|0)){continue}break}}else{b=d}w[a+4>>2]=b;break a}c=P()|0;w[a+4>>2]=d;break b}d:{e:{h=w[a>>2];j=(d-h|0)/52|0;e=j+f|0;if(e>>>0<82595525){d=0;b=i+8|0;w[b+12>>2]=0;w[b+16>>2]=a+8;f:{g:{g=(g-h|0)/52|0;h=g<<1;e=g>>>0>=41297762?82595524:e>>>0<h>>>0?h:e;if(e){if(e>>>0>=82595525){break g}d=Kb(C(e,52))}w[b>>2]=d;g=C(j,52)+d|0;w[b+8>>2]=g;w[b+12>>2]=C(e,52)+d;w[b+4>>2]=g;break f}vd();M()}d=w[b+8>>2];e=d+C(f,52)|0;while(1){w[114256]=0;f=Q(952,d|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}d=f+52|0;if((e|0)!=(d|0)){continue}break}w[b+8>>2]=e;w[114256]=0;T(956,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){fw(b);break a}c=P()|0;break d}Mb(a);M()}c=P()|0;w[b+8>>2]=d}fw(b)}R(c|0);M()}jb=i+32|0;return}if(b>>>0<e>>>0){b=f+C(b,52)|0;if((b|0)!=(d|0)){while(1){d=d-52|0;Cf(d);if((b|0)!=(d|0)){continue}break}}w[a+4>>2]=b}}function Xe(a,b,c,d){var e=0,f=0;w[d+8>>2]=b;w[d>>2]=0;w[d+4>>2]=0;w[c>>2]=d;b=w[w[a>>2]>>2];if(b){w[a>>2]=b;d=w[c>>2]}f=w[a+4>>2];b=(f|0)==(d|0);u[d+12|0]=b;a:{if(b){break a}while(1){b=w[d+8>>2];if(x[b+12|0]){break a}b:{c=w[b+8>>2];e=w[c>>2];if((e|0)==(b|0)){e=w[c+4>>2];if(!(!e|x[e+12|0])){break b}c:{if(w[b>>2]==(d|0)){d=b;break c}d=w[b+4>>2];e=w[d>>2];w[b+4>>2]=e;if(e){w[e+8>>2]=b;c=w[b+8>>2]}w[d+8>>2]=c;c=w[b+8>>2];w[((w[c>>2]!=(b|0))<<2)+c>>2]=d;w[d>>2]=b;w[b+8>>2]=d;c=w[d+8>>2];b=w[c>>2]}u[d+12|0]=1;u[c+12|0]=0;d=w[b+4>>2];w[c>>2]=d;if(d){w[d+8>>2]=c}w[b+8>>2]=w[c+8>>2];d=w[c+8>>2];w[((w[d>>2]!=(c|0))<<2)+d>>2]=b;w[b+4>>2]=c;w[c+8>>2]=b;break a}if(!(x[e+12|0]|!e)){break b}d:{if(w[b>>2]!=(d|0)){d=b;break d}e=w[d+4>>2];w[b>>2]=e;if(e){w[e+8>>2]=b;c=w[b+8>>2]}w[d+8>>2]=c;c=w[b+8>>2];w[((w[c>>2]!=(b|0))<<2)+c>>2]=d;w[d+4>>2]=b;w[b+8>>2]=d;c=w[d+8>>2]}u[d+12|0]=1;u[c+12|0]=0;b=w[c+4>>2];d=w[b>>2];w[c+4>>2]=d;if(d){w[d+8>>2]=c}w[b+8>>2]=w[c+8>>2];d=w[c+8>>2];w[((w[d>>2]!=(c|0))<<2)+d>>2]=b;w[b>>2]=c;w[c+8>>2]=b;break a}u[b+12|0]=1;u[c+12|0]=(c|0)==(f|0);u[e+12|0]=1;d=c;if((f|0)!=(d|0)){continue}break}}w[a+8>>2]=w[a+8>>2]+1}function qC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if((c|0)!=4){f=b+236|0;g=b+108|0;while(1){e=(d<<2)+a|0;u[d+g|0]=x[e+4|0]+1;v[f+(d<<1)>>1]=(x[e+6|0]|x[e+7|0]<<8)+1;d=d+1|0;if((d|0)!=120){continue}break}break a}e=b+236|0;while(1){f=(d<<2)+a|0;v[(e+(d<<1)|0)+24>>1]=(x[f+6|0]|x[f+7|0]<<8)+1;d=d+1|0;if((d|0)!=96){continue}break}}Sk(a+484|0,b+48|0,0);Sk(a+590|0,b+68|0,0);Sk(a+696|0,b+88|0,5);w[b>>2]=x[a+806|0]|x[a+807|0]<<8;d=u[a+808|0];b:{if((d|0)<0){u[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(u[a|0]&1){u[b+31|0]=d+1;break b}if(!d){break b}u[b+31|0]=d+1}if(x[b+31|0]){c:{d:{if((c|0)==4){d=x[a+810|0];break d}d=u[a+809|0];if((d|0)>=0){v[b+28>>1]=(d&255)+1}d=u[a+810|0];if((d|0)<0){break c}}u[b+30|0]=d+1}u[b+33|0]=x[a+811|0]}if((c|0)==32){c=x[a+812|0];w[b+4>>2]=(c>>>0>=128?128:c)>>>1}c=x[a+813|0]|x[a+814|0]<<8;if(c>>>0<=256){w[b+8>>2]=c;u[b+15|0]=x[b+15|0]|1}u[b+16|0]=x[a+815|0];u[b+26|0]=x[a+816|0];u[b+27|0]=x[a+817|0];u[b+17|0]=x[a+818|0];u[b+18|0]=x[a+819|0];c=x[a+820|0]|x[a+821|0]<<8;u[b+20|0]=c>>>0>=100?100:c;c=x[a+822|0]|x[a+823|0]<<8;u[b+19|0]=(c>>>0>=256?256:c)>>>2;u[b+21|0]=x[a+824|0];u[b+22|0]=x[a+825|0]}function vC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;a:{if(!c){break a}i=w[a+8>>2];h=w[a+4>>2];if(i-h>>>0>=c>>>0){i=c;g=h;j=g-b|0;if(j>>>0<c>>>0){g=h+(c-j|0)|0;e=h;while(1){u[e|0]=x[d|0];e=e+1|0;if((g|0)!=(e|0)){continue}break}w[a+4>>2]=g;if(!j){break a}i=j}e=g;j=e-c|0;if(h>>>0>j>>>0){while(1){u[e|0]=x[j|0];e=e+1|0;j=j+1|0;if((h|0)!=(j|0)){continue}break}}w[a+4>>2]=e;h=b+c|0;if((h|0)!=(g|0)){e=g-h|0;hc(g-e|0,b,e);e=w[a+4>>2]}a=(b>>>0<=d>>>0?d>>>0<e>>>0?c:0:0)+d|0;e=b;while(1){u[e|0]=x[a|0];e=e+1|0;i=i-1|0;if(i){continue}break}break a}e=w[a>>2];g=(h-e|0)+c|0;if((g|0)>=0){h=b-e|0;w[f+24>>2]=a+8;e=i-e|0;i=e<<1;g=e>>>0>=1073741823?2147483647:g>>>0<i>>>0?i:g;if(g){e=Kb(g)}else{e=0}w[f+8>>2]=e;w[f+20>>2]=e+g;e=e+h|0;w[f+12>>2]=e;c=c+e|0;while(1){u[e|0]=x[d|0];e=e+1|0;if((c|0)!=(e|0)){continue}break}w[114256]=0;w[f+16>>2]=c;b=S(492,a|0,f+8|0,b|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=w[f+12>>2];if((a|0)!=w[f+16>>2]){w[f+16>>2]=a}a=w[f+8>>2];if(!a){break a}zb(a);break a}a=P()|0;b=w[f+12>>2];if((b|0)!=w[f+16>>2]){w[f+16>>2]=b}b=w[f+8>>2];if(b){zb(b)}R(a|0);M()}Mb(a);M()}jb=f+32|0;return b|0}function oH(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!x[i|0]){break a}i=i+1|0;continue}break}w[h>>2]=f;w[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=w[b+4>>2];w[j+8>>2]=w[b>>2];w[j+12>>2]=l;k=jb-16|0;jb=k;w[k+12>>2]=w[a+8>>2];m=be(k+8|0,k+12|0);w[114256]=0;l=zs(f,e,i-c|0,g-f>>2,b);n=w[114256];w[114256]=0;e:{if((n|0)!=1){Lc(m);jb=k+16|0;break e}a=P()|0;Lc(m);R(a|0);M()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{w[h>>2]=f;if(w[e>>2]==(c|0)){break j}g=1;k:{l:{m:{b=sr(f,c,i-c|0,j+8|0,w[a+8>>2]);switch(b+2|0){case 2:break k;case 1:break m;case 0:break g;default:break l}}w[e>>2]=c;break i}g=b}c=c+g|0;f=w[h>>2]+4|0;continue}break}w[e>>2]=c;break d}f=w[h>>2]+(l<<2)|0;w[h>>2]=f;if((f|0)==(g|0)){break f}c=w[e>>2];if((d|0)==(i|0)){i=d;continue}if(!sr(f,c,1,b,w[a+8>>2])){break h}}a=2;break c}w[h>>2]=w[h>>2]+4;c=w[e>>2]+1|0;w[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!x[i|0]){break b}i=i+1|0;continue}}w[e>>2]=c;a=1;break c}c=w[e>>2]}a=(c|0)!=(d|0)}jb=j+16|0;return a|0}f=w[h>>2];continue}}function ik(a,b){a=a|0;b=b|0;var c=0,d=D(0),e=D(0),f=D(0),g=0;w[a+1074372>>2]=b;c=a+1074332|0;a:{b:{c:{switch(b|0){case 0:v[c+36>>1]=256;w[c>>2]=830472192;w[c+4>>2]=1300234240;w[c+8>>2]=1065353216;break b;case 1:v[c+36>>1]=256;w[c>>2]=805306368;w[c+4>>2]=1325400064;w[c+8>>2]=1107296256;break b;case 2:v[c+36>>1]=257;w[c>>2]=838860800;w[c+4>>2]=1291845632;w[c+8>>2]=1073741824;break b;default:v[c+36>>1]=1;w[c>>2]=838860800;w[c+4>>2]=1291845632;w[c+8>>2]=1065353216;u[c+38|0]=1;w[c+32>>2]=1;d=D(256);e=D(128);f=D(128);b=0;break a;case 4:case 5:break c}}v[c+36>>1]=1;w[c>>2]=838860800;w[c+4>>2]=1291845632;w[c+8>>2]=1061158912;u[c+38|0]=1;b=(b|0)==4;w[c+32>>2]=b?2:3;d=D(256);e=b?D(256):D(192);f=e;b=1;break a}u[c+38|0]=0;w[c+32>>2]=0;d=D(128);f=D(100);e=D(256);b=4}w[c+28>>2]=b;A[c+24>>2]=d;A[c+20>>2]=f;A[c+16>>2]=e;g=a+946300|0;a=a+906300|0;while(1){b=w[a>>2];if(b){d=D(1);c=w[b+20>>2];if(c){d=D(D(x[c+26|0])*D(.10000000149011612))}d=d<D(.10000000149011612)?D(1):d;if(ob[w[w[b>>2]+132>>2]](b)|0){c=w[b+16>>2];d=D(D(d*D(z[c+480232>>2]))/D(A[c+1074352>>2]*A[c+1074340>>2]))}A[b+4196>>2]=d}a=a+160|0;if((g|0)!=(a|0)){continue}break}}function aE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-2608|0;jb=d;w[d+8>>2]=w[a>>2];e=w[a+4>>2];w[d+12>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=w[a+12>>2];w[d+16>>2]=w[a+8>>2];w[d+20>>2]=e;Cb(d+24|0,0,2584);w[114256]=0;X(311,d+8|0);a=w[114256];w[114256]=0;a:{b:{if((a|0)!=1){if(!c|v[d+1074>>1]<0|v[d+1072>>1]<0){break a}a=0;e=0;c:{while(1){w[114256]=0;i=Q(131,d+8|0,1)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}f=0;d:{while(1){w[114256]=0;g=Q(131,d+8|0,1)|0;j=w[114256];w[114256]=0;if((j|0)==1){break d}f=v[((d+8|0)+C(f,6)|0)+(g?1066:1064)>>1];e:{if((f|0)>255){break e}g=(d+8|0)+C(f,6)|0;e=x[g+1068|0];if(v[g+1064>>1]<0){break e}if(v[g+1066>>1]>=0){continue}}break}e=(i?-1:0)^e;h=(h&255)+(e&255)|0;u[a+b|0]=h;a=a+1|0;if((c|0)!=(a|0)){continue}break a}break}a=W(75512)|0;break b}a=W(75512)|0;break b}a=W(75512)|0}if((kb|0)==(fa(75512)|0)){$(a|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0}Bb(d+8|0);R(a|0);M()}b=w[d+24>>2];c=w[d+28>>2];e=w[d+16>>2];a=w[d+12>>2];f:{if(!a){break f}f=w[a+4>>2];w[a+4>>2]=f-1;if(f){break f}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+2608|0;return b+(e-c|0)|0}function TF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(wd(a,w[b+8>>2],e)){pl(b,c,d);return}a:{if(wd(a,w[b>>2],e)){if(!(w[b+16>>2]!=(c|0)&w[b+20>>2]!=(c|0))){if((d|0)!=1){break a}w[b+32>>2]=1;return}w[b+32>>2]=d;if(w[b+44>>2]!=4){f=a+16|0;h=f+(w[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}v[b+52>>1]=0;ol(f,b,c,c,1,e);if(x[b+54|0]){break d}e:{if(!x[b+53|0]){break e}if(x[b+52|0]){d=1;if(w[b+24>>2]==1){break c}g=1;if(x[a+8|0]&2){break e}break c}g=1;if(!(u[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}w[b+44>>2]=a;if(d&1){break a}}w[b+20>>2]=c;w[b+40>>2]=w[b+40>>2]+1;if(w[b+36>>2]!=1|w[b+24>>2]!=2){break a}u[b+54|0]=1;return}g=w[a+12>>2];h=a+16|0;Si(h,b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=w[a+8>>2];if(!(!(a&2)&w[b+36>>2]!=1)){while(1){if(x[b+54|0]){break a}Si(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(x[b+54|0]|w[b+36>>2]==1){break a}Si(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(x[b+54|0]|w[b+36>>2]==1&w[b+24>>2]==1){break a}Si(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Qz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0;b=w[a+48>>2];m=w[a>>2];h=w[a+4>>2];k=w[a+40>>2];l=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=k>>12;i=l>>12;break a}n=w[a+8>>2];p=w[a+12>>2];q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];e=w[a+68>>2];v=e;x=e>>31;e=w[a+64>>2];y=e;z=e>>31;e=w[a+60>>2];A=e;B=e>>31;e=b;while(1){g=w[c>>2];b=f;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;f=BV(y,z,f,f>>31);i=nb;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;j=BV(v,x,e,e>>31);f=j+f|0;e=nb+i|0;e=f>>>0<j>>>0?e+1|0:e;j=f;o=h+q|0;f=u[o|0];D=g;i=j;j=((C(u[o+1|0]-f|0,m>>>10&4194048)|0)/16384|0)+(f<<8)<<8;f=j;g=BV(f,f>>31,A,B);f=i+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;l=l+s|0;i=l>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=D+C(i,f);k=k+r|0;g=k>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(j&t)|0;h=h+p|0;e=m+n|0;h=e>>>0<n>>>0?h+1|0:h;m=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=m;w[a+4>>2]=h;w[a+40>>2]=k;w[a+20>>2]=i;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function Oz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;b=w[a+48>>2];m=w[a>>2];h=w[a+4>>2];k=w[a+40>>2];l=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=k>>12;i=l>>12;break a}n=w[a+8>>2];p=w[a+12>>2];q=w[a+16>>2];r=w[a+32>>2];s=w[a+28>>2];t=w[a+72>>2];e=w[a+68>>2];u=e;x=e>>31;e=w[a+64>>2];y=e;z=e>>31;e=w[a+60>>2];A=e;B=e>>31;e=b;while(1){g=w[c>>2];b=f;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;f=BV(y,z,f,f>>31);i=nb;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;j=BV(u,x,e,e>>31);f=j+f|0;e=nb+i|0;e=f>>>0<j>>>0?e+1|0:e;j=f;o=(h<<1)+q|0;f=v[o>>1];D=g;i=j;j=f+((C(v[o+2>>1]-f|0,m>>>18|0)|0)/16384|0)<<8;f=j;g=BV(f,f>>31,A,B);f=i+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;l=l+s|0;i=l>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=D+C(i,f);k=k+r|0;g=k>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(j&t)|0;h=h+p|0;e=m+n|0;h=e>>>0<n>>>0?h+1|0:h;m=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=l;w[a>>2]=m;w[a+4>>2]=h;w[a+40>>2]=k;w[a+20>>2]=i;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function Sw(a){a=a|0;var b=0,c=0,d=0,e=0;c=a+1304360|0;b=a+1074984|0;while(1){w[b+104>>2]=0;w[b+656>>2]=0;w[b+76>>2]=0;w[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}b=a+484344|0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){while(1){c=c-52|0;Cf(c);if((c|0)!=(d|0)){continue}break}}w[b+4>>2]=d;a:{if(u[a+1304411|0]<0){u[w[a+1304400>>2]]=0;w[a+1304404>>2]=0;break a}u[a+1304411|0]=0;u[a+1304400|0]=0}b:{if(u[a+1304423|0]<0){u[w[a+1304412>>2]]=0;w[a+1304416>>2]=0;break b}u[a+1304423|0]=0;u[a+1304412|0]=0}c:{if(u[a+1304435|0]<0){u[w[a+1304424>>2]]=0;w[a+1304428>>2]=0;break c}u[a+1304435|0]=0;u[a+1304424|0]=0}w[a+1304504>>2]=w[a+1304500>>2];b=a+900380|0;c=a+484380|0;while(1){zi(c);c=c+104|0;if((c|0)!=(b|0)){continue}break}e=a+901404|0;while(1){c=w[b>>2];if(c){d=w[c+88>>2];if(d){w[c+92>>2]=d;zb(d)}d=w[c+68>>2];if(d){w[c+72>>2]=d;zb(d)}d=w[c+48>>2];if(d){w[c+52>>2]=d;zb(d)}zb(c)}w[b>>2]=0;b=b+4|0;if((e|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){Pv(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}w[a+480180>>2]=0;w[a+480184>>2]=0;a=a+480186|0;v[a>>1]=0;v[a+2>>1]=0;v[a+4>>1]=0;v[a+6>>1]=0;return 1}function UD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;lc(b,32);e=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);w[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=x[a+10|0]|x[a+11|0]<<8|(x[a+12|0]<<16|x[a+13|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);w[b+4>>2]=e;f=e;e=x[a+14|0]|x[a+15|0]<<8|(x[a+16|0]<<16|x[a+17|0]<<24);w[b+8>>2]=f+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));a:{if(!(!c|d)){w[b+24>>2]=c;c=x[a+8|0]<<28>>24;break a}c=x[a+46|0]|x[a+47|0]<<8|(x[a+48|0]<<16|x[a+49|0]<<24);w[b+24>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);c=x[a+8|0]<<28>>24;if((d|0)!=841887798){break a}d=x[a+42|0]|x[a+43|0]<<8;d=d<<8|d>>>8;e=d&65535;if(!e|(e|0)==48){break a}c=(c-((d&65535)<<7)|0)+6144|0}yi(b,+(c|0)*.0006510416666666666);c=x[a+9|0];v[b+30>>1]=(c>>>0>=64?64:c)<<2;if(u[a+40|0]&1){v[b+34>>1]=y[b+34>>1]|64;w[b>>2]=w[b>>2]>>>1;w[b+4>>2]=w[b+4>>2]>>>1;w[b+8>>2]=w[b+8>>2]>>>1}b:{if(x[a+41|0]<=8){a=w[b+4>>2];c=w[b+8>>2];break b}v[b+34>>1]=y[b+34>>1]|1;w[b>>2]=w[b>>2]>>>1;a=w[b+4>>2]>>>1|0;w[b+4>>2]=a;c=w[b+8>>2]>>>1|0;w[b+8>>2]=c}if(a+1>>>0<c>>>0){v[b+34>>1]=y[b+34>>1]|2;return}w[b+4>>2]=0;w[b+8>>2]=0}function Oy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0;s=w[a+16>>2];t=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);l=w[a+128>>2];a:{if(!l){m=w[a+8>>2];n=w[a+12>>2];j=w[a>>2];g=w[a+4>>2];o=0;break a}g=w[a+4>>2];e=w[a+76>>2];j=w[a>>2];m=w[a+8>>2];n=w[a+12>>2];i=BV(m,n,d,0);f=j+i|0;b=nb+g|0;q=e>>>0<(f>>>0<i>>>0?b+1|0:b)>>>0?d:0;i=CV(m,n,l,l>>31);o=nb}if(d){h=a+112|0;v=w[a+24>>2];x=w[a+20>>2];y=(l|0)>0;while(1){q=q-1|0;b=q;i=b?i:0;o=b?o:0;f=0;k=j;p=(((g&2147483647)<<1|k>>>31)&-2)+s|0;b=l;if(y){while(1){e=(f&2147483647)<<1|k>>>31;Ee(h,u[(e|1)+p|0]+u[(e&-2)+p|0]<<5);De(h,4);f=f+o|0;k=i+k|0;f=k>>>0<i>>>0?f+1|0:f;e=b>>>0>1;b=b-1|0;if(e){continue}break}}d=d-1|0;r=w[a+120>>2];b=r+w[a+112>>2]|0;e=w[a+116>>2]+w[a+124>>2]|0;e=b>>>0<r>>>0?e+1|0:e;w[a+112>>2]=b;w[a+116>>2]=e;b=e;if(b){f=(f&2147483647)<<1|k>>>31;Ee(h,u[(f|1)+p|0]+u[(f&-2)+p|0]<<5);De(h,b);w[h>>2]=w[h>>2];w[h+4>>2]=0}b=ih(h,t);w[c>>2]=w[c>>2]+C(b,x);w[c+4>>2]=w[c+4>>2]+C(b,v);g=g+n|0;b=j+m|0;g=b>>>0<m>>>0?g+1|0:g;j=b;c=c+8|0;if(d){continue}break}}w[a>>2]=j;w[a+4>>2]=g}function VL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;w[114256]=0;Q(14,c+24|0,a|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)!=1){d:{if(!x[c+24|0]){break d}d=w[w[a>>2]-12>>2];h=w[(d+a|0)+4>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;e:{f:{g:{if((d|0)!=1){w[114256]=0;d=V(1579,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}Ab(c+16|0);e=Vd(c+8|0,a);f=w[w[a>>2]-12>>2];w[114256]=0;f=a+f|0;i=V(1580,f|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break f}e=w[e>>2];w[114256]=0;g=d;d=b&65535;j=b;b=h&74;b=da(1581,g|0,e|0,f|0,i|0,((b|0)==64?d:(b|0)==8?d:j)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}w[c+16>>2]=b;if(!qf(c+16|0)){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,5);b=w[114256];w[114256]=0;if((b|0)!=1){break d}b=W(0)|0;break e}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0);break e}b=W(0)|0}id(c+24|0);break c}id(c+24|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+32|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function sz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0;k=jb-16|0;a:{b:{c:{f=w[a+12>>2];i=w[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}j=w[a>>2];h=w[a+4>>2];if(d){n=w[a+16>>2];o=w[a+24>>2];p=w[a+20>>2];while(1){g=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+n|0;b=(j>>>16&65520)+l|0;q=v[b+14>>1];r=v[b+12>>1];s=v[b+10>>1];t=v[b+8>>1];u=v[b+6>>1];x=v[b+4>>1];y=v[b+2>>1];z=v[b>>1];m=0;b=1;while(1){e=m<<1;w[(k+8|0)+(m<<2)>>2]=(((((((C(v[(e|-8)+g>>1],y)+C(v[(e|-12)+g>>1],z)|0)+C(v[(e|-4)+g>>1],x)|0)+C(v[e+g>>1],u)|0)+C(v[(e|4)+g>>1],t)|0)+C(v[(e|8)+g>>1],s)|0)+C(v[(e|12)+g>>1],r)|0)+C(v[(e|16)+g>>1],q)|0)/32768;e=b;b=0;m=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[k+8>>2],p);w[c+4>>2]=w[c+4>>2]+C(w[k+12>>2],o);h=f+h|0;b=i+j|0;h=b>>>0<i>>>0?h+1|0:h;j=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=j;w[a+4>>2]=h}function cg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;w[a+4>>2]=0;Oe(e+8|0,a,1);if(x[e+8|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+24>>2];d=w[114256];w[114256]=0;if((d|0)==1){break c}w[114256]=0;b=V(1572,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(Kc(b,-1)){break b}w[a+4>>2]=w[a+4>>2]+1;if(!Kc(b,c)){continue}break}d=0;break a}if(w[a+4>>2]>=(b|0)){break a}while(1){d:{d=w[w[a>>2]-12>>2];w[114256]=0;d=w[(a+d|0)+24>>2];f=w[114256];w[114256]=0;if((f|0)==1){break d}w[114256]=0;f=V(1572,d|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}if(Kc(f,-1)){break b}w[a+4>>2]=w[a+4>>2]+1;d=0;if(Kc(f,c)){break a}if(w[a+4>>2]<(b|0)){continue}break a}break}}$(W(0)|0)|0;Me(w[w[a>>2]-12>>2]+a|0,1);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];c=w[114256];w[114256]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break e}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break f}R(a|0);M()}aa();d=1;break a}W(0)|0;Eb()}M()}d=2}Kd(w[w[a>>2]-12>>2]+a|0,d)}jb=e+16|0;return a|0}function Fb(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){ab(a|0,b|0,c|0);return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){u[c|0]=x[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){w[c>>2]=w[b>>2];w[c+4>>2]=w[b+4>>2];w[c+8>>2]=w[b+8>>2];w[c+12>>2]=w[b+12>>2];w[c+16>>2]=w[b+16>>2];w[c+20>>2]=w[b+20>>2];w[c+24>>2]=w[b+24>>2];w[c+28>>2]=w[b+28>>2];w[c+32>>2]=w[b+32>>2];w[c+36>>2]=w[b+36>>2];w[c+40>>2]=w[b+40>>2];w[c+44>>2]=w[b+44>>2];w[c+48>>2]=w[b+48>>2];w[c+52>>2]=w[b+52>>2];w[c+56>>2]=w[b+56>>2];w[c+60>>2]=w[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){w[c>>2]=w[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){u[c|0]=x[b|0];u[c+1|0]=x[b+1|0];u[c+2|0]=x[b+2|0];u[c+3|0]=x[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){u[c|0]=x[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function $g(a){var b=0,c=0,d=0,e=0;d=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=w[a+480180>>2];if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break e;case 7:break h;case 0:case 1:case 3:break i;default:break f}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break a}break e}if((b|0)==256|(b|0)==512){break a}break e}if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break a}if((b|0)!=8192){break e}break a}if((b|0)==65536){break d}if((b|0)!=2097152){break e}break c}if((b|0)<=67108863){if((b|0)==4194304){break g}d=b;if((b|0)!=16777216){break e}break c}if((b|0)==67108864|(b|0)==134217728){break c}if((b|0)!=536870912){break e}break c}return b}if(y[a+480192>>1]){break b}c=w[a+484344>>2];a=w[a+484348>>2];if((c|0)==(a|0)){break c}while(1){if(w[c>>2]!=w[c+4>>2]&w[c+12>>2]!=64){break b}c=c+52|0;if((a|0)!=(c|0)){continue}break}break c}d=32;e=y[a+480188>>1];if(e>>>0>16){break c}if(!e){break a}while(1){b=(c<<5)+a|0;if(u[b+480281|0]&1|y[b+480286>>1]!=64){break c}c=c+1|0;if((e|0)!=(c|0)){continue}break}break a}if((b|0)==16){break a}}return 32}d=16777216}return d}return 4}return 2}function _u(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;w[a+32>>2]=0;w[a+36>>2]=0;w[a+24>>2]=0;w[a+4>>2]=0;w[a>>2]=d;w[a+68>>2]=0;w[a+72>>2]=0;w[a+56>>2]=3;w[a+40>>2]=0;w[a+44>>2]=0;w[a+76>>2]=0;w[114256]=0;T(1461,a|0,e|0);d=w[114256];w[114256]=0;g=a+24|0;a:{b:{c:{d:{e:{if((d|0)==1){break e}w[114256]=0;d=V(22,24)|0;h=w[114256];w[114256]=0;if((h|0)==1){break d}w[d+4>>2]=0;w[d+8>>2]=0;w[d+20>>2]=c;w[d+16>>2]=b;w[d+12>>2]=75592;w[d>>2]=75552;w[114256]=0;w[f+8>>2]=0;w[f+12>>2]=0;w[f+4>>2]=d;w[f>>2]=d+12;U(1462,a|0,f|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[d+4>>2];w[d+4>>2]=b-1;if(!b){ob[w[w[d>>2]+8>>2]](d);Ib(d)}w[114256]=0;U(1349,a|0,2,100);b=w[114256];w[114256]=0;if((b|0)==1){break e}b=w[g>>2];w[114256]=0;T(264,b+484360|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}e=P()|0;break b}e=P()|0;break b}e=P()|0;Bb(f)}bc(a+68|0);b=w[a+36>>2];if(b){w[a+40>>2]=b;zb(b)}b=w[a+32>>2];w[a+32>>2]=0;if(b){zb(b)}Tj(g,0);b=w[a+4>>2];w[a+4>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}b=w[a>>2];w[a>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}R(e|0);M()}jb=f+16|0;return a|0}function MC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=w[a>>2];d=(w[a+4>>2]-c|0)/33|0;if(d>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{d=b-d|0;e=w[a+8>>2];c=w[a+4>>2];c:{if(d>>>0<=(e-c|0)/33>>>0){if(d){b=C(d,33)-33|0;b=(b-((b>>>0)%33|0)|0)+33|0;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break c}f=w[a>>2];i=(c-f|0)/33|0;c=i+d|0;if(c>>>0>=130150525){break b}b=h+8|0;w[b+12>>2]=0;w[b+16>>2]=a+8;d:{e:{e=(e-f|0)/33|0;f=e<<1;c=e>>>0>=65075262?130150524:c>>>0<f>>>0?f:c;if(c){if(c>>>0>=130150525){break e}g=Kb(C(c,33))}w[b>>2]=g;e=C(i,33)+g|0;w[b+8>>2]=e;w[b+12>>2]=C(c,33)+g;w[b+4>>2]=e;break d}vd();M()}c=C(d,33)-33|0;c=(c-((c>>>0)%33|0)|0)+33|0;g=Cb(w[b+8>>2],0,c)+c|0;w[b+8>>2]=g;e=w[a+4>>2];c=w[a>>2];f=e-c|0;d=w[b+4>>2]+C((f|0)/-33|0,33)|0;w[b+4>>2]=d;if((f|0)>0){Fb(d,c,f);g=w[b+8>>2];e=w[a+4>>2];d=w[b+4>>2];c=w[a>>2]}w[a>>2]=d;w[b+4>>2]=c;w[a+4>>2]=g;w[b+8>>2]=e;g=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=g;a=w[b+8>>2];c=w[b+4>>2];if((a|0)!=(c|0)){c=(a-c|0)-33|0;w[b+8>>2]=(a+(((c>>>0)%33|0)-c|0)|0)-33}a=w[b>>2];if(a){zb(a)}}jb=h+32|0;break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=c+C(b,33)}}function Rx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;j=jb-32|0;jb=j;a:{e=d-c|0;if((e|0)<=0){break a}i=e>>1;h=w[a+8>>2];g=w[a+4>>2];if((i|0)<=h-g>>1){f=g-b|0;h=f>>1;b:{if((h|0)>=(i|0)){e=g;h=d;break b}e=g;h=(h<<1)+c|0;d=d-h|0;if((d|0)>0){e=Fb(g,h,d)+d|0}w[a+4>>2]=e;if((f|0)<=0){break a}}d=i<<1;i=d+b|0;f=e;d=e-d|0;if(g>>>0>d>>>0){while(1){v[f>>1]=y[d>>1];f=f+2|0;d=d+2|0;if(g>>>0>d>>>0){continue}break}}w[a+4>>2]=f;if((e|0)!=(i|0)){a=e-i|0;hc(e-(a&-2)|0,b,a)}if((c|0)==(h|0)){break a}hc(b,c,h-c|0);break a}e=w[a>>2];f=i+(g-e>>1)|0;if((f|0)>=0){g=h-e|0;e=Vf(j+8|0,g>>>0>=2147483646?2147483647:f>>>0<g>>>0?g:f,b-e>>1,a+8|0);f=w[e+8>>2];if((c|0)!=(d|0)){d=(i<<1)+f|0;while(1){v[f>>1]=y[c>>1];c=c+2|0;f=f+2|0;if((d|0)!=(f|0)){continue}break}f=d}w[e+8>>2]=f;w[114256]=0;b=S(740,a|0,e|0,b|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=w[e+8>>2];c=w[e+4>>2];if((a|0)!=(c|0)){w[e+8>>2]=a+((c-a|0)+1&-2)}a=w[e>>2];if(!a){break a}zb(a);break a}b=P()|0;a=w[e+8>>2];c=w[e+4>>2];if((a|0)!=(c|0)){w[e+8>>2]=a+((c-a|0)+1&-2)}a=w[e>>2];if(a){zb(a)}R(b|0);M()}Mb(a);M()}jb=j+32|0;return b|0}function Rn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=C(b,896)+a|0;a:{if(c){if(!(x[a+1074323|0]&4)){u[(C(b,896)+a|0)+1075815|0]=c}u[(C(b,896)+a|0)+1075816|0]=c;break a}c=x[e+1075816|0]}g=e+1074984|0;f=c&255;h=!(w[a+480180>>2]&204473357)&(d^-1);Mn(a,b,0-f|0,h);e=w[a+480180>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}i=w[(C(b,896)+a|0)+1075640>>2];if(!i|!w[i+44>>2]){break c}c=c&255;if(!(c>>>0<240|d)){Ln(a,g,240-f|0);return}if(!(c>>>0<224|d)){a=C(b,896)+a|0;b=a+1075856|0;c=x[b|0];if(!(c&1)){break b}a=a+1075860|0;w[a>>2]=(w[a>>2]-f|0)+224;u[b|0]=c|16;return}a=C(b,896)+a|0;b=a+1075860|0;w[b>>2]=w[b>>2]-f;a=a+1075856|0;u[a|0]=x[a|0]|16;return}w[(C(b,896)+a|0)+1075692>>2]=65535}d:{if(!((c&255)>>>0>223&h)){break d}e:{d=f&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}In(a,g,d);return}if((e|0)==524288){break d}On(a,g,d);return}if((e|0)!=524288){break b}}f:{if(!(u[(C(b,896)+a|0)+1075856|0]&1)){break f}g:{if(w[a+1074416>>2]==1){if(!(w[a+1074312>>2]&64|e&32832)){break g}break f}if(e&32832){break f}}if(!(x[a+480208|0]&2)|(e|0)!=8){break b}}Jn(a,g,f<<2)}}function Tn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=C(b,896)+a|0;a:{if(c){if(!(x[a+1074323|0]&4)){u[(C(b,896)+a|0)+1075816|0]=c}u[(C(b,896)+a|0)+1075815|0]=c;break a}c=x[e+1075815|0]}g=e+1074984|0;f=c&255;h=!(w[a+480180>>2]&204473357)&(d^-1);Mn(a,b,f,h);e=w[a+480180>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}i=w[(C(b,896)+a|0)+1075640>>2];if(!i|!w[i+44>>2]){break c}c=c&255;if(!(c>>>0<240|d)){Ln(a,g,f-240|0);return}if(!(c>>>0<224|d)){a=C(b,896)+a|0;b=a+1075856|0;c=x[b|0];if(!(c&1)){break b}a=a+1075860|0;w[a>>2]=(w[a>>2]+f|0)-224;u[b|0]=c|16;return}a=C(b,896)+a|0;b=a+1075860|0;w[b>>2]=w[b>>2]+f;a=a+1075856|0;u[a|0]=x[a|0]|16;return}w[(C(b,896)+a|0)+1075692>>2]=1}d:{if(!((c&255)>>>0>223&h)){break d}e:{d=f&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}Kn(a,g,d);return}if((e|0)==524288){break d}Nn(a,g,d);return}if((e|0)!=524288){break b}}f:{if(!(u[(C(b,896)+a|0)+1075856|0]&1)){break f}g:{if(w[a+1074416>>2]==1){if(!(w[a+1074312>>2]&64|e&32832)){break g}break f}if(e&32832){break f}}if(!(x[a+480208|0]&2)|(e|0)!=8){break b}}Jn(a,g,0-(f<<2)|0)}}function JR(a){a=a|0;var b=D(0),c=0,d=0,e=0,f=0,g=0,h=0;u[a+4202|0]=1;f=-1;b=_b(D(D(z[w[a+16>>2]+24620>>2])*D(.04500000178813934)));c=-1;a:{if(b>=D(4294967296)){break a}c=0;if(b<=D(0)){break a}c=~~b>>>0;if(b<D(4294967296)&b>=D(0)){break a}c=0}b=_b(D(D(c>>>0)*D(1.1892070770263672)));b:{if(b>=D(4294967296)){break b}f=0;if(b<=D(0)){break b}f=b<D(4294967296)&b>=D(0)?~~b>>>0:f}h=-1;b=_b(D(D(f>>>0)*D(1.1892070770263672)));d=-1;c:{if(b>=D(4294967296)){break c}d=0;if(b<=D(0)){break c}d=~~b>>>0;if(b<D(4294967296)&b>=D(0)){break c}d=0}b=_b(D(D(d>>>0)*D(1.1892070770263672)));d:{if(b>=D(4294967296)){break d}h=0;if(b<=D(0)){break d}h=b<D(4294967296)&b>=D(0)?~~b>>>0:h}g=-1;b=_b(D(D(c+d>>>0)*D(.11546666920185089)));e=-1;e:{if(b>=D(4294967296)){break e}e=0;if(b<=D(0)){break e}e=~~b>>>0;if(b<D(4294967296)&b>=D(0)){break e}e=0}b=_b(D(D(f+h>>>0)*D(.11546666920185089)));f:{if(b>=D(4294967296)){break f}g=0;if(b<=D(0)){break f}g=b<D(4294967296)&b>=D(0)?~~b>>>0:g}w[a+4292>>2]=g;w[a+4288>>2]=e;w[a+4284>>2]=h-g;w[a+4280>>2]=f-g;w[a+4276>>2]=d-e;w[a+4272>>2]=c-e;uv(a);Cb(a+4296|0,0,81928)}function bt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(gt(b)){f=b>>>0<=4?4:b;b=a?a:1;a:{while(1){i=jb-16|0;jb=i;w[i+12>>2]=0;b:{c:{if((f|0)==8){a=fc(b);break c}if(f&3|f>>>0<4){break b}a=f>>>2|0;if(a-1&a|b>>>0>-64-f>>>0){break b}c=16;a=f>>>0<=16?16:f;d=a>>>0<=16?16:a;d:{if(!(d-1&d)){a=d;break d}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}e:{if(b>>>0>=-64-a>>>0){w[114084]=48;c=0;break e}j=b>>>0<11?16:b+11&-8;e=fc((j+a|0)+12|0);c=0;if(!e){break e}c=e-8|0;f:{if(!(e&a-1)){a=c;break f}h=e-4|0;d=w[h>>2];g=a;a=((a+e|0)-1&0-a)-8|0;a=(a-c>>>0<=15?g:0)+a|0;g=a-c|0;e=(d&-8)-g|0;if(!(d&3)){c=w[c>>2];w[a+4>>2]=e;w[a>>2]=c+g;break f}w[a+4>>2]=e|w[a+4>>2]&1|2;d=a+e|0;w[d+4>>2]=w[d+4>>2]|1;w[h>>2]=g|w[h>>2]&1|2;d=c+g|0;w[d+4>>2]=w[d+4>>2]|1;Gj(c,g)}d=w[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=j+16>>>0){break g}w[a+4>>2]=j|d&1|2;h=a+j|0;d=c-j|0;w[h+4>>2]=d|3;c=a+c|0;w[c+4>>2]=w[c+4>>2]|1;Gj(h,d)}c=a+8|0}a=c}if(!a){break b}w[i+12>>2]=a}jb=i+16|0;a=w[i+12>>2];if(a){break a}a=w[115571];if(a){ob[a|0]();continue}break}ka(Ye(ba(4)|0)|0,74720,68);M()}return a}return Kb(a)}function FU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=w[a>>2];b:{if((w[a+8>>2]-d|0)/52>>>0>=b>>>0){f=(w[a+4>>2]-d|0)/52|0;e=b>>>0>f>>>0?f:b;if(e){while(1){mw(d,c);d=d+52|0;e=e-1|0;if(e){continue}break}}if(b>>>0>f>>>0){e=w[a+4>>2];b=e+C(b-f|0,52)|0;c:{while(1){w[114256]=0;d=Q(952,e|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break c}e=d+52|0;if((e|0)!=(b|0)){continue}break}break a}break b}b=w[a>>2]+C(b,52)|0;d=w[a+4>>2];if((b|0)!=(d|0)){while(1){d=d-52|0;Cf(d);if((b|0)!=(d|0)){continue}break}}break a}f=w[a>>2];if(f){d=f;e=w[a+4>>2];if((d|0)!=(e|0)){while(1){e=e-52|0;Cf(e);if((f|0)!=(e|0)){continue}break}d=w[a>>2]}w[a+4>>2]=f;zb(d);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0}d:{if(b>>>0<82595525){d=(w[a+8>>2]-w[a>>2]|0)/52|0;f=d<<1;d=d>>>0>=41297762?82595524:b>>>0<f>>>0?f:b;if(d>>>0>=82595525){Mb(a);M()}f=C(d,52);d=Kb(f);w[a>>2]=d;w[a+4>>2]=d;w[a+8>>2]=d+f;e=w[a+4>>2];b=e+C(b,52)|0;while(1){w[114256]=0;d=Q(952,e|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break d}e=d+52|0;if((e|0)!=(b|0)){continue}break}break a}Mb(a);M()}}b=P()|0;w[a+4>>2]=e;R(b|0);M()}w[a+4>>2]=b}function YA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;w[114256]=0;h=Q(14,f|0,a|0)|0;e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)!=1){d:{e:{f:{if(!x[h|0]){break f}e=w[w[a>>2]-12>>2]+a|0;i=w[e+4>>2];j=w[e+24>>2];d=w[e+76>>2];if((d|0)==-1){w[114256]=0;T(10,f+8|0,e|0);d=w[114256];w[114256]=0;if((d|0)==1){break e}w[114256]=0;d=Q(11,f+8|0,460428)|0;g=w[114256];w[114256]=0;g:{if((g|0)!=1){g=w[w[d>>2]+28>>2];w[114256]=0;d=Q(g|0,d|0,32)|0;g=w[114256];w[114256]=0;if((g|0)!=1){break g}}b=W(0)|0;Ab(f+8|0);break d}Ab(f+8|0);w[e+76>>2]=d}w[114256]=0;c=b+c|0;b=la(15,j|0,b|0,((i&176)==32?c:b)|0,c|0,e|0,d<<24>>24)|0;c=w[114256];w[114256]=0;if((c|0)==1){break e}if(b){break f}b=w[w[a>>2]-12>>2]+a|0;c=w[b+16>>2];w[114256]=0;T(16,b|0,c|5);b=w[114256];w[114256]=0;if((b|0)!=1){break f}b=W(0)|0;break d}id(h);break b}b=W(0)|0}id(h);break c}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=f+16|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){W(0)|0;Eb();M()}R(a|0);M()}function ex(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0;i=B[e+8>>3];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>3|0;j=c>>>0>e>>>0?e:c;a:{if(!j){break a}e=j;c=b;while(1){g=0;h=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);f=h;k=g;g=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);h=g<<24|f>>>8;l(0,k|(((g&255)<<24|f>>>8)&-16777216|((g&16777215)<<8|f>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,(f<<24|f<<8&16711680|(h&65280|(g<<8|f>>>24)&255))&2147483647);i=H(+n(),i);c=c+8|0;e=e-1|0;if(e){continue}break}c=i==0;if(c|!j){break a}o=c?1:1/i;c=w[a+20>>2];a=j;while(1){h=0;g=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);f=g;g=f<<24|f<<8&16711680;k=h;e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);h=e<<24|f>>>8;l(0,k|(((e&255)<<24|f>>>8)&-16777216|((e&16777215)<<8|f>>>24)&16711680|(e>>>8&65280|e>>>24)));l(1,g|(h&65280|(e<<8|f>>>24)&255));m=Tb(H(G(o*+n(),1),-1)*32768);b:{if(E(m)<2147483648){e=~~m;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[c>>1]=(e|0)<=-32768?-32768:e;b=b+8|0;c=c+2|0;a=a-1|0;if(a){continue}break}}if(d){B[d>>3]=i}return j<<3}function tz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0;j=jb-16|0;a:{b:{c:{e=w[a+12>>2];h=w[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}i=w[a>>2];g=w[a+4>>2];if(d){m=w[a+16>>2];n=w[a+24>>2];o=w[a+20>>2];while(1){f=(((g&2147483647)<<1|i>>>31)&-2)+m|0;b=(i>>>16&65520)+k|0;p=v[b+14>>1];q=v[b+12>>1];r=v[b+10>>1];s=v[b+8>>1];t=v[b+6>>1];x=v[b+4>>1];y=v[b+2>>1];z=v[b>>1];b=0;l=1;while(1){w[(j+8|0)+(b<<2)>>2]=(((((((C(u[(b|-4)+f|0],y)+C(u[(b|-6)+f|0],z)|0)+C(u[(b|-2)+f|0],x)|0)+C(u[b+f|0],t)|0)+C(u[(b|2)+f|0],s)|0)+C(u[(b|4)+f|0],r)|0)+C(u[(b|6)+f|0],q)|0)+C(u[(b|8)+f|0],p)<<8)/32768;A=l;l=0;b=1;if(A){continue}break}w[c>>2]=w[c>>2]+C(w[j+8>>2],o);w[c+4>>2]=w[c+4>>2]+C(w[j+12>>2],n);g=e+g|0;b=h+i|0;g=b>>>0<h>>>0?g+1|0:g;i=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=i;w[a+4>>2]=g}function Ap(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=y[c>>1];a:{if(x[d|0]<=4){while(1){d=g<<1;v[c>>1]=d;u[b|0]=(d&65534)>>>0>255;d=x[c|0];v[c>>1]=d;if(!d){if(!Xb(a,f+15|0)){break a}d=x[f+15|0];v[c>>1]=d<<1|1;u[b|0]=d>>>7;v[c>>1]=x[c|0]}v[e>>1]=u[b|0]+(y[e>>1]<<1);d=y[c>>1]<<1;v[c>>1]=d;u[b|0]=(d&65534)>>>0>255;d=x[c|0];v[c>>1]=d;if(!d){if(!Xb(a,f+14|0)){break a}d=x[f+14|0];v[c>>1]=d<<1|1;u[b|0]=d>>>7;v[c>>1]=x[c|0]}v[e>>1]=u[b|0]+(y[e>>1]<<1);d=y[c>>1]<<1;v[c>>1]=d;u[b|0]=(d&65534)>>>0>255;g=x[c|0];v[c>>1]=g;if(!g){if(!Xb(a,f+13|0)){break a}d=x[f+13|0];v[c>>1]=d<<1|1;u[b|0]=d>>>7;g=x[c|0];v[c>>1]=g;if(x[b|0]){continue}break a}if(x[b|0]){continue}break a}}while(1){d=g<<1;v[c>>1]=d;u[b|0]=(d&65534)>>>0>255;d=x[c|0];v[c>>1]=d;if(!d){if(!Xb(a,f+12|0)){break a}d=x[f+12|0];v[c>>1]=d<<1|1;u[b|0]=d>>>7;v[c>>1]=x[c|0]}v[e>>1]=u[b|0]+(y[e>>1]<<1);d=y[c>>1]<<1;v[c>>1]=d;u[b|0]=(d&65534)>>>0>255;g=x[c|0];v[c>>1]=g;if(!g){if(!Xb(a,f+11|0)){break a}d=x[f+11|0];v[c>>1]=d<<1|1;u[b|0]=d>>>7;g=x[c|0];v[c>>1]=g;if(x[b|0]){continue}break a}if(x[b|0]){continue}break}}jb=f+16|0}function kC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-16|0;jb=h;if(d){m=C(c,d);p=(m|0)<=0;c=0;k=4;while(1){if(!p){j=b+l|0;q=m+j|0;while(1){r=g;g=0;while(1){a:{b:{c:{c=c<<1;e=c&254;d:{e:{if(e){c=(c&65534)>>>0>255;break e}if(!Xb(a,h+15|0)){break d}e=x[h+15|0];c=e>>>7|0;e=e<<1&254|1}g=g<<1|c;c=e<<1&254;if(c){break b}if(Xb(a,h+14|0)){break c}}c=0;break a}e=u[h+14|0];c=e<<1&254|1;if((e|0)<0){continue}break a}if(e>>>0>127){continue}}break}e=k;f:{if(!(e&255)){break f}while(1){g:{f=c<<1;c=f&254;h:{if(c){f=(f&65534)>>>0>255;break h}if(!Xb(a,h+13|0)){break g}c=x[h+13|0];f=c>>>7|0;c=c<<1&254|1}g=g<<1|f;e=e-1|0;if(e&255){continue}break f}break}c=0}e=1;n=g&255;i:{if(n>>>0<4){break i}f=7;while(1){e=f;o=e&255;if(n>>>o&1){break i}f=e-1|0;if(o>>>0>1){continue}break}}f=i;i=(g&1)-1^(g&254)>>>1;g=f+i|0;u[j|0]=g;f=-128;j=d+j|0;e=e+k&254;i=((i>>1)-(r<<24>>24)|0)+(g<<24>>24<<1)|0;j:{if((i|0)>=-128){f=127;if((i|0)<128){break j}}i=f}k=e>>>1|0;if(j>>>0<q>>>0){continue}break}}l=l+1|0;if((l|0)!=(d|0)){continue}break}}jb=h+16|0}function dA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,D=0;b=w[a+48>>2];l=w[a>>2];i=w[a+4>>2];j=w[a+40>>2];k=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=j>>12;h=k>>12;break a}m=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];s=w[a+72>>2];e=w[a+68>>2];t=e;u=e>>31;e=w[a+64>>2];x=e;y=e>>31;e=w[a+60>>2];z=e;A=e>>31;e=b;while(1){g=w[c>>2];n=v[(i<<1)+p>>1]<<8;b=n;h=BV(b,b>>31,z,A);B=nb;b=f;D=g;g=h;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;h=BV(x,y,f,f>>31);g=g+h|0;f=nb+B|0;f=g>>>0<h>>>0?f+1|0:f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;h=BV(t,u,e,e>>31);g=h+g|0;e=nb+f|0;e=g>>>0<h>>>0?e+1|0:e;f=g+8388608|0;e=f>>>0<8388608?e+1|0:e;k=k+r|0;h=k>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=D+C(h,f);j=j+q|0;g=j>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(s&n)|0;i=i+o|0;e=l+m|0;i=e>>>0<m>>>0?i+1|0:i;l=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=k;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=j;w[a+20>>2]=h;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function ky(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=jb+-64|0;jb=c;v[c+32>>1]=0;w[c+52>>2]=c+34;w[c+48>>2]=c+32;Ob(a,c+48|0);d=y[c+32>>1];v[c+46>>1]=d;a:{b:{c:{d:{e:{e=w[19467];if(y[e+12>>1]<d>>>0){g=w[b+12>>2];d=Hb(c,12506);w[114256]=0;Y(713,c+16|0,d|0,c+46|0,e+12|0);f=w[114256];w[114256]=0;if((f|0)==1){break e}w[114256]=0;U(6,c+48|0,0,c+16|0);f=w[114256];w[114256]=0;if((f|0)==1){break d}w[c+40>>2]=w[c+56>>2];w[114256]=0;f=w[c+52>>2];w[c+32>>2]=w[c+48>>2];w[c+36>>2]=f;T(348,g|0,c+32|0);g=w[114256];w[114256]=0;if((g|0)==1){break c}if(u[c+43|0]<0){zb(w[c+32>>2])}if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[d+11|0]<0){zb(w[d>>2])}d=y[e+12>>1];v[c+46>>1]=d}e=w[b>>2];v[c+48>>1]=65535;$d(e,d,c+48|0);d=w[b>>2];b=w[d>>2];d=w[d+4>>2];if((b|0)!=(d|0)){e=c+34|0;while(1){v[c+32>>1]=0;w[c+52>>2]=e;w[c+48>>2]=c+32;Ob(a,c+48|0);v[b>>1]=y[c+32>>1];b=b+2|0;if((d|0)!=(b|0)){continue}break}}jb=c- -64|0;return}b=P()|0;break a}b=P()|0;break b}b=P()|0;if(u[c+43|0]>=0){break b}zb(w[c+32>>2])}if(u[c+27|0]>=0){break a}zb(w[c+16>>2])}if(u[d+11|0]<0){zb(w[d>>2])}R(b|0);M()}function eA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0,B=0,D=0;b=w[a+48>>2];l=w[a>>2];i=w[a+4>>2];j=w[a+40>>2];k=w[a+36>>2];f=w[a+44>>2];a:{if(!d){g=j>>12;h=k>>12;break a}m=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];s=w[a+72>>2];e=w[a+68>>2];t=e;v=e>>31;e=w[a+64>>2];x=e;y=e>>31;e=w[a+60>>2];z=e;A=e>>31;e=b;while(1){g=w[c>>2];n=u[i+p|0]<<16;b=n;h=BV(b,b>>31,z,A);B=nb;b=f;D=g;g=h;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;h=BV(x,y,f,f>>31);g=g+h|0;f=nb+B|0;f=g>>>0<h>>>0?f+1|0:f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;h=BV(t,v,e,e>>31);g=h+g|0;e=nb+f|0;e=g>>>0<h>>>0?e+1|0:e;f=g+8388608|0;e=f>>>0<8388608?e+1|0:e;k=k+r|0;h=k>>12;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=D+C(h,f);j=j+q|0;g=j>>12;w[c+4>>2]=w[c+4>>2]+C(f,g);f=e-(s&n)|0;i=i+o|0;e=l+m|0;i=e>>>0<m>>>0?i+1|0:i;l=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+36>>2]=k;w[a>>2]=l;w[a+4>>2]=i;w[a+40>>2]=j;w[a+20>>2]=h;w[a+48>>2]=b;w[a+44>>2]=f;w[a+24>>2]=g}function Jq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=jb-1040|0;jb=i;q=w[114084];a:{b:{c:{a=i+16|0;l=y[((b>>>0<=149?b:0)<<1)+73584>>1]+71761|0;c=w[w[114126]+20>>2];if(c){j=w[c+4>>2];c=w[c>>2];e=w[c>>2]+1794895138|0;h=Xf(w[c+8>>2],e);g=Xf(w[c+12>>2],e);d=Xf(w[c+16>>2],e);d:{if(j>>>2>>>0<=h>>>0){break d}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break d}r=d>>>2|0;s=g>>>2|0;g=0;while(1){k=h>>>1|0;m=k+g|0;n=m<<1;d=c+(n+s<<2)|0;o=Xf(w[d>>2],e);d=Xf(w[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|x[c+(d+o|0)|0]){break d}d=Qe(l,c+d|0);if(!d){g=c+(r+n<<2)|0;h=Xf(w[g>>2],e);e=Xf(w[g+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break d}f=x[c+(e+h|0)|0]?0:c+e|0;break d}if((h|0)==1){break d}d=(d|0)<0;h=d?k:h-k|0;g=d?g:m;continue}}}f=f?f:l;c=ec(f);e:{if(c>>>0>=1024){Fb(a,f,1023);u[a+1023|0]=0;f=68;break e}Fb(a,f,c+1|0);f=0}switch(f+1|0){case 1:break a;case 0:break c;default:break b}}f=w[114084]}a=17256;if((f|0)==28){break a}wa();M()}if(!x[a|0]){w[i>>2]=b;a=i+16|0;$l(a,1024,8835,i)}w[114084]=q;Hb(p,a);jb=i+1040|0}function Lp(a,b){var c=0;a:{c=x[a|0];if(c>>>0>21){break a}u[a|0]=x[c+23600|0];b:{switch(c-8|0){case 0:u[b|0]=x[b|0]<<1;return;case 4:u[b|0]=x[b|0]+1>>>1;return;case 5:a=x[b|0];u[b|0]=C(a>>>4|0,10)+(a&15);return;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{c=x[b|0];switch((c>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 3:break i;case 1:break j;case 0:break k;case 14:break c;case 10:break d;default:break l}}u[a|0]=0;return}u[a|0]=29;a=x[b|0];u[b|0]=(a&15)==15?-17:a<<4|15;return}u[a|0]=29;a=x[b|0];u[b|0]=(a&15)==15?-2:a|240;return}u[b|0]=c&15|48;return}u[b|0]=c&15|176;return}u[b|0]=c&15|64;return}u[a|0]=15;u[b|0]=x[b|0]&15;return}u[a|0]=24;u[b|0]=(x[b|0]<<3&120)+8&240;return}u[a|0]=24;u[b|0]=(x[b|0]&15)+1>>>1;return}u[a|0]=10;return;case 8:a=x[b|0];if(a>>>0<=223){u[b|0]=a>>>0>63?-16:a<<2&240;return}if(a>>>0<=239){u[b|0]=a<<2&48|15;return}u[b|0]=a<<4|15;return;case 9:break b;default:break a}}a=x[b|0];if(a>>>0<=223){u[b|0]=a>>>0>63?15:a>>>2|0;return}if(a>>>0>239){break a}u[b|0]=a>>>2&3|240}}function Cz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0;f=w[a+48>>2];i=w[a>>2];h=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+24>>2];n=w[a+20>>2];o=w[a+16>>2];p=w[a+72>>2];b=w[a+68>>2];q=b;r=b>>31;b=w[a+64>>2];s=b;t=b>>31;b=w[a+60>>2];u=b;x=b>>31;while(1){g=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(s,t,e,e>>31);j=nb;y=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(q,r,f,f>>31);e=g+e|0;f=nb+j|0;f=e>>>0<g>>>0?f+1|0:f;z=e;e=(h<<1)+o|0;g=(i>>>21&2040)+32832|0;g=(((C(v[e>>1],v[g+2>>1])+C(v[e-2>>1],v[g>>1])|0)+C(v[e+2>>1],v[g+4>>1])|0)+C(v[e+4>>1],v[g+6>>1])|0)/16384<<8;e=g;j=BV(e,e>>31,u,x);e=z+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=y+C(e,n);w[c+4>>2]=w[c+4>>2]+C(e,m);e=f-(g&p)|0;h=h+l|0;f=i+k|0;h=f>>>0<k>>>0?h+1|0:h;i=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=i;w[a+4>>2]=h}function RS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=D(0),f=0,g=0,h=D(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=D(0);a:{if(!w[a+4272>>2]){break a}g=w[a+56>>2];i=w[a+44>>2];if((0-(w[a+60>>2]-g>>11)|0)==w[a+48>>2]-i>>11){break a}n=b;o=c;if(d){l=i+2048|0;m=g+2048|0;f=w[a+4256>>2];c=w[a+4268>>2];b=d;while(1){e=A[l>>2];c=(c<<3)+f|0;h=A[i>>2];A[c>>2]=h;A[c+4>>2]=e;e=Ev(D(D(D(E(e))+D(E(h)))*D(536870912)),31,5);h=A[a+4276>>2];e=D(D(E(e))*D(4.656612873077393e-10));e=D(D(A[(h>e?4240:4236)+a>>2]*D(h-e))+e);A[a+4276>>2]=e;p=D(A[a+4232>>2]*D(4.656612873077393e-10));h=A[a+4244>>2];e=D(D(D(A[a+4248>>2]*D(2147483648))*D(h-D(H(e,h))))+D(2147483392));b:{if(e<D(4294967296)&e>=D(0)){c=~~e>>>0;break b}c=0}f=c<<5;j=f;k=f|-2147483648;f=c>>>0<67108864;e=D(p*D((f?j:k)>>>(f?31:32-(c>>>26|0)|0)>>>0));f=w[a+4256>>2];j=w[a+4272>>2];c=w[a+4268>>2];k=f+((((j+(w[a+4252>>2]+(c<<12)|0)|0)-1|0)/4096|0)%(j|0)<<3)|0;A[g>>2]=e*A[k>>2];A[m>>2]=e*A[k+4>>2];c=((c?0:j)+c|0)-1|0;w[a+4268>>2]=c;m=m+4|0;g=g+4|0;l=l+4|0;i=i+4|0;b=b-1|0;if(b){continue}break}g=w[a+56>>2]}ye(a,n,o,g,g+2048|0,d)}}function yU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=D(0),l=0,m=0;h=v[d>>1];i=v[d+2>>1];a:{if((h|0)>(i|0)){break a}j=w[b>>2];g=w[b+4>>2];if((j|0)==(g|0)){break a}f=v[e>>1];if((f|0)<(h|0)|(f|0)>(i|0)){break a}g=g-j>>2;if((g-1&65535)>>>0>(i-f&65535)>>>0|z[a+36>>2]>65535){break a}l=g>>>0<=1?1:g;f=0;while(1){if(A[(f<<2)+j>>2]<D(0)){break a}f=f+1|0;if((l|0)!=(f|0)){continue}break}k=A[c>>2];if(k<=D(0)){break a}v[a+28>>1]=h;v[a>>1]=1;A[a+32>>2]=E(k);v[a+30>>1]=g>>>0>=32767?32767:g;Fe(a+4|0,(i-h|0)+1|0);c=w[b+4>>2];b=w[b>>2];if((c|0)!=(b|0)){hc(w[a+4>>2]+(v[e>>1]-v[d>>1]<<2)|0,b,c-b|0)}f=v[e>>1];g=v[a+28>>1];b:{if((f|0)<=(g|0)){c=v[a+30>>1];break b}h=w[a+4>>2];c=v[a+30>>1];while(1){c:{f=f-1|0;b=f-g|0;A[h+(b<<2)>>2]=A[h+(b+c<<2)>>2]/A[a+32>>2];b=y[e>>1];if((f|0)<=(g|0)){break c}if((b|0)!=32768){continue}}break}f=b}b=f<<16>>16;f=b+c|0;d=v[d+2>>1];if(!((f|0)>(d|0)|(b|0)>(32767-c|0))){c=c+g|0;b=w[a+4>>2];while(1){A[b+(f-g<<2)>>2]=A[b+(f-c<<2)>>2]*A[a+32>>2];e=(d|0)>(f|0);f=f+1|0;if(e){continue}break}}ii(a);m=1}return m|0}function mx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;d=w[a>>2];c=c>>>4|0;f=c>>>0>d>>>0?d:c;if(f){a=w[a+20>>2];g=f;while(1){c=0;d=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);h=d<<24|d<<8&16711680;i=c;c=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);j=c<<24|d>>>8;l(0,i|(((c&255)<<24|d>>>8)&-16777216|((c&16777215)<<8|d>>>24)&16711680|(c>>>8&65280|c>>>24)));c=j&65280|(c<<8|d>>>24)&255|h;d=0;l(1,c|(d|d));e=Tb(H(G(+n(),1),-1)*32768);a:{if(E(e)<2147483648){c=~~e;break a}c=-2147483648}c=(c|0)>=32767?32767:c;v[a>>1]=(c|0)<=-32768?-32768:c;c=0;d=x[b+8|0]|x[b+9|0]<<8|(x[b+10|0]<<16|x[b+11|0]<<24);h=d<<24|d<<8&16711680;i=c;c=x[b+12|0]|x[b+13|0]<<8|(x[b+14|0]<<16|x[b+15|0]<<24);j=c<<24|d>>>8;l(0,i|(((c&255)<<24|d>>>8)&-16777216|((c&16777215)<<8|d>>>24)&16711680|(c>>>8&65280|c>>>24)));c=j&65280|(c<<8|d>>>24)&255|h;d=0;l(1,c|(d|d));e=Tb(H(G(+n(),1),-1)*32768);b:{if(E(e)<2147483648){c=~~e;break b}c=-2147483648}c=(c|0)>=32767?32767:c;v[a+2>>1]=(c|0)<=-32768?-32768:c;a=a+4|0;b=b+16|0;g=g-1|0;if(g){continue}break}}return f<<4}function Dz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0;f=w[a+48>>2];i=w[a>>2];h=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+24>>2];n=w[a+20>>2];o=w[a+16>>2];p=w[a+72>>2];b=w[a+68>>2];q=b;r=b>>31;b=w[a+64>>2];s=b;t=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){g=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(s,t,e,e>>31);j=nb;z=g;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;g=BV(q,r,f,f>>31);e=g+e|0;f=nb+j|0;f=e>>>0<g>>>0?f+1|0:f;A=e;e=h+o|0;g=(i>>>21&2040)+32832|0;g=(((C(u[e|0],v[g+2>>1])+C(u[e-1|0],v[g>>1])|0)+C(u[e+1|0],v[g+4>>1])|0)+C(u[e+2|0],v[g+6>>1])<<8)/16384<<8;e=g;j=BV(e,e>>31,x,y);e=A+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=z+C(e,n);w[c+4>>2]=w[c+4>>2]+C(e,m);e=f-(g&p)|0;h=h+l|0;f=i+k|0;h=f>>>0<k>>>0?h+1|0:h;i=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=i;w[a+4>>2]=h}function RL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;w[114256]=0;Q(14,d+24|0,a|0)|0;e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)!=1){d:{if(!x[d+24|0]){break d}e=w[w[a>>2]-12>>2];w[114256]=0;Sb(d+16|0,a+e|0);e=w[114256];w[114256]=0;e:{f:{g:{if((e|0)!=1){w[114256]=0;e=V(1579,d+16|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}Ab(d+16|0);f=Vd(d+8|0,a);g=w[w[a>>2]-12>>2];w[114256]=0;g=a+g|0;h=V(1580,g|0)|0;i=w[114256];w[114256]=0;if((i|0)==1){break f}f=w[f>>2];w[114256]=0;b=Da(1583,e|0,f|0,g|0,h|0,b|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}w[d+16>>2]=b;if(!qf(d+16|0)){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,5);b=w[114256];w[114256]=0;if((b|0)!=1){break d}b=W(0)|0;break e}b=W(0)|0;break e}b=W(0)|0;Ab(d+16|0);break e}b=W(0)|0}id(d+24|0);break c}id(d+24|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=d+32|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function ug(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(b&2){u[a+861|0]=0;w[a+708>>2]=0;w[a+656>>2]=0;w[a+104>>2]=0;u[a+819|0]=0;w[a+804>>2]=0;w[a+824>>2]=0;w[a+696>>2]=0;w[a+668>>2]=0;w[a+88>>2]=w[a+88>>2]|6144;if(x[c+1074314|0]&128){v[a+798>>1]=0;v[a+800>>1]=1}u[a+866|0]=0;u[a+859|0]=0;u[a+871|0]=255;w[a+660>>2]=0;v[a+810>>1]=0;v[a+812>>1]=0;v[a+814>>1]=0;u[a+872|0]=x[a+872|0]&248}if(b&4){w[a+84>>2]=0;w[a+76>>2]=0;w[a+80>>2]=0;w[a+700>>2]=0;w[a+656>>2]=0;w[a+104>>2]=0;w[a+92>>2]=0;w[a+96>>2]=0;w[a>>2]=0;w[a+4>>2]=0;u[a+865|0]=0;u[a+858|0]=0;w[a+688>>2]=0;w[a+672>>2]=0;w[a+676>>2]=0;v[a+840>>1]=0;u[a+839|0]=0;v[a+856>>1]=32512;v[a+862>>1]=0;w[a+20>>2]=0;w[a+24>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+28>>2]=0;w[a+32>>2]=0;w[a+876>>2]=0;w[a+880>>2]=0;u[a+872|0]=x[a+872|0]&231}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=w[b+480280>>2];w[a+88>>2]=c;w[a+692>>2]=y[b+480284>>1];w[a+760>>2]=y[b+480286>>1];if(!(c&1024)){break a}w[a+88>>2]=c&-1025|e;break a}w[a+760>>2]=64;w[a+692>>2]=128;w[a+88>>2]=0}v[a+796>>1]=0;u[a+817|0]=0;u[a+818|0]=0}}function yf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;c=w[a+28>>2];Jg(w[w[c>>2]-12>>2]+c|0,0);if(!(x[a+24|0]&16)){vv(a)}c=w[a+4>>2];if(!(!c|x[a+24|0]&192)){e=w[a+28>>2];c=C(c,w[a+20>>2]);g=c+w[a+80>>2]|0;f=w[a+84>>2];f=c>>>0>g>>>0?f+1|0:f;c=g;w[d+72>>2]=c;w[d+76>>2]=f;w[d+24>>2]=c;w[d+28>>2]=f;w[d+64>>2]=0;w[d+68>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;rf(e,d+16|0)}a:{if(!(x[a+24|0]&32)){break a}e=w[a+48>>2];c=w[a+44>>2];if((e|0)==(c|0)){break a}i=e-c>>4;f=i>>>0<=1?1:i;while(1){b:{j=(w[a+96>>2]+h>>>0)%(i>>>0)|0;e=w[a+44>>2]+(j<<4)|0;c=w[e>>2];g=w[a+32>>2];if(c>>>0>=w[a+36>>2]-g>>>0){break b}e=Uj(d+48|0,c+g|0,y[e+12>>1]);c=Yd(b,e);if(u[d+59|0]<0){zb(w[e>>2])}if(!c){break b}w[a+96>>2]=(j+1>>>0)%(i>>>0);c=w[a+44>>2];e=j<<4;b=w[(c+e|0)+4>>2];if(b){c=w[a+28>>2];f=w[a+12>>2];g=b+w[a+8>>2]|0;f=g>>>0<b>>>0?f+1|0:f;w[d+40>>2]=g;w[d+44>>2]=f;w[d+8>>2]=g;w[d+12>>2]=f;w[d+32>>2]=0;w[d+36>>2]=0;w[d>>2]=0;w[d+4>>2]=0;rf(c,d);c=w[a+44>>2]}h=c+e|0;break a}h=h+1|0;if((f|0)!=(h|0)){continue}break}h=0}jb=d+80|0;return h|0}function qu(a,b,c,d,e){var f=D(0),g=0,h=D(0),i=0,j=D(0),k=D(0);if(!(a&3)){if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>>2|0;while(1){b=d-4|0;h=A[b>>2];j=A[d>>2];k=A[c>>2];A[c>>2]=j+k;g=c-4|0;f=A[g>>2];A[g>>2]=A[b>>2]+f;j=D(k-j);f=D(f-h);A[d>>2]=D(A[e>>2]*j)-D(A[e+4>>2]*f);A[b>>2]=D(A[e+4>>2]*j)+D(A[e>>2]*f);b=d-12|0;j=A[b>>2];g=c-8|0;f=A[g>>2];i=g;g=d-8|0;k=A[g>>2];A[i>>2]=k+f;i=c-12|0;h=A[i>>2];A[i>>2]=A[b>>2]+h;f=D(f-k);h=D(h-j);A[g>>2]=D(A[e+32>>2]*f)-D(A[e+36>>2]*h);A[b>>2]=D(A[e+36>>2]*f)+D(A[e+32>>2]*h);b=d-20|0;j=A[b>>2];g=c-16|0;f=A[g>>2];i=g;g=d-16|0;k=A[g>>2];A[i>>2]=k+f;i=c-20|0;h=A[i>>2];A[i>>2]=A[b>>2]+h;f=D(f-k);h=D(h-j);A[g>>2]=D(A[e+64>>2]*f)-D(A[e+68>>2]*h);A[b>>2]=D(A[e+68>>2]*f)+D(A[e+64>>2]*h);b=d-28|0;j=A[b>>2];g=c-24|0;f=A[g>>2];i=g;g=d-24|0;k=A[g>>2];A[i>>2]=k+f;i=c-28|0;h=A[i>>2];A[i>>2]=A[b>>2]+h;f=D(f-k);h=D(h-j);A[g>>2]=D(A[e+96>>2]*f)-D(A[e+100>>2]*h);A[b>>2]=D(A[e+100>>2]*f)+D(A[e+96>>2]*h);d=d-32|0;c=c-32|0;e=e+128|0;b=a>>>0>1;a=a-1|0;if(b){continue}break}}return}ha(11695,9008,2423,5141);M()}function om(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;w[114256]=0;Q(14,c+24|0,a|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)!=1){d:{if(!x[c+24|0]){break d}d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;e:{f:{g:{if((d|0)!=1){w[114256]=0;d=V(1579,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}Ab(c+16|0);e=Vd(c+8|0,a);f=w[w[a>>2]-12>>2];w[114256]=0;f=a+f|0;g=V(1580,f|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}e=w[e>>2];w[114256]=0;b=da(1582,d|0,e|0,f|0,g|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}w[c+16>>2]=b;if(!qf(c+16|0)){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,5);b=w[114256];w[114256]=0;if((b|0)!=1){break d}b=W(0)|0;break e}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0);break e}b=W(0)|0}id(c+24|0);break c}id(c+24|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+32|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function SL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;w[114256]=0;Q(14,c+24|0,a|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)!=1){d:{if(!x[c+24|0]){break d}d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;e:{f:{g:{if((d|0)!=1){w[114256]=0;d=V(1579,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}Ab(c+16|0);e=Vd(c+8|0,a);f=w[w[a>>2]-12>>2];w[114256]=0;f=a+f|0;g=V(1580,f|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}e=w[e>>2];w[114256]=0;b=da(1581,d|0,e|0,f|0,g|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}w[c+16>>2]=b;if(!qf(c+16|0)){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,5);b=w[114256];w[114256]=0;if((b|0)!=1){break d}b=W(0)|0;break e}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0);break e}b=W(0)|0}id(c+24|0);break c}id(c+24|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+32|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Tw(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-896|0;jb=c;f=Cb(a,0,66);a=f;w[a+72>>2]=0;w[a+76>>2]=0;w[a+68>>2]=256;v[a+66>>1]=65535;w[a+80>>2]=0;w[a+84>>2]=0;u[a+88|0]=1;b=a+229984|0;d=a+608|0;a=d;while(1){w[a>>2]=0;w[a+4>>2]=0;w[a+88>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;vk(a+112|0,48e3);v[a+810>>1]=0;v[a+812>>1]=0;w[a+752>>2]=0;w[a+756>>2]=-1;u[a+748|0]=0;w[a+740>>2]=0;w[a+744>>2]=-1;u[a+736|0]=0;w[a+728>>2]=0;w[a+732>>2]=-1;u[a+724|0]=0;w[a+668>>2]=0;v[a+814>>1]=0;a=a+896|0;if((b|0)!=(a|0)){continue}break}a=Cb(c,0,896);vk(a+112|0,48e3);w[a+740>>2]=0;w[a+744>>2]=-1;w[a+728>>2]=0;w[a+732>>2]=-1;w[a+752>>2]=0;w[a+756>>2]=-1;v[a+814>>1]=0;v[a+810>>1]=0;v[a+812>>1]=0;g=a+760|0;h=a+672|0;i=a+92|0;e=256;c=w[a+88>>2];while(1){b=Fb(d,a,88);w[b+88>>2]=c;Fb(b+92|0,i,576);w[b+668>>2]=0;Fb(b+672|0,h,52);w[b+752>>2]=0;w[b+756>>2]=-1;u[b+748|0]=0;w[b+740>>2]=0;w[b+744>>2]=-1;u[b+736|0]=0;w[b+728>>2]=0;w[b+732>>2]=-1;u[b+724|0]=0;Fb(b+760|0,g,135);d=b+896|0;b=e>>>0>1;e=e-1|0;if(b){continue}break}jb=a+896|0;return f|0}function NL(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;w[114256]=0;Q(14,d+24|0,a|0)|0;c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){d:{if(!x[d+24|0]){break d}c=w[w[a>>2]-12>>2];w[114256]=0;Sb(d+16|0,a+c|0);c=w[114256];w[114256]=0;e:{f:{g:{if((c|0)!=1){w[114256]=0;c=V(1579,d+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}Ab(d+16|0);e=Vd(d+8|0,a);f=w[w[a>>2]-12>>2];w[114256]=0;f=a+f|0;g=V(1580,f|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break f}e=w[e>>2];w[114256]=0;c=Va(1584,c|0,e|0,f|0,g|0,+b)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}w[d+16>>2]=c;if(!qf(d+16|0)){break d}c=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+c|0,5);c=w[114256];w[114256]=0;if((c|0)!=1){break d}c=W(0)|0;break e}c=W(0)|0;break e}c=W(0)|0;Ab(d+16|0);break e}c=W(0)|0}id(d+24|0);break c}id(d+24|0);break b}c=W(0)|0}$(c|0)|0;c=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+c|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}aa()}jb=d+32|0;return a|0}a=P()|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;if((d|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function _y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0;l=jb-16|0;i=w[a>>2];g=w[a+4>>2];j=w[a+40>>2];k=w[a+36>>2];a:{if(!d){b=j>>12;h=k>>12;break a}n=b+24|0;m=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];while(1){f=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;b=(((i>>>16|0)+4&131064)<<1)+n|0;s=v[b+14>>1];t=v[b+12>>1];u=v[b+10>>1];x=v[b+8>>1];y=v[b+6>>1];z=v[b+4>>1];A=v[b+2>>1];B=v[b>>1];h=0;b=1;while(1){e=h<<1;w[(l+8|0)+(h<<2)>>2]=(((((C(v[(e|8)+f>>1],u)+C(v[(e|4)+f>>1],x)|0)+C(v[(e|12)+f>>1],t)|0)+C(v[(e|16)+f>>1],s)|0)/2|0)+((((C(v[(e|-8)+f>>1],A)+C(v[(e|-12)+f>>1],B)|0)+C(v[(e|-4)+f>>1],z)|0)+C(v[e+f>>1],y)|0)/2|0)|0)/16384;e=b;b=0;h=1;if(e){continue}break}k=k+r|0;h=k>>12;w[c>>2]=w[c>>2]+C(h,w[l+8>>2]);j=j+q|0;b=j>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[l+12>>2]);g=g+o|0;e=i+m|0;g=e>>>0<m>>>0?g+1|0:g;i=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=k;w[a>>2]=i;w[a+4>>2]=g;w[a+40>>2]=j;w[a+20>>2]=h;w[a+24>>2]=b}function mc(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;w[c+12>>2]=0;w[c+8>>2]=1836;b=w[c+12>>2];w[c>>2]=w[c+8>>2];w[c+4>>2]=b;d=w[c+4>>2];b=c+16|0;w[b+4>>2]=w[c>>2];w[b+8>>2]=d;w[b>>2]=a;d=jb-16|0;jb=d;if(w[a>>2]!=-1){a:{b=Eg(d,Eg(d+8|0,b));while(1){if(w[a>>2]==1){continue}break}b:{c:{if(!w[a>>2]){hd(a,1);w[114256]=0;e=w[114256];w[114256]=0;d:{if((e|0)==1){break d}w[114256]=0;X(1842,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[a>>2]=-1;w[114256]=0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}}$(W(0)|0)|0;w[114256]=0;c=w[114256];w[114256]=0;e:{if((c|0)==1){break e}hd(a,0);w[114256]=0;a=w[114256];w[114256]=0;if((a|0)==1){break e}w[114256]=0;a=w[114256];w[114256]=0;if((a|0)==1){break e}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)==1){break c}R(a|0);M()}break a}W(0)|0;Eb()}M()}}jb=d+16|0;jb=c+32|0;return w[a+4>>2]-1|0}function Lk(a,b){a=a|0;b=b|0;a:{b:{switch((x[a+3|0]|64)+-64|0){case 0:u[a+3|0]=x[a+5|0]?42:0;return;case 1:u[a+3|0]=16;return;case 2:u[a+3|0]=12;return;case 3:u[a+3|0]=14;if(b){break a}b=a;a=x[a+5|0];u[b+5|0]=C(a>>>4|0,10)+(a&15);return;case 4:u[a+3|0]=11;return;case 5:u[a+3|0]=3;return;case 6:u[a+3|0]=2;return;case 7:u[a+3|0]=4;return;case 8:u[a+3|0]=5;return;case 9:u[a+3|0]=18;return;case 10:u[a+3|0]=1;return;case 11:u[a+3|0]=7;return;case 12:u[a+3|0]=6;return;case 13:u[a+3|0]=21;return;case 14:u[a+3|0]=22;return;case 15:u[a+3|0]=10;return;case 16:u[a+3|0]=29;return;case 17:u[a+3|0]=15;return;case 18:u[a+3|0]=8;return;case 19:u[a+3|0]=20;return;case 20:u[a+3|0]=17;return;case 21:u[a+3|0]=26;return;case 22:u[a+3|0]=23;return;case 23:u[a+3|0]=24;return;case 24:u[a+3|0]=9;return;case 25:u[a+3|0]=27;return;case 26:u[a+3|0]=31;return;case 28:u[a+3|0]=b?32:31;return;case 29:u[a+3|0]=33;return;case 27:u[a+3|0]=34;return;case 50:u[a+3|0]=b?25:0;return;case 51:u[a+3|0]=b?30:0;return;default:break b}}u[a+3|0]=0}}function Py(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0;r=w[a+16>>2];s=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);l=w[a+128>>2];a:{if(!l){m=w[a+8>>2];n=w[a+12>>2];j=w[a>>2];e=w[a+4>>2];o=0;break a}e=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];m=w[a+8>>2];n=w[a+12>>2];i=BV(m,n,d,0);g=j+i|0;b=nb+e|0;p=f>>>0<(g>>>0<i>>>0?b+1|0:b)>>>0?d:0;i=CV(m,n,l,l>>31);o=nb}if(d){h=a+112|0;t=w[a+24>>2];u=w[a+20>>2];x=(l|0)>0;while(1){p=p-1|0;b=p;i=b?i:0;o=b?o:0;g=0;k=j;q=(e<<1)+r|0;b=l;if(x){while(1){Ee(h,v[(g<<1)+q>>1]/4<<16>>16);De(h,4);g=g+o|0;k=i+k|0;g=k>>>0<i>>>0?g+1|0:g;f=b>>>0>1;b=b-1|0;if(f){continue}break}}d=d-1|0;k=w[a+120>>2];b=k+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<k>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){Ee(h,v[(g<<1)+q>>1]/4<<16>>16);De(h,b);w[h>>2]=w[h>>2];w[h+4>>2]=0}b=ih(h,s);w[c>>2]=w[c>>2]+C(b,u);w[c+4>>2]=w[c+4>>2]+C(b,t);e=e+n|0;b=j+m|0;e=b>>>0<m>>>0?e+1|0:e;j=b;c=c+8|0;if(d){continue}break}}w[a>>2]=j;w[a+4>>2]=e}function Fn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;h=ea(79)|0;e=w[114256];w[114256]=0;a:{b:{c:{d:{if((e|0)==1){break d}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;U(80,f+152|0,c|0,h|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,h|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}c=c+4|0;e=Ic(f+144|0,c);Wc(c,h);Ab(e)}Ab(f);b=w[b>>2];w[114256]=0;Q(85,d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=d+4|0;T(82,g|0,b|0);h=w[114256];w[114256]=0;if((h|0)==1){break d}h=w[15e3];w[d>>2]=h;w[w[h-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(b);pc(d+56|0);jb=f+160|0;break a}a=P()|0;break b}a=P()|0;Ab(f)}nd(d);R(a|0);M()}w[114256]=0;U(6,a|0,0,g|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+11|0]<0){zb(w[g>>2])}jb=g+16|0;return}a=P()|0;if(u[g+11|0]<0){zb(w[g>>2])}R(a|0);M()}function bh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;h=ea(79)|0;e=w[114256];w[114256]=0;a:{b:{c:{d:{if((e|0)==1){break d}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;U(80,f+152|0,c|0,h|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,h|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}c=c+4|0;e=Ic(f+144|0,c);Wc(c,h);Ab(e)}Ab(f);b=x[b|0];w[114256]=0;Q(85,d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=d+4|0;T(82,g|0,b|0);h=w[114256];w[114256]=0;if((h|0)==1){break d}h=w[15e3];w[d>>2]=h;w[w[h-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(b);pc(d+56|0);jb=f+160|0;break a}a=P()|0;break b}a=P()|0;Ab(f)}nd(d);R(a|0);M()}w[114256]=0;U(6,a|0,0,g|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[g+11|0]<0){zb(w[g>>2])}jb=g+16|0;return}a=P()|0;if(u[g+11|0]<0){zb(w[g>>2])}R(a|0);M()}function Hu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=jb-32|0;jb=f;a:{e=w[b>>2];b:{if(!(ob[w[w[e>>2]+40>>2]](e,c,d)|0)){b=Kb(16);w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=75696;w[b>>2]=75656;w[a+8>>2]=0;w[a+12>>2]=0;w[a+4>>2]=b;w[a>>2]=b+12;break b}e=w[b>>2];w[f+16>>2]=e;g=w[b+4>>2];w[f+20>>2]=g;if(g){w[g+4>>2]=w[g+4>>2]+1;e=w[b>>2]}b=w[w[e>>2]+24>>2];w[114256]=0;b=V(b|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}e=w[f+20>>2];w[f+8>>2]=w[f+16>>2];w[f+12>>2]=e;b=b-c|0;g=b>>>0<d>>>0?b:d;b=jb-16|0;jb=b;d=f+8|0;w[b+8>>2]=w[d>>2];e=w[d+4>>2];w[b+12>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}w[114256]=0;e=w[b+12>>2];w[b>>2]=w[b+8>>2];w[b+4>>2]=e;Y(135,f+24|0,b|0,c|0,g|0);c=w[114256];w[114256]=0;c:{if((c|0)!=1){Bb(d);jb=b+16|0;break c}a=P()|0;Bb(d);R(a|0);M()}c=w[f+24>>2];b=w[f+28>>2];w[a+4>>2]=b;w[a>>2]=c;if(!b){w[a+8>>2]=0;w[a+12>>2]=0;break b}w[b+4>>2]=w[b+4>>2]+1;w[a+8>>2]=0;w[a+12>>2]=0;a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break b}ob[w[w[b>>2]+8>>2]](b);Ib(b)}jb=f+32|0;return}a=P()|0;Bb(f+16|0);R(a|0);M()}function aQ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){w[b+24>>2]=0;w[b+16>>2]=0;w[b+20>>2]=0;c=w[a+24>>2];w[114256]=0;T(1394,b|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break f}c=w[b>>2];if((c|0)!=w[b+4>>2]){break e}a=b+16|0;break b}c=W(0)|0;break d}c=W(0)|0;break d}d=1;while(1){g:{if(!(d&1)){w[114256]=0;Q(1315,b+16|0,10070)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}}e=w[c>>2];f=w[c+4>>2];d=x[c+11|0];w[114256]=0;g=e;e=d<<24>>24<0;S(92,b+16|0,(e?g:c)|0,(e?f:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}d=0;c=c+12|0;if((c|0)!=w[b+4>>2]){continue}break c}break}c=W(0)|0;bc(b);if(u[b+27|0]>=0){break d}zb(w[b+16>>2])}$(c|0)|0;d=0;w[114256]=0;Y(1333,3360,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}a=u[b+27|0]<0?w[b+16>>2]:b+16|0}d=rc(a);bc(b);if(u[b+27|0]>=0){break a}zb(w[b+16>>2])}jb=b+32|0;return d|0}function KQ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){w[b+24>>2]=0;w[b+16>>2]=0;w[b+20>>2]=0;c=w[a+24>>2];w[114256]=0;T(1360,b|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break f}c=w[b>>2];if((c|0)!=w[b+4>>2]){break e}a=b+16|0;break b}c=W(0)|0;break d}c=W(0)|0;break d}d=1;while(1){g:{if(!(d&1)){w[114256]=0;Q(1315,b+16|0,10070)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}}e=w[c>>2];f=w[c+4>>2];d=x[c+11|0];w[114256]=0;g=e;e=d<<24>>24<0;S(92,b+16|0,(e?g:c)|0,(e?f:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}d=0;c=c+12|0;if((c|0)!=w[b+4>>2]){continue}break c}break}c=W(0)|0;bc(b);if(u[b+27|0]>=0){break d}zb(w[b+16>>2])}$(c|0)|0;d=0;w[114256]=0;Y(1333,2920,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}a=u[b+27|0]<0?w[b+16>>2]:b+16|0}d=rc(a);bc(b);if(u[b+27|0]>=0){break a}zb(w[b+16>>2])}jb=b+32|0;return d|0}function Zp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;g=x[a+11|0];j=g<<24>>24;k=(j|0)<0;h=k?w[a>>2]:a;i=b-h|0;a:{b:{if((c|0)!=(d|0)){f=d-c|0;g=k?w[a+4>>2]:g;if(g+h>>>0>=c>>>0&c>>>0>=h>>>0){break b}b=(j|0)>=0?10:(w[a+8>>2]&2147483647)-1|0;c:{if(b-g>>>0>=f>>>0){if((g|0)==(i|0)){break c}b=h+i|0;hc(b+f|0,b,g-i|0);break c}yg(a,b,(f+g|0)-b|0,g,i,0,f);h=w[a>>2]}b=f+g|0;d:{if(u[a+11|0]<0){w[a+4>>2]=b;break d}u[a+11|0]=b}u[b+h|0]=0;b=h+i|0;while(1){u[b|0]=x[c|0];b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}c=(u[a+11|0]<0?w[a>>2]:a)+i|0;break a}if(f>>>0<4294967280){e:{if(f>>>0<=10){u[e+11|0]=f;d=e;break e}h=(f|15)+1|0;d=Kb(h);w[e+8>>2]=h|-2147483648;w[e>>2]=d;w[e+4>>2]=f}l=Fb(d,c,f)+f|0,m=0,u[l|0]=m;w[114256]=0;d=a;f=b;a=x[e+11|0];b=a<<24>>24<0;c=b?w[e>>2]:e;c=Z(339,d|0,f|0,c|0,c+(b?w[e+4>>2]:a)|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}zc(e);M()}jb=e+16|0;return c|0}function ED(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-48|0;jb=f;a:{if(u[c+11|0]>=0){w[f+16>>2]=w[c+8>>2];g=w[c+4>>2];w[f+8>>2]=w[c>>2];w[f+12>>2]=g;break a}me(f+8|0,w[c>>2],w[c+4>>2])}c=f+20|0;b:{c:{d:{e:{if(u[d+11|0]>=0){g=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=g;w[c+8>>2]=w[d+8>>2];break e}g=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,c|0,d|0,g|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}c=f+32|0;f:{if(u[e+11|0]>=0){d=w[e+4>>2];w[c>>2]=w[e>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+8>>2];break f}d=w[e+4>>2];e=w[e>>2];w[114256]=0;U(3,c|0,e|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}w[114256]=0;d=f+44|0;w[f+4>>2]=d;w[f>>2]=f+8;U(51,a|0,b|0,f|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(f+8|0)){continue}break}jb=f+48|0;return}e=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(f+8|0)){continue}break}break b}e=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(f+8|0)){continue}break}}R(e|0);M()}function IE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=jb-32|0;jb=k;u[k+15|0]=0;l=Mi(k+16|0,d,k+15|0);i=w[l>>2];a:{if(!(!b|!d)){f=d;while(1){h=b-1|0;g=x[a|0];b:{c:{if(!(!h|(g|0)!=(e&255))){d:{h=b-2|0;if(!h){break d}g=x[a+1|0];g=f>>>0<g>>>0?f:g;if(!g){break d}j=x[a+2|0];h=b-3|0;a=a+3|0;i=(Cb(i,j,g)+(g-1&255)|0)+1|0;f=(0-g|-256)+f|0;break b}u[i|0]=e;a=a+2|0;break c}u[i|0]=g;a=a+1|0}i=i+1|0;f=f-1|0}if(h){b=h;if(f){continue}}break}i=w[l>>2];break a}f=d}g=d-f|0;e:{if(!g){break e}f=128;b=0;e=i;while(1){n=x[e|0];h=0;a=0;while(1){j=b+c|0;u[j|0]=x[j|0]|C(f&n,257)>>>(a-h&7);j=b+1|0;b=d>>>0>j>>>0?j:0;a=(d>>>0<=j>>>0)+a|0;f=(f<<8|f)>>>1&255;j=h&65535;h=h+1|0;if(j>>>0<7){continue}break}f=(f<<8|f)>>>a&255;e=e+1|0;m=m+1|0;if((m|0)!=(g|0)){continue}break}if(!g){break e}h=0;while(1){d=h<<24>>24;b=u[c|0];a=128;f:{if((b|0)==-128){break f}a=b;if((a|0)>=0){break f}a=0-(b&127)|0}h=d-(a&255)|0;u[c|0]=h;c=c+1|0;g=g-1|0;if(g){continue}break}}if(i){w[l+4>>2]=i;zb(i)}jb=k+32|0}function qz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a:{b:{c:{f=w[a+12>>2];h=w[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}k=w[a>>2];g=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];e:{if(!d){b=i>>12;m=j>>12;break e}n=w[a+16>>2];o=w[a+32>>2];p=w[a+28>>2];while(1){j=j+p|0;m=j>>12;e=(g<<1)+n|0;b=(k>>>16&65520)+l|0;e=(((((((C(v[e-4>>1],v[b+2>>1])+C(v[e-6>>1],v[b>>1])|0)+C(v[e-2>>1],v[b+4>>1])|0)+C(v[e>>1],v[b+6>>1])|0)+C(v[e+2>>1],v[b+8>>1])|0)+C(v[e+4>>1],v[b+10>>1])|0)+C(v[e+6>>1],v[b+12>>1])|0)+C(v[e+8>>1],v[b+14>>1])|0)/32768|0;w[c>>2]=w[c>>2]+C(m,e);i=i+o|0;b=i>>12;w[c+4>>2]=w[c+4>>2]+C(e,b);g=f+g|0;e=h+k|0;g=e>>>0<h>>>0?g+1|0:g;k=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=k;w[a+4>>2]=g;w[a+40>>2]=i;w[a+20>>2]=m;w[a+24>>2]=b}function jj(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;w[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!x[b|0]){break b}a=0;u[b|0]=0;b=w[e>>2];w[e>>2]=b+1;u[b|0]=46;if(!Db(h)){break a}b=w[j>>2];if((b-i|0)>159){break a}c=w[k>>2];w[j>>2]=b+4;w[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Db(h)){break c}if(!x[b|0]){break b}a=0;b=w[j>>2];if((b-i|0)>159){break a}a=w[k>>2];w[j>>2]=b+4;w[b>>2]=a;a=0;w[k>>2]=0;break a}a=-1;f=Pl(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=x[(f>>2)+64768|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=w[e>>2];if((b|0)!=(d|0)){a=-1;if((x[b-1|0]&95)!=(x[c|0]&127)){break a}}w[e>>2]=b+1;u[b|0]=g;a=0;break a}u[c|0]=80;break d}a=g&95;if((a|0)!=x[c|0]){break d}u[c|0]=a|128;if(!x[b|0]){break d}u[b|0]=0;if(!Db(h)){break d}a=w[j>>2];if((a-i|0)>159){break d}b=w[k>>2];w[j>>2]=a+4;w[a>>2]=b}a=w[e>>2];w[e>>2]=a+1;u[a|0]=g;a=0;if((f|0)>84){break a}w[k>>2]=w[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function YO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=w[b+12>>2];w[d+8>>2]=w[b+8>>2];w[d+12>>2]=e;e=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=e;a:{b:{c:{g=_p(d);d:{if(g){e=Kb(324);w[114256]=0;b=Q(1459,e|0,b|0)|0;f=w[114256];w[114256]=0;e:{if((f|0)!=1){w[d+28>>2]=b;w[d+24>>2]=b+12;break e}break a}e=w[d+24>>2];b=w[d+28>>2];if(!b){break d}break c}e=Kb(56);w[114256]=0;b=Q(1460,e|0,b|0)|0;f=w[114256];w[114256]=0;f:{if((f|0)!=1){w[d+20>>2]=b;w[d+16>>2]=b+12;break f}break a}e=w[d+16>>2];b=w[d+20>>2];if(b){break c}}w[a+12>>2]=c;w[a+4>>2]=0;w[a+8>>2]=0;w[a>>2]=e;break b}w[b+4>>2]=w[b+4>>2]+1;w[a+4>>2]=b;w[a>>2]=e;w[b+4>>2]=w[b+4>>2]+1;w[a+12>>2]=c;w[a+8>>2]=0;a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break b}ob[w[w[b>>2]+8>>2]](b);Ib(b)}g:{if(!g){a=w[d+20>>2];if(!a){break g}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break g}ob[w[w[a>>2]+8>>2]](a);Ib(a);break g}a=w[d+28>>2];if(!a){break g}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break g}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+32|0;return}a=P()|0;zb(e);R(a|0);M()}function di(a,b,c,d,e,f){var g=D(0),h=0,i=D(0),j=0,k=D(0),l=D(0);if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;b=a>>>2|0;a=f<<2;while(1){f=d-4|0;i=A[f>>2];k=A[d>>2];l=A[c>>2];A[c>>2]=k+l;h=c-4|0;g=A[h>>2];A[h>>2]=A[f>>2]+g;k=D(l-k);g=D(g-i);A[d>>2]=D(A[e>>2]*k)-D(A[e+4>>2]*g);A[f>>2]=D(A[e+4>>2]*k)+D(A[e>>2]*g);f=d-12|0;k=A[f>>2];h=c-8|0;g=A[h>>2];j=h;h=d-8|0;l=A[h>>2];A[j>>2]=l+g;j=c-12|0;i=A[j>>2];A[j>>2]=A[f>>2]+i;e=a+e|0;g=D(g-l);i=D(i-k);A[h>>2]=D(A[e>>2]*g)-D(A[e+4>>2]*i);A[f>>2]=D(A[e+4>>2]*g)+D(A[e>>2]*i);f=d-20|0;k=A[f>>2];h=c-16|0;g=A[h>>2];j=h;h=d-16|0;l=A[h>>2];A[j>>2]=l+g;j=c-20|0;i=A[j>>2];A[j>>2]=A[f>>2]+i;e=a+e|0;g=D(g-l);i=D(i-k);A[h>>2]=D(A[e>>2]*g)-D(A[e+4>>2]*i);A[f>>2]=D(A[e+4>>2]*g)+D(A[e>>2]*i);f=d-28|0;k=A[f>>2];h=c-24|0;g=A[h>>2];j=h;h=d-24|0;l=A[h>>2];A[j>>2]=l+g;j=c-28|0;i=A[j>>2];A[j>>2]=A[f>>2]+i;e=a+e|0;g=D(g-l);i=D(i-k);A[h>>2]=D(A[e>>2]*g)-D(A[e+4>>2]*i);A[f>>2]=D(A[e+4>>2]*g)+D(A[e>>2]*i);e=a+e|0;d=d-32|0;c=c-32|0;f=b>>>0>1;b=b-1|0;if(f){continue}break}}}function yO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;a:{b:{c:{d=w[b+24>>2];if(!y[d+480192>>1]){break c}f=1;d:{while(1){w[114256]=0;d=Q(1466,d|0,f&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;d=Q(5,c|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}e=w[d>>2];w[114256]=0;i=e;e=x[c+11|0];g=e<<24>>24<0;e=g?w[c+4>>2]:e;S(92,c+16|0,(g?i:d)|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;Q(1315,c+16|0,17238)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(u[c+11|0]<0){zb(w[d>>2])}h=(e|0)!=0|h;d=w[b+24>>2];f=f+1|0;if(y[d+480192>>1]>=(f&65535)>>>0){continue}break}if(!(h&1)){break c}w[114256]=0;Q(237,a|0,c+16|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}f=P()|0;break a}f=P()|0;if(u[c+11|0]>=0){break a}zb(w[d>>2]);break a}if(u[c+27|0]<0){zb(w[c+16>>2])}jb=c+32|0;return}f=P()|0}if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[a+11|0]<0){zb(w[a>>2])}R(f|0);M()}function xO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;a:{b:{c:{d=w[b+24>>2];if(!y[d+480190>>1]){break c}f=1;d:{while(1){w[114256]=0;d=Q(1467,d|0,f&65535)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}w[114256]=0;d=Q(5,c|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break b}e=w[d>>2];w[114256]=0;i=e;e=x[c+11|0];g=e<<24>>24<0;e=g?w[c+4>>2]:e;S(92,c+16|0,(g?i:d)|0,e|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}w[114256]=0;Q(1315,c+16|0,17238)|0;g=w[114256];w[114256]=0;if((g|0)==1){break d}if(u[c+11|0]<0){zb(w[d>>2])}h=(e|0)!=0|h;d=w[b+24>>2];f=f+1|0;if(y[d+480190>>1]>=(f&65535)>>>0){continue}break}if(!(h&1)){break c}w[114256]=0;Q(237,a|0,c+16|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}f=P()|0;break a}f=P()|0;if(u[c+11|0]>=0){break a}zb(w[d>>2]);break a}if(u[c+27|0]<0){zb(w[c+16>>2])}jb=c+32|0;return}f=P()|0}if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[a+11|0]<0){zb(w[a>>2])}R(f|0);M()}function $y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0,B=0,D=0;l=jb-16|0;h=w[a>>2];f=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];a:{if(!d){b=i>>12;g=j>>12;break a}n=b+24|0;m=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];while(1){e=(((f&2147483647)<<1|h>>>31)&-2)+p|0;b=(((h>>>16|0)+4&131064)<<1)+n|0;s=v[b+14>>1];t=v[b+12>>1];x=v[b+10>>1];y=v[b+8>>1];z=v[b+6>>1];A=v[b+4>>1];B=v[b+2>>1];D=v[b>>1];b=0;g=1;while(1){w[(l+8|0)+(b<<2)>>2]=(((((C(u[(b|4)+e|0],x)+C(u[(b|2)+e|0],y)|0)+C(u[(b|6)+e|0],t)|0)+C(u[(b|8)+e|0],s)<<8)/2|0)+((((C(u[(b|-4)+e|0],B)+C(u[(b|-6)+e|0],D)|0)+C(u[(b|-2)+e|0],A)|0)+C(u[b+e|0],z)<<8)/2|0)|0)/16384;k=g;g=0;b=1;if(k){continue}break}j=j+r|0;g=j>>12;w[c>>2]=w[c>>2]+C(g,w[l+8>>2]);i=i+q|0;b=i>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[l+12>>2]);f=f+o|0;k=h+m|0;f=k>>>0<m>>>0?f+1|0:f;h=k;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=h;w[a+4>>2]=f;w[a+40>>2]=i;w[a+20>>2]=g;w[a+24>>2]=b}function Ed(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=ve(a)&2047;c=ve(5551115123125783e-32);d=e-c|0;a:{if(d>>>0>=ve(512)-c>>>0){if((d|0)<0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(ve(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(ve(O)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Oj(3105036184601418e216)}if(c>>>0<3230714880){break b}return Oj(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=B[6437];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*B[6442]+B[6441]);b=b*(a*B[6440]+B[6439]);a=a*B[6438];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+B[d+51544>>3]));d=d+51552|0;h=w[d>>2];c=w[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){gu(hu()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function xm(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;$c(g+16|0,a,b,c,e,h-15233|0);fg(g,a,b,c,e,15361-h|0);e=w[g+4>>2];h=e;a=w[g+8>>2];c=w[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=w[g>>2]|(w[g+16>>2]|w[g+24>>2]|(w[g+20>>2]|w[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a:{b:{c:{f=w[a+12>>2];h=w[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}k=w[a>>2];g=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];e:{if(!d){b=i>>12;m=j>>12;break e}n=w[a+16>>2];o=w[a+32>>2];p=w[a+28>>2];while(1){j=j+p|0;m=j>>12;e=g+n|0;b=(k>>>16&65520)+l|0;e=(((((((C(u[e-2|0],v[b+2>>1])+C(u[e-3|0],v[b>>1])|0)+C(u[e-1|0],v[b+4>>1])|0)+C(u[e|0],v[b+6>>1])|0)+C(u[e+1|0],v[b+8>>1])|0)+C(u[e+2|0],v[b+10>>1])|0)+C(u[e+3|0],v[b+12>>1])|0)+C(u[e+4|0],v[b+14>>1])<<8)/32768|0;w[c>>2]=w[c>>2]+C(m,e);i=i+o|0;b=i>>12;w[c+4>>2]=w[c+4>>2]+C(e,b);g=f+g|0;e=h+k|0;g=e>>>0<h>>>0?g+1|0:g;k=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=k;w[a+4>>2]=g;w[a+40>>2]=i;w[a+20>>2]=m;w[a+24>>2]=b}function mj(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;u[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!x[b|0]){break b}a=0;u[b|0]=0;b=w[e>>2];w[e>>2]=b+1;u[b|0]=46;if(!Db(h)){break a}b=w[j>>2];if((b-i|0)>159){break a}c=w[k>>2];w[j>>2]=b+4;w[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Db(h)){break c}if(!x[b|0]){break b}a=0;b=w[j>>2];if((b-i|0)>159){break a}a=w[k>>2];w[j>>2]=b+4;w[b>>2]=a;a=0;w[k>>2]=0;break a}a=-1;f=Tl(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=x[f+64768|0];d:{e:{switch((f&-2)-22|0){case 2:b=w[e>>2];if((b|0)!=(d|0)&(x[b-1|0]&95)!=(x[c|0]&127)){break a}w[e>>2]=b+1;u[b|0]=g;a=0;break a;case 0:u[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=x[c|0]){break d}u[c|0]=a|128;if(!x[b|0]){break d}u[b|0]=0;if(!Db(h)){break d}a=w[j>>2];if((a-i|0)>159){break d}b=w[k>>2];w[j>>2]=a+4;w[a>>2]=b}a=w[e>>2];w[e>>2]=a+1;u[a|0]=g;a=0;if((f|0)>21){break a}w[k>>2]=w[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function Uz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0;f=w[a+48>>2];j=w[a>>2];g=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}l=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;v=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){k=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,v,e,e>>31);h=nb;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;i=BV(r,s,f,f>>31);e=i+e|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;h=e;i=g+p|0;e=u[i|0];z=k;A=h;k=((C(u[i+1|0]-e|0,j>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=k;h=BV(e,e>>31,x,y);e=A+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=z+C(e,o);w[c+4>>2]=w[c+4>>2]+C(e,n);e=f-(k&q)|0;g=g+m|0;f=j+l|0;g=f>>>0<l>>>0?g+1|0:g;j=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=j;w[a+4>>2]=g}function Qy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0;r=w[a+16>>2];s=ed(b+327720|0,w[b+20>>2],(w[a+88>>2]&16384)>>>14|0);l=w[a+128>>2];a:{if(!l){m=w[a+8>>2];n=w[a+12>>2];j=w[a>>2];e=w[a+4>>2];o=0;break a}e=w[a+4>>2];f=w[a+76>>2];j=w[a>>2];m=w[a+8>>2];n=w[a+12>>2];i=BV(m,n,d,0);g=j+i|0;b=nb+e|0;p=f>>>0<(g>>>0<i>>>0?b+1|0:b)>>>0?d:0;i=CV(m,n,l,l>>31);o=nb}if(d){h=a+112|0;t=w[a+24>>2];v=w[a+20>>2];x=(l|0)>0;while(1){p=p-1|0;b=p;i=b?i:0;o=b?o:0;g=0;k=j;q=e+r|0;b=l;if(x){while(1){Ee(h,u[g+q|0]<<6);De(h,4);g=g+o|0;k=i+k|0;g=k>>>0<i>>>0?g+1|0:g;f=b>>>0>1;b=b-1|0;if(f){continue}break}}d=d-1|0;k=w[a+120>>2];b=k+w[a+112>>2]|0;f=w[a+116>>2]+w[a+124>>2]|0;f=b>>>0<k>>>0?f+1|0:f;w[a+112>>2]=b;w[a+116>>2]=f;b=f;if(b){Ee(h,u[g+q|0]<<6);De(h,b);w[h>>2]=w[h>>2];w[h+4>>2]=0}b=ih(h,s);w[c>>2]=w[c>>2]+C(b,v);w[c+4>>2]=w[c+4>>2]+C(b,t);e=e+n|0;b=j+m|0;e=b>>>0<m>>>0?e+1|0:e;j=b;c=c+8|0;if(d){continue}break}}w[a>>2]=j;w[a+4>>2]=e}function Tz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0;f=w[a+48>>2];j=w[a>>2];g=w[a+4>>2];e=w[a+44>>2];a:{if(!d){b=f;break a}l=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;u=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){k=w[c>>2];b=e;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;e=BV(t,u,e,e>>31);h=nb;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;i=BV(r,s,f,f>>31);e=i+e|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;h=e;i=(g<<1)+p|0;e=v[i>>1];z=k;A=h;k=e+((C(v[i+2>>1]-e|0,j>>>18|0)|0)/16384|0)<<8;e=k;h=BV(e,e>>31,x,y);e=A+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;w[c>>2]=z+C(e,o);w[c+4>>2]=w[c+4>>2]+C(e,n);e=f-(k&q)|0;g=g+m|0;f=j+l|0;g=f>>>0<l>>>0?g+1|0:g;j=f;c=c+8|0;f=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=e;w[a>>2]=j;w[a+4>>2]=g}function sA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;a:{b:{c:{d:{while(1){h=c;if(!c){break d}c=h-1|0;if(!x[c+b|0]){continue}break}if((d|0)!=4){break b}c=0;while(1){e:{f:{g:{d=b+c|0;f=x[d|0];switch(f-10|0){case 0:break f;case 3:break g;default:break e}}e=e+1|0;break e}g=g+1|0}i=c?(x[d-1|0]==13&(f|0)==10)+i|0:i;c=c+1|0;if((h|0)!=(c|0)){continue}break}break c}f=1;h=0;if((d|0)!=4){break a}}h:{if((e|0)==(g|0)){d=2;if((e|0)==(i|0)){break h}}if(e){d=0;if(!g){break h}}d=e?3:g?1:3}if(h){break b}h=0;f=1;e=0;break a}f=0;g=(d|0)==2;c=0;e=0;while(1){e=e+1|0;c=((g&x[b+c|0]==13)+c|0)+1|0;if(h>>>0>c>>>0){continue}break}}i:{if(u[a+11|0]<0){u[w[a>>2]]=0;w[a+4>>2]=0;break i}u[a+11|0]=0;u[a|0]=0}xl(a,e);if(!f){g=(d|0)==1?32:13;f=d&-3?13:32;d=(d|0)==2;c=0;while(1){j:{k:{l:{m:{e=u[b+c|0];switch(e-10|0){case 1:case 2:break j;case 0:break k;case 3:break l;default:break m}}if(e){break j}e=32;break j}c=c+d|0;e=g;break j}e=f}Ui(a,e);c=c+1|0;if(h>>>0>c>>>0){continue}break}}return 1}function lC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;u[e+15|0]=8;v[e+12>>1]=0;if(d){l=C(c,d);c=0;while(1){if((l|0)>0){i=(k<<1)+b|0;o=i+(l<<1)|0;m=c;while(1){v[e+10>>1]=0;Ap(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=x[e+15|0];if(!g){break b}c=y[e+12>>1];while(1){f=c<<1;c=f&254;v[e+12>>1]=c;f=(f&65534)>>>0>255;u[e+14|0]=f;if(!c){if(!Xb(a,e+9|0)){break b}c=x[e+9|0];f=c>>>7|0;u[e+14|0]=f;c=c<<1&254|1;v[e+12>>1]=c}j=y[e+10>>1]<<1|f;v[e+10>>1]=j;g=g-1|0;if(g&255){continue}break}break a}j=y[e+10>>1]}c=1;g=j&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;n=c&255;if(g>>>n&1){break c}f=c-1|0;if(n>>>0>1){continue}break}}u[e+15|0]=(x[e+15|0]+c&254)>>>1;c=j&1;u[e+14|0]=c;f=h;h=c-1^(j&65534)>>>1;c=f+h|0;v[e+10>>1]=c;v[i>>1]=c;f=-32768;i=(d<<1)+i|0;h=((h>>1)-(m<<16>>16)|0)+(c<<16>>16<<1)|0;d:{if((h|0)>=-32768){f=32767;if((h|0)<32768){break d}}h=f}m=c;if(i>>>0<o>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function _t(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-208|0;jb=d;w[d+8>>2]=1;w[d+12>>2]=0;h=b<<2;a:{if(!h){break a}w[d+16>>2]=4;w[d+20>>2]=4;b=4;e=4;g=2;while(1){f=b;b=(e+4|0)+b|0;w[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;e=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){g=0;b=1;f=0;break b}g=1;b=1;while(1){c:{if((g&3)==3){Am(a,c,b,d+16|0);Mj(d+8|0,2);b=b+2|0;break c}e=b-1|0;d:{if(z[(d+16|0)+(e<<2)>>2]>=f-a>>>0){Lj(a,c,d+8|0,b,0,d+16|0);break d}Am(a,c,b,d+16|0)}if((b|0)==1){Kj(d+8|0,1);b=0;break c}Kj(d+8|0,e);b=1}e=w[d+8>>2];g=e|1;w[d+8>>2]=g;a=a+4|0;if(f>>>0>a>>>0){continue}break}g=e>>>0>1;f=w[d+12>>2]!=0}Lj(a,c,d+8|0,b,0,d+16|0);if(!(f|((b|0)!=1|g))){break a}while(1){e:{if((b|0)<=1){e=d+8|0;f=Zt(e);Mj(e,f);g=w[d+8>>2];b=b+f|0;break e}e=d+8|0;Kj(e,2);w[d+8>>2]=w[d+8>>2]^7;Mj(e,1);i=a-4|0;h=d+16|0;f=b-2|0;Lj(i-w[h+(f<<2)>>2]|0,c,e,b-1|0,1,h);Kj(e,1);g=w[d+8>>2]|1;w[d+8>>2]=g;Lj(i,c,e,f,1,h);b=f}a=a-4|0;if(w[d+12>>2]|(g|0)!=1|(b|0)!=1){continue}break}}jb=d+208|0}function dQ(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;f=Hb(g,11528);c=x[f+11|0];h=c<<24>>24;d=(h|0)<0?w[f+4>>2]:c;b=0;a:{if(!d){break a}b:{if((d|0)<=0){break b}c=(h|0)<0?w[f>>2]:f;e=c+d|0;b=d;a=c;c:{while(1){a=uc(a,58,b);if(!a){break c}if(x[a|0]!=58){a=a+1|0;b=e-a|0;if((b|0)>0){continue}break c}break}if((a|0)==(e|0)){break c}b=1;if((a-c|0)!=-1){break a}}if((d|0)<=0){break b}b=d;a=c;d:{while(1){a=uc(a,45,b);if(!a){break d}if(x[a|0]!=45){a=a+1|0;b=e-a|0;if((b|0)>0){continue}break d}break}if((a|0)==(e|0)){break d}b=1;if((a-c|0)!=-1){break a}}if((d|0)<=0){break b}b=d;a=c;e:{while(1){a=uc(a,83,b);if(!a){break e}if(x[a|0]!=83){a=a+1|0;b=e-a|0;if((b|0)>0){continue}break e}break}if((a|0)==(e|0)){break e}b=1;if((a-c|0)!=-1){break a}}if((d|0)<=0){break b}b=c;while(1){a=uc(b,80,d);if(!a){break b}if(x[a|0]!=80){b=a+1|0;d=e-b|0;if((d|0)>0){continue}break b}break}if((a|0)==(e|0)){break b}b=1;if((a-c|0)!=-1){break a}}b=0}c=b;if((h|0)<0){zb(w[f>>2])}jb=g+16|0;return c|0}function Df(a){var b=0,c=0,d=0,e=0;w[114256]=0;V(816,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=w[a+4>>2];if(b){d=w[b>>2];if(d){c=w[b+4>>2];if((d|0)!=(c|0)){while(1){c=c-4|0;e=w[c>>2];w[c>>2]=0;if(e){od(e)}if((d|0)!=(c|0)){continue}break}}w[b+4>>2]=d;zb(w[b>>2])}zb(b)}w[a+4>>2]=0;b=w[a+1304500>>2];if(b){w[a+1304504>>2]=b;zb(b)}if(u[a+1304495|0]<0){zb(w[a+1304484>>2])}if(u[a+1304483|0]<0){zb(w[a+1304472>>2])}if(u[a+1304471|0]<0){zb(w[a+1304460>>2])}if(u[a+1304459|0]<0){zb(w[a+1304448>>2])}if(u[a+1304447|0]<0){zb(w[a+1304436>>2])}if(u[a+1304435|0]<0){zb(w[a+1304424>>2])}if(u[a+1304423|0]<0){zb(w[a+1304412>>2])}if(u[a+1304411|0]<0){zb(w[a+1304400>>2])}kk(a+1304396|0,0);jk(a+1304392|0,0);b=w[a+1304372>>2];if(b){w[a+1304376>>2]=b;zb(b)}ui(a+1304360|0);b=a+946300|0;e=a+906300|0;while(1){c=b-160|0;d=w[c+4>>2];if(d){w[b-152>>2]=d;zb(d)}b=c;if((e|0)!=(b|0)){continue}break}Ak(a+484360|0);Gn(a+484344|0);b=w[a+480248>>2];if(b){w[a+480252>>2]=b;zb(b)}return a}W(0)|0;Eb();M()}function wK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;w[g+24>>2]=b;a:{b:{if(!(w[d+4>>2]&1)){w[g>>2]=-1;b=ob[w[w[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(w[g>>2]){case 1:u[f|0]=1;break a;case 0:break b;default:break c}}u[f|0]=1;w[e>>2]=4;break a}Sb(g,d);w[114256]=0;b=V(1561,g|0)|0;a=w[114256];w[114256]=0;d:{e:{f:{g:{if((a|0)!=1){Ab(g);Sb(g,d);w[114256]=0;a=V(1704,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}Ab(g);w[114256]=0;T(1705,g|0,a|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;break d}w[114256]=0;T(1706,g|12,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}w[114256]=0;d=g+24|0;a=va(1707,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}u[f|0]=(a|0)==(g|0);b=w[g+24>>2];while(1){d=Gb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;Ab(g);break d}b=P()|0;Ab(g);break d}b=P()|0;Gb(g);break d}b=P()|0;while(1){d=Gb(d-12|0);if((g|0)!=(d|0)){continue}break}}R(b|0);M()}u[f|0]=0}jb=g+32|0;return b|0}function bK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;w[g+24>>2]=b;a:{b:{if(!(w[d+4>>2]&1)){w[g>>2]=-1;b=ob[w[w[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(w[g>>2]){case 1:u[f|0]=1;break a;case 0:break b;default:break c}}u[f|0]=1;w[e>>2]=4;break a}Sb(g,d);w[114256]=0;b=V(1735,g|0)|0;a=w[114256];w[114256]=0;d:{e:{f:{g:{if((a|0)!=1){Ab(g);Sb(g,d);w[114256]=0;a=V(1736,g|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break g}Ab(g);w[114256]=0;T(1737,g|0,a|0);d=w[114256];w[114256]=0;if((d|0)==1){b=P()|0;break d}w[114256]=0;T(1738,g|12,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break f}w[114256]=0;d=g+24|0;a=va(1739,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}u[f|0]=(a|0)==(g|0);b=w[g+24>>2];while(1){d=$b(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;Ab(g);break d}b=P()|0;Ab(g);break d}b=P()|0;$b(g);break d}b=P()|0;while(1){d=$b(d-12|0);if((g|0)!=(d|0)){continue}break}}R(b|0);M()}u[f|0]=0}jb=g+32|0;return b|0}function Gf(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=(w[a+1074324>>2]&1?0:w[b+660>>2])+c|0;w[b+660>>2]=f;d=w[a+480180>>2];g=w[b+84>>2];if(!(!(d&18)|g>>>0>c>>>0|(!(x[b+88|0]&2)|!g))){e=c;c=w[b+80>>2];c=((e-c>>>0)%(g-c>>>0)|0)+c|0}h=w[b+88>>2];c=c>>>(h&1&(d|0)==16384)|0;e=x[b+810|0];a:{if((e-1&255)>>>0<=119){d=w[b+656>>2];if(d){d=y[(d+(e<<1)|0)+234>>1];if(!d|d>>>0>y[a+480190>>1]){break a}}e=w[a+480208>>2];b:{if(e&2097152){w[b+660>>2]=c+f;c=f;f=0;break b}f=0}w[b>>2]=f;w[b+4>>2]=c;d=w[b+76>>2];if((!(h&2)|c>>>0<g>>>0)&c>>>0<d>>>0){break a}c:{if(!(x[a+1074319|0]&2)){c=w[a+480180>>2];if((c|0)!=16){break c}}w[b+700>>2]=0;w[b+88>>2]=h|2097152;return}if(!(c&1048581)){if(x[a+1074315|0]&8){if(e&4){w[b>>2]=0;w[b+4>>2]=d;return}w[b>>2]=0;w[b+4>>2]=0;return}c=w[b+80>>2];w[b>>2]=0;w[b+4>>2]=c;if(!(e&4)|d>>>0<5){break a}w[b>>2]=0;w[b+4>>2]=d-2;return}if(!(h&2)|(c|0)!=1){break a}a=w[b+80>>2];w[b>>2]=0;w[b+4>>2]=a;return}if(!(d&268582928)|c>>>0>=z[b+76>>2]){break a}w[b>>2]=0;w[b+4>>2]=c}}function We(a){a=a|0;var b=0;a:{b:{switch(x[a+3|0]){case 0:if(!x[a+5|0]){break a}u[a+3|0]=1;return;case 1:u[a+3|0]=2;return;case 2:u[a+3|0]=3;return;case 3:u[a+3|0]=4;return;case 4:u[a+3|0]=5;return;case 5:u[a+3|0]=6;return;case 6:u[a+3|0]=7;return;case 7:u[a+3|0]=8;return;case 8:u[a+3|0]=9;return;case 9:u[a+3|0]=10;return;case 10:u[a+3|0]=11;return;case 11:u[a+3|0]=12;return;case 12:u[a+3|0]=13;return;case 13:u[a+3|0]=14;b=a;a=x[a+5|0];u[b+5|0]=C(a>>>4|0,10)+(a&15);return;case 14:u[a+3|0]=19;return;case 15:if(x[a+5|0]<=31){u[a+3|0]=16;return}u[a+3|0]=17;return;case 16:u[a+3|0]=23;return;case 17:u[a+3|0]=24;return;case 20:u[a+3|0]=25;return;case 21:u[a+3|0]=30;return;case 25:u[a+3|0]=29;return;case 27:u[a+3|0]=15;return;case 29:u[a+3|0]=18;return;case 32:u[a+3|0]=42;return;case 33:u[a+3|0]=28;return;case 34:u[a+3|0]=27;return;case 35:u[a+3|0]=31;return;case 36:u[a+3|0]=32;return;case 37:u[a+3|0]=32;return;case 38:u[a+3|0]=34;return;default:break b}}u[a+3|0]=0}}function ix(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=w[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>2|0;j=c>>>0>e>>>0?e:c;a:{if(!j){break a}i=j;e=b;while(1){c=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);b:{c:{d:{if((f|0)>=0){c=f;break d}c=-2147483648;if((f|0)==-2147483648){break c}c=0-f|0}if(g>>>0>=c>>>0){break b}}g=c}e=e+4|0;i=i-1|0;if(i){continue}break}if(!g|!j){break a}i=g-1|0;k=g>>>1|0;e=w[a+20>>2];a=j;while(1){c=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=c>>31;f=c;c=h<<31|c>>>1;f=k|f<<31;e:{if((c|0)>0|(c|0)>=0){f=EV(f,c,g,0);c=nb;h=(c|0)>=0&f>>>0>=2147483647|(c|0)>0;f=h?2147483647:f;c=h?0:c;break e}c=EV(i-f|0,0-((f>>>0>i>>>0)+c|0)|0,g,0);f=0-c|0;c=0-(nb+((c|0)!=0)|0)|0;h=(c|0)<0&f>>>0<=2147483648|(c|0)<-1;f=h?-2147483648:f;c=h?-1:c}v[e>>1]=(c&65535)<<16|f>>>16;b=b+4|0;e=e+2|0;a=a-1|0;if(a){continue}break}}if(d){w[d>>2]=g}return j<<2}function ey(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=w[a+4>>2];e=w[a>>2];f=d-e>>5;if(f>>>0<b>>>0){h=jb-32|0;jb=h;a:{e=b-f|0;g=w[a+8>>2];d=w[a+4>>2];b:{if(e>>>0<=g-d>>5>>>0){c:{if(e){b=(e<<5)+d|0;while(1){w[114256]=0;e=Q(709,d|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break c}d=e+32|0;if((b|0)!=(d|0)){continue}break}}else{b=d}w[a+4>>2]=b;break a}c=P()|0;w[a+4>>2]=d;break b}d:{e:{b=d;d=w[a>>2];f=b-d>>5;b=f+e|0;if(b>>>0<134217728){d=g-d|0;g=d>>4;b=Vh(h+8|0,d>>>0>=2147483616?134217727:b>>>0<g>>>0?g:b,f,a+8|0);d=w[b+8>>2];f=d+(e<<5)|0;while(1){w[114256]=0;e=Q(709,d|0,c|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break e}d=e+32|0;if((f|0)!=(d|0)){continue}break}w[b+8>>2]=f;w[114256]=0;T(712,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){xi(b);break a}c=P()|0;break d}Mb(a);M()}c=P()|0;w[b+8>>2]=d}xi(b)}R(c|0);M()}jb=h+32|0;return}if(b>>>0<f>>>0){b=e+(b<<5)|0;if((b|0)!=(d|0)){while(1){d=d-32|0;mh(d);if((b|0)!=(d|0)){continue}break}}w[a+4>>2]=b}}function _g(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;e=a+1074404|0;b=w[a+480244>>2];f=b;g=b>>31;a:{b:{switch(w[a+480224>>2]-1|0){default:b=w[a+24620>>2];b=BV(b,b>>31,5e4,0);a=w[a+1074420>>2]<<1;a=a?a:1;b=CV(b,nb,a,a>>31);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;d=c;a=b?0:a;c=(a|0)<0&c>>>0<=2147483648|(a|0)<-1;b=c?-2147483648:d;break a;case 1:h=BV(w[a+24620>>2],0,6e5,0);d=nb;a=BV(w[a+1074420>>2],0,BV(w[a+1074408>>2],0,w[a+1074416>>2],0),nb);c=a;b=nb;a=!b&a>>>0<=1;b=EV(h,d,a?1:c,a?0:b);break a;case 0:break b}}b=w[a+24620>>2];b=BV(b,b>>31,1e4,0);a=w[a+1074420>>2];a=a>>>0<=1?1:a;b=CV(b,nb,a,a>>31);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;d=c;a=b?0:a;c=(a|0)<0&c>>>0<=2147483648|(a|0)<-1;b=c?-2147483648:d}a=b;b=a>>31;b=BV(f,g,a,b)+32768|0;a=nb;d=e;b=CV(b,b>>>0<32768?a+1|0:a,65536,0);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;e=b?2147483647:c;a=b?0:a;a=(a|0)<0&e>>>0<=2147483648|(a|0)<-1?-2147483648:e;w[d>>2]=a?a:1}function Hw(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;b=jb-16|0;jb=b;A[b+8>>2]=2;v[b+14>>1]=12;w[b+4>>2]=15;e=Kb(64);w[114256]=0;c=V(836,e|0)|0;f=w[114256];w[114256]=0;a:{b:{c:{if((f|0)!=1){w[114256]=0;w[b>>2]=c;Q(117,c+40|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}w[114256]=0;a=S(837,c|0,b+14|0,b+8|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break c}d:{if(a){w[114256]=0;T(838,c|0,b+4|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}a=c;break d}w[b>>2]=0;od(c);a=0}jb=b+16|0;break a}a=P()|0;zb(e);break b}a=P()|0;w[b>>2]=0;od(c)}R(a|0);M()}c=a;w[d+24>>2]=c;a=0;e:{f:{g:{while(1){w[114256]=0;v[d+22>>1]=a;b=Q(1,d+8|0,(a<<2)+25728|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(835,c|0,d+22|0,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break f}if(u[d+19|0]<0){zb(w[b>>2])}a=a+1|0;if((a|0)!=12){continue}break}jb=d+32|0;return c|0}a=P()|0;break e}a=P()|0;if(u[d+19|0]>=0){break e}zb(w[b>>2])}w[d+24>>2]=0;if(c){od(c)}R(a|0);M()}function To(a,b,c){var d=0;d=x[a|0]&15;u[a|0]=x[d+23872|0];a:{b:{c:{switch(d|0){case 0:if(x[b|0]?c>>>0>=51:0){break b}u[a|0]=0;return;case 5:d=x[b|0];if(!((d&15)!=2&(d&240)!=32)){u[a|0]=20;u[b|0]=159;return}d:{if((d&15)!=12){if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}u[a|0]=25;u[b|0]=0;return;case 7:if(c>>>0>51){break b}u[a|0]=0;return;case 10:a=x[b|0]&240;if(!a){break b}u[b|0]=a;return;case 11:u[b|0]=C(x[b|0]&15,17);return;case 12:u[b|0]=x[b|0]>>>2;return;case 13:a=x[b|0];u[b|0]=C(a>>>4|0,10)+(a&15);return;case 14:e:{switch((x[b|0]>>>4|0)-1|0){case 0:u[a|0]=2;break a;case 1:u[a|0]=3;break a;case 7:if(c>>>0<52){break b}u[a|0]=20;u[b|0]=x[b|0]&15|96;return;case 8:u[a|0]=15;u[b|0]=x[b|0]&15;return;case 9:u[a|0]=11;u[b|0]=x[b|0]<<4|15;return;case 10:u[a|0]=11;break a;case 11:case 12:break e;default:break b}}u[a|0]=20;return;case 15:break c;default:break b}}if(x[b|0]<48){break b}u[a|0]=17}return}u[b|0]=x[b|0]|240}function or(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;w[a+12>>2]=c;w[a+8>>2]=f;w[a+12>>2]=c;w[a+8>>2]=f;b=w[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=w[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=w[a+8>>2];if((g-f|0)<=0){break a}w[a+8>>2]=f+1;u[f|0]=b;break c}if(b>>>0<=2047){c=w[a+8>>2];if((g-c|0)<2){break b}w[a+8>>2]=c+1;u[c|0]=b>>>6|192;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128;break c}c=w[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}w[a+8>>2]=c+1;u[c|0]=b>>>12|224;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b>>>6&63|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128;break c}if((f|0)<4){break b}w[a+8>>2]=c+1;u[c|0]=b>>>18|240;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b>>>12&63|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b>>>6&63|128;c=w[a+8>>2];w[a+8>>2]=c+1;u[c|0]=b&63|128}b=w[a+12>>2]+4|0;w[a+12>>2]=b;continue}break}c=1}w[e>>2]=w[a+12>>2];w[h>>2]=w[a+8>>2];jb=a+16|0;return c|0}function Ie(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;w[i+16>>2]=c;w[i+24>>2]=b;b=i+8|0;Sb(b,d);w[114256]=0;j=V(1735,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){Ab(i+8|0);w[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Le(i+24|0,i+16|0)){break b}c:{if((Bg(j,w[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}k=0;c=Bg(j,w[b>>2]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=Bg(j,w[g+8>>2])}l=i,m=ob[w[w[a>>2]+36>>2]](a,w[i+24>>2],w[i+16>>2],d,e,f,c,k)|0,w[l+24>>2]=m;g=b+8|0;break c}if(pf(j,1,w[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(pf(j,1,w[g>>2])){continue}}break}while(1){if(!zj(i+24|0,i+16|0)){break c}if(!pf(j,1,bg(i+24|0))){break c}Mg(i+24|0);continue}}if(($f(j,bg(i+24|0))|0)==($f(j,w[g>>2])|0)){g=g+4|0;Mg(i+24|0);break c}w[e>>2]=4}b=w[e>>2];continue}break}w[e>>2]=4}if(Le(i+24|0,i+16|0)){w[e>>2]=w[e>>2]|2}jb=i+32|0;return w[i+24>>2]}a=P()|0;Ab(i+8|0);R(a|0);M()}function mC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-16|0;jb=f;if(d){l=C(c,d);p=(l|0)<=0;c=0;j=4;while(1){if(!p){i=b+k|0;q=l+i|0;while(1){h=0;while(1){a:{b:{c:{c=c<<1;e=c&254;d:{e:{if(e){c=(c&65534)>>>0>255;break e}if(!Xb(a,f+15|0)){break d}e=x[f+15|0];c=e>>>7|0;e=e<<1&254|1}h=h<<1|c;c=e<<1&254;if(c){break b}if(Xb(a,f+14|0)){break c}}c=0;break a}e=u[f+14|0];c=e<<1&254|1;if((e|0)<0){continue}break a}if(e>>>0>127){continue}}break}e=j;f:{if(!e){break f}while(1){g:{g=c<<1;c=g&254;h:{if(c){g=(g&65534)>>>0>255;break h}if(!Xb(a,f+13|0)){break g}c=x[f+13|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;e=e-1|0;if(e&255){continue}break f}break}c=0}e=1;m=h&255;i:{if(m>>>0<4){break i}g=7;while(1){e=g;n=e&255;if(m>>>n&1){break i}g=e-1|0;if(n>>>0>1){continue}break}}o=((h&1)-1^(h&254)>>>1)+o|0;u[i|0]=o;j=(e+j&254)>>>1|0;i=d+i|0;if(q>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=f+16|0}function cP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;h=jb-32|0;jb=h;a:{f=w[a>>2];c=w[f+4>>2];d=w[f+8>>2];b:{if(c>>>0<d>>>0){d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;w[c+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[f+4>>2]=c+12;break b}e=w[f>>2];g=(c-e|0)/12|0;c=g+1|0;if(c>>>0>=357913942){break a}d=(d-e|0)/12|0;e=d<<1;d=Re(h+8|0,d>>>0>=178956970?357913941:c>>>0<e>>>0?e:c,g,f+8|0);c=w[d+8>>2];e=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=e;w[c+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;g=w[d+8>>2]+12|0;w[d+8>>2]=g;e=w[d+4>>2];b=w[f+4>>2];c=w[f>>2];c:{if((b|0)==(c|0)){b=c;break c}while(1){b=b-12|0;g=w[b+4>>2];e=e-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=g;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[d+4>>2]-12|0;w[d+4>>2]=e;if((b|0)!=(c|0)){continue}break}g=w[d+8>>2];c=w[f+4>>2];b=w[f>>2]}w[f>>2]=e;w[d+4>>2]=b;w[f+4>>2]=g;w[d+8>>2]=c;c=w[f+8>>2];w[f+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=c;sc(d)}jb=h+32|0;return a|0}Mb(f);M()}function hM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;w[c+28>>2]=0;d=c+24|0;Oe(d,a,0);a:{b:{c:{if(x[d|0]){d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;d:{e:{f:{g:{h:{if((d|0)!=1){w[114256]=0;d=V(1565,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break h}e=Vd(c+8|0,a);f=Ne(c);g=w[w[a>>2]-12>>2];f=w[f>>2];e=w[e>>2];w[114256]=0;la(1568,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break h}Ab(c+16|0);break f}b=W(0)|0;break g}b=W(0)|0;Ab(c+16|0)}$(b|0)|0;b=w[c+28>>2]|1;w[c+28>>2]=b;Me(w[w[a>>2]-12>>2]+a|0,b);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];d=w[114256];w[114256]=0;if((d|0)!=1){if(!(b&1)){break e}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break c}R(a|0);M()}d=w[c+20>>2];w[b>>2]=d;break d}aa()}Kd(w[w[a>>2]-12>>2]+a|0,w[c+28>>2])}jb=c+32|0;break a}W(0)|0;Eb()}M()}return a|0}function Je(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;w[i+16>>2]=c;w[i+24>>2]=b;b=i+8|0;Sb(b,d);w[114256]=0;j=V(1561,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){Ab(i+8|0);w[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(ue(i+24|0,i+16|0)){break b}c:{if((Cg(j,u[g|0])|0)==37){b=g+1|0;if((h|0)==(b|0)){break b}k=0;c=Cg(j,u[b|0]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+2|0)==(h|0)){break b}k=c;c=Cg(j,u[g+2|0])}l=i,m=ob[w[w[a>>2]+36>>2]](a,w[i+24>>2],w[i+16>>2],d,e,f,c,k)|0,w[l+24>>2]=m;g=b+2|0;break c}if(Ld(j,1,u[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Ld(j,1,u[g|0])){continue}}break}while(1){if(!Wh(i+24|0,i+16|0)){break c}if(!Ld(j,1,tf(i+24|0))){break c}eg(i+24|0);continue}}if((Vl(j,tf(i+24|0))|0)==(Vl(j,u[g|0])|0)){g=g+1|0;eg(i+24|0);break c}w[e>>2]=4}b=w[e>>2];continue}break}w[e>>2]=4}if(ue(i+24|0,i+16|0)){w[e>>2]=w[e>>2]|2}jb=i+32|0;return w[i+24>>2]}a=P()|0;Ab(i+8|0);R(a|0);M()}function RJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;a:{b:{c=w[a+4>>2];d=w[a+8>>2];c:{if(c>>>0<d>>>0){d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;w[c+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[c+12>>2]=w[b+12>>2];w[c+16>>2]=w[b+16>>2];w[b+12>>2]=0;w[b+16>>2]=0;d=w[b+24>>2];w[c+20>>2]=w[b+20>>2];w[c+24>>2]=d;d=w[b+28>>2];w[b+28>>2]=0;w[c+28>>2]=d;w[a+4>>2]=c+32;break c}e=w[a>>2];g=c-e>>5;c=g+1|0;if(c>>>0>=134217728){break b}d=d-e|0;e=d>>4;c=Vh(f+8|0,d>>>0>=2147483616?134217727:c>>>0<e>>>0?e:c,g,a+8|0);d=w[c+8>>2];e=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=e;w[d+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;w[d+12>>2]=w[b+12>>2];w[d+16>>2]=w[b+16>>2];w[b+12>>2]=0;w[b+16>>2]=0;e=w[b+24>>2];w[d+20>>2]=w[b+20>>2];w[d+24>>2]=e;e=w[b+28>>2];w[b+28>>2]=0;w[d+28>>2]=e;w[c+8>>2]=w[c+8>>2]+32;w[114256]=0;T(134,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}Bj(c)}jb=f+32|0;return}Mb(a);M()}a=P()|0;Bj(c);R(a|0);M()}function XP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break g}w[114256]=0;X(1361,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break g}d=w[a+24>>2];w[114256]=0;b=Q(5,e+16|0,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break g}w[114256]=0;c=Q(5,e|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break f}w[114256]=0;Y(1400,d|0,b|0,c|0,1);d=w[114256];w[114256]=0;if((d|0)==1){break e}if(u[c+11|0]<0){zb(w[c>>2])}c=1;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}d=W(0)|0;break c}d=W(0)|0;break d}d=W(0)|0;if(u[c+11|0]>=0){break d}zb(w[c>>2])}if(u[b+11|0]>=0){break c}zb(w[b>>2])}$(d|0)|0;c=0;w[114256]=0;Y(1333,2763,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=e+32|0;return c|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Em(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=ve(a)&2047;e=ve(5551115123125783e-32);c=d-e|0;if(c>>>0<ve(512)-e>>>0){e=d;break b}if((c|0)<0){return a+1}e=0;if(ve(1024)>>>0>d>>>0){break b}o(+a);e=j(1)|0;b=0;if(!(j(0)|0)&(e|0)==-1048576){break a}if(ve(O)>>>0<=d>>>0){return a+1}if((e|0)<0){return Oj(12882297539194267e-247)}return Oj(3105036184601418e216)}b=B[6430];f=B[6429]*a+b;b=f-b;a=b*B[6432]+(b*B[6431]+a);b=a*a;g=b*b*(a*B[6436]+B[6435]);b=b*(a*B[6434]+B[6433]);o(+f);j(1)|0;i=j(0)|0;c=i<<4&2032;a=g+(b+(B[c+51544>>3]+a));c=c+51552|0;h=w[c>>2];d=w[c+4>>2];c=h;h=0;c=c+h|0;d=(i<<13)+d|0;d=c>>>0<h>>>0?d+1|0:d;if(!e){c:{if(!(i&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){gu(hu()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function hA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0;e=w[a+48>>2];j=w[a>>2];h=w[a+4>>2];f=w[a+44>>2];a:{if(!d){b=e;break a}k=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;u=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){g=w[c>>2];l=v[(h<<1)+p>>1]<<8;b=l;i=BV(b,b>>31,x,y);z=nb;b=f;A=g;g=i;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;i=BV(t,u,f,f>>31);g=g+i|0;f=nb+z|0;f=g>>>0<i>>>0?f+1|0:f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;i=BV(r,s,e,e>>31);g=i+g|0;e=nb+f|0;e=g>>>0<i>>>0?e+1|0:e;f=g+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=A+C(f,o);w[c+4>>2]=w[c+4>>2]+C(f,n);f=e-(q&l)|0;h=h+m|0;e=j+k|0;h=e>>>0<k>>>0?h+1|0:h;j=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=f;w[a>>2]=j;w[a+4>>2]=h}function PE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;a:{b:{if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],7)|0)){break b}if(!Ah(a,13548,7)){break a}if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1)|0)){break b}e=zh(a,d+15|0);e=e?x[d+15|0]:0;if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],e)|0)){j=a,k=ob[w[w[a>>2]+24>>2]](a)|0,w[j+12>>2]=k;break b}w[a+12>>2]=e+w[a+12>>2];e=-1;c=jb-16|0;jb=c;g=w[a+12>>2];f=d+8|0;w[c+8>>2]=f;w[c+12>>2]=f+7;f=ob[w[w[a>>2]+32>>2]](a,g,c+8|0)|0;if((f|0)==7){c:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],7)|0){h=w[a+12>>2]+7|0;break c}h=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=h}jb=c+16|0;if((f|0)!=7){break a}e=0;if(x[d+9|0]!=2|x[d+8|0]>2){break a}f=a;h=b;c=x[d+11|0]|x[d+12|0]<<8;e=c>>>30|0;i=c<<2;c=x[d+10|0];a=c+(x[d+13|0]|x[d+14|0]<<8)|0;b=0;b=a>>>0<c>>>0?1:b;c=b<<1|a>>>31;g=a<<1;b=i+g|0;a=e+c|0;a=b>>>0<g>>>0?a+1|0:a;b=b+47|0;a=b>>>0<47?a+1|0:a;e=Uc(f,h,b,a);break a}e=-1}jb=d+16|0;return e|0}function jA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,x=0,y=0,z=0,A=0;e=w[a+48>>2];j=w[a>>2];h=w[a+4>>2];f=w[a+44>>2];a:{if(!d){b=e;break a}k=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];q=w[a+72>>2];b=w[a+68>>2];r=b;s=b>>31;b=w[a+64>>2];t=b;v=b>>31;b=w[a+60>>2];x=b;y=b>>31;while(1){g=w[c>>2];l=u[h+p|0]<<16;b=l;i=BV(b,b>>31,x,y);z=nb;b=f;A=g;g=i;f=(f|0)>=16776704?16776704:f;f=(f|0)<=-16777216?-16777216:f;i=BV(t,v,f,f>>31);g=g+i|0;f=nb+z|0;f=g>>>0<i>>>0?f+1|0:f;e=(e|0)>=16776704?16776704:e;e=(e|0)<=-16777216?-16777216:e;i=BV(r,s,e,e>>31);g=i+g|0;e=nb+f|0;e=g>>>0<i>>>0?e+1|0:e;f=g+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;w[c>>2]=A+C(f,o);w[c+4>>2]=w[c+4>>2]+C(f,n);f=e-(q&l)|0;h=h+m|0;e=j+k|0;h=e>>>0<k>>>0?h+1|0:h;j=e;c=c+8|0;e=b;d=d-1|0;if(d){continue}break}}w[a+48>>2]=b;w[a+44>>2]=f;w[a>>2]=j;w[a+4>>2]=h}function mr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=h>>>0|a>>>0>=d>>>0){break b}b=u[a|0];g=b&255;c:{if((b|0)>=0){b=1;break c}if(b>>>0<4294967234){break b}if(b>>>0<=4294967263){if((x[a+1|0]&192)!=128|(d-a|0)<2){break b}b=2;break c}d:{e:{if(b>>>0<=4294967279){if((d-a|0)<3){break b}f=x[a+2|0];b=x[a+1|0];if((g|0)==237){break e}if((g|0)==224){if((b&224)==160){break d}break b}if((b&192)!=128){break b}break d}if((d-a|0)<4|b>>>0>4294967284){break b}i=x[a+3|0];j=x[a+2|0];f=x[a+1|0];f:{g:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((j&192)!=128|(i&192)!=128){break b}b=4;if((i&63|(j<<6&4032|(g<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}break c}if((b&224)!=128){break b}}if((f&192)!=128){break b}b=3}h=h+1|0;a=a+b|0;continue}break}return a-c|0}function $h(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;o(+a);d=j(1)|0;j(0)|0;e=d>>>16|0;o(+a);c=j(1)|0;d=j(0)|0;f=c-1072562176|0;if((f|0)==198911|f>>>0<198911){if(!d&(c|0)==1072693248){return 0}a=a+-1;b=a*134217728;b=a+b-b;i=B[6706];k=b*b*i;m=a+k;g=a*a;h=a*g;return m+(h*(h*(h*(h*B[6716]+(g*B[6715]+(a*B[6714]+B[6713])))+(g*B[6712]+(a*B[6711]+B[6710])))+(g*B[6709]+(a*B[6708]+B[6707])))+((a-b)*i*(a+b)+(k+(a-m))))}a:{if(e-32752>>>0<=4294934559){if(!(c&2147483647|d)){return iu(-1)/0}if(!d&(c|0)==2146435072){break a}if(!(!(e&32768)&(e&32752)!=32752)){a=a-a;return a/a}o(+(a*4503599627370496));c=j(1)|0;d=j(0)|0;c=c-54525952|0}e=c-1072037888|0;g=+(e>>20);f=(e>>>13&127)<<4;h=g*B[6699]+B[f+53744>>3];a=B[f+53736>>3];l(0,d-0|0);l(1,c-((e&-1048576)+(d>>>0<p>>>0)|0)|0);a=a*(+n()-B[f+55784>>3]-B[f+55792>>3]);i=h+a;b=a*a;a=i+(a*b*(b*(a*B[6705]+B[6704])+(a*B[6703]+B[6702]))+(b*B[6701]+(g*B[6700]+(a+(h-i)))))}return a}function jV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;c=a+33|0;w[b>>2]=x[c+206|0]|x[c+207|0]<<8;uw(c,b+48|0,x[c+192|0],x[c+200|0],x[c+194|0],x[c+195|0],x[c+196|0],0);uw(c,b+68|0,x[c+193|0],x[c+201|0],x[c+197|0],x[c+198|0],x[c+199|0],1);f=b+236|0;while(1){v[(f+(d<<1)|0)+24>>1]=x[c+d|0];d=d+1|0;if((d|0)!=96){continue}break}if(x[c+208|0]){d=1;f=x[c+209|0]+1|0;u[b+31|0]=f;h=f&255;a:{if((f|0)==(h|0)){d=16;if(h>>>0<17){break a}}u[b+31|0]=d}d=x[c+210|0]|x[c+211|0]<<8;u[b+30|0]=(d>>>0>=127?127:d)+1}u[b+33|0]=x[c+212|0];d=b+236|0;while(1){f=x[c+g|0];v[(d+(g<<1)|0)+24>>1]=f>>>0<(x[a+27|0]|x[a+28|0]<<8)>>>0?f:0;g=g+1|0;if((g|0)!=96){continue}break}c=e+8|0;Vb(c,3,a+4|0,22);w[114256]=0;w[e+28>>2]=32;w[e+24>>2]=b+492;Q(200,e+24|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[e+19|0]<0){zb(w[e+8>>2])}if(!x[a+241|0]){u[b+30|0]=x[a+26|0]}jb=e+32|0;return}a=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}R(a|0);M()}function hy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-32|0;jb=g;l=yf(a,c);rd(g+8|0,w[a+28>>2]);d=w[g+20>>2];w[g+24>>2]=w[g+16>>2];w[g+28>>2]=d;a:{if(!l){if(x[a+24|0]&32){break a}}i=w[a+28>>2];d=jb-16|0;jb=d;w[d+4>>2]=0;e=d+4|0;w[d+12>>2]=e|1;w[d+8>>2]=e;Ob(i,d+8|0);e=w[d+4>>2];h=e>>>2&3;if(h){u[d+4|0]=0;w[d+12>>2]=d+5;w[d+8>>2]=d+4;Ob(i,d+8|0);f=x[d+4|0];m=e&255;k=0;b:{if((h|0)==1){break b}u[d+4|0]=0;e=d+5|0;w[d+12>>2]=e;w[d+8>>2]=d+4;Ob(i,d+8|0);j=x[d+4|0];k=0;if((h|0)!=3){break b}u[d+4|0]=0;w[d+12>>2]=e;w[d+8>>2]=d+4;Ob(i,d+8|0);k=x[d+4|0]<<24}e=m|(k|((j&255)<<16|f<<8))}j=0;h=e>>>4|0;ul(b,h>>>0>=1e6?1e6:h,0);f=x[b+11|0];e=f<<24>>24<0;c:{if(!(e?w[b+4>>2]:f)){f=0;break c}while(1){sf(i,(e&1?w[b>>2]:b)+j|0,1);f=x[b+11|0];e=f<<24>>24<0;j=j+1|0;f=e?w[b+4>>2]:f;if(j>>>0<f>>>0){continue}break}}if((f|0)!=(h|0)){cg(i,h-f|0,-1)}jb=d+16|0}a=zf(a,l,c,g+24|0);jb=g+32|0;return a|0}function VU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;lc(c,0);d=x[a+36|0]|x[a+37|0]<<8;v[c+28>>1]=((d>>>0>=32767?32767:d)<<8>>>0)/32767;d=x[a+38|0]|x[a+39|0]<<8;v[c+32>>1]=64;v[c+30>>1]=((d>>>0>=32767?32767:d)<<8>>>0)/32767;w[c>>2]=x[a+44|0]|x[a+45|0]<<8|(x[a+46|0]<<16|x[a+47|0]<<24);w[c+4>>2]=x[a+48|0]|x[a+49|0]<<8|(x[a+50|0]<<16|x[a+51|0]<<24);w[c+8>>2]=x[a+52|0]|x[a+53|0]<<8|(x[a+54|0]<<16|x[a+55|0]<<24);w[c+24>>2]=x[a+56|0]|x[a+57|0]<<8|(x[a+58|0]<<16|x[a+59|0]<<24);d=x[b+166|0];if(d>>>0<=4){u[c+38|0]=x[d+35690|0]}d=x[b+167|0]|x[b+168|0]<<8;u[c+39|0]=d;e=(x[b+171|0]|x[b+172|0]<<8)>>>4|0;u[c+41|0]=e;b=(x[b+169|0]|x[b+170|0]<<8)>>>2|0;u[c+40|0]=b;if((b|e)&255){u[c+39|0]=d^-1}b=x[a+40|0]|x[a+41|0]<<8;if(b&4){v[c+34>>1]=y[c+34>>1]|1;b=x[a+40|0]|x[a+41|0]<<8}if(b&8){v[c+34>>1]=y[c+34>>1]|2;b=x[a+40|0]|x[a+41|0]<<8}if(b&16){v[c+34>>1]=y[c+34>>1]|4;b=x[a+40|0]|x[a+41|0]<<8}if(b&32){v[c+34>>1]=y[c+34>>1]|32}}function CR(){var a=0,b=0,c=0,d=0,e=0,f=0;a=jb-32|0;jb=a;w[a+24>>2]=0;w[114256]=0;w[a+16>>2]=0;w[a+20>>2]=0;X(1319,a|0);b=w[114256];w[114256]=0;c=1;a:{b:{c:{d:{e:{if((b|0)!=1){b=w[a>>2];if((b|0)!=w[a+4>>2]){break e}d=a+16|0;break b}b=W(0)|0;break d}while(1){f:{if(!(c&1)){w[114256]=0;Q(1315,a+16|0,10070)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}}d=w[b>>2];e=w[b+4>>2];c=x[b+11|0];w[114256]=0;f=d;d=c<<24>>24<0;S(92,a+16|0,(d?f:b)|0,(d?e:c)|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break f}c=0;b=b+12|0;if((b|0)!=w[a+4>>2]){continue}break c}break}b=W(0)|0;bc(a);if(u[a+27|0]>=0){break d}zb(w[a+16>>2])}$(b|0)|0;c=0;w[114256]=0;na(1314,3291,0,0,0,0,0,0,0,0);b=w[114256];w[114256]=0;if((b|0)!=1){aa();break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}d=u[a+27|0]<0?w[a+16>>2]:a+16|0}c=rc(d);bc(a);if(u[a+27|0]>=0){break a}zb(w[a+16>>2])}jb=a+32|0;return c|0}function no(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{b:{c:{d:{f=c-b|0;h=w[a+8>>2];i=x[a+11|0];d=i<<24>>24<0;g=d?(h&2147483647)-1|0:10;e:{if(f>>>0<=g>>>0){d=h>>>24|0;break e}h=d?w[a>>2]:a;d=d?w[a+4>>2]:i;if(h>>>0<=b>>>0&d+h>>>0>=b>>>0){break d}yg(a,g,f-g|0,d,0,d,0);d=x[a+11|0]}d=d<<24>>24<0?w[a>>2]:a;if((b|0)!=(c|0)){while(1){u[d|0]=x[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}u[d|0]=0;if(u[a+11|0]>=0){break c}w[a+4>>2]=f;break b}if(f>>>0>=4294967280){break a}f:{if(f>>>0<=10){u[e+11|0]=f;d=e;break f}g=(f|15)+1|0;d=Kb(g);w[e+8>>2]=g|-2147483648;w[e>>2]=d;w[e+4>>2]=f}if((b|0)!=(c|0)){d=Fb(d,b,f)+f|0}u[d|0]=0;w[114256]=0;b=x[e+11|0];c=b<<24>>24<0;S(78,a|0,(c?w[e>>2]:e)|0,(c?w[e+4>>2]:b)|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(u[e+11|0]>=0){break b}zb(w[e>>2]);break b}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}u[a+11|0]=f}jb=e+16|0;return a|0}zc(e);M()}function jM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;w[c+28>>2]=0;d=c+24|0;Oe(d,a,0);a:{b:{c:{if(x[d|0]){d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;d:{e:{f:{if((d|0)!=1){w[114256]=0;d=V(1565,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}e=Vd(c+8|0,a);f=Ne(c);g=w[w[a>>2]-12>>2];f=w[f>>2];e=w[e>>2];w[114256]=0;la(1566,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}Ab(c+16|0);break d}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0)}$(b|0)|0;b=w[c+28>>2]|1;w[c+28>>2]=b;Me(w[w[a>>2]-12>>2]+a|0,b);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];d=w[114256];w[114256]=0;g:{if((d|0)!=1){if(!(b&1)){break g}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break c}R(a|0);M()}aa()}Kd(w[w[a>>2]-12>>2]+a|0,w[c+28>>2])}jb=c+32|0;break a}W(0)|0;Eb()}M()}return a|0}function fM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;w[c+28>>2]=0;d=c+24|0;Oe(d,a,0);a:{b:{c:{if(x[d|0]){d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;d:{e:{f:{if((d|0)!=1){w[114256]=0;d=V(1565,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}e=Vd(c+8|0,a);f=Ne(c);g=w[w[a>>2]-12>>2];f=w[f>>2];e=w[e>>2];w[114256]=0;la(1569,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}Ab(c+16|0);break d}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0)}$(b|0)|0;b=w[c+28>>2]|1;w[c+28>>2]=b;Me(w[w[a>>2]-12>>2]+a|0,b);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];d=w[114256];w[114256]=0;g:{if((d|0)!=1){if(!(b&1)){break g}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break c}R(a|0);M()}aa()}Kd(w[w[a>>2]-12>>2]+a|0,w[c+28>>2])}jb=c+32|0;break a}W(0)|0;Eb()}M()}return a|0}function dM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;w[c+28>>2]=0;d=c+24|0;Oe(d,a,0);a:{b:{c:{if(x[d|0]){d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;d:{e:{f:{if((d|0)!=1){w[114256]=0;d=V(1565,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}e=Vd(c+8|0,a);f=Ne(c);g=w[w[a>>2]-12>>2];f=w[f>>2];e=w[e>>2];w[114256]=0;la(1570,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}Ab(c+16|0);break d}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0)}$(b|0)|0;b=w[c+28>>2]|1;w[c+28>>2]=b;Me(w[w[a>>2]-12>>2]+a|0,b);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];d=w[114256];w[114256]=0;g:{if((d|0)!=1){if(!(b&1)){break g}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break c}R(a|0);M()}aa()}Kd(w[w[a>>2]-12>>2]+a|0,w[c+28>>2])}jb=c+32|0;break a}W(0)|0;Eb()}M()}return a|0}function cM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;w[c+28>>2]=0;d=c+24|0;Oe(d,a,0);a:{b:{c:{if(x[d|0]){d=w[w[a>>2]-12>>2];w[114256]=0;Sb(c+16|0,a+d|0);d=w[114256];w[114256]=0;d:{e:{f:{if((d|0)!=1){w[114256]=0;d=V(1565,c+16|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break f}e=Vd(c+8|0,a);f=Ne(c);g=w[w[a>>2]-12>>2];f=w[f>>2];e=w[e>>2];w[114256]=0;la(1571,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break f}Ab(c+16|0);break d}b=W(0)|0;break e}b=W(0)|0;Ab(c+16|0)}$(b|0)|0;b=w[c+28>>2]|1;w[c+28>>2]=b;Me(w[w[a>>2]-12>>2]+a|0,b);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];d=w[114256];w[114256]=0;g:{if((d|0)!=1){if(!(b&1)){break g}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break c}R(a|0);M()}aa()}Kd(w[w[a>>2]-12>>2]+a|0,w[c+28>>2])}jb=c+32|0;break a}W(0)|0;Eb()}M()}return a|0}function pr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break b}b=x[a|0];f=a+1|0;c:{if(b<<24>>24>=0){break c}if(b>>>0<194){break b}if(b>>>0<=223){if((x[a+1|0]&192)!=128|(d-a|0)<2){break b}f=a+2|0;break c}d:{e:{if(b>>>0<=239){if((d-a|0)<3){break b}h=x[a+2|0];f=x[a+1|0];if((b|0)==237){break e}if((b|0)==224){if((f&224)==160){break d}break b}if((f&192)!=128){break b}break d}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break b}h=x[a+3|0];i=x[a+2|0];f=x[a+1|0];f:{g:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}g=g+1|0;f=a+4|0;break c}if((f&224)!=128){break b}}if((h&192)!=128){break b}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function kq(a,b){var c=0,d=0;d=x[a|0];if(d>>>0>=36){u[a|0]=0;return}c=x[d+23296|0];u[a|0]=c;a:{b:{c:{d:{e:{f:{g:{if(c>>>0<=22){switch(c-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break b;case 13:break c;case 0:case 1:case 5:break e;case 8:break f;default:break g}}if((c|0)==23){break d}if((c|0)!=31){break a}u[b|0]=(d<<5|x[b|0]>>>3)^128;return}if(x[b|0]|(c|0)!=1){break a}u[a|0]=0;return}a=x[b|0];u[b|0]=C(a>>>4|0,10)+(a&15);return}c=x[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}u[b|0]=a;return}a=x[b|0];if(a>>>0<=64){u[b|0]=a<<1;return}u[b|0]=128;return}h:{i:{j:{k:{c=x[b|0];switch((c&240)-48>>>4|0){case 4:break h;case 2:break i;case 1:break j;case 0:break k;default:break a}}u[a|0]=20;u[b|0]=159;return}u[a|0]=20;u[b|0]=192;return}if(c&14){break a}u[a|0]=21;u[b|0]=(x[b|0]!=80)<<6;return}u[a|0]=20;u[b|0]=x[b|0]&15|160;return}if(x[b|0]>31){break a}u[a|0]=16}}function aU(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-176|0;jb=e;a=Zg(e+16|0,a,8);b=w[w[a>>2]-12>>2];w[114256]=0;c=ea(79)|0;d=w[114256];w[114256]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}w[114256]=0;b=a+b|0;T(10,e+8|0,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break e}w[114256]=0;U(80,e+168|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}Ab(e+168|0);b=w[b+24>>2];if(b){d=w[w[b>>2]+8>>2];w[114256]=0;T(d|0,b|0,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}b=b+4|0;d=Ic(e+160|0,b);Wc(b,c);Ab(d)}Ab(e+8|0);c=a+w[w[a>>2]-12>>2]|0;w[c+4>>2]=w[c+4>>2]&-75|8;w[114256]=0;c=Q(99,a|0,e+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}c=w[(c+w[w[c>>2]-12>>2]|0)+16>>2];b=w[e+168>>2];d=w[15045];w[a>>2]=d;w[a+w[d-12>>2]>>2]=w[15048];w[a+8>>2]=59272;if(u[a+51|0]<0){zb(w[a+40>>2])}wc(a+8|0);pc(a+60|0);jb=e+176|0;a=c&5?0:b;break a}c=P()|0;break b}c=P()|0;break b}c=P()|0;Ab(e+8|0)}Se(a);R(c|0);M()}return a|0}function Hd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];f=w[a+4>>2]-c>>2;if(f>>>0<b>>>0){h=jb-32|0;jb=h;e=b-f|0;a:{b:{c=w[a+8>>2];b=w[a+4>>2];c:{if(e>>>0<=c-b>>2>>>0){if(e){c=(e<<2)+b|0;while(1){u[b+2|0]=0;v[b>>1]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}b=c}w[a+4>>2]=b;break c}d=b;b=w[a>>2];f=d-b>>2;g=f+e|0;if(g>>>0>=1073741824){break b}c=c-b|0;b=c>>1;d=ud(h+8|0,c>>>0>=2147483644?1073741823:b>>>0>g>>>0?b:g,f,a+8|0);b=w[d+8>>2];g=b+(e<<2)|0;while(1){u[b+2|0]=0;v[b>>1]=0;b=b+4|0;if((g|0)!=(b|0)){continue}break}w[d+8>>2]=g;e=w[a+4>>2];b=w[a>>2];c=e-b|0;f=w[d+4>>2]-c|0;w[d+4>>2]=f;if((c|0)>0){Fb(f,b,c);e=w[a+4>>2];f=w[d+4>>2];g=w[d+8>>2];b=w[a>>2]}w[a>>2]=f;w[d+4>>2]=b;w[a+4>>2]=g;w[d+8>>2]=e;c=w[a+8>>2];w[a+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=c;if((b|0)!=(e|0)){w[d+8>>2]=((b-e|0)+3&-4)+e}if(!b){break c}zb(b)}jb=h+32|0;break a}Mb(a);M()}return}if(b>>>0<f>>>0){w[a+4>>2]=c+(b<<2)}}function rf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=w[w[a>>2]-12>>2]+a|0;e=w[d+16>>2]&-3;Jg(d,e);Oe(c+56|0,a,1);a:{b:{if(x[c+56|0]){d=w[w[a>>2]-12>>2];w[114256]=0;d=w[(a+d|0)+24>>2];f=w[114256];w[114256]=0;c:{d:{if((f|0)==1){break d}w[114256]=0;f=w[b+12>>2];w[c+16>>2]=w[b+8>>2];w[c+20>>2]=f;f=w[b+4>>2];w[c+8>>2]=w[b>>2];w[c+12>>2]=f;Y(1575,c+40|0,d|0,c+8|0,8);b=w[114256];w[114256]=0;if((b|0)==1){break d}b=Xh(c+24|0,-1,-1);w[114256]=0;b=At(c+40|0,b);d=w[114256];w[114256]=0;if((d|0)==1){break d}b=b?e|4:e;break c}$(W(0)|0)|0;b=e|1;Me(w[w[a>>2]-12>>2]+a|0,b);e=w[w[a>>2]-12>>2];w[114256]=0;e=w[(a+e|0)+20>>2];d=w[114256];w[114256]=0;e:{if((d|0)!=1){if(!(e&1)){break e}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}aa()}Kd(w[w[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return a|0}W(0)|0;Eb()}M()}function Qj(a,b,c){var d=D(0),e=0,f=0;f=32767;d=D(D(D(D(D(D(D(D(D(A[c+3328>>2]+A[c+256>>2])*D(213))+D(D(A[c+3584>>2]-A[c>>2])*D(29)))+D(D(A[c+3072>>2]-A[c+512>>2])*D(459)))+D(D(A[c+2816>>2]+A[c+768>>2])*D(2037)))+D(D(A[c+2560>>2]-A[c+1024>>2])*D(5153)))+D(D(A[c+2304>>2]+A[c+1280>>2])*D(6574)))+D(D(A[c+2048>>2]-A[c+1536>>2])*D(37489)))+D(A[c+1792>>2]*D(75038)));e=32767;a:{if(d>=D(32766.5)){break a}e=32768;if(d<=D(-32767.5)){break a}d=D(d+D(.5));b:{if(D(E(d))<D(2147483648)){e=~~d;break b}e=-2147483648}e=e+(e>>15)|0}v[a>>1]=e;d=D(D(D(D(D(D(D(D(A[c+3080>>2]*D(1567))+D(A[c+3592>>2]*D(104)))+D(A[c+2568>>2]*D(9727)))+D(A[c+2056>>2]*D(64019)))+D(A[c+1544>>2]*D(-9975)))+D(A[c+1032>>2]*D(-45)))+D(A[c+520>>2]*D(146)))+D(A[c+8>>2]*D(-5)));c:{if(d>=D(32766.5)){break c}f=32768;if(d<=D(-32767.5)){break c}d=D(d+D(.5));d:{if(D(E(d))<D(2147483648)){c=~~d;break d}c=-2147483648}f=(c>>15)+c|0}v[(b<<5)+a>>1]=f}function ew(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=w[a>>2];f=w[a+4>>2]-d>>2;if(f>>>0<b>>>0){i=jb-32|0;jb=i;h=b-f|0;a:{b:{d=w[a+8>>2];b=w[a+4>>2];c:{if(h>>>0<=d-b>>2>>>0){if(h){d=(h<<2)+b|0;while(1){A[b>>2]=A[c>>2];b=b+4|0;if((d|0)!=(b|0)){continue}break}b=d}w[a+4>>2]=b;break c}e=b;b=w[a>>2];f=e-b>>2;g=f+h|0;if(g>>>0>=1073741824){break b}d=d-b|0;b=d>>1;e=ud(i+8|0,d>>>0>=2147483644?1073741823:b>>>0>g>>>0?b:g,f,a+8|0);b=w[e+8>>2];g=b+(h<<2)|0;while(1){A[b>>2]=A[c>>2];b=b+4|0;if((g|0)!=(b|0)){continue}break}w[e+8>>2]=g;c=w[a+4>>2];b=w[a>>2];d=c-b|0;f=w[e+4>>2]-d|0;w[e+4>>2]=f;if((d|0)>0){Fb(f,b,d);f=w[e+4>>2];g=w[e+8>>2];c=w[a+4>>2];b=w[a>>2]}w[a>>2]=f;w[e+4>>2]=b;w[a+4>>2]=g;w[e+8>>2]=c;d=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=d;if((b|0)!=(c|0)){w[e+8>>2]=((b-c|0)+3&-4)+c}if(!b){break c}zb(b)}jb=i+32|0;break a}Mb(a);M()}return}if(b>>>0<f>>>0){w[a+4>>2]=d+(b<<2)}}function Dn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=w[a>>2];f=w[a+4>>2]-d>>2;if(f>>>0<b>>>0){i=jb-32|0;jb=i;h=b-f|0;a:{b:{d=w[a+8>>2];b=w[a+4>>2];c:{if(h>>>0<=d-b>>2>>>0){if(h){d=(h<<2)+b|0;while(1){w[b>>2]=w[c>>2];b=b+4|0;if((d|0)!=(b|0)){continue}break}b=d}w[a+4>>2]=b;break c}e=b;b=w[a>>2];f=e-b>>2;g=f+h|0;if(g>>>0>=1073741824){break b}d=d-b|0;b=d>>1;e=ud(i+8|0,d>>>0>=2147483644?1073741823:b>>>0>g>>>0?b:g,f,a+8|0);b=w[e+8>>2];g=b+(h<<2)|0;while(1){w[b>>2]=w[c>>2];b=b+4|0;if((g|0)!=(b|0)){continue}break}w[e+8>>2]=g;c=w[a+4>>2];b=w[a>>2];d=c-b|0;f=w[e+4>>2]-d|0;w[e+4>>2]=f;if((d|0)>0){Fb(f,b,d);f=w[e+4>>2];g=w[e+8>>2];c=w[a+4>>2];b=w[a>>2]}w[a>>2]=f;w[e+4>>2]=b;w[a+4>>2]=g;w[e+8>>2]=c;d=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=d;if((b|0)!=(c|0)){w[e+8>>2]=((b-c|0)+3&-4)+c}if(!b){break c}zb(b)}jb=i+32|0;break a}Mb(a);M()}return}if(b>>>0<f>>>0){w[a+4>>2]=d+(b<<2)}}function $C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;c=w[a>>2];e=(w[a+4>>2]-c|0)/12|0;d=e+1|0;if(d>>>0<357913942){f=a+8|0;c=(w[f>>2]-c|0)/12|0;h=c<<1;c=Re(g+8|0,c>>>0>=178956970?357913941:d>>>0<h>>>0?h:d,e,f);d=w[c+8>>2];a:{b:{if(u[b+11|0]>=0){e=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=e;w[d+8>>2]=w[b+8>>2];break b}e=w[b+4>>2];b=w[b>>2];w[114256]=0;U(3,d|0,b|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}}f=w[c+8>>2]+12|0;w[c+8>>2]=f;e=w[c+4>>2];b=w[a+4>>2];d=w[a>>2];c:{if((b|0)==(d|0)){b=d;break c}while(1){b=b-12|0;f=w[b+4>>2];e=e-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=f;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[c+4>>2]-12|0;w[c+4>>2]=e;if((b|0)!=(d|0)){continue}break}f=w[c+8>>2];d=w[a+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=f;w[c+8>>2]=d;d=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=d;sc(c);jb=g+32|0;return}a=P()|0;sc(c);R(a|0);M()}Mb(a);M()}function AS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=0,p=0,q=0,r=0,s=0,t=D(0),u=D(0),v=D(0),y=0,z=0,B=0,C=0;f=jb-16|0;jb=f;o=w[a+4240>>2];a:{if(!o){break a}k=w[a+56>>2];g=w[a+44>>2];if((0-(w[a+60>>2]-k>>11)|0)==w[a+48>>2]-g>>11){break a}v=A[a+4220>>2];w[f+8>>2]=g;w[f+12>>2]=g+2048;w[f>>2]=k;p=k+2048|0;w[f+4>>2]=p;if(d){i=w[a+4244>>2];q=w[a+4208>>2];y=x[a+4264|0];g=d;while(1){z=i<<1;j=1;e=0;m=0;while(1){r=(y?1-m|0:e)&255;B=w[((r<<2)+a|0)+4248>>2];C=w[a+4240>>2];s=e<<2;l=s+(f+8|0)|0;h=w[l>>2];w[l>>2]=h+4;l=((e|z)<<2)+q|0;e=i-B|0;t=A[(((e>>31&C)+e<<1)+r<<2)+q>>2];n=A[h>>2];u=D(D(A[a+4224>>2]*t)+D(A[a+4260>>2]*n));A[l>>2]=D(E(u))<D(10000000195414814e-40)?D(0):u;e=f+s|0;h=w[e>>2];w[e>>2]=h+4;A[h>>2]=n+D(D(t-n)*v);m=m+1|0;h=j;j=0;e=1;if(h){continue}break}j=i+1|0;i=(j|0)!=(o|0)?j:0;w[a+4244>>2]=i;g=g-1|0;if(g){continue}break}}ye(a,b,c,k,p,d)}jb=f+16|0}function Ts(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-32|0;jb=c;a:{if(x[a+52|0]){d=w[a+48>>2];if(!b){break a}u[a+52|0]=0;w[a+48>>2]=-1;break a}w[c+24>>2]=1;e=w[Ss(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=qj(w[a+32>>2]);if((g|0)==-1){break b}u[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(x[a+53|0]){u[c+23|0]=x[c+24|0];break c}g=c+24|0;while(1){d:{d=w[a+40>>2];i=w[d>>2];j=w[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(mt(w[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=w[a+40>>2];w[d>>2]=i;w[d+4>>2]=j;if((e|0)==8){break b}d=qj(w[a+32>>2]);if((d|0)==-1){break b}u[f|0]=d;e=e+1|0;continue}break}u[c+23|0]=x[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((rj(Md(u[e+(c+24|0)|0]),w[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Md(u[c+23|0]),w[k+48>>2]=l}d=Md(u[c+23|0]);break a}d=-1}jb=c+32|0;return d}function aC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-1632|0;jb=e;b=jb-16|0;jb=b;c=w[a+12>>2];d=e+8|0;w[b+8>>2]=d;w[b+12>>2]=d+600;d=ob[w[w[a>>2]+32>>2]](a,c,b+8|0)|0;if((d|0)==600){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],600)|0){c=w[a+12>>2]+600|0;break a}c=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=c}jb=b+16|0;b=-1;b:{if((d|0)!=600){break b}b=0;if(!up(e+8|0)){break b}b=-1;if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1024)|0)){break b}b=jb-16|0;jb=b;c=w[a+12>>2];d=e+608|0;w[b+8>>2]=d;w[b+12>>2]=d+1024;d=ob[w[w[a>>2]+32>>2]](a,c,b+8|0)|0;if((d|0)==1024){c:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1024)|0){c=w[a+12>>2]+1024|0;break c}c=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=c}jb=b+16|0;if((d|0)==1024){b=0;c=e+608|0;while(1){a=0;while(1){b=(x[(a<<2)+c|0]>15)+b|0;a=a+1|0;if((a|0)!=4){continue}break}f=f+1|0;c=(e+608|0)+(f<<4)|0;if((f|0)!=64){continue}break}b=b>>>0<17;break b}b=0}jb=e+1632|0;return b|0}function jx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=w[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>2|0;j=c>>>0>e>>>0?e:c;a:{if(!j){break a}i=j;c=b;while(1){f=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);b:{c:{d:{if((f|0)>=0){e=f;break d}e=-2147483648;if((f|0)==-2147483648){break c}e=0-f|0}if(g>>>0>=e>>>0){break b}}g=e}c=c+4|0;i=i-1|0;if(i){continue}break}if(!g|!j){break a}i=g-1|0;k=g>>>1|0;c=w[a+20>>2];e=j;while(1){a=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);h=a>>31;f=a;a=h<<31|a>>>1;f=k|f<<31;e:{if((a|0)>0|(a|0)>=0){f=EV(f,a,g,0);a=nb;h=(a|0)>=0&f>>>0>=2147483647|(a|0)>0;f=h?2147483647:f;a=h?0:a;break e}a=EV(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);f=0-a|0;a=0-(nb+((a|0)!=0)|0)|0;h=(a|0)<0&f>>>0<=2147483648|(a|0)<-1;f=h?-2147483648:f;a=h?-1:a}v[c>>1]=(a&65535)<<16|f>>>16;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){w[d>>2]=g}return j<<2}function aB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-48|0;jb=f;a:{if(u[c+11|0]>=0){w[f+16>>2]=w[c+8>>2];g=w[c+4>>2];w[f+8>>2]=w[c>>2];w[f+12>>2]=g;break a}me(f+8|0,w[c>>2],w[c+4>>2])}w[114256]=0;c=f+20|0;T(116,c|0,d|0);d=w[114256];w[114256]=0;b:{c:{if((d|0)!=1){d:{c=f+32|0;e:{if(u[e+11|0]>=0){d=w[e+4>>2];w[c>>2]=w[e>>2];w[c+4>>2]=d;w[c+8>>2]=w[e+8>>2];break e}d=w[e+4>>2];e=w[e>>2];w[114256]=0;U(3,c|0,e|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}w[114256]=0;e=f+44|0;w[f+4>>2]=e;w[f>>2]=f+8;U(51,a|0,b|0,f|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}while(1){a=e-12|0;if(u[e-1|0]<0){zb(w[a>>2])}e=a;if((e|0)!=(f+8|0)){continue}break}jb=f+48|0;return}}b=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(f+8|0)){continue}break}break b}b=P()|0;while(1){a=e-12|0;if(u[e-1|0]<0){zb(w[a>>2])}e=a;if((e|0)!=(f+8|0)){continue}break}}R(b|0);M()}
function HO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb+-64|0;jb=d;a:{b:{if((b|0)>=0){f=w[a+24>>2];if(If(w[f+484360>>2]+(x[f+484376|0]<<5)|0)>>>0>b>>>0){break b}}a=a+16|0;break a}f=0;e=w[a+24>>2];g=y[w[w[e+484360>>2]+(x[e+484376|0]<<5)>>2]+(b<<1)>>1];c:{h=w[e+484344>>2];if(g>>>0>=((w[e+484348>>2]-h|0)/52&65535)>>>0){break c}if((c|0)>=0){f=c;if(w[(C(g,52)+h|0)+12>>2]>(c|0)){break c}}a=a+16|0;break a}v[e+1074438>>1]=b;c=e;e=b&65535;Bn(c,e);c=w[a+24>>2];w[c+1074392>>2]=-2;w[c+1074428>>2]=f;g=x[a+64|0];u[d+30|0]=255;w[d+40>>2]=0;v[d+28>>1]=0;w[d+24>>2]=0;if((e|0)!=65535){v[d+36>>1]=b;w[d+32>>2]=f;w[d+40>>2]=2}b=w[d+44>>2];w[d+16>>2]=w[d+40>>2];w[d+20>>2]=b;b=w[d+36>>2];w[d+8>>2]=w[d+32>>2];w[d+12>>2]=b;b=w[d+28>>2];w[d>>2]=w[d+24>>2];w[d+4>>2]=b;ri(d+48|0,c,g?7:1,d);B[a+16>>3]=B[w[d+52>>2]-32>>3];b=w[d+48>>2];if(b){w[d+52>>2]=b;zb(b)}a=a+16|0}jb=d- -64|0;return+B[a>>3]}function nq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((x[a|0]-16&255)>>>0<241){break a}e=a+1954|0;c=a+1698|0;while(1){if(u[c|0]<-1){break a}c=c+1|0;if((e|0)!=(c|0)){continue}break}e=0;b:{if(x[a+14|0]){f=1;break b}f=1;c=0;while(1){c:{b=(c<<4)+a|0;if(x[b+418|0]|x[b+419|0]<<8|(x[b+420|0]<<16|x[b+421|0]<<24)){break c}g=x[b+422|0]|x[b+423|0]<<8|(x[b+424|0]<<16|x[b+425|0]<<24);if(x[(C(c,13)+a|0)+942|0]|g>>>0>1048575){break c}d=C(c,11)+a|0;h=d+1346|0;if(x[h|0]>15|x[d+1351|0]>3|x[d+1356|0]>3){break c}d:{e:{if(g){d=x[b+430|0]|x[b+431|0]<<8|(x[b+432|0]<<16|x[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(x[b+426|0]|x[b+427|0]<<8|(x[b+428|0]<<16|x[b+429|0]<<24))>>>0|d>>>0>g>>>0)){break c}b=1;if(e&1){break d}break e}b=1;if(e&1){break d}if(Jb(h,23261,11)){break e}b=0;break d}b=1}f=c>>>0<31;c=c+1|0;if((c|0)==32){break b}e=b;if(!x[(C(c,13)+a|0)+14|0]){continue}break b}break}b=e}b=!f&b}return b&1}function Px(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a:{b:{c:{d:{d=w[b>>2];if((d|0)!=w[b+4>>2]){while(1){if(g){f=w[c>>2];h=w[c+4>>2];d=x[c+11|0];w[114256]=0;i=f;f=d<<24>>24<0;S(92,a|0,(f?i:c)|0,(f?h:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}d=w[b>>2]}d=C(g,12)+d|0;e:{if(u[d+11|0]>=0){w[e+8>>2]=w[d+8>>2];f=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=f;break e}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(76,e|0,d|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}w[114256]=0;d=x[e+11|0];f=d<<24>>24<0;S(92,a|0,(f?w[e>>2]:e)|0,(f?w[e+4>>2]:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(u[e+11|0]<0){zb(w[e>>2])}g=g+1|0;d=w[b>>2];if(g>>>0<(w[b+4>>2]-d|0)/12>>>0){continue}break}}jb=e+16|0;return}g=P()|0;break a}g=P()|0;if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}g=P()|0}if(u[a+11|0]<0){zb(w[a>>2])}R(g|0);M()}function $d(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=w[a>>2];f=w[a+4>>2]-d>>1;if(f>>>0<b>>>0){i=jb-32|0;jb=i;h=b-f|0;a:{b:{f=w[a+8>>2];b=w[a+4>>2];c:{if(h>>>0<=f-b>>1>>>0){if(h){d=(h<<1)+b|0;while(1){v[b>>1]=y[c>>1];b=b+2|0;if((d|0)!=(b|0)){continue}break}b=d}w[a+4>>2]=b;break c}d=w[a>>2];b=b-d>>1;g=b+h|0;if((g|0)<0){break b}d=f-d|0;e=Vf(i+8|0,d>>>0>=2147483646?2147483647:d>>>0>g>>>0?d:g,b,a+8|0);b=w[e+8>>2];g=b+(h<<1)|0;while(1){v[b>>1]=y[c>>1];b=b+2|0;if((g|0)!=(b|0)){continue}break}w[e+8>>2]=g;c=w[a+4>>2];b=w[a>>2];d=c-b|0;f=w[e+4>>2]-d|0;w[e+4>>2]=f;if((d|0)>0){Fb(f,b,d);f=w[e+4>>2];g=w[e+8>>2];c=w[a+4>>2];b=w[a>>2]}w[a>>2]=f;w[e+4>>2]=b;w[a+4>>2]=g;w[e+8>>2]=c;d=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=d;if((b|0)!=(c|0)){w[e+8>>2]=((b-c|0)+1&-2)+c}if(!b){break c}zb(b)}jb=i+32|0;break a}Mb(a);M()}return}if(b>>>0<f>>>0){w[a+4>>2]=d+(b<<1)}}function pk(a,b){var c=0,d=0,e=0,f=0,g=0;d=y[a+480188>>1];a:{if(d>>>0<=255){while(1){c=C(d,896)+a|0;b:{if(w[c+1075060>>2]){c=w[c+1075072>>2];break b}e=w[c+1075640>>2];if(!e|(x[e+31|0]-1&255)>>>0>16){break a}c=w[c+1075072>>2];if(c&6144){break a}}if(c&512){c=w[a+1304392>>2];if(!c){break a}if((po(c,d&65535)|0)==255){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}e=8388608;if(b>>>0<=255){b=C(b,896)+a|0;if(!w[b+1075680>>2]){d=65535;if(w[b+1075060>>2]){break a}}e=w[b+1075672>>2]|w[b+1075664>>2]<<9}d=65535;b=y[a+480188>>1];if(b>>>0>255){break a}while(1){c=C(b,896)+a|0;if(!(w[c+1075680>>2]?0:w[c+1075060>>2])){f=(w[c+1075672>>2]|w[c+1075664>>2]<<9)>>>(w[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<e>>>0){c=w[c+1075712>>2];break d}if((e|0)!=(f|0)){break c}c=w[c+1075712>>2];if(g>>>0>=c>>>0){break c}}e=f;d=b;g=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function rD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;c=w[a>>2];a:{if(!(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],1)|0)){w[b>>2]=0;a=0;break a}c=w[a>>2];d=ob[w[w[c>>2]+28>>2]](c,g,w[a+8>>2],16)|0;e=x[g|0];c=e&127;w[b>>2]=c;if(c){while(1){h=h+1|0;f=c>>>0>1;c=c>>>1|0;if(f){continue}break}}f=e<<24>>24;e=(f|0)<0;c=1;b:{if(d>>>0<2|(f|0)>=0){break b}while(1){e=x[c+g|0];w[b>>2]=e&127|w[b>>2]<<7;h=h+7|0;f=e<<24>>24;e=(f|0)<0;c=c+1|0;if((d|0)==(c|0)){c=w[a>>2];c:{if(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],d)|0){c=w[a+8>>2]+d|0;break c}c=w[a>>2];c=ob[w[w[c>>2]+24>>2]](c)|0}w[a+8>>2]=c;d=w[a>>2];d=ob[w[w[d>>2]+28>>2]](d,g,c,16)|0;c=0}if(c>>>0>=d>>>0){break b}if((f|0)<0){continue}break}}d=w[a>>2];d:{if(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],c)|0){c=w[a+8>>2]+c|0;break d}c=w[a>>2];c=ob[w[w[c>>2]+24>>2]](c)|0}w[a+8>>2]=c;if(h>>>0>=33){w[b>>2]=-1;a=0;break a}a=!e}jb=g+16|0;return a|0}function cz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=0,z=0;i=jb-16|0;h=w[a>>2];g=w[a+4>>2];if(d){l=b+24|0;k=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];while(1){f=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+p|0;b=(((h>>>16|0)+4&131064)<<1)+l|0;q=v[b+14>>1];r=v[b+12>>1];s=v[b+10>>1];t=v[b+8>>1];u=v[b+6>>1];x=v[b+4>>1];y=v[b+2>>1];z=v[b>>1];j=0;b=1;while(1){e=j<<1;w[(i+8|0)+(j<<2)>>2]=(((((C(v[(e|8)+f>>1],s)+C(v[(e|4)+f>>1],t)|0)+C(v[(e|12)+f>>1],r)|0)+C(v[(e|16)+f>>1],q)|0)/2|0)+((((C(v[(e|-8)+f>>1],y)+C(v[(e|-12)+f>>1],z)|0)+C(v[(e|-4)+f>>1],x)|0)+C(v[e+f>>1],u)|0)/2|0)|0)/16384;e=b;b=0;j=1;if(e){continue}break}w[c>>2]=w[c>>2]+C(w[i+8>>2],o);w[c+4>>2]=w[c+4>>2]+C(w[i+12>>2],n);g=g+m|0;b=h+k|0;g=b>>>0<k>>>0?g+1|0:g;h=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=h;w[a+4>>2]=g}function LO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a:{b:{c:{d:{d=w[b>>2];if((d|0)!=w[b+4>>2]){while(1){if(g){f=w[c>>2];h=w[c+4>>2];d=x[c+11|0];w[114256]=0;i=f;f=d<<24>>24<0;S(2,a|0,(f?i:c)|0,(f?h:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}d=w[b>>2]}d=C(g,12)+d|0;e:{if(u[d+11|0]>=0){w[e+8>>2]=w[d+8>>2];f=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=f;break e}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,e|0,d|0,f|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}}w[114256]=0;d=x[e+11|0];f=d<<24>>24<0;S(2,a|0,(f?w[e>>2]:e)|0,(f?w[e+4>>2]:d)|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}if(u[e+11|0]<0){zb(w[e>>2])}g=g+1|0;d=w[b>>2];if(g>>>0<(w[b+4>>2]-d|0)/12>>>0){continue}break}}jb=e+16|0;return}g=P()|0;break a}g=P()|0;if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}g=P()|0}if(u[a+11|0]<0){zb(w[a>>2])}R(g|0);M()}function Gs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;$c(g+16|0,a,b,c,e,f-16129|0);fg(g,a,b,c,e,16257-f|0);b=w[g+8>>2];e=(w[g+12>>2]&33554431)<<7|b>>>25;h=w[g>>2]|(w[g+16>>2]|w[g+24>>2]|(w[g+20>>2]|w[g+28>>2]))!=0;f=w[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}jb=g+32|0;return l(2,d&-2147483648|e),q()}function VR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=D(0),m=0,n=D(0),o=D(0),p=D(0),q=D(0),r=D(0),s=D(0),t=D(0),u=D(0),v=D(0);h=jb-16|0;jb=h;j=w[a+56>>2];f=w[a+44>>2];if((0-(w[a+60>>2]-j>>11)|0)!=w[a+48>>2]-f>>11){w[h+8>>2]=f;k=f+2048|0;w[h+12>>2]=k;w[h>>2]=j;e=j+2048|0;w[h+4>>2]=e;a:{if(A[a+4216>>2]!=D(.5)){if(!d){break a}f=d;while(1){g=0;k=1;while(1){g=g<<2;e=g+(h+8|0)|0;i=w[e>>2];w[e>>2]=i+4;e=a+g|0;m=e+4248|0;p=A[m>>2];l=A[i>>2];q=A[a+4228>>2];r=A[a+4224>>2];s=A[a+4220>>2];t=A[a+4236>>2];u=A[a+4232>>2];i=e+4240|0;n=A[i>>2];A[m>>2]=n;A[i>>2]=l;i=e+4264|0;v=A[i>>2];e=e+4256|0;o=A[e>>2];A[i>>2]=o;l=D(D(D(D(n*r)+D(s*l))+D(p*q))-D(D(v*t)+D(o*u)));A[e>>2]=l;g=h+g|0;e=w[g>>2];w[g>>2]=e+4;A[e>>2]=l;e=k;k=0;g=1;if(e){continue}break}f=f-1|0;if(f){continue}break}break a}m=f;f=d<<2;Fb(j,m,f);Fb(e,k,f);j=w[a+56>>2]}ye(a,b,c,j,j+2048|0,d)}jb=h+16|0}function OP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;w[114256]=0;X(1407,a|0);e=w[114256];w[114256]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}w[114256]=0;X(1361,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break e}e=0;w[114256]=0;X(1408,c|0);f=w[114256];w[114256]=0;if((f|0)==1){break e}a=Cb(c,0,d);if(!x[b|0]){break b}if(Qe(b,3490)|(d|0)!=8){break d}w[a+4>>2]=1409;w[a>>2]=1410;break c}$(W(0)|0)|0;w[114256]=0;Y(1333,8059,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();return 0}if(Qe(b,7090)|(d|0)!=64){break b}w[a+60>>2]=1411;w[a+56>>2]=1412;w[a+52>>2]=1413;w[a+48>>2]=1414;w[a+44>>2]=1415;w[a+40>>2]=1416;w[a+36>>2]=1417;w[a+32>>2]=1418;w[a+28>>2]=1419;w[a+24>>2]=1420;w[a+20>>2]=1421;w[a+16>>2]=1422;w[a+12>>2]=1423;w[a+8>>2]=1424;w[a+4>>2]=1425;w[a>>2]=1426}e=1}return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function lx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=w[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=(c>>>0)/3|0;j=c>>>0>e>>>0?e:c;a:{if(!j){break a}i=j;c=b;while(1){f=x[c+1|0]<<16|x[c|0]<<8|x[c+2|0]<<24;b:{c:{d:{if((f|0)>=0){e=f;break d}e=-2147483648;if((f|0)==-2147483648){break c}e=0-f|0}if(g>>>0>=e>>>0){break b}}g=e}c=c+3|0;i=i-1|0;if(i){continue}break}if(!g|!j){break a}i=g-1|0;k=g>>>1|0;c=w[a+20>>2];e=j;while(1){a=x[b+1|0]<<16|x[b|0]<<8|x[b+2|0]<<24;h=a>>31;f=a;a=h<<31|a>>>1;f=k|f<<31;e:{if((a|0)>0|(a|0)>=0){f=EV(f,a,g,0);a=nb;h=(a|0)>=0&f>>>0>=2147483647|(a|0)>0;f=h?2147483647:f;a=h?0:a;break e}a=EV(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);f=0-a|0;a=0-(nb+((a|0)!=0)|0)|0;h=(a|0)<0&f>>>0<=2147483648|(a|0)<-1;f=h?-2147483648:f;a=h?-1:a}v[c>>1]=(a&65535)<<16|f>>>16;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){w[d>>2]=g}return C(j,3)|0}function kx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=w[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=(c>>>0)/3|0;j=c>>>0>e>>>0?e:c;a:{if(!j){break a}i=j;c=b;while(1){f=x[c+1|0]<<16|x[c+2|0]<<8|x[c|0]<<24;b:{c:{d:{if((f|0)>=0){e=f;break d}e=-2147483648;if((f|0)==-2147483648){break c}e=0-f|0}if(g>>>0>=e>>>0){break b}}g=e}c=c+3|0;i=i-1|0;if(i){continue}break}if(!g|!j){break a}i=g-1|0;k=g>>>1|0;c=w[a+20>>2];e=j;while(1){a=x[b+1|0]<<16|x[b+2|0]<<8|x[b|0]<<24;h=a>>31;f=a;a=h<<31|a>>>1;f=k|f<<31;e:{if((a|0)>0|(a|0)>=0){f=EV(f,a,g,0);a=nb;h=(a|0)>=0&f>>>0>=2147483647|(a|0)>0;f=h?2147483647:f;a=h?0:a;break e}a=EV(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);f=0-a|0;a=0-(nb+((a|0)!=0)|0)|0;h=(a|0)<0&f>>>0<=2147483648|(a|0)<-1;f=h?-2147483648:f;a=h?-1:a}v[c>>1]=(a&65535)<<16|f>>>16;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){w[d>>2]=g}return C(j,3)|0}function Os(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(x[a+52|0]){d=w[a+48>>2];if(!b){break a}u[a+52|0]=0;w[a+48>>2]=-1;break a}w[c+24>>2]=1;e=w[Ss(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=qj(w[a+32>>2]);if((g|0)==-1){break b}u[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(x[a+53|0]){w[c+20>>2]=u[c+24|0];break c}g=c+24|0;while(1){d:{d=w[a+40>>2];i=w[d>>2];j=w[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(mt(w[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=w[a+40>>2];w[d>>2]=i;w[d+4>>2]=j;if((e|0)==8){break b}d=qj(w[a+32>>2]);if((d|0)==-1){break b}u[f|0]=d;e=e+1|0;continue}break}w[c+20>>2]=u[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((rj(u[e+(c+24|0)|0],w[a+32>>2])|0)!=-1){continue}break b}}w[a+48>>2]=w[c+20>>2]}d=w[c+20>>2];break a}d=-1}jb=c+32|0;return d}function uu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b=w[a+32>>2];d=w[a+40>>2];if(b>>>0>=d>>>0){w[a+96>>2]=1;c=b;break a}c=b+1|0;w[a+32>>2]=c;if(!x[b|0]){break a}w[a+100>>2]=31;return 0}b:{if(c>>>0>=d>>>0){w[a+96>>2]=1;b=0;break b}w[a+32>>2]=c+1;b=x[c|0]}u[a+1375|0]=b;e=we(a);g=we(a);we(a);h=a,i=we(a),w[h+1112>>2]=i;we(a);b=w[a+32>>2];f=w[a+40>>2];c:{if(b>>>0>=f>>>0){w[a+96>>2]=1;d=0;break c}c=b+1|0;w[a+32>>2]=c;d=x[b|0];b=c}w[a+1116>>2]=d;c=b+d|0;if(c>>>0>f>>>0){w[a+96>>2]=1;w[a+100>>2]=10;return 0}Fb(a+1120|0,b,d);w[a+1404>>2]=-2;w[a+32>>2]=c;b=d;d:{if((e&g)==-1){break d}while(1){if((b|0)<=0){break d}b=b-1|0;if(x[(b+a|0)+1120|0]==255){continue}break}w[a+1408>>2]=e;w[a+1404>>2]=b}if(x[a+1377|0]){c=0;if(d){b=0;while(1){c=x[(a+b|0)+1120|0]+c|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}}w[a- -64>>2]=e;w[a+60>>2]=(w[a+56>>2]+(c+d|0)|0)+27}w[a+1380>>2]=0;return 1}function JE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;lc(b,0);w[b>>2]=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);d=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);c=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);w[b+4>>2]=c>>>0>d>>>0?d:c;d=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);c=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);w[b+8>>2]=c>>>0>d>>>0?d:c;c=(x[a+15|0]|x[a+16|0]<<8)<<1;w[b+24>>2]=c;w[b+24>>2]=x[a+15|0]|x[a+16|0]<<8?c:16726;f=b,g=(C(Bk(u[a+17|0],x[a+14|0]<<28>>24),w[b+24>>2])>>>0)/8363|0,w[f+24>>2]=g;c=x[a+18|0];v[b+30>>1]=(((c>>>0>=127?127:c)<<8|64)>>>0)/127;c=x[a+14|0];if(c>>>0>=16){v[b+34>>1]=32;v[b+28>>1]=c&240}c=x[a+19|0];if(c&4){v[b+34>>1]=y[b+34>>1]|1;c=x[a+19|0]}a:{if(!(c&8)|z[b+4>>2]>=z[b+8>>2]){break a}d=y[b+34>>1];e=d|2;v[b+34>>1]=e;c=x[a+19|0];if(c&16){e=d|6;v[b+34>>1]=e;c=x[a+19|0]}if(!(c&64)){break a}v[b+34>>1]=e|128}}function ie(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=w[a>>2];g=(w[a+4>>2]-d|0)/52|0;if((g&65535)>>>0>b>>>0){f=C(b,52)+d|0;if(w[f>>2]!=w[f+4>>2]){break b}}c:{d:{if(b>>>0>=g>>>0){d=e+8|0;Cb(d,0,48);w[114256]=0;w[e+56>>2]=a;U(954,a|0,b+1|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}if(u[e+55|0]<0){zb(w[e+44>>2])}d=w[e+32>>2];if(d){w[e+36>>2]=d;zb(d)}d=w[e+8>>2];if(d){w[e+12>>2]=d;zb(d)}d=w[a>>2]}w[114256]=0;f=d;d=C(b,52);Q(955,f+d|0,c|0)|0;c=w[114256];w[114256]=0;e:{if((c|0)!=1){c=d+w[a>>2]|0;w[c+16>>2]=0;w[c+20>>2]=0;w[114256]=0;S(227,c|0,17256,1)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break e}}a=W(74720)|0;b=kb;break c}a=w[a>>2]+C(b,52)|0;h=w[a>>2]!=w[a+4>>2];break b}a=W(74720)|0;b=kb;Cf(e+8|0)}if((fa(74720)|0)!=(b|0)){break a}$(a|0)|0;aa()}jb=e- -64|0;return h|0}R(a|0);M()}function cU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{if(!(w[a+4>>2]-w[a>>2]>>11==(b|0)&w[a+16>>2]-w[a+12>>2]>>11==(c|0))){w[114256]=0;T(987,a|0,b|0);f=w[114256];w[114256]=0;b:{c:{if((f|0)==1){break c}w[114256]=0;f=a;T(987,a+12|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;T(988,a+24|0,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;e=a;T(988,a+36|0,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}if(b){d=0;while(1){w[w[a+24>>2]+(d<<2)>>2]=w[a>>2]+(d<<11);d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break b}return 1}b=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;w[a+4>>2]=w[a>>2];Xv(a);w[a+16>>2]=w[a+12>>2];Xv(a+12|0);w[a+28>>2]=w[a+24>>2];Wv(a+24|0);w[a+40>>2]=w[a+36>>2];Wv(a+36|0);aa();return 0}a=0;while(1){w[w[e+36>>2]+(a<<2)>>2]=w[f+12>>2]+(a<<11);a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}R(b|0);M()}function Tv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=x[b+4244|0];k=x[b+4243|0];l=x[b+4242|0];m=x[b+4241|0];n=x[b+4240|0];d=w[b+4236>>2];e=w[b+4232>>2];f=w[b+4228>>2];g=w[b+4224>>2];h=w[b+4220>>2];c=w[b+4208>>2];i=w[b+4212>>2]-c|0;a:{if(i>>>0<=32){c=b+4208|0;Il(c,33-i|0);c=w[c>>2];break a}if((i|0)==33){break a}w[b+4212>>2]=c+33}u[c+32|0]=j;u[c+31|0]=k;u[c+30|0]=l;u[c+29|0]=m;u[c+28|0]=n;u[c+24|0]=d;u[c+25|0]=d>>>8;u[c+26|0]=d>>>16;u[c+27|0]=d>>>24;u[c+20|0]=e;u[c+21|0]=e>>>8;u[c+22|0]=e>>>16;u[c+23|0]=e>>>24;u[c+16|0]=f;u[c+17|0]=f>>>8;u[c+18|0]=f>>>16;u[c+19|0]=f>>>24;u[c+12|0]=g;u[c+13|0]=g>>>8;u[c+14|0]=g>>>16;u[c+15|0]=g>>>24;u[c+8|0]=h;u[c+9|0]=h>>>8;u[c+10|0]=h>>>16;u[c+11|0]=h>>>24;u[c|0]=76;u[c+1|0]=70;u[c+2|0]=79;u[c+3|0]=32;u[c+4|0]=0;u[c+5|0]=0;u[c+6|0]=0;u[c+7|0]=0;c=w[b+4212>>2];w[a>>2]=w[b+4208>>2];w[a+4>>2]=c}function qE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;e=w[b+4>>2];d=x[b+11|0];w[114256]=0;h=d<<24>>24<0?e:d;T(72,a|0,h|0);e=w[114256];w[114256]=0;if((e|0)!=1){a:{if(h){d=0;while(1){e=d+1|0;f=u[b+11|0]<0?w[b>>2]:b;g=x[f+d|0];b:{c:{if((e|0)==(h|0)|(g|0)!=37){break c}g=x[e+f|0];f=g-49|0;if((f&255)>>>0<=8){d=w[c>>2];if(f>>>0>=(w[c+4>>2]-d|0)/12>>>0){d=e;break b}i=d+C(f,12)|0;d=w[i>>2];f=w[i+4>>2];g=x[i+11|0];w[114256]=0;j=d;d=g<<24>>24<0;S(92,a|0,(d?j:i)|0,(d?f:g)|0)|0;f=w[114256];w[114256]=0;d=e;if((f|0)!=1){break b}break a}if((g|0)==37){d=e;g=37;break c}w[114256]=0;S(291,a|0,1,37)|0;f=w[114256];w[114256]=0;d=e;if((f|0)==1){break a}}w[114256]=0;S(291,a|0,1,g<<24>>24)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function Xn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;g=ea(79)|0;e=w[114256];w[114256]=0;b:{c:{d:{if((e|0)==1){break d}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;U(80,f+152|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}c=c+4|0;e=Ic(f+144|0,c);Wc(c,g);Ab(e)}Ab(f);g=w[b+4>>2];b=w[b>>2];w[114256]=0;Oa(89,d|0,b|0,g|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=a;a=d+4|0;T(82,b|0,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}b=w[15e3];w[d>>2]=b;w[w[b-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(a);pc(d+56|0);jb=f+160|0;break a}a=P()|0;break b}a=P()|0;Ab(f)}nd(d);R(a|0);M()}}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=x[b+5|0];c=x[b+3|0];if(!(i|(c|0)!=4)){d=y[a+14>>1];c=w[a>>2]+(d>>>3&8188)|0;e=w[c>>2];j=c,k=FV(-2,d)&e,w[j>>2]=k;u[b+3|0]=0;c=0}e=x[b+2|0];if(!(x[b+4|0]|(e|0)!=11)){d=y[a+14>>1];e=w[a>>2]+(d>>>3&8188)|0;f=w[e>>2];j=e,k=FV(-2,d)&f,w[j>>2]=k;u[b+2|0]=0;e=0}d=y[a+14>>1];a:{b:{c:{if(x[b|0]){g=1<<d;f=d>>>5|0;h=w[a>>2];break c}g=1<<d;h=w[a>>2];f=d>>>5|0;if(!(g&w[h+(f<<2)>>2])){break c}if(!((e|0)==11|c)){u[b+5|0]=0;u[b+3|0]=4;break a}if((c|0)==4|e){break b}u[b+4|0]=0;u[b+2|0]=11;break b}f=(f<<2)+h|0;if(!((c|0)!=4&(e|0)!=11)){w[f>>2]=w[f>>2]|g;break b}w[f>>2]=w[f>>2]&(g^-1)}d:{c=x[b+3|0];if(!(c|!x[a+16|0])){u[b+5|0]=125;u[b+3|0]=17;break d}e:{switch(c-16|0){case 0:break e;case 1:break d;default:break a}}if(i){break a}u[b+5|0]=6;u[a+16|0]=1;break a}u[a+16|0]=0}v[a+14>>1]=(d+1>>>0)%y[a+12>>1]}function pU(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-176|0;jb=e;a=Zg(e+16|0,a,8);b=w[w[a>>2]-12>>2];w[114256]=0;d=ea(79)|0;c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}w[114256]=0;b=a+b|0;T(10,e+8|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break e}w[114256]=0;U(80,e+168|0,b|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}Ab(e+168|0);b=w[b+24>>2];if(b){c=w[w[b>>2]+8>>2];w[114256]=0;T(c|0,b|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}b=b+4|0;c=Ic(e+160|0,b);Wc(b,d);Ab(c)}Ab(e+8|0);w[114256]=0;d=Q(96,a|0,e+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}d=w[(d+w[w[d>>2]-12>>2]|0)+16>>2];b=y[e+168>>1];c=w[15045];w[a>>2]=c;w[a+w[c-12>>2]>>2]=w[15048];w[a+8>>2]=59272;if(u[a+51|0]<0){zb(w[a+40>>2])}wc(a+8|0);pc(a+60|0);jb=e+176|0;a=(d&5?0:b)&65535;break a}d=P()|0;break b}d=P()|0;break b}d=P()|0;Ab(e+8|0)}Se(a);R(d|0);M()}return a|0}function nC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;u[e+15|0]=8;u[e+14|0]=0;v[e+12>>1]=0;if(d){l=C(c,d);while(1){if((l|0)>0){h=(j<<1)+b|0;n=h+(l<<1)|0;while(1){v[e+10>>1]=0;Ap(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=x[e+15|0];if(!g){break b}c=y[e+12>>1];while(1){f=c<<1;c=f&254;v[e+12>>1]=c;f=(f&65534)>>>0>255;u[e+14|0]=f;if(!c){if(!Xb(a,e+9|0)){break b}c=x[e+9|0];f=c>>>7|0;u[e+14|0]=f;c=c<<1&254|1;v[e+12>>1]=c}i=y[e+10>>1]<<1|f;v[e+10>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=y[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}u[e+15|0]=(x[e+15|0]+c&254)>>>1;c=i&1;u[e+14|0]=c;k=(c-1^(i&65534)>>>1)+k|0;v[e+10>>1]=k;v[h>>1]=k;h=(d<<1)+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}jb=e+16|0}function vu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=w[a+32>>2];b=w[a+1380>>2];a:{b:{if((b|0)==-1){g=1;b=-1;break b}d=w[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=x[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}e=1;if(z[a+40>>2]<c>>>0){break a}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}d:{f=w[a+40>>2];if(f>>>0<=c+26>>>0){break d}e=21;if(x[c+4|0]|(x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24))!=(x[82856]|x[82857]<<8|(x[82858]<<16|x[82859]<<24))){break a}e:{if(g){if(!w[a+992>>2]|!(u[c+5|0]&1)){break e}break a}if(!(u[c+5|0]&1)){break a}}h=c+27|0;d=x[c+26|0];c=h+d|0;if(f>>>0<c>>>0){break d}g=0;b=0;f:{if(!d){break f}while(1){e=x[b+h|0];c=e+c|0;if((e|0)!=255){break f}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}b=(b|0)==(d|0)?-1:b;e=1;if(c>>>0<=f>>>0){continue}break a}break}e=1}w[a+100>>2]=e;return 0}function DB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;e=w[b+4>>2];d=x[b+11|0];w[114256]=0;h=d<<24>>24<0?e:d;T(52,a|0,h|0);e=w[114256];w[114256]=0;if((e|0)!=1){a:{if(h){d=0;while(1){e=d+1|0;f=u[b+11|0]<0?w[b>>2]:b;g=x[f+d|0];b:{c:{if((e|0)==(h|0)|(g|0)!=37){break c}g=x[e+f|0];f=g-49|0;if((f&255)>>>0<=8){d=w[c>>2];if(f>>>0>=(w[c+4>>2]-d|0)/12>>>0){d=e;break b}i=d+C(f,12)|0;d=w[i>>2];f=w[i+4>>2];g=x[i+11|0];w[114256]=0;j=d;d=g<<24>>24<0;S(2,a|0,(d?j:i)|0,(d?f:g)|0)|0;f=w[114256];w[114256]=0;d=e;if((f|0)!=1){break b}break a}if((g|0)==37){d=e;g=37;break c}w[114256]=0;S(53,a|0,1,37)|0;f=w[114256];w[114256]=0;d=e;if((f|0)==1){break a}}w[114256]=0;S(53,a|0,1,g<<24>>24)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function fU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;w[g>>2]=b;a:{d=w[a+4>>2];e=w[a>>2];f=d-e|0;c=0;b:{if(f>>>0>2047){break b}c=0;if(!b){break b}c=w[a+8>>2];c:{if(c>>>0>d>>>0){w[g>>2]=0;w[d>>2]=b;w[a+4>>2]=d+4;break c}w[114256]=0;c=c-e|0;d=c>>1;e=f>>2;f=e+1|0;e=Z(981,g+8|0,(c>>>0>=2147483644?1073741823:d>>>0>f>>>0?d:f)|0,e|0,a+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}c=w[e+8>>2];w[g>>2]=0;w[c>>2]=b;h=c+4|0;w[e+8>>2]=h;f=w[e+4>>2];d=w[a+4>>2];c=w[a>>2];d:{if((d|0)==(c|0)){d=c;break d}while(1){d=d-4|0;h=w[d>>2];w[d>>2]=0;w[f-4>>2]=h;f=w[e+4>>2]-4|0;w[e+4>>2]=f;if((c|0)!=(d|0)){continue}break}h=w[e+8>>2];c=w[a+4>>2];d=w[a>>2]}w[a>>2]=f;w[e+4>>2]=d;w[a+4>>2]=h;w[e+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=d;w[e+12>>2]=c;Yv(e)}c=b}a=w[g>>2];w[g>>2]=0;if(a){od(a)}jb=g+32|0;return c|0}a=P()|0;w[g>>2]=0;od(b);R(a|0);M()}function oh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{b:{c:{d:{g=w[a>>2];h=w[a+4>>2]-g>>2;e=h-1|0;e:{if(e){f:{while(1){if((f|0)==(h|0)){break a}if(y[(f<<2)+g>>1]>=(b|0)){break f}f=f+1|0;if((e|0)!=(f|0)){continue}break}f=e}if(f>>>0>=h>>>0){break a}i=y[(f<<2)+g>>1];if((i|0)<=(b|0)){break e}if(f){break d}f=0;a=0;e=0;break c}a=0;i=y[g>>1];e=0;if((i|0)>(b|0)){break c}}a=(x[((f<<2)+g|0)+2|0]<<16)/(d|0)|0;break b}e=f-1|0;if(e>>>0>=h>>>0){break a}e=(e<<2)+g|0;a=(x[e+2|0]<<16)/(d|0)|0;e=y[e>>1]}if((e|0)>=(b|0)|e>>>0>=i>>>0){break b}h=a;a=((x[((f<<2)+g|0)+2|0]<<16)/(d|0)|0)-a|0;d=a;f=a>>31;a=b-e|0;b=BV(d,f,a,a>>31);a=i-e|0;b=CV(b,nb,a,a>>31);d=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;d=b?2147483647:d;a=b?0:a;a=h+((a|0)<0&d>>>0<=2147483648|(a|0)<-1?-2147483648:d)|0}f=0;g:{if((a|0)>=0){f=65536;if(a>>>0<65537){break g}}a=f}return(C(a,c)+32768|0)/65536|0}Bc(a);M()}function zy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=jb-32|0;jb=i;d=w[a+8>>2];a:{if((d|0)!=w[a+12>>2]){e=d;break a}f=w[a+4>>2];c=w[a>>2];if(f>>>0>c>>>0){h=d-f|0;c=((f-c>>2)+1|0)/-2<<2;e=c+f|0;if((d|0)!=(f|0)){hc(e,f,h);d=w[a+4>>2]}e=e+h|0;w[a+8>>2]=e;w[a+4>>2]=d+c;break a}c=(d|0)==(c|0)?1:d-c>>1;g=ud(i+8|0,c,c>>>2|0,w[a+16>>2]);c=w[g+8>>2];d=w[a+4>>2];e=w[a+8>>2];b:{if((d|0)==(e|0)){e=c;c=d;break b}e=(e-d|0)+c|0;while(1){h=y[d>>1]|y[d+2>>1]<<16;v[c>>1]=h;v[c+2>>1]=h>>>16;d=d+4|0;c=c+4|0;if((c|0)!=(e|0)){continue}break}d=w[a+8>>2];c=w[a+4>>2]}f=w[a>>2];w[a>>2]=w[g>>2];w[g>>2]=f;w[a+4>>2]=w[g+4>>2];w[g+4>>2]=c;w[a+8>>2]=e;w[g+8>>2]=d;h=w[a+12>>2];w[a+12>>2]=w[g+12>>2];w[g+12>>2]=h;if((d|0)!=(c|0)){w[g+8>>2]=((c-d|0)+3&-4)+d}if(!f){break a}zb(f);e=w[a+8>>2]}b=y[b>>1]|y[b+2>>1]<<16;v[e>>1]=b;v[e+2>>1]=b>>>16;w[a+8>>2]=w[a+8>>2]+4;jb=i+32|0}function pQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1381,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7714,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function nQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1382,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7682,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function mQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1383,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7620,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function lQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1384,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7650,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function kQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1385,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7585,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function jQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1386,d|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break i}c=w[d>>2];e=(w[d+4>>2]-c|0)/12|0;if(e>>>0<2147483647){break h}c=ba(8)|0;w[114256]=0;b=Q(191,c|0,3641)|0;e=w[114256];w[114256]=0;if((e|0)==1){break g}w[114256]=0;U(194,b|0,75040,133);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=W(0)|0;break f}b=W(0)|0;break e}b=W(0)|0;break e}j:{if(!(b>>>0<e>>>0&(b|0)>=0)){b=rc(17256);break j}a=c+C(b,12)|0;b=rc(u[a+11|0]<0?w[a>>2]:a)}bc(d);break d}b=W(0)|0;ca(c|0)}bc(d)}$(b|0)|0;b=0;w[114256]=0;Y(1333,7746,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){break a}W(0)|0;Eb()}M()}R(a|0);M()}function PU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;a:{b:{if(b-1025>>>0<4294966272){break b}e=w[a+12>>2];if((e|0)==(b|0)){break b}f=w[w[a+48>>2]+12>>2];if(c){c=w[f+8>>2];if(z[c+40>>2]<b>>>0|z[c+36>>2]>b>>>0){break b}}c=b-e|0;h=e-b|0;e=b>>>0>e>>>0;c=C(y[f+480188>>1],e?c:h);c:{if(e){d=w[(d?a+4|0:a)>>2];w[114256]=0;v[g+12>>1]=0;w[g+8>>2]=0;Z(944,a|0,d|0,c|0,g+8|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break c}a=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(a|0)|0;aa();break b}if(d){if(!c){break c}f=C((C(c,6)|0)/6|0,6);d=w[a+4>>2];e=d+C(c,-6)|0;c=w[a>>2];e=C((e-c|0)/6|0,6)+c|0;c=f+e|0;f=d-c|0;if((c|0)!=(d|0)){hc(e,c,f)}w[a+4>>2]=e+C((f|0)/6|0,6);break c}if(!c){break c}f=w[a+4>>2];d=C(c,6);c=w[a>>2];d=d+c|0;e=f-d|0;if((d|0)!=(f|0)){hc(c,d,e)}w[a+4>>2]=c+C((e|0)/6|0,6)}w[a+12>>2]=b;i=1}jb=g+16|0;return i|0}R(a|0);M()}function Kn(a,b,c){var d=0,e=0,f=0;d=w[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=x[b+833|0];if(c){u[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){u[b+833|0]=c;break a}c=x[b+833|0]}b:{if(!(u[b+872|0]&1)){break b}d=w[b+700>>2];if(!d|!(c&255)){break b}if(!(!(x[a+480208|0]&16)|w[a+480180>>2]==4)){f=w[a+1074312>>2]&128;a=w[((c&15)<<2)+(f?30256:31280)>>2];c=BV(a,a>>31,d,d>>31)+32768|0;a=nb;c=CV(c,c>>>0<32768?a+1|0:a,65536,0);e=c;a=nb;c=(a|0)>=0&c>>>0>=2147483647|(a|0)>0;e=c?2147483647:e;a=c?0:a;a=(a|0)<0&e>>>0<=2147483648|(a|0)<-1?-2147483648:e;w[b+700>>2]=a;if((a|0)!=(d|0)){break b}if(f){if((d|0)==2147483647){break b}w[b+700>>2]=d+1;return}if((d|0)<2){break b}w[b+700>>2]=d-1;return}c=d-((c&255)<<2)|0;w[b+700>>2]=c;if((c|0)>0){break b}w[b+700>>2]=1;if(w[a+480180>>2]!=2){break b}w[b+696>>2]=0;w[b+88>>2]=w[b+88>>2]|2101248}}function dB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;lc(c,2);d=x[b+13|0];v[c+30>>1]=(d>>>0>=64?64:d)<<2;w[c+24>>2]=(x[b+14|0]|x[b+15|0]<<8)<<1;d=e+8|0;Vb(d,2,b+1|0,12);w[114256]=0;w[e+28>>2]=22;w[e+24>>2]=c+43;Q(200,e+24|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(u[e+19|0]<0){zb(w[e+8>>2])}u[a|0]=8;u[a+1|0]=1;u[a+2|0]=0;u[a+3|0]=2;a:{if((x[b|0]&3)!=1){break a}g=x[b+22|0]|x[b+23|0]<<8|(x[b+24|0]<<16|x[b+25|0]<<24);w[c>>2]=g;f=x[b+26|0]|x[b+27|0]<<8|(x[b+28|0]<<16|x[b+29|0]<<24);w[c+4>>2]=f;d=x[b+30|0]|x[b+31|0]<<8|(x[b+32|0]<<16|x[b+33|0]<<24);h=d-(d>>>0>f>>>0)|0;w[c+8>>2]=h;d=x[b|0];if(d&4){v[c+34>>1]=y[c+34>>1]|2;d=x[b|0]}if(d&8){v[c+34>>1]=y[c+34>>1]|4;d=x[b|0]}if(!(d&16)){break a}u[a+3|0]=9;u[a|0]=16;w[c+8>>2]=h>>>1;w[c+4>>2]=f>>>1;w[c>>2]=g>>>1}jb=e+32|0;return}a=P()|0;if(u[e+19|0]<0){zb(w[e+8>>2])}R(a|0);M()}function bm(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=x[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}d=w[b>>2];b:{if((d^-1)&d-16843009&-2139062144){break b}while(1){c=d^1027423549;if((c^-1)&c-16843009&-2139062144){break b}d=w[b+4>>2];b=b+4|0;if(!(d-16843009&(d^-1)&-2139062144)){continue}break}}while(1){c=b;e=x[b|0];if(e){b=c+1|0;if((e|0)!=61){continue}}break}b=c}if((a|0)==(b|0)){return 0}e=b-a|0;c:{if(x[e+a|0]){break c}f=w[115039];if(!f){break c}d=w[f>>2];if(!d){break c}while(1){d:{b=a;h=0;g=e;c=0;e:{if(!e){break e}c=x[b|0];f:{if(!c){break f}while(1){g:{i=x[d|0];if(!i){break g}g=g-1|0;if(!g|(c|0)!=(i|0)){break g}d=d+1|0;c=x[b+1|0];b=b+1|0;if(c){continue}break f}break}h=c}c=(h&255)-x[d|0]|0}if(!c){b=w[f>>2]+e|0;if(x[b|0]==61){break d}}d=w[f+4>>2];f=f+4|0;if(d){continue}break c}break}j=b+1|0}return j}function uz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{f=w[a+12>>2];h=w[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}j=b+196648|0;break a}j=b+131112|0;break a}j=b+262184|0}i=w[a>>2];b=w[a+4>>2];if(d){k=w[a+16>>2];l=w[a+24>>2];m=w[a+20>>2];while(1){g=(b<<1)+k|0;e=(i>>>16&65520)+j|0;e=(((((((C(v[g-4>>1],v[e+2>>1])+C(v[g-6>>1],v[e>>1])|0)+C(v[g-2>>1],v[e+4>>1])|0)+C(v[g>>1],v[e+6>>1])|0)+C(v[g+2>>1],v[e+8>>1])|0)+C(v[g+4>>1],v[e+10>>1])|0)+C(v[g+6>>1],v[e+12>>1])|0)+C(v[g+8>>1],v[e+14>>1])|0)/32768|0;w[c>>2]=w[c>>2]+C(e,m);w[c+4>>2]=w[c+4>>2]+C(e,l);b=b+f|0;e=h+i|0;b=e>>>0<h>>>0?b+1|0:b;i=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=i;w[a+4>>2]=b}function Sn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;g=ea(79)|0;e=w[114256];w[114256]=0;b:{c:{d:{if((e|0)==1){break d}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break d}w[114256]=0;U(80,f+152|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}c=c+4|0;e=Ic(f+144|0,c);Wc(c,g);Ab(e)}Ab(f);h=B[b>>3];w[114256]=0;Ba(90,d|0,+h)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}w[114256]=0;b=a;a=d+4|0;T(82,b|0,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}b=w[15e3];w[d>>2]=b;w[w[b-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(a);pc(d+56|0);jb=f+160|0;break a}a=P()|0;break b}a=P()|0;Ab(f)}nd(d);R(a|0);M()}}function JT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=ze(a,b,c,d);w[a+4280>>2]=0;w[a+4284>>2]=0;w[a+4208>>2]=0;w[a+4212>>2]=0;w[a+4216>>2]=0;w[a>>2]=78100;b=a+4288|0;w[b>>2]=0;w[b+4>>2]=0;w[114256]=0;b=ea(812)|0;c=w[114256];w[114256]=0;a:{b:{if((c|0)==1){break b}w[114256]=0;b=ml(b);c=w[114256];w[114256]=0;if((c|0)==1){break b}w[a+4228>>2]=1049926264;w[a+4232>>2]=0;w[a+4220>>2]=1056964608;w[a+4224>>2]=1056964608;u[a+4244|0]=0;w[a+4236>>2]=2147483647;w[a+4240>>2]=0;w[a+4296>>2]=C(b,214013)+2531011;Xj(a);e=B[a+4248>>3]/+z[w[a+16>>2]+24620>>2];B[a+4264>>3]=e;if(x[a+4240|0]){B[a+4264>>3]=e*.016666666666666666*B[a+4288>>3]}w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+4208>>2];if(b){w[a+4212>>2]=b;zb(b)}Oc(a);R(c|0);M()}return a|0}function dz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0,z=0,A=0;h=jb-16|0;g=w[a>>2];f=w[a+4>>2];if(d){k=b+24|0;i=w[a+8>>2];l=w[a+12>>2];m=w[a+24>>2];n=w[a+20>>2];o=w[a+16>>2];while(1){e=(((f&2147483647)<<1|g>>>31)&-2)+o|0;b=(((g>>>16|0)+4&131064)<<1)+k|0;p=v[b+14>>1];q=v[b+12>>1];r=v[b+10>>1];s=v[b+8>>1];t=v[b+6>>1];x=v[b+4>>1];y=v[b+2>>1];z=v[b>>1];b=0;j=1;while(1){w[(h+8|0)+(b<<2)>>2]=(((((C(u[(b|4)+e|0],r)+C(u[(b|2)+e|0],s)|0)+C(u[(b|6)+e|0],q)|0)+C(u[(b|8)+e|0],p)<<8)/2|0)+((((C(u[(b|-4)+e|0],y)+C(u[(b|-6)+e|0],z)|0)+C(u[(b|-2)+e|0],x)|0)+C(u[b+e|0],t)<<8)/2|0)|0)/16384;A=j;j=0;b=1;if(A){continue}break}w[c>>2]=w[c>>2]+C(w[h+8>>2],n);w[c+4>>2]=w[c+4>>2]+C(w[h+12>>2],m);f=f+l|0;b=g+i|0;f=b>>>0<i>>>0?f+1|0:f;g=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=g;w[a+4>>2]=f}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;lc(b,4);c=x[a+12|0]<<2;v[b+30>>1]=c>>>0>=256?256:c;c=x[a+15|0];v[b+34>>1]=32;v[b+28>>1]=c;u[b+37|0]=x[a+13|0];u[b+36|0]=x[a+16|0];g=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);w[b>>2]=g;d=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);w[b+4>>2]=d;e=(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))+d|0;w[b+8>>2]=e;c=x[a+14|0];if(c&16){e=e>>>1|0;w[b+8>>2]=e;d=d>>>1|0;w[b+4>>2]=d;g=g>>>1|0;w[b>>2]=g;c=x[a+14|0]}if(c&32){e=e>>>1|0;w[b+8>>2]=e;d=d>>>1|0;w[b+4>>2]=d;w[b>>2]=g>>>1;c=x[a+14|0]}if(!(!(c&3)|d>>>0>=e>>>0)){v[b+34>>1]=34;v[b+34>>1]=x[a+14|0]&2?38:34}a=Hb(f+8|0,17256);w[114256]=0;w[f+28>>2]=22;w[f+24>>2]=b+43;Q(200,f+24|0,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(u[a+11|0]<0){zb(w[a>>2])}jb=f+32|0;return}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function $T(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=D(0),o=D(0),p=D(0),q=D(0),r=0,s=0,t=D(0),u=D(0),v=0,x=D(0),y=D(0),z=0;if(w[a+4220>>2]){h=w[a+56>>2];if(d){j=h+2048|0;i=w[a+44>>2];k=i+2048|0;e=w[a+4224>>2];r=w[a+4208>>2];z=w[a+4228>>2];l=h;m=d;while(1){s=(e<<3)+r|0;f=A[a+4248>>2];n=A[k>>2];t=A[a+4256>>2];o=A[i>>2];u=A[a+4252>>2];v=w[a+4220>>2];g=e-z|0;g=((v&g>>31)+g<<3)+r|0;p=A[g>>2];x=A[a+4244>>2];q=A[g+4>>2];y=D(D(D(D(f*n)+D(t*o))+D(u*p))+D(x*q));A[s>>2]=D(E(y))<D(10000000195414814e-40)?D(0):y;f=D(D(D(D(f*o)+D(t*n))+D(u*q))+D(x*p));A[s+4>>2]=D(E(f))<D(10000000195414814e-40)?D(0):f;e=e+1|0;e=(e|0)!=(v|0)?e:0;w[a+4224>>2]=e;A[l>>2]=D(p*A[a+4236>>2])+D(o*A[a+4240>>2]);A[j>>2]=D(q*A[a+4236>>2])+D(n*A[a+4240>>2]);j=j+4|0;l=l+4|0;k=k+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}ye(a,b,c,h,h+2048|0,d)}}function zu(a,b,c,d){var e=0,f=0,g=0,h=D(0),i=0,j=D(0),k=0,l=D(0),m=D(0),n=D(0),o=0;e=jb-96|0;jb=e;if((d|0)>0){while(1){A[e+48>>2]=-A[a>>2];A[e>>2]=A[a+68>>2];f=0;while(1){g=(e+48|0)+(f<<3)|0;i=(f<<4)+a|0;j=A[i+8>>2];h=A[i+4>>2];A[g+4>>2]=j+h;k=f<<1;A[(8-k<<2)+e>>2]=h-j;j=A[i+16>>2];h=A[i+12>>2];A[(7-k<<2)+e>>2]=j-h;A[g+8>>2]=-D(h+j);f=f+1|0;if((f|0)!=4){continue}break}xu(e+48|0);xu(e);A[e+4>>2]=-A[e+4>>2];A[e+12>>2]=-A[e+12>>2];A[e+20>>2]=-A[e+20>>2];A[e+28>>2]=-A[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=A[g>>2];k=g;h=A[f+45680>>2];l=A[f+(e+48|0)>>2];m=A[e+f>>2];g=f+36|0;n=A[g+45680>>2];A[k>>2]=D(h*l)-D(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=D(D(h*m)+D(n*l));A[k>>2]=D(j*A[f>>2])-D(A[g>>2]*h);A[(17-i<<2)+a>>2]=D(A[f>>2]*h)+D(j*A[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}jb=e+96|0}function vz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{f=w[a+12>>2];h=w[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}j=b+196648|0;break a}j=b+131112|0;break a}j=b+262184|0}i=w[a>>2];b=w[a+4>>2];if(d){k=w[a+16>>2];l=w[a+24>>2];m=w[a+20>>2];while(1){g=b+k|0;e=(i>>>16&65520)+j|0;e=(((((((C(u[g-2|0],v[e+2>>1])+C(u[g-3|0],v[e>>1])|0)+C(u[g-1|0],v[e+4>>1])|0)+C(u[g|0],v[e+6>>1])|0)+C(u[g+1|0],v[e+8>>1])|0)+C(u[g+2|0],v[e+10>>1])|0)+C(u[g+3|0],v[e+12>>1])|0)+C(u[g+4|0],v[e+14>>1])<<8)/32768|0;w[c>>2]=w[c>>2]+C(e,m);w[c+4>>2]=w[c+4>>2]+C(e,l);b=b+f|0;e=h+i|0;b=e>>>0<h>>>0?b+1|0:b;i=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=i;w[a+4>>2]=b}function sm(a){a=a|0;var b=0,c=0,d=0;c=jb-16|0;jb=c;b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+24>>2];d=w[114256];w[114256]=0;a:{b:{c:{d:{e:{if((d|0)!=1){if(!b){break b}w[114256]=0;Q(14,c+8|0,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break d}if(!x[c+8|0]){break e}b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+24>>2];d=w[114256];w[114256]=0;f:{if((d|0)==1){break f}w[114256]=0;b=V(1563,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break f}if((b|0)!=-1){break e}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,1);b=w[114256];w[114256]=0;if((b|0)!=1){break e}}b=W(0)|0;id(c+8|0);break c}b=W(0)|0;break c}id(c+8|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+16|0;return a|0}a=P()|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Sv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=jb+-64|0;jb=c;d=w[b+4>>2];e=w[b>>2];b=Kb(24);w[b+12>>2]=75592;w[b>>2]=75552;w[b+4>>2]=0;w[b+8>>2]=0;d=d-e|0;w[b+20>>2]=d;w[b+16>>2]=e;w[114256]=0;w[c+56>>2]=0;w[c+60>>2]=0;w[c+52>>2]=b;w[c+48>>2]=b+12;b=S(1040,c+48|0,c+8|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(!(!b|(w[c+12>>2]|w[c+8>>2]!=542066252))){A[a+4220>>2]=H(D(G(A[c+16>>2],D(1))),D(0));A[a+4224>>2]=H(D(G(A[c+20>>2],D(1))),D(0));A[a+4228>>2]=H(D(G(A[c+24>>2],D(1))),D(0));b=w[c+28>>2];if(b>>>0<=5){w[a+4232>>2]=b}w[a+4236>>2]=w[c+32>>2];u[a+4240|0]=x[c+36|0]!=0;u[a+4241|0]=x[c+37|0]!=0;u[a+4242|0]=x[c+38|0]!=0;u[a+4243|0]=x[c+39|0]!=0;u[a+4244|0]=x[c+40|0]!=0;Xj(a)}a=w[c+52>>2];a:{if(!a){break a}b=w[a+4>>2];w[a+4>>2]=b-1;if(b){break a}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=c- -64|0;return}a=P()|0;Bb(c+48|0);R(a|0);M()}function Ku(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((b|0)>=0){if((fi(a+8|0)|0)>(b|0)){break d}}d=ba(8)|0;w[114256]=0;a=Q(5,e|0,6646)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}if(!(!(c<0)&c<=1)){d=ba(8)|0;w[114256]=0;a=Q(5,e|0,7555)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}b=P()|0;ca(d|0);break b}c=Tb(c*64);d=2147483647;e:{if(c>=2147483647){break e}d=-2147483648;if(c<=-2147483648){break e}d=~~c;if(E(c)<2147483648){break e}d=-2147483648}w[(w[a+32>>2]+C(b,896)|0)+1075744>>2]=d;jb=e+16|0;return}b=P()|0;ca(d|0)}R(b|0)}M()}function jw(a){var b=0,c=0,d=0,e=0;e=jb-176|0;jb=e;a=Zg(e+16|0,a,8);b=w[w[a>>2]-12>>2];w[114256]=0;d=ea(79)|0;c=w[114256];w[114256]=0;a:{b:{c:{d:{if((c|0)==1){break d}w[114256]=0;b=a+b|0;T(10,e+8|0,b|0);c=w[114256];w[114256]=0;if((c|0)==1){break d}w[114256]=0;U(80,e+168|0,b|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}Ab(e+168|0);b=w[b+24>>2];if(b){c=w[w[b>>2]+8>>2];w[114256]=0;T(c|0,b|0,d|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}b=b+4|0;c=Ic(e+160|0,b);Wc(b,d);Ab(c)}Ab(e+8|0);w[114256]=0;d=Q(94,a|0,e+168|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}d=w[(d+w[w[d>>2]-12>>2]|0)+16>>2];b=w[e+168>>2];c=w[15045];w[a>>2]=c;w[a+w[c-12>>2]>>2]=w[15048];w[a+8>>2]=59272;if(u[a+51|0]<0){zb(w[a+40>>2])}wc(a+8|0);pc(a+60|0);jb=e+176|0;return d&5?0:b}d=P()|0;break a}d=P()|0;break a}d=P()|0;Ab(e+8|0)}Se(a);R(d|0);M()}function hn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=x[a+2|0];if(!(!d|(d|0)==255)){Hd(b,(d>>>0>=9?9:d)+1|0);j=x[a+3|0];u[b+15|0]=j;u[b+16|0]=j;k=x[a+4|0];u[b+13|0]=k;l=x[a+5|0];u[b+14|0]=l;d=0;h=511;a:{b:{switch(c-1|0){case 1:d=4096;h=128;break a;case 0:break b;default:break a}}d=32768;h=1024}e=w[b+4>>2];c=w[b>>2];i=e-c>>2;if((c|0)!=(e|0)){m=i>>>0<=1?1:i;n=h>>>1|d;d=0;while(1){f=d<<2;e=f+c|0;f=a+f|0;g=(x[f+6|0]|x[f+7|0]<<8)>>>4|0;v[e>>1]=g;c:{if(!d){v[c>>1]=0;break c}o=g;g=y[e-4>>1];if(o>>>0>=g>>>0){break c}v[e>>1]=g+1}g=e;e=(((x[f+8|0]|x[f+9|0]<<8)<<16>>16)+n|0)/(h|0)|0;e=(e|0)>=64?64:e;u[g+2|0]=(e|0)>0?e:0;d=d+1|0;if((m|0)!=(d|0)){continue}break}}c=x[b+12|0]&-2|u[a|0]&1;u[b+12|0]=c;c=x[a|0]&2?c&-5|(i>>>0>=j>>>0?4:0):c&251;u[b+12|0]=c;u[b+12|0]=(k>>>0<=l>>>0?x[a|0]&4:0)?c&-3|(i>>>0>=k>>>0?2:0):c&253}}function _E(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+8|0]){c=w[a+12>>2]+c|0;a=w[a+16>>2]-c|0;a=a>>>0<d>>>0?a:d;if(!a){return 0}hc(b,c,a);return a|0}a:{if(x[a+24|0]){l=a+40|0;while(1){if(d){i=a+40|0;f=a+232|0;g=c&-4096;e=0;b:{while(1){h=w[f+(e<<2)>>2];k=i+C(h,12)|0;if(!(!x[k+8|0]|(g|0)!=w[k>>2])){if(e){hc(a+236|0,f,e<<2)}w[f>>2]=h;break b}e=e+1|0;if((e|0)!=16){continue}break}h=w[a+292>>2];hc(a+236|0,f,60);w[a+232>>2]=h;e=i+C(h,12)|0;w[e>>2]=g;f=ob[w[w[a>>2]+44>>2]](a,w[a+28>>2]+(h<<12)|0,g,4096)|0;u[e+8|0]=1;w[e+4>>2]=f}e=C(h,12)+l|0;g=w[e+4>>2];f=c-w[e>>2]|0;e=g-f|0;g=e>>>0<=g>>>0?e:0;e=4096-f|0;i=d>>>0<e>>>0?d:e;e=g>>>0<i>>>0?g:i;if(e){hc(b,f+(w[a+28>>2]+(h<<12)|0)|0,e)}d=d-e|0;j=e+j|0;b=b+e|0;c=c+e|0;if(g>>>0>=i>>>0){continue}}break}break a}j=ob[w[w[a>>2]+44>>2]](a,b,c,d)|0}return j|0}function tk(a,b){var c=0,d=0,e=0,f=0,g=0;f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;g=ea(79)|0;e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)==1){break c}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;U(80,f+152|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}c=c+4|0;e=Ic(f+144|0,c);Wc(c,g);Ab(e)}Ab(f);b=w[b>>2];w[114256]=0;Q(81,d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;b=a;a=d+4|0;T(82,b|0,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[15e3];w[d>>2]=b;w[w[b-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(a);pc(d+56|0);jb=f+160|0;return}a=P()|0;break a}a=P()|0;Ab(f)}nd(d);R(a|0);M()}function bo(a,b){var c=0,d=0,e=0,f=0,g=0;f=jb-160|0;jb=f;d=Od(f+8|0);c=w[w[d>>2]-12>>2];w[114256]=0;g=ea(79)|0;e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)==1){break c}w[114256]=0;c=d+c|0;T(10,f|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;U(80,f+152|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}Ab(f+152|0);c=w[c+24>>2];if(c){e=w[w[c>>2]+8>>2];w[114256]=0;T(e|0,c|0,g|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}c=c+4|0;e=Ic(f+144|0,c);Wc(c,g);Ab(e)}Ab(f);b=y[b>>1];w[114256]=0;Q(87,d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}w[114256]=0;b=a;a=d+4|0;T(82,b|0,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=w[15e3];w[d>>2]=b;w[w[b-12>>2]+d>>2]=w[15003];w[d+4>>2]=59272;if(u[d+47|0]<0){zb(w[d+36>>2])}wc(a);pc(d+56|0);jb=f+160|0;return}a=P()|0;break a}a=P()|0;Ab(f)}nd(d);R(a|0);M()}function rh(a,b,c){var d=0,e=0,f=0,g=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;e=x[b+11|0];d=w[b+4>>2];w[114256]=0;T(72,a|0,(e<<24>>24<0?d:e)|0);d=w[114256];w[114256]=0;if((d|0)!=1){a:{d=x[b+11|0];e=d<<24>>24<0;if(e?w[b+4>>2]:d){while(1){g=w[(f<<2)+(e&1?w[b>>2]:b)>>2];e=32;b:{while(1){d=e;if(w[(d<<2)+c>>2]==(g|0)){w[114256]=0;T(71,a|0,d<<24>>24);d=w[114256];w[114256]=0;if((d|0)!=1){break b}break a}e=d+1|0;if((e|0)!=256){continue}break}e=0;while(1){if(w[(e<<2)+c>>2]==(g|0)){w[114256]=0;T(71,a|0,e<<24>>24);d=w[114256];w[114256]=0;if((d|0)!=1){break b}break a}e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0<255){break b}w[114256]=0;T(71,a|0,63);d=w[114256];w[114256]=0;if((d|0)!=1){break b}break a}d=x[b+11|0];e=d<<24>>24<0;f=f+1|0;if(f>>>0<(e?w[b+4>>2]:d)>>>0){continue}break}}return}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function eK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;a:{b:{c:{if((b|0)!=(c|0)){j=w[114084];w[114084]=0;g=jb-16|0;jb=g;Cc();e=jb-16|0;jb=e;f=jb-16|0;jb=f;Xl(f,b,h+28|0,2);k=w[f>>2];i=w[f+4>>2];b=w[f+12>>2];w[e+8>>2]=w[f+8>>2];w[e+12>>2]=b;w[e>>2]=k;w[e+4>>2]=i;jb=f+16|0;i=w[e>>2];f=w[e+4>>2];b=w[e+12>>2];w[g+8>>2]=w[e+8>>2];w[g+12>>2]=b;w[g>>2]=i;w[g+4>>2]=f;jb=e+16|0;f=w[g>>2];e=w[g+4>>2];b=w[g+12>>2];w[h+16>>2]=w[g+8>>2];w[h+20>>2]=b;w[h+8>>2]=f;w[h+12>>2]=e;jb=g+16|0;i=w[h+16>>2];f=w[h+20>>2];g=w[h+8>>2];e=w[h+12>>2];b=w[114084];if(!b){break c}if(w[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}w[d>>2]=4;break a}w[114084]=j;if(w[h+28>>2]==(c|0)){break a}}w[d>>2]=4;g=l;e=m;i=n;f=o}w[a>>2]=g;w[a+4>>2]=e;w[a+8>>2]=i;w[a+12>>2]=f;jb=h+32|0}function Ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=jb-16|0;h=w[a>>2];f=w[a+4>>2];i=w[a+40>>2];j=w[a+36>>2];a:{if(!d){b=i>>12;g=j>>12;break a}m=w[a+8>>2];n=w[a+12>>2];o=w[a+16>>2];p=w[a+32>>2];q=w[a+28>>2];while(1){k=((((f&2147483647)<<1|h>>>31)&2147483646)<<1)+o|0;b=(h>>>21&2040)+32832|0;r=v[b+6>>1];s=v[b+4>>1];t=v[b+2>>1];u=v[b>>1];g=0;b=1;while(1){e=g<<1;w[(l+8|0)+(g<<2)>>2]=(((C(v[e+k>>1],t)+C(v[(e|-4)+k>>1],u)|0)+C(v[(e|4)+k>>1],s)|0)+C(v[(e|8)+k>>1],r)|0)/16384;e=b;b=0;g=1;if(e){continue}break}j=j+q|0;g=j>>12;w[c>>2]=w[c>>2]+C(g,w[l+8>>2]);i=i+p|0;b=i>>12;w[c+4>>2]=w[c+4>>2]+C(b,w[l+12>>2]);f=f+n|0;e=h+m|0;f=e>>>0<m>>>0?f+1|0:f;h=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=j;w[a>>2]=h;w[a+4>>2]=f;w[a+40>>2]=i;w[a+20>>2]=g;w[a+24>>2]=b}function eS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=ze(a,b,c,d);w[b+4260>>2]=0;w[b>>2]=80064;c=b+4960|0;e=b+4504|0;d=e;while(1){w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;d=d+24|0;if((d|0)!=(c|0)){continue}break}u[b+5046|0]=1;v[b+5044>>1]=0;w[b+4208>>2]=1063675494;w[b+4212>>2]=1065185444;w[b+4256>>2]=1059760811;a=b+4248|0;w[a>>2]=1065353216;w[a+4>>2]=1048525618;a=b+4240|0;w[a>>2]=1038174126;w[a+4>>2]=1065353216;a=b+4232|0;w[a>>2]=1047457519;w[a+4>>2]=1062836634;a=b+4224|0;w[a>>2]=1053079357;w[a+4>>2]=1059859440;a=b+4216|0;w[a>>2]=0;w[a+4>>2]=1032805417;w[114256]=0;S(985,b+44|0,2,2)|0;a=w[114256];w[114256]=0;a:{if((a|0)!=1){w[114256]=0;X(986,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}f=P()|0;while(1){a=c-24|0;d=w[a>>2];if(d){w[c-20>>2]=d;zb(d)}c=a;if((a|0)!=(e|0)){continue}break}Oc(b);R(f|0);M()}return b|0}function xD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];d=(w[a+4>>2]-c|0)/48|0;if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{d=b-d|0;e=w[a+8>>2];c=w[a+4>>2];c:{if(d>>>0<=(e-c|0)/48>>>0){if(d){b=C(d,48)-48|0;b=(b-((b>>>0)%48|0)|0)+48|0;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break c}b=c;c=w[a>>2];f=(b-c|0)/48|0;b=f+d|0;if(b>>>0>=89478486){break b}c=(e-c|0)/48|0;e=c<<1;b=bl(g+8|0,c>>>0>=44739242?89478485:b>>>0<e>>>0?e:b,f,a+8|0);c=C(d,48)-48|0;c=(c-((c>>>0)%48|0)|0)+48|0;d=Cb(w[b+8>>2],0,c)+c|0;w[b+8>>2]=d;f=w[a+4>>2];c=w[a>>2];h=f-c|0;e=w[b+4>>2]+C((h|0)/-48|0,48)|0;w[b+4>>2]=e;if((h|0)>0){Fb(e,c,h);d=w[b+8>>2];f=w[a+4>>2];e=w[b+4>>2];c=w[a>>2]}w[a>>2]=e;w[b+4>>2]=c;w[a+4>>2]=d;w[b+8>>2]=f;d=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=d;al(b)}jb=g+32|0;break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=c+C(b,48)}}function kB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-56|0;w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;c=c-56|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[d+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[d+20>>2]=0;w[d+12>>2]=0;w[d+16>>2]=0;w[d+12>>2]=w[c+12>>2];w[d+16>>2]=w[c+16>>2];w[d+20>>2]=w[c+20>>2];w[c+20>>2]=0;w[c+12>>2]=0;w[c+16>>2]=0;w[d+24>>2]=w[c+24>>2];w[d+28>>2]=w[c+28>>2];w[d+32>>2]=w[c+32>>2];w[c+32>>2]=0;w[c+24>>2]=0;w[c+28>>2]=0;v[d+52>>1]=y[c+52>>1];f=w[c+48>>2];w[d+44>>2]=w[c+44>>2];w[d+48>>2]=f;f=w[c+40>>2];w[d+36>>2]=w[c+36>>2];w[d+40>>2]=f;d=w[b+4>>2]-56|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function _U(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;lc(c,0);v[c+28>>1]=x[a+36|0]<<2;d=x[a+37|0];v[c+32>>1]=64;v[c+30>>1]=d<<2;w[c>>2]=x[a+40|0]|x[a+41|0]<<8|(x[a+42|0]<<16|x[a+43|0]<<24);w[c+4>>2]=x[a+44|0]|x[a+45|0]<<8|(x[a+46|0]<<16|x[a+47|0]<<24);w[c+8>>2]=x[a+48|0]|x[a+49|0]<<8|(x[a+50|0]<<16|x[a+51|0]<<24);w[c+24>>2]=x[a+52|0]|x[a+53|0]<<8|(x[a+54|0]<<16|x[a+55|0]<<24);d=x[b+151|0];if(d>>>0<=4){u[c+38|0]=x[d+35690|0]}d=x[b+152|0]|x[b+153|0]<<8;u[c+39|0]=d;e=(x[b+156|0]|x[b+157|0]<<8)>>>4|0;u[c+41|0]=e;b=(x[b+154|0]|x[b+155|0]<<8)>>>2|0;u[c+40|0]=b;if((b|e)&255){u[c+39|0]=d^-1}b=x[a+38|0]|x[a+39|0]<<8;if(b&4){v[c+34>>1]=y[c+34>>1]|1;b=x[a+38|0]|x[a+39|0]<<8}if(b&8){v[c+34>>1]=y[c+34>>1]|2;b=x[a+38|0]|x[a+39|0]<<8}if(b&16){v[c+34>>1]=y[c+34>>1]|4;b=x[a+38|0]|x[a+39|0]<<8}if(b&32){v[c+34>>1]=y[c+34>>1]|32}}function Jn(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=w[b+700>>2];if(!e){break a}d=C(c,-20);f=c;c=w[a+480180>>2];g=(c|0)==64?d:f;b:{c:{d:{if(!(!(x[a+480208|0]&16)|(c|0)==4)){d=g>>31;d=(d^g)-d|0;if(d>>>0<=1023){if(d>>>0<4){break c}f=d>>>2|0}else{f=255}h=w[a+1074312>>2];c=h&128;c=w[(f<<2)+((g|0)<0?c?30256:31280:c?31280:30256)>>2];d=BV(c,c>>31,e,e>>31)+32768|0;c=nb;d=CV(d,d>>>0<32768?c+1|0:c,65536,0);f=d;c=nb;d=(c|0)>=0&d>>>0>=2147483647|(c|0)>0;f=d?2147483647:f;c=d?0:c;c=(c|0)<0&f>>>0<=2147483648|(c|0)<-1?-2147483648:f;w[b+700>>2]=c;if((c|0)!=(e|0)){break b}if((h>>>7&1)==(g>>>31|0)){if((e|0)==2147483647){break a}c=e+1|0;break d}if((e|0)<2){break c}w[b+700>>2]=e-1;return}c=e+g|0}w[b+700>>2]=c;break b}c=e}if((c|0)>0){break a}w[b+700>>2]=1;if(w[a+480180>>2]!=2){break a}w[b+696>>2]=0;w[b+88>>2]=w[b+88>>2]|2101248}}function mw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if((a|0)==(b|0)){w[a+12>>2]=w[b+12>>2];w[a+16>>2]=w[b+16>>2];w[a+20>>2]=w[b+20>>2];break a}b:{g=w[b+4>>2];d=w[b>>2];e=g-d|0;h=(e|0)/6|0;f=w[a+8>>2];c=w[a>>2];if(h>>>0<=(f-c|0)/6>>>0){f=(w[a+4>>2]-c|0)/6|0;e=f>>>0<h>>>0?d+C(f,6)|0:g;i=e-d|0;if((d|0)!=(e|0)){hc(c,d,i)}if(f>>>0<h>>>0){c=w[a+4>>2];d=g-e|0;if((d|0)>0){c=Fb(c,e,d)+C((d>>>0)/6|0,6)|0}w[a+4>>2]=c;break b}w[a+4>>2]=c+C((i|0)/6|0,6);break b}if(c){w[a+4>>2]=c;zb(c);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;f=0}if(h>>>0<715827883){c=(f|0)/6|0;g=c<<1;yh(a,c>>>0>=357913941?715827882:h>>>0<g>>>0?g:h);c=w[a+4>>2];if((e|0)>0){c=Fb(c,d,e)+C((e>>>0)/6|0,6)|0}w[a+4>>2]=c;break b}Mb(a);M()}w[a+12>>2]=w[b+12>>2];w[a+16>>2]=w[b+16>>2];w[a+20>>2]=w[b+20>>2];Uk(a+24|0,w[b+24>>2],w[b+28>>2])}Ni(a+36|0,b+36|0)}function Fz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;l=jb-16|0;g=w[a>>2];f=w[a+4>>2];h=w[a+40>>2];i=w[a+36>>2];a:{if(!d){e=h>>12;b=i>>12;break a}m=w[a+8>>2];n=w[a+12>>2];o=w[a+16>>2];p=w[a+32>>2];q=w[a+28>>2];while(1){j=(((f&2147483647)<<1|g>>>31)&-2)+o|0;b=(g>>>21&2040)+32832|0;r=v[b+6>>1];s=v[b+4>>1];t=v[b+2>>1];x=v[b>>1];e=0;b=1;while(1){w[(l+8|0)+(e<<2)>>2]=(((C(u[e+j|0],t)+C(u[(e|-2)+j|0],x)|0)+C(u[(e|2)+j|0],s)|0)+C(u[(e|4)+j|0],r)<<8)/16384;k=b;b=0;e=1;if(k){continue}break}i=i+q|0;b=i>>12;w[c>>2]=w[c>>2]+C(b,w[l+8>>2]);h=h+p|0;e=h>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[l+12>>2]);f=f+n|0;k=g+m|0;f=k>>>0<m>>>0?f+1|0:f;g=k;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=i;w[a>>2]=g;w[a+4>>2]=f;w[a+40>>2]=h;w[a+20>>2]=b;w[a+24>>2]=e}function PA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=w[a+4>>2];e=w[a>>2];d=(c-e|0)/12|0;if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{c:{b=b-d|0;f=w[a+8>>2];c=w[a+4>>2];d:{if(b>>>0<=(f-c|0)/12>>>0){if(b){b=C(b,12)-12|0;b=(b-((b>>>0)%12|0)|0)+12|0;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break d}d=w[a>>2];g=(c-d|0)/12|0;c=b+g|0;if(c>>>0>=357913942){break c}d=(f-d|0)/12|0;f=d<<1;c=Re(e+8|0,d>>>0>=178956970?357913941:c>>>0<f>>>0?f:c,g,a+8|0);b=C(b,12)-12|0;b=(b-((b>>>0)%12|0)|0)+12|0;h=c,i=Cb(w[c+8>>2],0,b)+b|0,w[h+8>>2]=i;w[114256]=0;T(581,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}Uo(c)}jb=e+32|0;break a}Mb(a);M()}a=P()|0;Uo(c);R(a|0);M()}return}if(b>>>0<d>>>0){d=e+C(b,12)|0;if((d|0)!=(c|0)){while(1){b=c-12|0;e=w[b>>2];if(e){w[c-8>>2]=e;zb(e)}c=b;if((d|0)!=(b|0)){continue}break}}w[a+4>>2]=d}}function Hp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;h=jb-32|0;c=h;d=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);d=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))+788|0;w[c>>2]=d;w[c+4>>2]=0;b=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);w[c+8>>2]=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);w[c+12>>2]=0;b=x[a+24|0]|x[a+25|0]<<8|(x[a+26|0]<<16|x[a+27|0]<<24);w[c+16>>2]=b?b<<24|b<<8&16711680|(b>>>8&65280|b>>>24):52;w[c+20>>2]=0;a=x[a+32|0]|x[a+33|0]<<8|(x[a+34|0]<<16|x[a+35|0]<<24);w[c+24>>2]=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))+80;w[c+28>>2]=0;a=1;while(1){b=(a<<3)+h|0;f=w[b>>2];g=b;b=w[b+4>>2];c=(b|0)==(e|0)&d>>>0<f>>>0|b>>>0>e>>>0?g:c;g=f;f=(b|0)==(e|0)&d>>>0>f>>>0|b>>>0<e>>>0;d=f?d:g;e=f?e:b;a=a+1|0;if((a|0)!=4){continue}break}a=w[c>>2];e=a-52|0;nb=w[c+4>>2]-(a>>>0<52)|0;return e}function AU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-52|0;w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;c=c-52|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[d+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;f=w[c+16>>2];w[d+12>>2]=w[c+12>>2];w[d+16>>2]=f;w[d+20>>2]=w[c+20>>2];w[d+32>>2]=0;w[d+24>>2]=0;w[d+28>>2]=0;w[d+24>>2]=w[c+24>>2];w[d+28>>2]=w[c+28>>2];w[d+32>>2]=w[c+32>>2];w[c+32>>2]=0;w[c+24>>2]=0;w[c+28>>2]=0;w[d+44>>2]=w[c+44>>2];f=w[c+40>>2];w[d+36>>2]=w[c+36>>2];w[d+40>>2]=f;w[c+36>>2]=0;w[c+40>>2]=0;w[c+44>>2]=0;w[d+48>>2]=w[c+48>>2];d=w[b+4>>2]-52|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function up(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){e=d;d=u[a+b|0];d=e+((d&255)!=0&(d|0)<32)|0;b=b+1|0;if((b|0)!=20){continue}break}a:{if(d>>>0>5){break a}while(1){j=f&65535;c=C(j,30)+a|0;h=c+20|0;e=0;b=0;while(1){k=e;e=u[b+h|0];e=k+((e&255)!=0&(e|0)<32)|0;b=b+1|0;if((b|0)!=22){continue}break}h=0;d=d+e|0;if(d>>>0>48){break a}b=x[c+45|0];if(x[c+44|0]|b>>>0>64){break a}c=x[c+42|0]|x[c+43|0]<<8;c=(c<<8|c>>>8)&65535;if(c>>>0>32768){break a}f=f+1|0;g=b|g;i=c+i|0;if(j>>>0<14){continue}break}if(!i|!(g&255)){break a}f=x[a+470|0];if(f>>>0>128){break a}g=x[a+471|0];if(g>>>0>220){break a}b=a+473|0;i=a+600|0;d=a+472|0;a=x[d|0];while(1){c=a&255;e=x[b|0];a=c>>>0>e>>>0?c:e;d=c>>>0<e>>>0?b:d;b=b+1|0;if((i|0)!=(b|0)){continue}break}a=x[d|0];if(a>>>0>63){break a}h=(g|(a|f))!=0}return h}function qn(a,b,c){var d=0,e=0,f=0,g=0;a:{if(!nn(a,b,2)){break a}e=w[b+752>>2];f=w[a+1074312>>2];if(!e&(f|0)<0){break a}g=w[a+480180>>2];d=(g|0)==4096;f=e+(f>>31)|0;e=d?64:(g|0)==16384?192:512;d=oh(w[b+656>>2]+88|0,f,e,d?255:64)-(e>>>1|0)|0;if(x[b+748|0]&16){return hh(a,b,!(w[b+88>>2]&32768),d)}e=w[b+656>>2];if(!(!e|!w[e+44>>2])){if((d|0)==w[b+768>>2]){break a}w[b+768>>2]=d;u[b+872|0]=x[b+872|0]|16;return-1}b=0;b:{if(!(x[a+480208|0]&16)){break b}b=0;if(!(x[a+1074312|0]&128)){break b}b=w[a+480180>>2]!=4}e=c;a=d>>31;a=(a^d)-a|0;a=w[((a>>>0>=255?255:a)<<2)+((d|0)<0?b?31280:30256:b?30256:31280)>>2];b=a;d=a>>31;a=w[c>>2];b=CV(BV(b,d,a,a>>31),nb,65536,0);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;a=b?0:a;w[e>>2]=(a|0)<0&c>>>0<=2147483648|(a|0)<-1?-2147483648:c}return-1}function QH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=ae(a);if(c>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=w[Xi(a)>>2]-w[a+4>>2]>>2>>>0){Jr(a,f);break c}g=Uf(a);c=h+8|0;e=ae(a)+f|0;d=jb-16|0;jb=d;w[d+12>>2]=e;d:{b=gr(a);if(e>>>0<=b>>>0){e=Tf(a);if(e>>>0<b>>>1>>>0){w[d+8>>2]=e<<1;b=w[of(d+8|0,d+12|0)>>2]}jb=d+16|0;break d}fr();M()}i=ae(a);d=0;e=jb-16|0;jb=e;w[e+12>>2]=0;Eg(Ne(c+12|0)+4|0,g);if(b){d=er(w[c+16>>2],b)}w[c>>2]=d;g=(i<<2)+d|0;w[c+8>>2]=g;w[c+4>>2]=g;j=El(c),k=(b<<2)+d|0,w[j>>2]=k;jb=e+16|0;w[114256]=0;T(1839,c|0,f|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}w[114256]=0;T(1840,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}$q(c)}jb=h+32|0;break a}a=P()|0;$q(c);R(a|0);M()}return}if(b>>>0<c>>>0){b=w[a>>2]+(b<<2)|0;ae(a);ar(a,b);Hr(a)}}function Cc(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(x[460388]){return w[115096]}c=jb-32|0;jb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=Ds(a,d?9910:17256)}else{d=w[a<<2>>2]}w[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!Cs(0)){b=61544;if(!Jb(c+8|0,61544,24)){break a}b=61568;if(!Jb(c+8|0,61568,24)){break a}a=0;if(!x[460216]){while(1){f=(a<<2)+460168|0,g=Ds(a,17256),w[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}u[460216]=1;w[115048]=w[115042]}b=460168;if(!Jb(c+8|0,460168,24)){break a}b=460192;if(!Jb(c+8|0,460192,24)){break a}b=fc(24);if(!b){break b}}a=w[c+12>>2];w[b>>2]=w[c+8>>2];w[b+4>>2]=a;a=w[c+28>>2];w[b+16>>2]=w[c+24>>2];w[b+20>>2]=a;a=w[c+20>>2];w[b+8>>2]=w[c+16>>2];w[b+12>>2]=a;break a}b=0}jb=c+32|0;u[460388]=1;w[115096]=b;return b|0}function $P(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((d|0)==1){break f}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break f}e=w[a+24>>2];w[114256]=0;d=Q(5,c|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}w[114256]=0;Y(1395,c+16|0,e|0,d|0,1);b=w[114256];w[114256]=0;if((b|0)==1){break d}b=rc(u[c+27|0]<0?w[c+16>>2]:c+16|0);if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}b=W(0)|0;break c}b=W(0)|0;break c}b=W(0)|0;if(u[d+11|0]>=0){break c}zb(w[d>>2])}$(b|0)|0;b=0;w[114256]=0;Y(1333,2786,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=c+32|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function bU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];d=w[a+4>>2]-c>>11;if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{d=b-d|0;e=w[a+8>>2];c=w[a+4>>2];c:{if(d>>>0<=e-c>>11>>>0){if(d){b=d<<11;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break c}b=c;c=w[a>>2];f=b-c>>11;b=f+d|0;if(b>>>0>=2097152){break b}c=e-c|0;e=c>>10;b=Uv(g+8|0,c>>>0>=2147481600?2097151:b>>>0<e>>>0?e:b,f,a+8|0);c=d<<11;e=Cb(w[b+8>>2],0,c)+c|0;w[b+8>>2]=e;d=w[a+4>>2];c=w[a>>2];h=d-c|0;f=w[b+4>>2]-h|0;w[b+4>>2]=f;if((h|0)>0){Fb(f,c,h);e=w[b+8>>2];d=w[a+4>>2];f=w[b+4>>2];c=w[a>>2]}w[a>>2]=f;w[b+4>>2]=c;w[a+4>>2]=e;w[b+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=e;if((c|0)!=(d|0)){w[b+8>>2]=((c-d|0)+2047&-2048)+d}if(!c){break c}zb(c)}jb=g+32|0;break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=c+(b<<11)}}function JQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{d:{e:{f:{if((d|0)==1){break f}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break f}e=w[a+24>>2];w[114256]=0;d=Q(5,c|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break e}w[114256]=0;U(1362,c+16|0,e|0,d|0);b=w[114256];w[114256]=0;if((b|0)==1){break d}b=rc(u[c+27|0]<0?w[c+16>>2]:c+16|0);if(u[c+27|0]<0){zb(w[c+16>>2])}if(u[d+11|0]>=0){break b}zb(w[d>>2]);break b}b=W(0)|0;break c}b=W(0)|0;break c}b=W(0)|0;if(u[d+11|0]>=0){break c}zb(w[d>>2])}$(b|0)|0;b=0;w[114256]=0;Y(1333,9117,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=c+32|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Ym(a){a=a|0;var b=0,c=0,d=0;d=jb-16|0;jb=d;b=Hb(d,10145);w[114256]=0;U(6,a|0,1,b|0);c=w[114256];w[114256]=0;a:{b:{c:{if((c|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}w[114256]=0;b=ea(111)|0;c=w[114256];w[114256]=0;d:{if((c|0)==1){break d}w[a+12>>2]=b;w[114256]=0;b=ea(112)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}u[a+16|0]=b;w[114256]=0;b=ea(113)|0;c=w[114256];w[114256]=0;if((c|0)==1){break d}u[a+18|0]=0;u[a+17|0]=b;w[114256]=0;b=Q(5,d|0,9258)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break c}}d=P()|0;break b}d=P()|0;if(u[b+11|0]>=0){break a}zb(w[b>>2]);break a}w[114256]=0;U(6,a+20|0,1,b|0);c=w[114256];w[114256]=0;if((c|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=d+16|0;return a|0}d=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2])}if(u[a+11|0]>=0){break a}zb(w[a>>2])}R(d|0);M()}function ac(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=w[a+112>>2];d=w[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=w[a+4>>2];e=w[a+44>>2];b=f-e|0;h=b;g=b+w[a+120>>2]|0;b=w[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=gm(a);if((h|0)>=0){break a}f=w[a+4>>2];e=w[a+44>>2]}w[a+112>>2]=-1;w[a+116>>2]=-1;w[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;w[a+120>>2]=d;w[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=w[a+4>>2];e=w[a+8>>2];c=w[a+112>>2];g=w[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}w[a+104>>2]=e;c=w[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;w[a+120>>2]=d;w[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){u[f-1|0]=h}return h}function uv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=D(0),m=0,n=D(0);c=-9965.784284662086/+D(D(D(A[a+4216>>2]*D(2999.9990234375))+D(.0010000000474974513))*D(z[w[a+16>>2]+24620>>2]));m=a,n=D(Ed(c*+z[a+4288>>2])),A[m+4232>>2]=n;m=a+4236|0,n=D(Ed(c*+z[a+4292>>2])),A[m>>2]=n;k=c*(1/+D(D(A[a+4220>>2]*D(.9980000257492065))+D(.0010000000474974513))+-1);g=a+4272|0;h=a+4232|0;while(1){i=w[(d<<2)+g>>2];e=d<<1&-4;f=Ed(k*+(i+w[(e+g|0)+16>>2]>>>0));b=Ed(c*+(i>>>0));l=A[e+h>>2];e=(d<<3)+h|0;f=f*.5;A[e+12>>2]=b*(.5-f);A[e+8>>2]=b*(f+.5);b=b*+l;b=(((b+1)*b+1)*b+1)*b+1;j=b*b+j;d=d+1|0;if((d|0)!=4){continue}break}c=Ed(+D(D(A[a+4208>>2]*D(96))+D(-96))*.16609640474436813);b=Ed(+D(D(A[a+4212>>2]*D(96))+D(-96))*.33219280948873625);A[a+4228>>2]=c*4*L(b)/L(j);A[a+4224>>2]=c*L(1-b)}function az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=w[a>>2];f=w[a+4>>2];g=w[a+40>>2];h=w[a+36>>2];a:{if(!d){b=g>>12;j=h>>12;break a}l=b+24|0;k=w[a+8>>2];m=w[a+12>>2];n=w[a+16>>2];o=w[a+32>>2];p=w[a+28>>2];while(1){h=h+p|0;j=h>>12;b=(f<<1)+n|0;e=(((i>>>16|0)+4&131064)<<1)+l|0;e=(((((C(v[b+4>>1],v[e+10>>1])+C(v[b+2>>1],v[e+8>>1])|0)+C(v[b+6>>1],v[e+12>>1])|0)+C(v[b+8>>1],v[e+14>>1])|0)/2|0)+((((C(v[b-4>>1],v[e+2>>1])+C(v[b-6>>1],v[e>>1])|0)+C(v[b-2>>1],v[e+4>>1])|0)+C(v[b>>1],v[e+6>>1])|0)/2|0)|0)/16384|0;w[c>>2]=w[c>>2]+C(j,e);g=g+o|0;b=g>>12;w[c+4>>2]=w[c+4>>2]+C(e,b);f=f+m|0;e=i+k|0;f=e>>>0<k>>>0?f+1|0:f;i=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=i;w[a+4>>2]=f;w[a+40>>2]=g;w[a+20>>2]=j;w[a+24>>2]=b}function kf(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;u[k+15|0]=a;a:{b:{c:{if(w[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=x[j+24|0]){l=45;if(x[j+25|0]!=(m|0)){break c}}w[d>>2]=c+1;u[c|0]=l;break b}if(!(!Db(g)|(a|0)!=(f|0))){a=0;b=w[i>>2];if((b-h|0)>159){break a}a=w[e>>2];w[i>>2]=b+4;w[b>>2]=a;break b}a=-1;f=Tl(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=w[d>>2];if((b|0)==(c|0)|(b-c|0)>2|x[b-1|0]!=48){break a}a=0;w[e>>2]=0;w[d>>2]=b+1;u[b|0]=x[f+64768|0];break a}a=w[d>>2];w[d>>2]=a+1;u[a|0]=x[f+64768|0];w[e>>2]=w[e>>2]+1;a=0;break a}a=0;w[e>>2]=0}jb=k+16|0;return a|0}function jf(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=jb-16|0;jb=k;w[k+12>>2]=a;a:{b:{c:{if(w[d>>2]!=(c|0)){break c}l=43;if(w[j+96>>2]!=(a|0)){l=45;if(w[j+100>>2]!=(a|0)){break c}}w[d>>2]=c+1;u[c|0]=l;break b}if(!(!Db(g)|(a|0)!=(f|0))){a=0;b=w[i>>2];if((b-h|0)>159){break a}a=w[e>>2];w[i>>2]=b+4;w[b>>2]=a;break b}a=-1;g=Pl(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=w[d>>2];if((b|0)==(c|0)|(b-c|0)>2|x[b-1|0]!=48){break a}a=0;w[e>>2]=0;w[d>>2]=b+1;u[b|0]=x[f+64768|0];break a}a=w[d>>2];w[d>>2]=a+1;u[a|0]=x[f+64768|0];w[e>>2]=w[e>>2]+1;a=0;break a}a=0;w[e>>2]=0}jb=k+16|0;return a|0}function Fe(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];d=w[a+4>>2]-c>>2;if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{d=b-d|0;e=w[a+8>>2];c=w[a+4>>2];c:{if(d>>>0<=e-c>>2>>>0){if(d){b=d<<2;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break c}b=c;c=w[a>>2];f=b-c>>2;b=f+d|0;if(b>>>0>=1073741824){break b}c=e-c|0;e=c>>1;b=ud(g+8|0,c>>>0>=2147483644?1073741823:b>>>0<e>>>0?e:b,f,a+8|0);c=d<<2;e=Cb(w[b+8>>2],0,c)+c|0;w[b+8>>2]=e;d=w[a+4>>2];c=w[a>>2];h=d-c|0;f=w[b+4>>2]-h|0;w[b+4>>2]=f;if((h|0)>0){Fb(f,c,h);e=w[b+8>>2];d=w[a+4>>2];f=w[b+4>>2];c=w[a>>2]}w[a>>2]=f;w[b+4>>2]=c;w[a+4>>2]=e;w[b+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=e;if((c|0)!=(d|0)){w[b+8>>2]=((c-d|0)+3&-4)+d}if(!c){break c}zb(c)}jb=g+32|0;break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=c+(b<<2)}}function Eo(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+15|0]=0;u[a+16|0]=0;u[a+17|0]=0;u[a+18|0]=0;u[a+19|0]=0;u[a+20|0]=0;u[a+21|0]=0;u[a+22|0]=0;u[a+14|0]=5;v[a+12>>1]=0;d=128;w[a+8>>2]=128;w[a>>2]=256;w[a+4>>2]=64;w[a+28>>2]=0;u[a+27|0]=60;w[a+48>>2]=0;w[a+52>>2]=0;u[a+33|0]=2;u[a+34|0]=0;u[a+35|0]=0;u[a+36|0]=2;w[a+68>>2]=0;w[a+72>>2]=0;w[a+88>>2]=0;w[a+92>>2]=0;u[a+23|0]=0;u[a+24|0]=0;u[a+25|0]=255;u[a+26|0]=0;u[a+32|0]=0;w[a+56>>2]=0;w[a+60>>2]=0;v[a- -64>>1]=65280;w[a+76>>2]=0;w[a+80>>2]=0;v[a+84>>1]=65280;u[a+104|0]=0;w[a+96>>2]=0;w[a+100>>2]=0;w[a+40>>2]=0;w[a+44>>2]=0;u[a+105|0]=255;u[a+22|0]=0;Cb(a+492|0,0,64);c=a+236|0;while(1){v[c>>1]=b;c=c+2|0;d=d-1|0;if(d){continue}break}b=a+108|0;c=0;while(1){d=b+c|0;c=c+1|0;u[d|0]=c;if((c|0)!=128){continue}break}return a|0}function ai(a){var b=D(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=D(1);if(d>>>0<964689920){break a}b=ge(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=D(-ge(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=fe(f+1.5707963267948966);break a}b=fe(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ge(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=fe(-4.71238898038469-+a);break a}b=fe(+a+-4.71238898038469);break a}b=D(a-a);if(d>>>0>=2139095040){break a}b:{switch(Fm(a,c+8|0)&3){case 0:b=ge(B[c+8>>3]);break a;case 1:b=fe(-B[c+8>>3]);break a;case 2:b=D(-ge(B[c+8>>3]));break a;default:break b}}b=fe(B[c+8>>3])}a=b;jb=c+16|0;return a}function oB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;g=a+8|0;a:{b:{c=w[a+4>>2];c:{if((c|0)!=w[a+8>>2]){w[114256]=0;U(554,g|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){b=P()|0;w[a+4>>2]=c;break a}w[a+4>>2]=c+56;break c}d=(c-w[a>>2]|0)/56|0;e=d+1|0;if(e>>>0>=76695845){break b}c=f+8|0;w[c+12>>2]=0;w[c+16>>2]=g;d:{e:{i=d<<1;e=d>>>0>=38347922?76695844:e>>>0<i>>>0?i:e;if(e){if(e>>>0>=76695845){break e}h=Kb(C(e,56))}w[c>>2]=h;d=C(d,56)+h|0;w[c+8>>2]=d;w[c+12>>2]=C(e,56)+h;w[c+4>>2]=d;break d}vd();M()}d=w[c+8>>2];w[114256]=0;U(554,g|0,d|0,b|0);b=w[114256];w[114256]=0;f:{if((b|0)!=1){w[c+8>>2]=w[c+8>>2]+56;w[114256]=0;T(555,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){break f}}b=P()|0;ep(c);break a}ep(c)}jb=f+32|0;return}Mb(a);M()}R(b|0);M()}function Hn(a,b,c,d){var e=0;if(!b){return 0}e=w[a+480180>>2];if(e&20){a:{b:{c:{if(x[a+1074321|0]&2){b=b&65535;if(!(x[a+480208|0]&16)){break b}a=14-((9983-b>>>0)/768|0)&31;break c}if(!(x[a+480208|0]&16)){break a}a=((b>>>0)/768|0)+2|0}return w[((b>>>0)%768<<2)+27056>>2]<<6>>>a|0}b=b?b:1}return 229079296/(b>>>0)|0}if(e&740327453){return 227001280/(b>>>0)|0}if((e|0)==64){return(b+c<<4)-133808|0}b=b>>>0>=16777215?16777215:b;if(e&17408){a=EV(BV(c?c:8363,0,3506176,0),nb,(b<<8)+d|0,0);b=nb;return!b&(a|0)==-1|b?-1:a}if(x[a+480208|0]&16){if(x[a+1074312|0]&128){c=b<<8;b=c+d|0;a=d>>31;a=b>>>0<c>>>0?a+1|0:a;return(a&15)<<28|b>>>4}a=EV(BV(c?c:8363,0,7012352,0),nb,(b<<8)+d|0,0);b=nb;return!b&(a|0)==-1|b?-1:a}a=EV(-1485242368,13,(b<<8)+d|0,0);b=nb;return!b&(a|0)==-1|b?-1:a}function IS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=D(0),j=0,k=0,l=0,m=0,n=0,o=D(0),p=D(0),q=0,r=0;g=jb-16|0;jb=g;k=w[a+56>>2];j=w[a+44>>2];if((0-(w[a+60>>2]-k>>11)|0)!=w[a+48>>2]-j>>11){w[g+8>>2]=j;w[g+12>>2]=j+2048;w[g>>2]=k;l=k+2048|0;w[g+4>>2]=l;if(d){q=x[a+4273|0];r=x[a+4272|0];j=d;while(1){e=0;m=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=w[f>>2];w[f>>2]=e+4;f=a+h|0;n=f+4228|0;i=D(D(A[a+4236>>2]*A[n>>2])+D(A[a+4240>>2]*A[e>>2]));A[n>>2]=i;i=D(A[a+4260>>2]*Ev(D(i*D(1073741824)),r,q));e=f+4244|0;o=A[a+4264>>2];f=f+4252|0;p=A[f>>2];i=D(i-D(D(A[a+4268>>2]*A[e>>2])+D(o*p)));A[f>>2]=i;A[e>>2]=p+D(i*o);e=g+h|0;h=w[e>>2];w[e>>2]=h+4;A[h>>2]=i*D(9.313225746154785e-10);h=m;m=0;e=1;if(h){continue}break}j=j-1|0;if(j){continue}break}}ye(a,b,c,k,l,d)}jb=g+16|0}function bz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=w[a>>2];f=w[a+4>>2];g=w[a+40>>2];h=w[a+36>>2];a:{if(!d){b=g>>12;j=h>>12;break a}l=b+24|0;k=w[a+8>>2];m=w[a+12>>2];n=w[a+16>>2];o=w[a+32>>2];p=w[a+28>>2];while(1){h=h+p|0;j=h>>12;b=f+n|0;e=(((i>>>16|0)+4&131064)<<1)+l|0;e=(((((C(u[b+2|0],v[e+10>>1])+C(u[b+1|0],v[e+8>>1])|0)+C(u[b+3|0],v[e+12>>1])|0)+C(u[b+4|0],v[e+14>>1])<<8)/2|0)+((((C(u[b-2|0],v[e+2>>1])+C(u[b-3|0],v[e>>1])|0)+C(u[b-1|0],v[e+4>>1])|0)+C(u[b|0],v[e+6>>1])<<8)/2|0)|0)/16384|0;w[c>>2]=w[c>>2]+C(j,e);g=g+o|0;b=g>>12;w[c+4>>2]=w[c+4>>2]+C(e,b);f=f+m|0;e=i+k|0;f=e>>>0<k>>>0?f+1|0:f;i=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=i;w[a+4>>2]=f;w[a+40>>2]=g;w[a+20>>2]=j;w[a+24>>2]=b}function HA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;h=jb-32|0;jb=h;a:{if(((w[b+4>>2]-w[b>>2]|0)/52&65535)>>>0<=d>>>0|c>>>0>d>>>0){break a}b:{while(1){f=w[b>>2]+C(c&65535,52)|0;g=w[f>>2];i=w[f+4>>2];c:{if((g|0)==(i|0)){break c}f=Nk(h+8|0,e);u[h+24|0]=x[e+16|0];w[h+20>>2]=w[e+12>>2];while(1){w[114256]=0;T(584,f|0,g|0);j=w[114256];w[114256]=0;if((j|0)==1){break b}g=g+6|0;if((i|0)!=(g|0)){continue}break}g=w[f>>2];w[f>>2]=0;w[h+12>>2]=0;w[h+16>>2]=0;if(!g){break c}zb(g);f=w[f>>2];if(!f){break c}zb(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}break a}a=P()|0;b=w[f>>2];if(b){zb(b)}R(a|0);M()}w[a>>2]=w[e>>2];w[a+4>>2]=w[e+4>>2];w[a+8>>2]=w[e+8>>2];w[e+8>>2]=0;w[e>>2]=0;w[e+4>>2]=0;u[a+16|0]=x[e+16|0];w[a+12>>2]=w[e+12>>2];jb=h+32|0}function In(a,b,c){var d=0,e=0,f=0,g=0;d=w[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=x[b+833|0];if(c){u[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(c){u[b+833|0]=c;break a}c=x[b+833|0]}b:{if(!(u[b+872|0]&1)){break b}d=w[b+700>>2];if(!d|!(c&255)){break b}f=b;c:{if(!(!(x[a+480208|0]&16)|w[a+480180>>2]==4)){g=b;b=w[a+1074312>>2]&128;a=w[((c&15)<<2)+(b?31280:30256)>>2];c=BV(a,a>>31,d,d>>31)+32768|0;a=nb;c=CV(c,c>>>0<32768?a+1|0:a,65536,0);e=c;a=nb;c=(a|0)>=0&c>>>0>=2147483647|(a|0)>0;e=c?2147483647:e;a=c?0:a;a=(a|0)<0&e>>>0<=2147483648|(a|0)<-1?-2147483648:e;w[g+700>>2]=a;if((a|0)!=(d|0)){break b}if(!b){if((d|0)==2147483647){break b}a=d+1|0;break c}if((d|0)<2){break b}a=d-1|0;break c}a=d+((c&255)<<2)|0;a=(a|0)>=65535?65535:a}w[f+700>>2]=a}}function zs(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-1040|0;jb=f;g=w[b>>2];w[f+12>>2]=g;j=a?a:f+16|0;d=a?d:256;a:{b:{c:{if(!g|!d){break c}while(1){h=c>>>2|0;if(h>>>0<d>>>0&c>>>0<=131){break b}h=Zl(j,f+12|0,d>>>0>h>>>0?h:d,e);if((h|0)==-1){i=-1;d=0;g=w[f+12>>2];break c}k=(f+16|0)!=(j|0)?h:0;d=d-k|0;j=(k<<2)+j|0;c=c+g|0;g=w[f+12>>2];c=g?c-g|0:0;i=h+i|0;if(!g){break c}if(d){continue}break}}if(!g){break a}}if(!d|!c){break a}h=i;while(1){d:{i=Rh(j,g,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:w[f+12>>2]=0;break e;case 0:break a;default:break f}}w[e>>2]=0;break e}g=w[f+12>>2]+i|0;w[f+12>>2]=g;h=h+1|0;d=d-1|0;if(d){break d}}i=h;break a}j=j+4|0;c=c-i|0;i=h;if(c){continue}break}}if(a){w[b>>2]=w[f+12>>2]}jb=f+1040|0;return i|0}function xu(a){var b=D(0),c=D(0),d=D(0),e=D(0),f=D(0),g=D(0),h=D(0),i=D(0),j=D(0),k=D(0),l=D(0),m=D(0),n=D(0),o=D(0);b=A[a+32>>2];c=A[a+8>>2];e=A[a+16>>2];f=D(D(b-c)+e);i=A[a>>2];j=A[a+24>>2];k=D(i-j);A[a+16>>2]=f+k;d=A[a+4>>2];g=A[a+20>>2];h=A[a+28>>2];l=D(D(d-D(g+h))*D(.8660253882408142));k=D(k-D(f*D(.5)));A[a+4>>2]=l+k;m=D(D(g+d)*D(.9848077297210693));f=D(A[a+12>>2]*D(.8660253882408142));n=D(D(h+d)*D(-.6427876353263855));o=D(D(m-f)+n);d=D(i+D(j*D(.5)));i=D(D(b+c)*D(.7660444378852844));b=D(D(e-b)*D(.1736481785774231));j=D(D(d-i)+b);A[a+12>>2]=o+j;A[a+20>>2]=j-o;A[a+28>>2]=k-l;g=D(D(g-h)*D(.3420201539993286));h=D(g-D(f+m));c=D(D(e+c)*D(.9396926164627075));b=D(D(d+c)-b);A[a+32>>2]=h+b;e=D(D(g+f)+n);c=D(D(d-c)+i);A[a+24>>2]=e+c;A[a+8>>2]=c-e;A[a>>2]=b-h}function tC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;a:{if(u[c+11|0]>=0){w[e+16>>2]=w[c+8>>2];f=w[c+4>>2];w[e+8>>2]=w[c>>2];w[e+12>>2]=f;break a}Ge(e+8|0,w[c>>2],w[c+4>>2])}c=e+20|0;b:{c:{d:{e:{if(u[d+11|0]>=0){f=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+8>>2];break e}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(76,c|0,d|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break d}}w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(290,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break b}zb(w[e+8>>2]);break b}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function Wt(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=fe(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=D(-ge(d+1.5707963267948966));break a}a=ge(d+-1.5707963267948966);break a}a=fe(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=ge(d+4.71238898038469);break a}a=D(-ge(d+-4.71238898038469));break a}a=fe(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=D(a-a);break a}b:{switch(Fm(a,b+8|0)&3){case 0:a=fe(B[b+8>>3]);break a;case 1:a=ge(B[b+8>>3]);break a;case 2:a=fe(-B[b+8>>3]);break a;default:break b}}a=D(-ge(B[b+8>>3]))}jb=b+16|0;return a}function nR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;a:{if(u[c+11|0]>=0){w[e+16>>2]=w[c+8>>2];f=w[c+4>>2];w[e+8>>2]=w[c>>2];w[e+12>>2]=f;break a}me(e+8|0,w[c>>2],w[c+4>>2])}c=e+20|0;b:{c:{d:{e:{if(u[d+11|0]>=0){f=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+8>>2];break e}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,c|0,d|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break d}}w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(51,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break b}zb(w[e+8>>2]);break b}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function rd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;a=Xh(a,-1,-1);Oe(d+24|0,b,1);a:{b:{if(x[d+24|0]){c=w[w[b>>2]-12>>2];w[114256]=0;c=w[(b+c|0)+24>>2];e=w[114256];w[114256]=0;c:{d:{if((e|0)==1){break d}w[114256]=0;Pa(1574,d+8|0,c|0,0,0,1,8);c=w[114256];w[114256]=0;if((c|0)==1){break d}c=w[d+12>>2];w[a>>2]=w[d+8>>2];w[a+4>>2]=c;c=w[d+20>>2];w[a+8>>2]=w[d+16>>2];w[a+12>>2]=c;a=0;break c}$(W(0)|0)|0;Me(w[w[b>>2]-12>>2]+b|0,1);a=w[w[b>>2]-12>>2];w[114256]=0;a=w[(a+b|0)+20>>2];c=w[114256];w[114256]=0;e:{if((c|0)!=1){if(!(a&1)){break e}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}aa();a=1}Kd(w[w[b>>2]-12>>2]+b|0,a)}jb=d+32|0;return}W(0)|0;Eb()}M()}function pg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=w[b+88>>2];d=c|2048;w[b+88>>2]=d;f=w[b+656>>2];if(!(!f|u[b+724|0]&1)){d=c|6144;w[b+88>>2]=d}a:{if(!w[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=w[b+104>>2];if(!c){break b}e=y[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;w[b+88>>2]=d;e=w[c>>2];w[b+76>>2]=e;g=w[c+4>>2];w[b+80>>2]=g;c=w[c+8>>2];w[b+84>>2]=c;if(c>>>0<e>>>0){w[b+76>>2]=c;h=c}else{h=e}e=w[b+4>>2];if(h>>>0>=e>>>0){break b}w[b>>2]=0;w[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;w[b+88>>2]=d;w[b+76>>2]=w[c>>2]}if(!f){break a}if(!(!(x[f+60|0]&2|w[a+480180>>2]&1064964)|!w[f>>2])){w[b+88>>2]=d|4096}if(x[f+65|0]==255|w[b+732>>2]!=-1){break a}i=b,j=oh(f+48|0,w[b+728>>2],256,64),w[i+732>>2]=j;w[b+728>>2]=y[w[f+48>>2]+(x[f+65|0]<<2)>>1]}}function id(a){var b=0,c=0;b=w[a+4>>2];c=w[w[b>>2]-12>>2];w[114256]=0;b=w[(b+c|0)+24>>2];c=w[114256];w[114256]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=w[a+4>>2];c=w[w[b>>2]-12>>2];w[114256]=0;b=dg(b+c|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}if(!b){break b}b=w[a+4>>2];if(!(w[(w[w[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(Lt()){break b}b=w[a+4>>2];c=w[w[b>>2]-12>>2];w[114256]=0;b=w[(b+c|0)+24>>2];c=w[114256];w[114256]=0;c:{if((c|0)==1){break c}w[114256]=0;b=V(1563,b|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=w[a+4>>2];b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,1);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function MI(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=Rr(c);b:{if(b){cf(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;bf(k,a);break b}dj(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;Td(k,a)}ne(i,k);$b(k);l=e,m=se(a),w[l>>2]=m;l=f,m=re(a),w[l>>2]=m;Ad(k,a);_c(g,k);Gb(k);Ud(k,a);ne(h,k);$b(k);a=af(a);break a}a=Qr(c);c:{if(b){cf(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;bf(k,a);break c}dj(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;Td(k,a)}ne(i,k);$b(k);l=e,m=se(a),w[l>>2]=m;l=f,m=re(a),w[l>>2]=m;Ad(k,a);_c(g,k);Gb(k);Ud(k,a);ne(h,k);$b(k);a=af(a)}w[j>>2]=a;jb=k+16|0}function wy(a,b){a=a|0;b=b|0;var c=0,d=0;if(z[a>>2]>=65537){w[a>>2]=65536}if(z[a+4>>2]>=65){w[a+4>>2]=64}if(z[a+8>>2]>=257){w[a+8>>2]=256}if(y[a+28>>1]>=16385){v[a+28>>1]=16384}if(x[a+30|0]>=129){u[a+30|0]=128}if(x[a+31|0]>=18){u[a+31|0]=17}if(x[a+16|0]>=4){u[a+16|0]=0}if(x[a+17|0]>=5){u[a+17|0]=0}if(x[a+18|0]>=3){u[a+18|0]=0}if(x[a+19|0]>=65){u[a+19|0]=64}if(x[a+20|0]>=101){u[a+20|0]=100}c=224;d=u[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}u[a+26|0]=c}if(x[a+23|0]>=65){u[a+23|0]=64}if(x[a+24|0]>=65){u[a+24|0]=64}Ek(a+48|0,64);Ek(a+68|0,64);Ek(a+88|0,(b|0)==4096?255:64);b=a+108|0;c=0;while(1){d=b+c|0;if((x[d|0]-121&255)>>>0<=135){u[d|0]=c+1}c=c+1|0;if((c|0)!=128){continue}break}if(x[a+14|0]>=5){u[a+14|0]=5}if(x[a+34|0]>=251){u[a+34|0]=0}}function kl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=w[a>>2];d=w[a+4>>2]-c>>1;if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{d=b-d|0;e=w[a+8>>2];c=w[a+4>>2];c:{if(d>>>0<=e-c>>1>>>0){if(d){b=d<<1;c=Cb(c,0,b)+b|0}w[a+4>>2]=c;break c}b=c;c=w[a>>2];f=b-c>>1;b=f+d|0;if((b|0)<0){break b}c=e-c|0;b=Vf(g+8|0,c>>>0>=2147483646?2147483647:b>>>0<c>>>0?c:b,f,a+8|0);c=d<<1;e=Cb(w[b+8>>2],0,c)+c|0;w[b+8>>2]=e;d=w[a+4>>2];c=w[a>>2];h=d-c|0;f=w[b+4>>2]-h|0;w[b+4>>2]=f;if((h|0)>0){Fb(f,c,h);e=w[b+8>>2];d=w[a+4>>2];f=w[b+4>>2];c=w[a>>2]}w[a>>2]=f;w[b+4>>2]=c;w[a+4>>2]=e;w[b+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=e;if((c|0)!=(d|0)){w[b+8>>2]=((c-d|0)+1&-2)+d}if(!c){break c}zb(c)}jb=g+32|0;break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=c+(b<<1)}}function gx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=D(0),g=0,h=0,i=D(0),j=D(0);f=A[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>2|0;g=c>>>0>e>>>0?e:c;a:{if(!g){break a}c=g;e=b;while(1){h=x[e|0]|x[e+1|0]<<8|(x[e+2|0]<<16|x[e+3|0]<<24);f=D(H((l(2,(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24))&2147483647),q()),f));e=e+4|0;c=c-1|0;if(c){continue}break}c=f==D(0);if(c|!g){break a}j=c?D(1):D(D(1)/f);e=w[a+20>>2];c=g;while(1){a=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);i=_b(D(D(H(D(G(D(j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q())),D(1))),D(-1)))*D(32768)));b:{if(D(E(i))<D(2147483648)){a=~~i;break b}a=-2147483648}a=(a|0)>=32767?32767:a;v[e>>1]=(a|0)<=-32768?-32768:a;b=b+4|0;e=e+2|0;c=c-1|0;if(c){continue}break}}if(d){A[d>>2]=f}return g<<2}function bF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=-1;a:{if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],7)|0)){break a}c=0;if(!Ah(a,7577,7)){break a}c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=f;w[c+12>>2]=f+11;d=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((d|0)==11){b:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],11)|0){e=w[a+12>>2]+11|0;break b}e=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=e}jb=c+16|0;c=-1;if((d|0)!=11){break a}c=0;if(x[f+1|0]!=1){break a}c=a;a=x[f+9|0]|x[f+10|0]<<8;d=BV(x[f+3|0],0,18,0);e=a+d|0;a=nb;a=d>>>0>e>>>0?a+1|0:a;d=e;e=a;h=d;d=y[f+6>>1];a=d>>>31|0;g=d<<1;d=h+g|0;a=a+e|0;a=d>>>0<g>>>0?a+1|0:a;e=a;g=c;h=b;b=y[f+4>>1];a=b>>>30|0;c=b<<2;b=c+d|0;a=a+e|0;a=b>>>0<c>>>0?a+1|0:a;b=b+3|0;a=b>>>0<3?a+1|0:a;c=Uc(g,h,b,a)}jb=f+16|0;return c|0}function QI(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=Xr(c);b:{if(b){cf(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;bf(k,a);break b}dj(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;Td(k,a)}_c(i,k);Gb(k);l=e,m=se(a),u[l|0]=m;l=f,m=re(a),u[l|0]=m;Ad(k,a);_c(g,k);Gb(k);Ud(k,a);_c(h,k);Gb(k);a=af(a);break a}a=Wr(c);c:{if(b){cf(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;bf(k,a);break c}dj(k,a);b=w[k>>2];u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;Td(k,a)}_c(i,k);Gb(k);l=e,m=se(a),u[l|0]=m;l=f,m=re(a),u[l|0]=m;Ad(k,a);_c(g,k);Gb(k);Ud(k,a);_c(h,k);Gb(k);a=af(a)}w[j>>2]=a;jb=k+16|0}function vi(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;w[b+40>>2]=0;w[b+44>>2]=0;f=b- -64|0;w[f>>2]=0;w[f+4>>2]=0;w[b+56>>2]=0;w[b+60>>2]=0;w[b+48>>2]=0;w[b+52>>2]=0;l=B[b+32>>3];m=B[b+24>>3];n=B[b+16>>3];o=B[b+8>>3];p=B[b>>3];f=w[c>>2];while(1){h=B[f>>3];B[b+64>>3]=i;B[b+40>>3]=h;B[b+48>>3]=d;g=d*o+p*h+g*n-(j*l+i*m);B[b+56>>3]=g;j=i;i=g;g=d;d=h;e=e+1|0;if((e|0)!=1e4){continue}break}k=w[c+4>>2];if((k|0)!=(f|0)){e=f;while(1){j=B[b+48>>3];h=B[e>>3];g=B[b+40>>3];B[b+48>>3]=g;i=B[b+64>>3];d=B[b+56>>3];B[b+64>>3]=d;B[b+40>>3]=h;d=g*B[b+8>>3]+h*B[b>>3]+j*B[b+16>>3]-(i*B[b+32>>3]+d*B[b+24>>3]);B[b+56>>3]=d;B[e>>3]=d;e=e+8|0;if((k|0)!=(e|0)){continue}break}}w[a+4>>2]=k;w[a>>2]=f;w[a+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0}function xe(a,b,c){var d=0,e=0,f=0;e=jb-48|0;jb=e;d=w[a+24>>2];a:{if(w[d+24620>>2]==(b|0)){if(w[d+24624>>2]==(c|0)){if(x[a+29|0]){break a}vn(d,1);break a}f=e+8|0;Fb(f,d+24604|0,40);w[e+28>>2]=c;w[e+24>>2]=b;li(d,f);break a}f=e+8|0;Fb(f,d+24604|0,40);w[e+28>>2]=c;w[e+24>>2]=b;li(d,f);b=w[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){b=w[c>>2];b:{if(!b){break b}if(!(ob[w[w[b>>2]+112>>2]](b)|0)){break b}ob[w[w[b>>2]+104>>2]](b,0);ob[w[w[b>>2]+92>>2]](b);ob[w[w[b>>2]+120>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}b=w[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){b=w[c>>2];c:{if(!b){break c}if(ob[w[w[b>>2]+112>>2]](b)|0){break c}ob[w[w[b>>2]+104>>2]](b,1);ob[w[w[b>>2]+116>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}u[a+29|0]=1;jb=e+48|0}function TP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)==1){break c}w[114256]=0;X(1361,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;X(1361,c|0);f=w[114256];w[114256]=0;e=1;if((f|0)==1){break c}f=w[a+24>>2];w[d+24>>2]=b;b=ec(b);w[d+16>>2]=c;w[d+28>>2]=b;b=ec(c);w[114256]=0;w[d+20>>2]=b;b=w[d+28>>2];w[d+8>>2]=w[d+24>>2];w[d+12>>2]=b;b=w[d+20>>2];w[d>>2]=w[d+16>>2];w[d+4>>2]=b;Y(1404,f|0,d+8|0,d|0,1);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,1993,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}jb=d+32|0;return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function ow(a){a=a|0;var b=0;a:{b:{c:{if(x[a+3|0]!=19){break c}u[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=x[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}u[a+3|0]=2;break a}u[a+3|0]=3;break a}u[a+5|0]=b&15|16;return}u[a+5|0]=b&3|48;return}u[a+5|0]=b&15|32;return}u[a+5|0]=b&15|176;return}u[a+5|0]=b&3|64;return}u[a+3|0]=15;u[a+5|0]=b&15;return}if(b&15){u[a+3|0]=11;u[a+5|0]=b<<4|15;return}break b}if(b&15){u[a+3|0]=11;break a}break b}if((b|0)!=192){break c}u[a|0]=254;break b}if((b|0)!=208){break c}u[a+3|0]=0}return}u[a+3|0]=0;return}u[a+5|0]=b|240}function gB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;lc(b,0);c=d+8|0;Vb(c,1,a,13);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=b+43;Q(200,d+24|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}w[b>>2]=x[a+48|0]|x[a+49|0]<<8|(x[a+50|0]<<16|x[a+51|0]<<24);w[b+4>>2]=x[a+52|0]|x[a+53|0]<<8|(x[a+54|0]<<16|x[a+55|0]<<24);w[b+8>>2]=x[a+56|0]|x[a+57|0]<<8|(x[a+58|0]<<16|x[a+59|0]<<24);w[b+24>>2]=x[a+62|0]|x[a+63|0]<<8;yi(b,+((x[a+60|0]^8)-120|0)*.005208333333333333);c=x[a+61|0];v[b+34>>1]=0;v[b+30>>1]=(c>>>0>=64?64:c)<<2;c=x[a+47|0];if(c&4){v[b+34>>1]=1;w[b>>2]=w[b>>2]>>>1;e=1;c=x[a+47|0]}if(c&32){e=e|4;v[b+34>>1]=e;c=x[a+47|0]}if(c<<24>>24<0){v[b+34>>1]=e|2}jb=d+32|0;return}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}function uw(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;Hd(b,c>>>0>=12?12:c);l=w[b>>2];m=w[b+4>>2];if((l|0)!=(m|0)){c=m-l>>2;n=c>>>0<=1?1:c;c=0;while(1){j=(c<<2)+l|0;a:{b:{c:{switch(h|0){case 0:k=c<<2;i=k+a|0;v[l+k>>1]=x[i+96|0]|x[i+97|0]<<8;i=i+98|0;break b;case 1:break c;default:break a}}k=c<<2;i=k+a|0;v[l+k>>1]=x[i+144|0]|x[i+145|0]<<8;i=i+146|0}u[j+2|0]=x[i|0]}d:{if(!c){break d}i=(c<<2)+l|0;j=y[i>>1];if(j>>>0>255){break d}k=y[i-4>>1];if(j>>>0>=k>>>0){break d}j=j|k&-256;v[i>>1]=j;if((j&65535)>>>0>=k>>>0){break d}v[i>>1]=j+256}c=c+1|0;if((n|0)!=(c|0)){continue}break}}c=(l|0)!=(m|0)&d;u[b+12|0]=c;if(e>>>0<12){if(d&2){c=c|4;u[b+12|0]=c}u[b+15|0]=e;u[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){u[b+12|0]=c|2}u[b+14|0]=g;u[b+13|0]=f}}function _w(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;c=w[a>>2];d=w[a+4>>2]-c>>5;e=d+1|0;if(e>>>0<134217728){c=w[a+8>>2]-c|0;f=c>>4;e=Vh(g+8|0,c>>>0>=2147483616?134217727:e>>>0<f>>>0?f:e,d,a+8|0);c=w[e+8>>2];d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;d=w[b+28>>2];w[c+24>>2]=w[b+24>>2];w[c+28>>2]=d;d=w[b+20>>2];w[c+16>>2]=w[b+16>>2];w[c+20>>2]=d;d=w[b+12>>2];w[c+8>>2]=w[b+8>>2];w[c+12>>2]=d;f=c+32|0;w[e+8>>2]=f;c=w[a+4>>2];b=w[a>>2];h=c-b|0;d=w[e+4>>2]-h|0;w[e+4>>2]=d;if((h|0)>0){Fb(d,b,h);f=w[e+8>>2];c=w[a+4>>2];d=w[e+4>>2];b=w[a>>2]}w[a>>2]=d;w[e+4>>2]=b;w[a+4>>2]=f;w[e+8>>2]=c;d=w[a+8>>2];w[a+8>>2]=w[e+12>>2];w[e>>2]=b;w[e+12>>2]=d;if((b|0)!=(c|0)){w[e+8>>2]=((b-c|0)+31&-32)+c}if(b){zb(b)}jb=g+32|0;return}Mb(a);M()}function Nn(a,b,c){var d=0,e=0;d=w[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=x[b+834|0];if(c){u[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){u[b+833|0]=c;break a}c=x[b+833|0]}b:{if(!(u[b+872|0]&1)){break b}d=w[b+700>>2];if(!d|!(c&255)){break b}if(!(!(x[a+480208|0]&16)|w[a+480180>>2]==4)){e=b;a=w[((c&15)<<2)+(w[a+1074312>>2]&128?30128:30192)>>2];b=BV(a,a>>31,d,d>>31)+32768|0;a=nb;b=CV(b,b>>>0<32768?a+1|0:a,65536,0);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;a=b?0:a;a=(a|0)<0&c>>>0<=2147483648|(a|0)<-1?-2147483648:c;w[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;w[b+700>>2]=c;if((c|0)>0){break b}w[b+700>>2]=1;if(w[a+480180>>2]!=2){break b}w[b+696>>2]=0;w[b+88>>2]=w[b+88>>2]|2101248}}function EU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){yh(a,(c-d|0)/6|0);c=w[a+4>>2];e=w[b>>2];d=w[b+4>>2]-e|0;if((d|0)>0){c=Fb(c,e,d)+C((d>>>0)/6|0,6)|0}w[a+4>>2]=c}w[a+20>>2]=w[b+20>>2];c=w[b+16>>2];w[a+12>>2]=w[b+12>>2];w[a+16>>2]=c;w[114256]=0;d=Q(953,a+24|0,b+24|0)|0;c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=a+36|0;c:{if(u[b+47|0]>=0){d=b+36|0;e=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=e;w[c+8>>2]=w[b+44>>2];break c}e=w[b+40>>2];f=w[b+36>>2];w[114256]=0;U(76,c|0,f|0,e|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}}w[a+48>>2]=w[b+48>>2];return a|0}b=P()|0;break a}b=P()|0;c=w[d>>2];if(!c){break a}w[a+28>>2]=c;zb(c)}c=w[a>>2];if(c){w[a+4>>2]=c;zb(c)}R(b|0);M()}function fx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=B[e+8>>3];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>3|0;g=c>>>0>e>>>0?e:c;a:{if(!g){break a}e=g;c=b;while(1){i=(x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24))&2147483647;l(0,x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24));l(1,i|0);f=H(+n(),f);c=c+8|0;e=e-1|0;if(e){continue}break}c=f==0;if(c|!g){break a}j=c?1:1/f;c=w[a+20>>2];a=g;while(1){e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);l(0,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24));l(1,e|0);h=Tb(H(G(j*+n(),1),-1)*32768);b:{if(E(h)<2147483648){e=~~h;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[c>>1]=(e|0)<=-32768?-32768:e;b=b+8|0;c=c+2|0;a=a-1|0;if(a){continue}break}}if(d){B[d>>3]=f}return g<<3}function wL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(z[b+24>>2]>z[b+44>>2]){w[b+44>>2]=w[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|(e|0)==1&(h|0)==24){break a}h=w[b+44>>2];if(h){g=h-Qb(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=w[b+12>>2]-w[b+8>>2]|0;i=e;j=e>>31;break b}e=w[b+24>>2]-w[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>m>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(w[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!w[b+24>>2]){break a}}if(d){Lg(b,w[b+8>>2],e+w[b+8>>2]|0,w[b+44>>2])}if(f&16){lm(b,w[b+20>>2],w[b+28>>2]);yj(b,e)}k=e;l=c}Xh(a,k,l)}function Pt(a,b,c,d){a:{switch(b-9|0){case 0:b=w[c>>2];w[c>>2]=b+4;w[a>>2]=w[b>>2];return;case 6:b=w[c>>2];w[c>>2]=b+4;b=v[b>>1];w[a>>2]=b;w[a+4>>2]=b>>31;return;case 7:b=w[c>>2];w[c>>2]=b+4;w[a>>2]=y[b>>1];w[a+4>>2]=0;return;case 8:b=w[c>>2];w[c>>2]=b+4;b=u[b|0];w[a>>2]=b;w[a+4>>2]=b>>31;return;case 9:b=w[c>>2];w[c>>2]=b+4;w[a>>2]=x[b|0];w[a+4>>2]=0;return;case 16:b=w[c>>2]+7&-8;w[c>>2]=b+8;B[a>>3]=B[b>>3];return;case 17:ob[d|0](a,c);default:return;case 1:case 4:case 14:b=w[c>>2];w[c>>2]=b+4;b=w[b>>2];w[a>>2]=b;w[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=w[c>>2];w[c>>2]=b+4;w[a>>2]=w[b>>2];w[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=w[c>>2]+7&-8;w[c>>2]=b+8;c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c}function Ef(a,b,c,d){var e=0;a:{b:{if(b>>>0>255){break b}c:{d:{e:{switch(c|0){case 1:c=w[(C(b,896)+a|0)+1075640>>2];if(!c){break b}f:{if((d|0)!=1){break f}a=w[(C(b,896)+a|0)+1075088>>2];if(!a){break f}if(x[a+35|0]&4){break a}}e=x[c+34|0];break a;case 3:break c;case 0:break d;case 2:break e;default:break a}}c=w[(C(b,896)+a|0)+1075640>>2];if(!c){break d}g:{if((d|0)!=1){break g}e=w[(C(b,896)+a|0)+1075088>>2];if(!e){break g}if(x[e+35|0]&4){break d}}e=x[c+34|0];if((e+5&255)>>>0>5){break a}}e=Vn(a,b,d);break a}e=Vn(a,b,d);if((e+5&255)>>>0>5){break a}c=w[(C(b,896)+a|0)+1075640>>2];if(!c){break b}h:{if((d|0)!=1){break h}a=w[(C(b,896)+a|0)+1075088>>2];if(!a){break h}e=0;if(x[a+35|0]&4){break a}}e=x[c+34|0];break a}e=0}return e&255}function yM(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;if(ju(0,c+40|0)){Ti(w[114084],8473);M()}e=uf(c+24|0,c+40|0);w[c+12>>2]=w[c+48>>2]/1e3;f=Mt(c+16|0,c+12|0);b=jb-32|0;jb=b;d=jb-16|0;jb=d;g=jb-16|0;jb=g;a=jb-16|0;jb=a;i=a,j=BV(w[e>>2],w[e+4>>2],1e6,0),w[i>>2]=j;w[a+4>>2]=nb;e=uf(a+8|0,a);h=w[e+4>>2];e=w[e>>2];jb=a+16|0;jb=g+16|0;a=d;w[a+8>>2]=e;w[a+12>>2]=h;d=w[a+12>>2];w[b+8>>2]=w[a+8>>2];w[b+12>>2]=d;jb=a+16|0;a=w[b+8>>2];e=w[b+12>>2];d=w[f+4>>2];w[b>>2]=w[f>>2];w[b+4>>2]=d;f=w[b>>2];d=a+f|0;a=w[b+4>>2]+e|0;w[b+16>>2]=d;w[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=uf(b+24|0,b+16|0);d=w[a+4>>2];a=w[a>>2];jb=b+32|0;w[c+32>>2]=a;w[c+36>>2]=d;b=uf(c+56|0,c+32|0);a=w[b+4>>2];b=w[b>>2];jb=c- -64|0;nb=a;return b|0}function aP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;b=w[a+4>>2];a=w[a>>2];w[c>>2]=a;w[c+4>>2]=b;w[c+8>>2]=a;w[c+12>>2]=b;a=jb-48|0;jb=a;a:{if(!w[c+4>>2]){break a}b=76832;f=w[c>>2];e=w[c+4>>2];b:{while(1){d=w[b+8>>2];if((ec(d)|0)==(e|0)){w[a+36>>2]=e;w[a+32>>2]=d;w[a+40>>2]=f;w[a+44>>2]=e;w[a+24>>2]=f;w[a+28>>2]=e;d=w[a+36>>2];w[a+16>>2]=w[a+32>>2];w[a+20>>2]=d;if(!to(a+24|0,a+16|0)){break b}}b=b+12|0;if((b|0)!=77348){continue}break}b=77360;while(1){d=w[b+8>>2];if((ec(d)|0)==(e|0)){w[a+36>>2]=e;w[a+32>>2]=d;w[a+40>>2]=f;w[a+44>>2]=e;w[a+8>>2]=f;w[a+12>>2]=e;d=w[a+36>>2];w[a>>2]=w[a+32>>2];w[a+4>>2]=d;if(!to(a+8|0,a)){break b}}b=b+12|0;if((b|0)!=77408){continue}break}break a}g=1}jb=a+48|0;jb=c+16|0;return g|0}function YE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;lc(b,0);w[b>>2]=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);d=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);w[b+4>>2]=c>>>0<d>>>0?c:d;c=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);d=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);w[b+8>>2]=c>>>0<d>>>0?c:d;c=x[a+15|0];v[b+30>>1]=(((c>>>0>=127?127:c)<<8|64)>>>0)/127;c=x[a+12|0];if(c>>>0>=16){v[b+34>>1]=32;v[b+28>>1]=c&240}c=(x[a+13|0]|x[a+14|0]<<8)<<1;w[b+24>>2]=c;w[b+24>>2]=x[a+13|0]|x[a+14|0]<<8?c:16726;e=b,f=(C(Bk(0,x[a+12|0]<<28>>24),w[b+24>>2])>>>0)/8363|0,w[e+24>>2]=f;if(z[b+4>>2]<z[b+8>>2]){v[b+34>>1]=y[b+34>>1]|2}if(x[a+16|0]&132){v[b+34>>1]=y[b+34>>1]|1}}function gC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb+-64|0;jb=e;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}a=Vc(e+40|0,a,d,1);g=w[a>>2];f=w[a+4>>2];i=w[a+12>>2];h=w[a+8>>2];w[114256]=0;Y(209,e+8|0,3,(f?f:(h|0)!=(i|0)?h:0)|0,g|0);f=w[114256];w[114256]=0;b:{c:{if((f|0)!=1){w[114256]=0;U(6,e+24|0,c|0,e+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}if(u[b+11|0]<0){zb(w[b>>2])}c=w[e+28>>2];w[b>>2]=w[e+24>>2];w[b+4>>2]=c;w[b+8>>2]=w[e+32>>2];u[e+35|0]=0;u[e+24|0]=0;if(u[e+19|0]<0){zb(w[e+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=e- -64|0;return!d|(g|0)!=0}b=P()|0;break b}b=P()|0;if(u[e+19|0]>=0){break b}zb(w[e+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function VB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb+-64|0;jb=e;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}a=Vc(e+40|0,a,d,1);g=w[a>>2];f=w[a+4>>2];i=w[a+12>>2];h=w[a+8>>2];w[114256]=0;Y(209,e+8|0,2,(f?f:(h|0)!=(i|0)?h:0)|0,g|0);f=w[114256];w[114256]=0;b:{c:{if((f|0)!=1){w[114256]=0;U(6,e+24|0,c|0,e+8|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}if(u[b+11|0]<0){zb(w[b>>2])}c=w[e+28>>2];w[b>>2]=w[e+24>>2];w[b+4>>2]=c;w[b+8>>2]=w[e+32>>2];u[e+35|0]=0;u[e+24|0]=0;if(u[e+19|0]<0){zb(w[e+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=e- -64|0;return!d|(g|0)!=0}b=P()|0;break b}b=P()|0;if(u[e+19|0]>=0){break b}zb(w[e+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function Gw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+480180>>2]=b;c=1409;b=0;a:{b:{c:{d:{e:{f:{f=$g(a);switch(f-1|0){case 2:break a;case 0:break c;case 3:break d;case 1:break e;default:break f}}if((f|0)==32){break b}if((f|0)!=16777216){break a}d=840;e=389766;c=-684218752;break a}d=1025;b=17162240;e=33587200;c=1281;break a}d=4;b=658513919;e=-524032;c=132865;break a}b=16777216;c=0;break a}d=464;b=25165824;e=393215;c=-127}w[a+1074312>>2]=c;w[a+1074324>>2]=d;w[a+1074320>>2]=b;w[a+1074316>>2]=e;b=77868;g:{h:{i:{j:{k:{c=$g(a);switch(c-2|0){case 0:break i;case 2:break j;case 1:break h;default:break k}}if((c|0)==16777216){break g}if((c|0)!=32){break h}b=77884;break g}b=77880;break g}b=77876;break g}b=77872}w[a+8>>2]=w[b>>2]}function ax(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=D(0);e=w[a>>2];c=c>>>3|0;c=c>>>0>e>>>0?e:c;if(c){g=A[d>>2];a=w[a+20>>2];d=c;while(1){e=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);f=_b(D(D(H(D(G(D(g*(l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q())),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);f=_b(D(D(H(D(G(D(g*(l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q())),D(1))),D(-1)))*D(32768)));b:{if(D(E(f))<D(2147483648)){e=~~f;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[a+2>>1]=(e|0)<=-32768?-32768:e;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}return c<<3}function Wg(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;a:{b:{if(!a){break b}i=w[e+12>>2];j=c-b|0;if((j|0)>0){if((ob[w[w[a>>2]+48>>2]](a,b,j)|0)!=(j|0)){break b}}b=d-b|0;b=(b|0)<(i|0)?i-b|0:0;if((b|0)>0){c:{if(b>>>0>=11){i=(b|15)+1|0;h=Kb(i);w[g+8>>2]=i|-2147483648;w[g>>2]=h;w[g+4>>2]=b;break c}u[g+11|0]=b;h=g}k=Cb(h,f,b)+b|0,l=0,u[k|0]=l;f=w[w[a>>2]+48>>2];w[114256]=0;f=S(f|0,a|0,(u[g+11|0]<0?w[g>>2]:g)|0,b|0)|0;h=w[114256];w[114256]=0;if((h|0)==1){break a}if(u[g+11|0]<0){zb(w[g>>2])}h=0;if((b|0)!=(f|0)){break b}}b=d-c|0;if((b|0)>0){if((ob[w[w[a>>2]+48>>2]](a,c,b)|0)!=(b|0)){break b}}w[e+12>>2]=0;h=a}jb=g+16|0;return h|0}a=P()|0;if(u[g+11|0]<0){zb(w[g>>2])}R(a|0);M()}function nB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;lc(b,0);c=d+8|0;Vb(c,2,a+1|0,8);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=b+43;Q(200,d+24|0,c|0)|0;c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}w[b+24>>2]=x[a+73|0]|x[a+74|0]<<8|(x[a+75|0]<<16|x[a+76|0]<<24);e=x[a+54|0]|x[a+55|0]<<8|(x[a+56|0]<<16|x[a+57|0]<<24);w[b>>2]=e;f=x[a+58|0]|x[a+59|0]<<8|(x[a+60|0]<<16|x[a+61|0]<<24);w[b+4>>2]=f;c=x[a+62|0]|x[a+63|0]<<8|(x[a+64|0]<<16|x[a+65|0]<<24);if(c){break b}c=w[b+8>>2];break a}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}c=c+1|0;w[b+8>>2]=c}v[b+30>>1]=(x[a+68|0]<<1)+2;v[b+34>>1]=y[b+34>>1]&65533|x[a|0]>>>6&2;if(c>>>0>e>>>0){w[b+8>>2]=e;c=e}if(c>>>0<f>>>0){w[b+4>>2]=c}jb=d+32|0}function GM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=w[a+28>>2];w[d+16>>2]=e;f=w[a+20>>2];w[d+28>>2]=c;w[d+24>>2]=b;b=f-e|0;w[d+20>>2]=b;f=b+c|0;i=2;a:{b:{b=d+16|0;c:{d:{if(Jj(ya(w[a+60>>2],b|0,2,d+12|0)|0)){e=b;break d}while(1){g=w[d+12>>2];if((g|0)==(f|0)){break c}if((g|0)<0){e=b;break b}h=w[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;w[e>>2]=h+w[e>>2];b=(j?12:4)+b|0;w[b>>2]=w[b>>2]-h;f=f-g|0;b=e;i=i-j|0;if(!Jj(ya(w[a+60>>2],b|0,i|0,d+12|0)|0)){continue}break}}if((f|0)!=-1){break b}}b=w[a+44>>2];w[a+28>>2]=b;w[a+20>>2]=b;w[a+16>>2]=b+w[a+48>>2];a=c;break a}w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a>>2]=w[a>>2]|32;a=0;if((i|0)==2){break a}a=c-w[e+4>>2]|0}jb=d+32|0;return a|0}function Ls(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){jc(g+32|0,b,c,d,e,0,0,0,2147352576);d=w[g+40>>2];e=w[g+44>>2];b=w[g+32>>2];c=w[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}jc(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=w[g+24>>2];e=w[g+28>>2];b=w[g+16>>2];c=w[g+20>>2];break a}if((f|0)>-16383){break a}jc(g- -64|0,b,c,d,e,0,0,0,7471104);d=w[g+72>>2];e=w[g+76>>2];b=w[g+64>>2];c=w[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}jc(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=w[g+56>>2];e=w[g+60>>2];b=w[g+48>>2];c=w[g+52>>2]}jc(g,b,c,d,e,0,0,0,f+16383<<16);b=w[g+12>>2];w[a+8>>2]=w[g+8>>2];w[a+12>>2]=b;b=w[g+4>>2];w[a>>2]=w[g>>2];w[a+4>>2]=b;jb=g+80|0}function hc(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){Fb(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}u[a|0]=x[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;u[d|0]=x[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;w[c+a>>2]=w[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;u[c+a|0]=x[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){w[a>>2]=w[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){u[a|0]=x[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function nv(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb-48|0;jb=j;w[j+44>>2]=e;e=w[a+4>>2];k=w[a>>2];a=w[a+8>>2];w[114256]=0;w[j+24>>2]=b;w[j+36>>2]=a;w[j+28>>2]=k;w[j+32>>2]=e;w[j+20>>2]=d?d:1321;a=Q(1322,j+20|0,j+44|0)|0;b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){w[114256]=0;b=w[j+36>>2];w[j+8>>2]=w[j+32>>2];w[j+12>>2]=b;b=w[j+28>>2];w[j>>2]=w[j+24>>2];w[j+4>>2]=b;c=+za(1323,j|0,+c,a|0);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;na(1314,10605,d|0,w[j+44>>2],f|0,g|0,0,0,h|0,i|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}jb=j+48|0;return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){W(0)|0;Eb();M()}R(a|0);M()}function tl(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;f=w[a>>2];e=w[f-4>>2];f=w[f-8>>2];w[d+32>>2]=0;w[d+36>>2]=0;w[d+40>>2]=0;w[d+44>>2]=0;w[d+48>>2]=0;w[d+52>>2]=0;u[d+55|0]=0;u[d+56|0]=0;u[d+57|0]=0;u[d+58|0]=0;u[d+59|0]=0;u[d+60|0]=0;u[d+61|0]=0;u[d+62|0]=0;w[d+24>>2]=0;w[d+28>>2]=0;w[d+20>>2]=0;w[d+16>>2]=b;w[d+12>>2]=a;w[d+8>>2]=c;a=a+f|0;b=0;a:{if(wd(e,c,0)){w[d+56>>2]=1;ob[w[w[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=w[d+32>>2]==1?a:0;break a}ob[w[w[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(w[d+44>>2]){case 0:b=w[d+48>>2]==1?w[d+36>>2]==1?w[d+40>>2]==1?w[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(w[d+32>>2]!=1){if(w[d+48>>2]|w[d+36>>2]!=1|w[d+40>>2]!=1){break a}}b=w[d+24>>2]}jb=d- -64|0;return b}function Vz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=jb-16|0;g=w[a>>2];e=w[a+4>>2];h=w[a+40>>2];i=w[a+36>>2];a:{if(!d){f=h>>12;b=i>>12;break a}l=w[a+8>>2];o=w[a+12>>2];p=w[a+16>>2];q=w[a+32>>2];r=w[a+28>>2];while(1){s=g>>>18|0;m=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;f=0;b=1;while(1){n=f<<1;j=v[n+m>>1];w[(k+8|0)+(f<<2)>>2]=j+((C(v[(n|4)+m>>1]-j|0,s)|0)/16384|0);j=b;b=0;f=1;if(j){continue}break}i=i+r|0;b=i>>12;w[c>>2]=w[c>>2]+C(b,w[k+8>>2]);h=h+q|0;f=h>>12;w[c+4>>2]=w[c+4>>2]+C(f,w[k+12>>2]);e=e+o|0;g=g+l|0;e=g>>>0<l>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=i;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=h;w[a+20>>2]=b;w[a+24>>2]=f}function OC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;d=Jp(b,e+24|0);f=d?y[e+26>>1]|y[e+28>>1]<<16:0;oc(e+8|0,b,f);d=y[e+28>>1];u[a+4|0]=d;u[a+5|0]=d>>>8;d=w[e+24>>2];u[a|0]=d;u[a+1|0]=d>>>8;u[a+2|0]=d>>>16;u[a+3|0]=d>>>24;w[a+8>>2]=w[e+8>>2];w[a+12>>2]=w[e+12>>2];d=w[e+20>>2];w[a+16>>2]=w[e+16>>2];w[a+20>>2]=d;a:{b:{if(!c){break b}d=(f>>>0)%(c>>>0)|0;if(!d){break b}f=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;c=c-d|0;d=S(h|0,g|0,f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}c:{if(d){c=c+w[b+8>>2]|0;break c}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}}w[b+8>>2]=c}jb=e+32|0;return}b=P()|0;Bb(a+8|0);R(b|0);M()}function Iu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{b:{c:{d:{if((b|0)>=0){if((fi(a+8|0)|0)>(b|0)){break d}}c=ba(8)|0;w[114256]=0;b=Q(5,f|0,6646)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}e=w[a+32>>2];a=(e+(b<<5)|0)+480280|0;c=c?134218752:0;w[a>>2]=c|w[a>>2]&-134218753;a=(C(b,896)+e|0)+1075072|0;w[a>>2]=c|w[a>>2]&-134218753;a=y[e+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){d=C(a,896)+e|0;if((b|0)==y[d+1075792>>1]){d=d+1075072|0;w[d>>2]=c|w[d>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}jb=f+16|0;return}a=P()|0;ca(c|0)}R(a|0)}M()}function Fm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;B[b>>3]=d;g=d<-.7853981852531433;if(E(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;B[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;B[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){B[b>>3]=D(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;B[e+8>>3]=(l(2,i-(c<<23)|0),q());c=nu(e+8|0,e,c,1,0);d=B[e>>3];if((g|0)<0){B[b>>3]=-d;c=0-c|0;break a}B[b>>3]=d}jb=e+16|0;return c}function ze(a,b,c,d){var e=0,f=0,g=0;w[a+24>>2]=0;w[a+28>>2]=0;w[a+20>>2]=d;w[a+16>>2]=c;w[a+12>>2]=b;w[a+4>>2]=0;w[a+8>>2]=0;w[a+32>>2]=0;w[a+36>>2]=0;d=0;w[a+40>>2]=0;w[a>>2]=78304;b=Cb(a+44|0,0,48);w[114256]=0;S(985,b|0,2,0)|0;c=w[114256];w[114256]=0;if((c|0)==1){c=P()|0;a=w[b+36>>2];if(a){w[b+40>>2]=a;zb(a)}a=w[b+24>>2];if(a){w[b+28>>2]=a;zb(a)}a=w[b+12>>2];if(a){w[b+16>>2]=a;zb(a)}a=w[b>>2];if(a){w[b+4>>2]=a;zb(a)}R(c|0);M()}v[a+4204>>1]=0;w[a+4196>>2]=1065353216;w[a+4200>>2]=0;c=w[a+16>>2];w[c+946300>>2]=w[c+946300>>2]+1;w[a+24>>2]=a+99&-8;e=w[a+20>>2];if((e|0)!=(c+906300|0)){f=a+4200|0;while(1){b=d+1|0;if(((c+C(b,160)|0)+906300|0)!=(e|0)){g=d>>>0<248;d=b;if(g){continue}}break}u[f|0]=b}return a}function UQ(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;c=Hb(b+16|0,12600);w[114256]=0;U(109,b|0,a|0,c|0);a=w[114256];w[114256]=0;a:{b:{c:{if((a|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}c=w[b>>2];if((c|0)!=w[b+4>>2]){break c}a=0;break a}d=P()|0;if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}a=0;d:{e:{while(1){w[114256]=0;U(9,b+16|0,0,C(d,12)+c|0);c=w[114256];w[114256]=0;if((c|0)==1){break e}w[114256]=0;c=V(110,b+16|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[b+27|0]<0){zb(w[b+16>>2])}a=(c&255)<<24-(d<<3)|a;c=w[b>>2];if(d>>>0>2){break a}d=d+1|0;if(d>>>0>=(w[b+4>>2]-c|0)/12>>>0){break a}continue}break}d=P()|0;if(u[b+27|0]>=0){break d}zb(w[b+16>>2]);break d}d=P()|0}bc(b)}R(d|0);M()}bc(b);jb=b+32|0;return a|0}function Cb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}u[a|0]=b;e=a+c|0;u[e-1|0]=b;if(c>>>0<3){break a}u[a+2|0]=b;u[a+1|0]=b;u[e-3|0]=b;u[e-2|0]=b;if(c>>>0<7){break a}u[a+3|0]=b;u[e-4|0]=b;if(c>>>0<9){break a}e=0-a&3;f=e+a|0;d=C(b&255,16843009);w[f>>2]=d;b=c-e&-4;c=b+f|0;w[c-4>>2]=d;if(b>>>0<9){break a}w[f+8>>2]=d;w[f+4>>2]=d;w[c-8>>2]=d;w[c-12>>2]=d;if(b>>>0<25){break a}w[f+24>>2]=d;w[f+20>>2]=d;w[f+16>>2]=d;w[f+12>>2]=d;w[c-16>>2]=d;w[c-20>>2]=d;w[c-24>>2]=d;w[c-28>>2]=d;c=b;b=f&4|24;c=c-b|0;if(c>>>0<32){break a}d=BV(d,0,1,1);e=nb;b=b+f|0;while(1){w[b+24>>2]=d;w[b+28>>2]=e;w[b+16>>2]=d;w[b+20>>2]=e;w[b+8>>2]=d;w[b+12>>2]=e;w[b>>2]=d;w[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function Qm(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(e){g=w[c+8>>2];h=w[c+4>>2];j=w[a+12>>2];k=w[a>>2];l=w[b+4>>2];m=w[b>>2];while(1){if(d){n=i+j|0;o=C(i,l);b=0;while(1){f=Tb(B[(b+o<<3)+m>>3]*134217728);a=2147483647;a:{if(f>=2147483647){break a}a=-2147483648;if(f<=-2147483648){break a}a=~~f;if(E(f)<2147483648){break a}a=-2147483648}h=((FV(h,1)^270549120)+(g<<2)|0)+2019860093|0;g=C(FV(h,16),5)+g|0;f=Tb(H(G(+(a+(g>>21)|0)*7.450580596923828e-9,1),-1)*32768);b:{if(E(f)<2147483648){a=~~f;break b}a=-2147483648}a=(a|0)>=32767?32767:a;v[w[(b<<2)+k>>2]+(n<<1)>>1]=(a|0)<=-32768?-32768:a;b=b+1|0;if((d|0)!=(b|0)){continue}break}w[c+8>>2]=g;w[c+4>>2]=h}i=i+1|0;if((i|0)!=(e|0)){continue}break}}}function Om(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if(e){g=w[c+8>>2];h=w[c+4>>2];j=w[a+4>>2];k=w[a>>2];l=w[b+4>>2];m=w[b>>2];while(1){if(d){n=C(i,j);o=C(i,l);b=0;while(1){p=(b+n<<1)+k|0;f=Tb(B[(b+o<<3)+m>>3]*134217728);a=2147483647;a:{if(f>=2147483647){break a}a=-2147483648;if(f<=-2147483648){break a}a=~~f;if(E(f)<2147483648){break a}a=-2147483648}h=((FV(h,1)^270549120)+(g<<2)|0)+2019860093|0;g=C(FV(h,16),5)+g|0;f=Tb(H(G(+(a+(g>>21)|0)*7.450580596923828e-9,1),-1)*32768);b:{if(E(f)<2147483648){a=~~f;break b}a=-2147483648}a=(a|0)>=32767?32767:a;v[p>>1]=(a|0)<=-32768?-32768:a;b=b+1|0;if((d|0)!=(b|0)){continue}break}w[c+8>>2]=g;w[c+4>>2]=h}i=i+1|0;if((i|0)!=(e|0)){continue}break}}}function Ds(a,b){var c=0,d=0,e=0;a:{if(x[b|0]){break a}b=bm(9600);if(x[b|0]?b:0){break a}b=bm(C(a,12)+61600|0);if(x[b|0]?b:0){break a}b=bm(9842);if(x[b|0]?b:0){break a}b=10264}b:{while(1){d=x[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=10264;c:{d:{c=x[b|0];e:{f:{if(!(x[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!x[e+1|0]){break e}}if(!Qe(e,10264)){break e}if(Qe(e,9320)){break d}}if(!a){c=61508;if(x[e+1|0]==46){break c}}return 0}c=w[115041];if(c){while(1){if(!Qe(e,c+8|0)){break c}c=w[c+32>>2];if(c){continue}break}}c=fc(36);if(c){b=w[15378];w[c>>2]=w[15377];w[c+4>>2]=b;b=c+8|0;Fb(b,e,d);u[b+d|0]=0;w[c+32>>2]=w[115041];w[115041]=c}c=a|c?c:61508}return c}
function sy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+14>>1]=c;a:{c=y[w[w[a+24>>2]+8>>2]+12>>1];d=b>>>0>c>>>0?c:b;c=w[a+8>>2];b=w[a>>2];if(d>>>0<=c-b>>1>>>0){f=w[a+4>>2];g=f-b>>1;h=d>>>0>g>>>0?g:d;if(h){c=b;while(1){v[c>>1]=y[e+14>>1];c=c+2|0;h=h-1|0;if(h){continue}break}}if(d>>>0>g>>>0){b=(d-g<<1)+f|0;while(1){v[f>>1]=y[e+14>>1];f=f+2|0;if((b|0)!=(f|0)){continue}break}w[a+4>>2]=b;break a}w[a+4>>2]=b+(d<<1);break a}if(b){w[a+4>>2]=b;zb(b);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=0}if((d|0)>=0){sh(a,c>>>0>=2147483646?2147483647:c>>>0>d>>>0?c:d);c=w[a+4>>2];b=c+(d<<1)|0;while(1){v[c>>1]=y[e+14>>1];c=c+2|0;if((b|0)!=(c|0)){continue}break}w[a+4>>2]=b;break a}Mb(a);M()}jb=e+16|0}function yR(a){a=a|0;var b=0;b=4201;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=13206;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=17256;break a}b=4234;break a}b=1518;break a}b=4257;break a}b=4271;break a}b=1874;break a}b=1894;break a}b=4283;break a}b=4215;break a}b=8629;break a}b=7946;break a}b=2446;break a}if((a|0)!=357){break a}b=4168}return rc(b)|0}function Wz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=jb-16|0;g=w[a>>2];f=w[a+4>>2];h=w[a+40>>2];i=w[a+36>>2];a:{if(!d){e=h>>12;b=i>>12;break a}l=w[a+8>>2];n=w[a+12>>2];o=w[a+16>>2];p=w[a+32>>2];q=w[a+28>>2];while(1){r=g>>>10&4194048;m=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=0;b=1;while(1){j=u[e+m|0];w[(k+8|0)+(e<<2)>>2]=((C(u[(e|2)+m|0]-j|0,r)|0)/16384|0)+(j<<8);j=b;b=0;e=1;if(j){continue}break}i=i+q|0;b=i>>12;w[c>>2]=w[c>>2]+C(b,w[k+8>>2]);h=h+p|0;e=h>>12;w[c+4>>2]=w[c+4>>2]+C(e,w[k+12>>2]);f=f+n|0;g=g+l|0;f=g>>>0<l>>>0?f+1|0:f;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=i;w[a>>2]=g;w[a+4>>2]=f;w[a+40>>2]=h;w[a+20>>2]=b;w[a+24>>2]=e}function qx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0);d=w[a>>2];c=c>>>3|0;c=c>>>0>d>>>0?d:c;if(c){a=w[a+20>>2];d=c;while(1){e=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);f=_b(D(D(H(D(G((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);f=_b(D(D(H(D(G((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()),D(1))),D(-1)))*D(32768)));b:{if(D(E(f))<D(2147483648)){e=~~f;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[a+2>>1]=(e|0)<=-32768?-32768:e;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}return c<<3}function rg(a,b,c){var d=0,e=0,f=0,g=0;a:{if(c){u[b+829|0]=c;break a}c=x[b+829|0]}e=w[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=w[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){dh(a,b,(d&240)>>>4|0,0);return}if(!(u[b+872|0]&1)){break b}c=x[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){ch(a,b,f,0);return}if(!(u[b+872|0]&1)){break b}c=x[a+480208|0]&2?c:c+60|0}c:{if(!(!(u[b+872|0]&1)|x[a+480208|0]&2)&(w[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}a=0-(a<<2)|0;break d}a=(d&255)>>>2&60}c=a+c|0;if((e|0)!=1){break c}w[b+88>>2]=w[b+88>>2]|2097152}a=(c|0)>=256?256:c;w[b+688>>2]=(a|0)>0?a:0}function xM(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;if(ju(1,d+24|0)){Ti(w[114084],8510);M()}c=uf(d+8|0,d+24|0);g=Mt(d,d+32|0);e=jb-32|0;jb=e;b=jb-16|0;jb=b;h=jb-16|0;jb=h;a=jb-16|0;jb=a;i=a,j=BV(w[c>>2],w[c+4>>2],1e9,0),w[i>>2]=j;w[a+4>>2]=nb;c=uf(a+8|0,a);f=w[c+4>>2];c=w[c>>2];jb=a+16|0;jb=h+16|0;w[b+8>>2]=c;w[b+12>>2]=f;a=w[b+12>>2];w[e+8>>2]=w[b+8>>2];w[e+12>>2]=a;jb=b+16|0;f=w[e+8>>2];c=w[e+12>>2];a=w[g+4>>2];w[e>>2]=w[g>>2];w[e+4>>2]=a;a=e;c=w[a+4>>2]+c|0;b=w[a>>2];f=f+b|0;w[a+16>>2]=f;w[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=uf(a+24|0,a+16|0);b=w[a+4>>2];a=w[a>>2];jb=e+32|0;w[d+16>>2]=a;w[d+20>>2]=b;a=uf(d+40|0,d+16|0);b=w[a+4>>2];a=w[a>>2];jb=d+48|0;nb=b;return a|0}function lo(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;w[a+4>>2]=0;a:{if(!b){break a}b:{e=w[a+8>>2];f=e<<5;if(f>>>0>=b>>>0){w[a+4>>2]=b;break b}w[d+8>>2]=0;w[d>>2]=0;w[d+4>>2]=0;c:{if((b|0)<0){w[114256]=0;X(525,a|0);a=w[114256];w[114256]=0;if((a|0)==1){break c}M()}w[114256]=0;if(f>>>0<=1073741822){e=e<<6;f=b+31&-32;e=f>>>0<e>>>0?e:f}else{e=2147483647}T(526,d|0,e|0);f=w[114256];w[114256]=0;if((f|0)==1){break c}e=w[a>>2];w[a>>2]=w[d>>2];w[d>>2]=e;f=w[a+4>>2];w[a+4>>2]=b;w[d+4>>2]=f;f=w[a+8>>2];w[a+8>>2]=w[d+8>>2];w[d+8>>2]=f;if(!e){break b}zb(e);break b}b=P()|0;a=w[d>>2];if(a){zb(a)}R(b|0);M()}a=w[a>>2];if(x[c|0]){w[d+4>>2]=0;w[d>>2]=a;Kl(d,b);break a}w[d+4>>2]=0;w[d>>2]=a;Jh(d,b)}jb=d+16|0}function Nd(a,b){var c=D(0),d=D(0),e=D(0),f=D(0),g=D(0);c=A[a+4268>>2];d=D(D(A[a+4224>>2]*D(1.899999976158142))+D(.10000000149011612));f=ai(d>D(1)?D(3.1415927410125732):D(D(D(A[a+4252>>2]*D(125538.046875))+D(125.66371154785156))/c));e=jd(D(D(D(w[((b<<2)+a|0)+4292>>2])*D(-9.965784072875977))/D(c*D(D(A[a+4220>>2]*D(19.899999618530273))+D(.10000000149011612)))));c=D(D(Rg(e,D(D(2)-D(D(2)/d)))+D(-1))/D(D(1)-f));a:{if(c==D(0)){break a}f=D(c+c);d=D(D(-2)-f);c=D(D(d*d)+D(D(c*c)*D(-4)));c=c>D(0)?D(L(c)):D(0);g=D(D(c-d)/f);if(D(E(g))<=D(1)){break a}g=D(D(-D(c+d))/f)}b=(b<<3)+a|0;A[b+4404>>2]=g;A[b+4400>>2]=e;c=A[a+4272>>2];c=D(c*c);d=D(D(1)-c);e=D(e*e);return D(D(D(D(d*d)*e)/D(D(1)-D(c*e)))+c)}function xV(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;b=76832;a:{while(1){b:{c=w[a+4>>2];if((c|0)!=w[a>>2]){if(!Qe(w[b+8>>2],w[c-4>>2])){break b}}d=b+8|0;if((c|0)!=w[a+8>>2]){w[c>>2]=w[d>>2];w[a+4>>2]=c+4;break b}w[114256]=0;T(915,a|0,d|0);c=w[114256];w[114256]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=77348){continue}break}b=77360;while(1){c:{c=w[a+4>>2];if((c|0)!=w[a>>2]){if(!Qe(w[b+8>>2],w[c-4>>2])){break c}}d=b+8|0;if((c|0)!=w[a+8>>2]){w[c>>2]=w[d>>2];w[a+4>>2]=c+4;break c}w[114256]=0;T(915,a|0,d|0);c=w[114256];w[114256]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=77408){continue}break}return}c=P()|0;b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(c|0);M()}function sf(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;w[a+4>>2]=0;Oe(e+8|0,a,1);a:{b:{d=4;c:{if(!x[e+8|0]){break c}d=w[w[a>>2]-12>>2];w[114256]=0;d=w[(a+d|0)+24>>2];f=w[114256];w[114256]=0;d:{if((f|0)==1){break d}w[114256]=0;b=S(1573,d|0,b|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break d}w[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}$(W(0)|0)|0;Me(w[w[a>>2]-12>>2]+a|0,1);b=w[w[a>>2]-12>>2];w[114256]=0;b=w[(a+b|0)+20>>2];c=w[114256];w[114256]=0;e:{if((c|0)!=1){if(!(b&1)){break e}w[114256]=0;_(56);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)==1){break b}R(a|0);M()}aa();d=1}Kd(w[w[a>>2]-12>>2]+a|0,d);jb=e+16|0;return}W(0)|0;Eb()}M()}function bk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;h=d-a|0;if((k|0)<h>>1){break a}g=h+1|0;e=(g<<1)+a|0;f=y[e>>1];i=h+2|0;b:{if((i|0)>=(c|0)){h=w[b>>2];break b}h=w[b>>2];b=h+1074984|0;j=y[e+2>>1];b=w[(b+C(f,896)|0)+680>>2]>w[(b+C(j,896)|0)+680>>2];e=b?e+2|0:e;f=b?j:f;g=b?i:g}i=h+1074984|0;j=y[d>>1];l=w[(i+C(j,896)|0)+680>>2];if((l|0)<w[(i+C(f,896)|0)+680>>2]){break a}while(1){c:{b=e;v[d>>1]=f;if((g|0)>(k|0)){break c}d=g<<1;g=d|1;e=(g<<1)+a|0;f=y[e>>1];m=d+2|0;if((m|0)<(c|0)){n=y[e+2>>1];d=w[(i+C(f,896)|0)+680>>2]>w[(i+C(n,896)|0)+680>>2];e=d?e+2|0:e;g=d?m:g;f=d?n:f}d=b;if(w[(C(f,896)+h|0)+1075664>>2]<=(l|0)){continue}}break}v[b>>1]=j}}function nx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=w[a>>2];c=c>>>4|0;c=c>>>0>d>>>0?d:c;if(c){a=w[a+20>>2];d=c;while(1){e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);l(0,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24));l(1,e|0);f=Tb(H(G(+n(),1),-1)*32768);a:{if(E(f)<2147483648){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;e=x[b+12|0]|x[b+13|0]<<8|(x[b+14|0]<<16|x[b+15|0]<<24);l(0,x[b+8|0]|x[b+9|0]<<8|(x[b+10|0]<<16|x[b+11|0]<<24));l(1,e|0);f=Tb(H(G(+n(),1),-1)*32768);b:{if(E(f)<2147483648){e=~~f;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[a+2>>1]=(e|0)<=-32768?-32768:e;a=a+4|0;b=b+16|0;d=d-1|0;if(d){continue}break}}return c<<4}function yL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;a:{b:{if(!Kc(b,-1)){f=w[a+12>>2];g=w[a+8>>2];if(w[a+24>>2]==w[a+28>>2]){c=-1;if(!(x[a+48|0]&16)){break a}h=w[a+24>>2];i=w[a+20>>2];j=w[a+44>>2];k=w[a+20>>2];w[114256]=0;c=a+32|0;T(71,c|0,0);d=w[114256];w[114256]=0;if((d|0)==1){break b}d=Yb(c);w[114256]=0;T(1592,c|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break b}d=Qb(c);lm(a,d,Db(c)+d|0);yj(a,h-i|0);w[a+44>>2]=w[a+20>>2]+(j-k|0)}w[e+12>>2]=w[a+24>>2]+1;l=a,m=w[of(e+12|0,a+44|0)>>2],w[l+44>>2]=m;if(x[a+48|0]&8){c=Qb(a+32|0);Lg(a,c,c+(f-g|0)|0,w[a+44>>2])}c=Bt(a,Ng(b));break a}c=vj(b);break a}$(W(0)|0)|0;aa();c=-1}jb=e+16|0;return c|0}function Lm(a,b,c){var d=D(0),e=D(0),f=D(0),g=0,h=D(0),i=0,j=0,k=D(0),l=D(0),m=D(0),n=0;f=A[a+12>>2];d=A[a+24>>2];g=jb-32|0;h=A[a+36>>2];k=A[a+48>>2];e=D(h+k);l=A[a>>2];A[g+24>>2]=e-l;m=D(D(f+d)*D(.8660253882408142));e=D(l+D(e*D(.5)));A[g+20>>2]=m-e;A[g+28>>2]=-D(e+m);e=A[a+60>>2];f=D(d-f);d=D(e-D(f*D(.5)));h=D(D(k-h)*D(.8660253882408142));A[g+16>>2]=d-h;A[g+8>>2]=d+h;A[g+12>>2]=-D(e+f);a=0;while(1){i=a<<2;j=i+c|0;f=A[j>>2];n=j;j=i+45760|0;d=A[j>>2];h=A[i+(g+20|0)>>2];k=A[i+(g+8|0)>>2];e=A[j+12>>2];A[n>>2]=D(d*h)-D(k*e);j=b+i|0;l=A[(0-a<<2)+45768>>2];i=5-a<<2;m=A[i+45760>>2];d=D(D(d*k)+D(e*h));A[j>>2]=D(f*l)-D(m*d);A[b+i>>2]=D(m*f)+D(d*l);a=a+1|0;if((a|0)!=3){continue}break}}function ut(a){a=a|0;var b=0,c=0,d=0;c=jb-16|0;jb=c;a:{b:{if(!w[(w[w[a>>2]-12>>2]+a|0)+24>>2]){break b}w[114256]=0;Q(1587,c+8|0,a|0)|0;b=w[114256];w[114256]=0;c:{if((b|0)!=1){d:{if(!x[c+8|0]){break d}b=w[(w[w[a>>2]-12>>2]+a|0)+24>>2];w[114256]=0;b=V(1588,b|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if((b|0)!=-1){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1589,a+b|0,1);b=w[114256];w[114256]=0;if((b|0)!=1){break d}}b=W(0)|0;qt(c+8|0);break c}qt(c+8|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+16|0;return a|0}a=P()|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Iz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-16|0;g=w[a>>2];e=w[a+4>>2];if(d){k=w[a+8>>2];l=w[a+12>>2];m=w[a+24>>2];n=w[a+20>>2];o=w[a+16>>2];while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;b=(g>>>21&2040)+32832|0;p=v[b+6>>1];q=v[b+4>>1];r=v[b+2>>1];s=v[b>>1];j=0;b=1;while(1){f=j<<1;w[(i+8|0)+(j<<2)>>2]=(((C(v[f+h>>1],r)+C(v[(f|-4)+h>>1],s)|0)+C(v[(f|4)+h>>1],q)|0)+C(v[(f|8)+h>>1],p)|0)/16384;f=b;b=0;j=1;if(f){continue}break}w[c>>2]=w[c>>2]+C(w[i+8>>2],n);w[c+4>>2]=w[c+4>>2]+C(w[i+12>>2],m);e=e+l|0;b=g+k|0;e=b>>>0<k>>>0?e+1|0:e;g=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=g;w[a+4>>2]=e}function Rh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:460152;d=w[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=x[b|0];d=a<<24>>24;if((d|0)>=0){w[i>>2]=a;e=(d|0)!=0;break a}a=u[b|0];if(!w[w[114126]>>2]){w[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=w[(a<<2)+61280>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=x[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){w[f>>2]=0;w[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=x[b|0];if((g&192)==128){continue}break}}w[f>>2]=0;w[114084]=25;e=-1;break a}w[f>>2]=d}jb=h+16|0;return e|0}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;u[c|0]=0;k=c+1|0;w[c+12>>2]=k;w[c+8>>2]=c;Ob(a,c+8|0);e=x[c|0];g=(e&252)>>>2|0;d=e&3;if(d){d=-1<<d;l=(d>>>0>=4294967294?-2:d)^-1;while(1){u[c|0]=0;w[c+12>>2]=k;w[c+8>>2]=c;Ob(a,c+8|0);e=x[c|0];d=f;f=i+1|0;d=f?d:d+1|0;i=f;f=d;d=(i<<3)-2|0;h=d&31;if((d&63)>>>0>=32){d=e<<h;e=0}else{d=(1<<h)-1&e>>>32-h;e=e<<h}g=e|g;j=d|j;if((i|0)!=(l|0)|f){continue}break}}f=!j&(g|0)==-1|j?-1:g;Fe(b,f>>>0>=256?256:f);if(w[b+4>>2]!=w[b>>2]){d=c|4;e=0;while(1){w[c>>2]=0;w[c+12>>2]=d;w[c+8>>2]=c;Ob(a,c+8|0);f=w[b>>2];A[f+(e<<2)>>2]=A[c>>2];e=e+1|0;if(e>>>0<w[b+4>>2]-f>>2>>>0){continue}break}}jb=c+16|0}function iq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;if(Mc(b,e+24|0)){d=w[e+28>>2];d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}oc(e+8|0,b,d);f=w[e+28>>2];w[a>>2]=w[e+24>>2];w[a+4>>2]=f;w[a+8>>2]=w[e+8>>2];w[a+12>>2]=w[e+12>>2];f=w[e+20>>2];w[a+16>>2]=w[e+16>>2];w[a+20>>2]=f;a:{b:{if(!c){break b}d=(d>>>0)%(c>>>0)|0;if(!d){break b}f=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;c=c-d|0;d=S(h|0,g|0,f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}c:{if(d){d=c+w[b+8>>2]|0;break c}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;d=V(d|0,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}}w[b+8>>2]=d}jb=e+32|0;return}b=P()|0;Bb(a+8|0);R(b|0);M()}function Nl(a,b,c,d){var e=0,f=0,g=0;u[b+12|0]=x[b+12|0]&240|x[a|0]&15;e=x[a+1|0];Hd(b,d>>>0>e>>>0?e:d);e=x[a+2|0];f=d>>>0>e>>>0?e:d;u[b+13|0]=f;g=e;e=x[a+3|0];e=e>>>0<f>>>0?g:e;u[b+14|0]=d>>>0>e>>>0?e:d;e=x[a+4|0];f=d>>>0>e>>>0?e:d;u[b+15|0]=f;g=e;e=x[a+5|0];e=e>>>0<f>>>0?g:e;u[b+16|0]=d>>>0>e>>>0?e:d;d=x[a+1|0];if(d>>>0>=25?25:d){g=w[b>>2];d=0;while(1){b=g+(d<<2)|0;e=C(d,3)+a|0;f=x[e+6|0]+c<<24>>24;f=(f|0)>=64?64:f;u[b+2|0]=(f|0)>0?f:0;e=x[e+7|0]|x[e+8|0]<<8;v[b>>1]=e;a:{if(!d|e>>>0>255){break a}f=y[b-4>>1];if(f>>>0<=e>>>0){break a}e=e|f&-256;v[b>>1]=e;if(f>>>0<=(e&65535)>>>0){break a}v[b>>1]=e+256}d=d+1|0;b=x[a+1|0];if(d>>>0<(b>>>0>=25?25:b)>>>0){continue}break}}}function QA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);w[b>>2]=d;c=x[a+4|0];v[b+30>>1]=(c>>>0>=64?64:c)<<2;c=x[a+6|0]|x[a+7|0]<<8|(x[a+8|0]<<16|x[a+9|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);w[b+4>>2]=c;e=x[a+10|0]|x[a+11|0]<<8|(x[a+12|0]<<16|x[a+13|0]<<24);a=x[a+6|0]|x[a+7|0]<<8|(x[a+8|0]<<16|x[a+9|0]<<24);a=(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))|0;w[b+8>>2]=a;if(c>>>0>=d>>>0){c=d-1|0;w[b+4>>2]=c}if(a>>>0>d>>>0){w[b+8>>2]=d;a=d}if(a>>>0<c>>>0){w[b+4>>2]=0;w[b+8>>2]=0;return}if(a>>>0>c>>>0){w[b+68>>2]=c;v[b+34>>1]=y[b+34>>1]|2}}function zA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;c=w[a>>2];e=w[a+4>>2]-c>>2;d=e+1|0;if(d>>>0<1073741824){c=w[a+8>>2]-c|0;f=c>>1;d=ud(g+8|0,c>>>0>=2147483644?1073741823:d>>>0<f>>>0?f:d,e,a+8|0);c=w[d+8>>2];b=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);u[c|0]=b;u[c+1|0]=b>>>8;u[c+2|0]=b>>>16;u[c+3|0]=b>>>24;f=w[d+8>>2]+4|0;w[d+8>>2]=f;c=w[a+4>>2];b=w[a>>2];h=c-b|0;e=w[d+4>>2]-h|0;w[d+4>>2]=e;if((h|0)>0){Fb(e,b,h);f=w[d+8>>2];c=w[a+4>>2];e=w[d+4>>2];b=w[a>>2]}w[a>>2]=e;w[d+4>>2]=b;w[a+4>>2]=f;w[d+8>>2]=c;e=w[a+8>>2];w[a+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=e;if((b|0)!=(c|0)){w[d+8>>2]=((b-c|0)+3&-4)+c}if(b){zb(b)}jb=g+32|0;return}Mb(a);M()}function Sk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a|0];if(d&1){u[b+12|0]=x[b+12|0]|1;d=x[a|0]}if(d&2){u[b+12|0]=x[b+12|0]|4;d=x[a|0]}if(d&4){u[b+12|0]=x[b+12|0]|2;d=x[a|0]}if(d&16){u[b+12|0]=x[b+12|0]|16;d=x[a|0]}if(d&32){u[b+12|0]=x[b+12|0]|8}d=x[a+1|0];Hd(b,d>>>0>=25?25:d);u[b+15|0]=x[a+2|0];u[b+16|0]=x[a+3|0];u[b+13|0]=x[a+4|0];u[b+14|0]=x[a+5|0];g=w[b>>2];b=w[b+4>>2];if((g|0)!=(b|0)){b=b-g>>2;h=b>>>0<=1?1:b;b=0;while(1){d=b<<2;e=d+g|0;f=a+d|0;d=x[f+6|0]|x[f+7|0]<<8;v[e>>1]=d;a:{if(!b){break a}i=d;d=y[e-4>>1];if(i>>>0>=d>>>0){break a}v[e>>1]=d+1}d=(x[f+8|0]|x[f+9|0]<<8)<<16>>16>>c;d=(d|0)>=64?64:d;u[e+2|0]=(d|0)>0?d:0;b=b+1|0;if((h|0)!=(b|0)){continue}break}}}function iU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb+-64|0;jb=e;f=w[a+28>>2];Jg(w[w[f>>2]-12>>2]+f|0,0);f=w[w[b>>2]+4>>2];if(f){h=w[a+28>>2];g=w[a+12>>2];i=f;f=w[a+8>>2]+f|0;g=i>>>0>f>>>0?g+1|0:g;w[e+56>>2]=f;w[e+60>>2]=g;w[e+16>>2]=f;w[e+20>>2]=g;w[e+48>>2]=0;w[e+52>>2]=0;w[e+8>>2]=0;w[e+12>>2]=0;rf(h,e+8|0)}f=e+24|0;rd(f,w[a+28>>2]);g=w[e+36>>2];w[e+40>>2]=w[e+32>>2];w[e+44>>2]=g;ob[d|0](w[a+28>>2],c,w[w[b>>2]+8>>2]);c=w[b>>2];b=Uj(f,w[c>>2]+w[a+32>>2]|0,y[c+12>>1]);w[114256]=0;a=Z(402,a|0,c|0,b|0,e+40|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=e- -64|0;return a|0}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}function FT(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);w[a+32>>2]=0;w[a+28>>2]=w[a+28>>2]&-7|2;a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}b:{switch(b|0){case 0:A[a+4220>>2]=c;return;case 1:A[a+4224>>2]=c;return;case 2:A[a+4228>>2]=c;Xj(a);return;case 3:u[a+4240|0]=c>=D(.5);Xj(a);return;case 4:c=_b(D(c*D(32)));b=5;c:{if(c>=D(2147483648)){break c}d:{if(c<=D(-2147483648)){break d}if(D(E(c))<D(2147483648)){b=~~c}else{b=-2147483648}if((b|0)<0){break d}b=(b|0)>=5?5:b;break c}b=0}w[a+4232>>2]=b;return;case 5:u[a+4241|0]=c>=D(.5);return;case 6:u[a+4242|0]=c>=D(.5);return;case 7:u[a+4244|0]=c>=D(.5);return;case 8:if(c==D(0)){Wj(a)}B[a+4256>>3]=c;break;default:break b}}}function YP(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)==1){break c}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}d=w[a+24>>2];w[c+8>>2]=b;b=ec(b);w[114256]=0;w[c+12>>2]=b;b=w[c+12>>2];w[c>>2]=w[c+8>>2];w[c+4>>2]=b;Y(1399,c+16|0,d|0,c|0,1);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=rc(u[c+27|0]<0?w[c+16>>2]:c+16|0);if(u[c+27|0]>=0){break b}zb(w[c+16>>2]);break b}$(W(0)|0)|0;b=0;w[114256]=0;Y(1333,2021,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=c+32|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Sj(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a:{b:{switch(b|0){case 0:b=Hb(d,11761);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];break a;case 1:b=Hb(d,11786);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];break a;case 2:b=Hb(d,11734);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];break a;case 3:b=Hb(d,11708);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];break a;case 4:b=Hb(d,8801);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];break a;case 5:break b;default:break a}}b=Hb(d,3460);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2]}jb=d+16|0}function hx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=D(0),g=0,h=D(0),i=D(0);f=A[e+4>>2];e=C(w[a>>2],x[a+34|0]&64?2:1);c=c>>>2|0;g=c>>>0>e>>>0?e:c;a:{if(!g){break a}e=g;c=b;while(1){f=D(H((l(2,(x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24))&2147483647),q()),f));c=c+4|0;e=e-1|0;if(e){continue}break}c=f==D(0);if(c|!g){break a}i=c?D(1):D(D(1)/f);c=w[a+20>>2];a=g;while(1){h=_b(D(D(H(D(G(D(i*(l(2,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24)),q())),D(1))),D(-1)))*D(32768)));b:{if(D(E(h))<D(2147483648)){e=~~h;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[c>>1]=(e|0)<=-32768?-32768:e;b=b+4|0;c=c+2|0;a=a-1|0;if(a){continue}break}}if(d){A[d>>2]=f}return g<<2}function dP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-48|0;jb=c;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;T(1454,c+8|0,0);b=w[114256];w[114256]=0;a:{b:{c:{if((b|0)!=1){f=w[c+12>>2];b=w[c+8>>2];w[c+40>>2]=a;d:{if((b|0)!=(f|0)){while(1){d=w[b>>2];w[114256]=0;d=Q(5,c+24|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break c}w[114256]=0;Q(1455,c+40|0,d|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break d}if(u[c+35|0]<0){zb(w[d>>2])}b=b+4|0;if((f|0)!=(b|0)){continue}break}b=w[c+8>>2]}if(b){w[c+12>>2]=b;zb(b)}jb=c+48|0;return}b=P()|0;if(u[c+35|0]>=0){break b}zb(w[d>>2]);break b}b=P()|0;break a}b=P()|0}d=w[c+8>>2];if(!d){break a}w[c+12>>2]=d;zb(d)}bc(a);R(b|0);M()}function QT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;d=x[c+11|0];f=d<<24>>24;e=x[b+11|0];g=e<<24>>24<0;a:{e=g?w[b+4>>2]:e;h=(f|0)<0?w[c+4>>2]:d;d=e+h|0;b:{if(d>>>0>=4294967280){w[114256]=0;X(103,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}M()}j=w[b>>2];c:{if(d>>>0<=10){u[a+11|0]=e;d=a;break c}w[114256]=0;i=(d|15)+1|0;d=V(22,i|0)|0;k=w[114256];w[114256]=0;if((k|0)==1){break b}w[a>>2]=d;w[a+4>>2]=e;w[a+8>>2]=i|-2147483648}if(e){Fb(d,g?j:b,e)}u[d+e|0]=0;b=w[c>>2];w[114256]=0;S(2,a|0,((f|0)<0?b:c)|0,h|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}}function su(a,b){var c=0,d=0,e=0;a:{b:{c:{if(!x[b+21|0]){c=-1;break c}c=w[a+1396>>2];d:{if((c|0)>9){break d}if(!c){w[a+1392>>2]=0}while(1){if(x[a+1376|0]?0:w[a+1384>>2]){break d}c=Dc(a);if((c|0)==-1){break d}d=w[a+1396>>2];w[a+1396>>2]=d+8;w[a+1392>>2]=w[a+1392>>2]+(c<<d);if((d|0)<17){continue}break}}d=w[a+1392>>2];c=v[(((d&1023)<<1)+b|0)+36>>1];e:{if((c|0)>=0){e=d;d=c&65535;c=x[d+w[b+8>>2]|0];w[a+1392>>2]=e>>>c;c=w[a+1396>>2]-c|0;w[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break e}c=hg(a,b)}if(w[b+2092>>2]<=(c|0)?x[b+23|0]:0){break a}if((c|0)>=0){break b}if(x[a+1376|0]){break c}if(w[a+1384>>2]){break b}}w[a+100>>2]=21}return c}ha(3778,9008,1793,2236);M()}function RC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=w[a+4>>2];e=w[a>>2];d=c-e>>4;if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{c:{c=b-d|0;f=w[a+8>>2];g=w[a+4>>2];d:{if(c>>>0<=f-g>>4>>>0){il(a,c);break d}d=w[a>>2];g=g-d>>4;b=c+g|0;if(b>>>0>=268435456){break c}d=f-d|0;f=d>>3;b=gi(e+8|0,d>>>0>=2147483632?268435455:b>>>0<f>>>0?f:b,g,a+8|0);w[114256]=0;T(433,b|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break b}w[114256]=0;T(338,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}xg(b)}jb=e+32|0;break a}Mb(a);M()}a=P()|0;xg(b);R(a|0);M()}return}if(b>>>0<d>>>0){b=e+(b<<4)|0;if((b|0)!=(c|0)){while(1){c=Bb(c-16|0);if((b|0)!=(c|0)){continue}break}}w[a+4>>2]=b}}function Jz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-16|0;g=w[a>>2];e=w[a+4>>2];if(d){j=w[a+8>>2];k=w[a+12>>2];l=w[a+24>>2];m=w[a+20>>2];n=w[a+16>>2];while(1){h=(((e&2147483647)<<1|g>>>31)&-2)+n|0;b=(g>>>21&2040)+32832|0;o=v[b+6>>1];p=v[b+4>>1];q=v[b+2>>1];r=v[b>>1];f=0;b=1;while(1){w[(i+8|0)+(f<<2)>>2]=(((C(u[f+h|0],q)+C(u[(f|-2)+h|0],r)|0)+C(u[(f|2)+h|0],p)|0)+C(u[(f|4)+h|0],o)<<8)/16384;s=b;b=0;f=1;if(s){continue}break}w[c>>2]=w[c>>2]+C(w[i+8>>2],m);w[c+4>>2]=w[c+4>>2]+C(w[i+12>>2],l);e=e+k|0;b=g+j|0;e=b>>>0<j>>>0?e+1|0:e;g=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=g;w[a+4>>2]=e}function dF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;lc(b,0);e=d+8|0;Vb(e,1,a+33|0,13);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=b+43;Q(200,d+24|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}e=x[a+50|0]|x[a+51|0]<<8|(x[a+52|0]<<16|x[a+53|0]<<24);w[b>>2]=e;w[b+24>>2]=x[a+54|0]|x[a+55|0]<<8;f=x[a+56|0];v[b+30>>1]=(f>>>0>=64?64:f)<<2;f=x[a+57|0]|x[a+58|0]<<8|(x[a+59|0]<<16|x[a+60|0]<<24);w[b+4>>2]=f;g=x[a+61|0]|x[a+62|0]<<8|(x[a+63|0]<<16|x[a+64|0]<<24);c=c?f?e:g:g;w[b+8>>2]=c;if(!(!x[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0)){v[b+34>>1]=y[b+34>>1]|2}jb=d+32|0;return}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}function OD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;a:{b:{c=w[a+4>>2];c:{if((c|0)!=w[a+8>>2]){w[c>>2]=w[b>>2];d=w[b+4>>2];w[c+4>>2]=d;if(d){w[d+4>>2]=w[d+4>>2]+1}d=w[b+12>>2];w[c+8>>2]=w[b+8>>2];w[c+12>>2]=d;w[a+4>>2]=c+16;break c}c=c-w[a>>2]|0;e=c>>4;d=e+1|0;if(d>>>0>=268435456){break b}g=c>>3;c=gi(f+8|0,c>>>0>=2147483632?268435455:d>>>0<g>>>0?g:d,e,a+8|0);d=w[c+8>>2];w[d>>2]=w[b>>2];e=w[b+4>>2];w[d+4>>2]=e;if(e){w[e+4>>2]=w[e+4>>2]+1}e=w[b+12>>2];w[d+8>>2]=w[b+8>>2];w[d+12>>2]=e;w[c+8>>2]=w[c+8>>2]+16;w[114256]=0;T(338,a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}xg(c)}jb=f+32|0;return}Mb(a);M()}a=P()|0;xg(c);R(a|0);M()}function qD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;ah(e+8|0,c);c=e+20|0;a:{b:{c:{d:{if(u[d+11|0]>=0){f=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+8>>2];break d}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,c|0,d|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}}w[114256]=0;c=e+32|0;w[e+4>>2]=c;w[e>>2]=e+8;U(51,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}b=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(e+8|0)){continue}break}}R(b|0);M()}function nk(a,b,c,d){var e=0,f=0;a:{if(!d){break a}if(c){u[b+835|0]=c;break a}c=x[b+835|0]}e=w[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{e:{if(!d){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(x[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(x[a+480209|0]&16)){break b}c=c<<2;break c}if(x[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!(u[a+1074319|0]&1)){break d}c=(c|0)/4<<24>>24;break d}if(x[a+480209|0]&16){break b}if(!f){c=c<<2;if(!(e&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0}if(!c){break b}}v[b+796>>1]=0;a=w[b+692>>2]+c|0;a=(a|0)>=256?256:a;w[b+692>>2]=(a|0)>0?a:0}}function mB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;lc(b,0);d=c+8|0;Vb(d,2,a+1|0,8);w[114256]=0;w[c+28>>2]=22;w[c+24>>2]=b+43;Q(200,c+24|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(u[c+19|0]<0){zb(w[c+8>>2])}w[b+24>>2]=x[a+78|0]|x[a+79|0]<<8;e=x[a+58|0]|x[a+59|0]<<8|(x[a+60|0]<<16|x[a+61|0]<<24);w[b>>2]=e;f=x[a+62|0]|x[a+63|0]<<8|(x[a+64|0]<<16|x[a+65|0]<<24);w[b+4>>2]=f;d=x[a+66|0]|x[a+67|0]<<8|(x[a+68|0]<<16|x[a+69|0]<<24);w[b+8>>2]=d;v[b+30>>1]=(x[a+73|0]<<1)+2;v[b+34>>1]=y[b+34>>1]&65533|x[a|0]>>>6&2;if(d>>>0>e>>>0){w[b+8>>2]=e;d=e}if(d>>>0<f>>>0){w[b+4>>2]=d}jb=c+32|0;return}a=P()|0;if(u[c+19|0]<0){zb(w[c+8>>2])}R(a|0);M()}function NE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;bh(e+8|0,c);c=e+20|0;a:{b:{c:{d:{if(u[d+11|0]>=0){f=w[d+4>>2];w[c>>2]=w[d>>2];w[c+4>>2]=f;w[c+8>>2]=w[d+8>>2];break d}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,c|0,d|0,f|0);c=w[114256];w[114256]=0;if((c|0)==1){break c}}w[114256]=0;c=e+32|0;w[e+4>>2]=c;w[e>>2]=e+8;U(51,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}b=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(e+8|0)){continue}break}}R(b|0);M()}function qp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],32)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+32;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+24|0]=0;u[b+25|0]=0;u[b+26|0]=0;u[b+27|0]=0;u[b+28|0]=0;u[b+29|0]=0;u[b+30|0]=0;u[b+31|0]=0;u[b+16|0]=0;u[b+17|0]=0;u[b+18|0]=0;u[b+19|0]=0;u[b+20|0]=0;u[b+21|0]=0;u[b+22|0]=0;u[b+23|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0}jb=c+16|0;return e|0}function dw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=D(0),i=0,j=0,k=D(0);g=jb-16|0;jb=g;e=v[d+2>>1];f=v[d>>1];i=!y[b>>1]|(e|0)<(f|0)|A[c>>2]<=D(0)|(e-f|0)>32766;if(!i){v[a>>1]=3;v[a+28>>1]=65472;w[a+8>>2]=w[a+4>>2];w[g+12>>2]=1065353216;e=a+4|0;ew(e,128,g+12|0);w[a+32>>2]=0;v[a+30>>1]=0;w[a+20>>2]=w[a+16>>2];f=v[d>>1];v[a+28>>1]=f;b=y[b>>1];b=b>>>0>=32767?32767:b;v[a+30>>1]=b;h=D(E(A[c>>2]));A[a+32>>2]=h;Fe(e,(v[d+2>>1]-f|0)+1|0);e=v[d+2>>1];d=v[d>>1];h=Rg(h,D(D(1)/D(b|0)));if((d|0)<=(e|0)){f=w[a+4>>2];c=v[a+28>>1];while(1){j=f+(d-c<<2)|0,k=Nt(h,d),A[j>>2]=k;b=(d|0)==(e|0);d=d+1|0;if(!b){continue}break}}ii(a)}jb=g+16|0;return!i|0}function TC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-48|0;jb=e;c=w[a+8>>2];d=w[a>>2];f=w[w[d>>2]+36>>2];w[114256]=0;c=S(f|0,d|0,c|0,1)|0;d=w[114256];w[114256]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}w[114256]=0;T(431,b|0,64);c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;c=Q(241,a|0,e+8|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break b}if(!c){break c}c=x[e+8|0];if(!c){break c}while(1){w[114256]=0;d=Q(432,a|0,e+8|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=x[e+8|0];if(d>>>0>63){break d}Fb(w[b>>2]+C(d,33)|0,e+8|0,33)}if(c&255){continue}break}}Bb(a);jb=e+48|0;return}}b=P()|0;Bb(a);R(b|0);M()}function dC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=jb+-64|0;jb=b;c=-1;a:{if(!(ob[w[w[a>>2]+36>>2]](a,0,1084)|0)){break a}b:{if(z[a+12>>2]<=1079){if(ob[w[w[a>>2]+24>>2]](a)>>>0<1080){break b}}w[a+12>>2]=1080}d=b+60|0;zp(a,d);w[b+44>>2]=40;c=0;if(!yp(d,b+40|0)){break a}c:{if(z[a+12>>2]<=19){if(ob[w[w[a>>2]+24>>2]](a)>>>0<20){break c}}w[a+12>>2]=20}c=1;while(1){d=0;e=0;f=0;g=0;if(xp(a,b+8|0)){e=y[b+34>>1];f=x[b+32|0];g=x[b+33|0];d=y[b+30>>1]}h=(((g>>>0>64)+h|0)+(f>>>0>15)|0)+(((e<<8|(e&65280)>>>8)&65535)>>>0>((d<<8|(d&65280)>>>8)&65535)<<1>>>0)|0;d=c&65535;c=c+1|0;if(d>>>0<31){continue}break}c=z[b+44>>2]>=h>>>0}jb=b- -64|0;return c|0}function ti(a,b,c,d){var e=0,f=0,g=0,h=0;h=1;f=w[a+24>>2];g=w[f+484360>>2];e=x[a+30|0];if(e>>>0>=(w[f+484364>>2]-g>>>5&255)>>>0){e=x[f+484376|0]}g=g+(e<<5)|0;e=w[g>>2];a:{if(w[g+4>>2]-e>>1>>>0<=b>>>0){break a}e=y[e+(b<<1)>>1];g=w[f+484348>>2];f=w[f+484344>>2];b:{if(e>>>0>=((g-f|0)/52&65535)>>>0){break b}g=f+C(e,52)|0;if(w[g>>2]==w[g+4>>2]){break b}h=w[(f+C(e,52)|0)+12>>2]}if(c>>>0>=h>>>0){break a}e=w[a>>2];if(!((w[a+4>>2]-e|0)/12>>>0>b>>>0&z[(C(b,12)+e|0)+4>>2]>c>>>0)){Te(a,0);e=w[a>>2];if((w[a+4>>2]-e|0)/12>>>0<=b>>>0){break a}}e=w[C(b,12)+e>>2]+(c>>>3&536870908)|0;f=1<<c;if(!d){w[e>>2]=w[e>>2]&(f^-1);return}w[e>>2]=f|w[e>>2];jo(a,b,c)}}function Fo(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}u[a+820|0]=0;return}u[a+820|0]=1;return}u[a+820|0]=2;return}u[a+820|0]=3;return}u[a+724|0]=x[a+724|0]&254;return}u[a+724|0]=x[a+724|0]|1;return}u[a+736|0]=x[a+736|0]&254;return}u[a+736|0]=x[a+736|0]|1;return}u[a+748|0]=x[a+748|0]&254;return}u[a+748|0]=x[a+748|0]|1;return}if(w[c+480180>>2]!=16777216){break a}c=a;a=x[a+748|0];u[c+748|0]=(b|0)==13?a&238|1:a|17}}function gh(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(e){u[e|0]=0}f=w[a+484344>>2];a:{if(((w[a+484348>>2]-f|0)/52&65535)>>>0<=b>>>0){break a}f=f+C(b,52)|0;if(w[f>>2]==w[f+4>>2]){break a}g=ld(f);f=w[f>>2]+C(C(c,g)+d|0,6)|0;g=x[f+5|0];d=2;b:{switch(x[f+3|0]-10|0){case 7:j=w[a+480180>>2]==4;case 2:case 4:d=1;break;case 0:break b;default:break a}}h=C(b,52);b=w[(h+w[a+484344>>2]|0)+12>>2]+(c^-1)|0;b=b>>>0>d>>>0?d:b;if(!b){break a}while(1){i=C(ld(w[a+484344>>2]+h|0),6);c=i+f|0;if(x[c+3|0]!=34){break a}d=g<<8;d=j?g>>>0<256?d+-8192|0:d:d;f=x[(f+i|0)+5|0];b=b-1|0;if(e){u[e|0]=1}g=d|f;f=c;if(b){continue}break}}return g|0}function UE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;if(Xb(a,f+8|0)){a:{d=jb-48|0;jb=d;e=a;a=x[f+8|0];c=a>>>0<c>>>0?a:c;e=Vc(d+24|0,e,c,1);h=w[e>>2];i=w[e+4>>2];a=w[e+12>>2];g=w[e+8>>2];w[114256]=0;Y(209,d+8|0,3,(i?i:(a|0)!=(g|0)?g:0)|0,h|0);a=w[114256];w[114256]=0;b:{c:{if((a|0)!=1){w[114256]=0;w[d+4>>2]=11;w[d>>2]=b;Q(200,d|0,d+8|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}if(u[d+19|0]<0){zb(w[d+8>>2])}a=w[e+8>>2];if(a){w[e+12>>2]=a;zb(a)}jb=d+48|0;g=!c|(h|0)!=0;break a}b=P()|0;break b}b=P()|0;if(u[d+19|0]>=0){break b}zb(w[d+8>>2])}a=w[e+8>>2];if(a){w[e+12>>2]=a;zb(a)}R(b|0);M()}}jb=f+16|0;return g|0}function On(a,b,c){var d=0,e=0;d=w[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=x[b+834|0];if(c){u[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(c){u[b+833|0]=c;break a}c=x[b+833|0]}b:{if(!(u[b+872|0]&1)){break b}d=w[b+700>>2];if(!d|!(c&255)){break b}e=b;c:{if(!(!(x[a+480208|0]&16)|w[a+480180>>2]==4)){a=w[((c&15)<<2)+(x[a+1074312|0]&128?30192:30128)>>2];c=BV(a,a>>31,d,d>>31)+32768|0;a=nb;c=CV(c,c>>>0<32768?a+1|0:a,65536,0);b=c;a=nb;c=(a|0)>=0&c>>>0>=2147483647|(a|0)>0;b=c?2147483647:b;a=c?0:a;a=(a|0)<0&b>>>0<=2147483648|(a|0)<-1?-2147483648:b;a=a-((a|0)==(d|0))|0;break c}a=d+(c&255)|0;a=(a|0)>=65535?65535:a}w[e+700>>2]=a}}function oD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=w[a>>2];d=w[a+4>>2]-e|0;if(d>>>0<b>>>0){a:{e=b-d|0;g=w[a+8>>2];f=w[a+4>>2];if(e>>>0<=g-f>>>0){b=a;if(e){a=e+f|0;while(1){u[f|0]=x[c|0];f=f+1|0;if((a|0)!=(f|0)){continue}break}}else{a=f}w[b+4>>2]=a;break a}d=w[a>>2];b=f-d|0;h=e+b|0;if((h|0)>=0){i=e;g=g-d|0;d=g<<1;h=g>>>0>=1073741823?2147483647:d>>>0>h>>>0?d:h;if(h){e=Kb(h)}else{e=0}d=b+e|0;g=i+d|0;b=d;while(1){u[b|0]=x[c|0];b=b+1|0;if((g|0)!=(b|0)){continue}break}b=d;d=w[a>>2];c=f-d|0;b=b-c|0;if((c|0)>0){Fb(b,d,c)}w[a+8>>2]=e+h;w[a+4>>2]=g;w[a>>2]=b;if(d){zb(d)}break a}Mb(a);M()}return}if(b>>>0<d>>>0){w[a+4>>2]=b+e}}function bx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=D(0);e=w[a>>2];c=c>>>3|0;c=c>>>0>e>>>0?e:c;if(c){g=A[d>>2];a=w[a+20>>2];d=c;while(1){f=_b(D(D(H(D(G(D(g*(l(2,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24)),q())),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;f=_b(D(D(H(D(G(D(g*(l(2,x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24)),q())),D(1))),D(-1)))*D(32768)));b:{if(D(E(f))<D(2147483648)){e=~~f;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[a+2>>1]=(e|0)<=-32768?-32768:e;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}return c<<3}function gp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;d=Mc(b,e+24|0);d=d?w[e+28>>2]:0;oc(e+8|0,b,d);f=w[e+28>>2];w[a>>2]=w[e+24>>2];w[a+4>>2]=f;w[a+8>>2]=w[e+8>>2];w[a+12>>2]=w[e+12>>2];f=w[e+20>>2];w[a+16>>2]=w[e+16>>2];w[a+20>>2]=f;a:{b:{if(!c){break b}d=(d>>>0)%(c>>>0)|0;if(!d){break b}f=w[b+8>>2];g=w[b>>2];h=w[w[g>>2]+36>>2];w[114256]=0;c=c-d|0;d=S(h|0,g|0,f|0,c|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}c:{if(d){c=c+w[b+8>>2]|0;break c}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}}w[b+8>>2]=c}jb=e+32|0;return}b=P()|0;Bb(a+8|0);R(b|0);M()}function Gm(a){var b=0,c=0,d=0,e=0,f=0;f=jb-32|0;jb=f;a:{c=w[a>>2];d=w[a+4>>2]-c>>5;b=d+1|0;if(b>>>0<134217728){c=w[a+8>>2]-c|0;e=c>>4;d=Vh(f+8|0,c>>>0>=2147483616?134217727:b>>>0<e>>>0?e:b,d,a+8|0);b=w[d+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+24>>2]=0;w[b+28>>2]=0;w[b+16>>2]=0;w[b+20>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;w[114256]=0;c=V(22,16)|0;e=w[114256];w[114256]=0;if((e|0)!=1){w[c+4>>2]=0;w[c+8>>2]=0;w[c+12>>2]=75696;w[c>>2]=75656;w[b+28>>2]=0;w[b+20>>2]=0;w[b+24>>2]=0;w[b+16>>2]=c;w[b+12>>2]=c+12;w[d+8>>2]=b+32;w[114256]=0;T(134,a|0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}a=P()|0;Bj(d);R(a|0);M()}Mb(a);M()}Bj(d);jb=f+32|0}function YD(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;lc(b,0);d=c+8|0;Vb(d,1,a,13);w[114256]=0;w[c+28>>2]=22;w[c+24>>2]=b+43;Q(200,c+24|0,d|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(u[c+19|0]<0){zb(w[c+8>>2])}w[b+24>>2]=x[a+32|0]|x[a+33|0]<<8|(x[a+34|0]<<16|x[a+35|0]<<24);v[b+34>>1]=y[b+34>>1]&65533|(x[a+13|0]|x[a+14|0]<<8)<<1&2;w[b>>2]=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);w[b+4>>2]=x[a+20|0]|x[a+21|0]<<8|(x[a+22|0]<<16|x[a+23|0]<<24);w[b+8>>2]=x[a+24|0]|x[a+25|0]<<8|(x[a+26|0]<<16|x[a+27|0]<<24);a=x[a+15|0];v[b+30>>1]=(a>>>0>=64?64:a)<<2;jb=c+32|0;return}a=P()|0;if(u[c+19|0]<0){zb(w[c+8>>2])}R(a|0);M()}function CB(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{b:{c:{if(w[a+8>>2]<<5>>>0>=b>>>0){break c}if((b|0)<0){break a}w[114256]=0;w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;T(528,c+16|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a>>2];w[c+12>>2]=0;w[c+8>>2]=b;d=w[a+4>>2];w[114256]=0;w[c+4>>2]=d&31;w[c>>2]=b+(d>>>3&536870908);U(529,c+16|0,c+8|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){break b}b=w[a>>2];w[a>>2]=w[c+16>>2];w[c+16>>2]=b;d=w[a+4>>2];w[a+4>>2]=w[c+20>>2];w[c+20>>2]=d;d=w[a+8>>2];w[a+8>>2]=w[c+24>>2];w[c+24>>2]=d;if(!b){break c}zb(b)}jb=c+32|0;return}a=P()|0;b=w[c+16>>2];if(b){zb(b)}R(a|0);M()}Mb(a);M()}function rB(a){a=a|0;var b=0,c=0,d=0;c=jb-16|0;jb=c;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;b=Kb(127);w[a>>2]=b;d=b+127|0;w[a+8>>2]=d;Cb(b,128,127);w[a+20>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+4>>2]=d;w[114256]=0;b=V(22,127)|0;d=w[114256];w[114256]=0;a:{b:{if((d|0)!=1){w[a+12>>2]=b;d=b+127|0;w[a+20>>2]=d;Cb(b,64,127);w[a+16>>2]=d;w[114256]=0;u[c+15|0]=0;S(552,a+24|0,127,c+15|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}w[a+36>>2]=-1;w[a+40>>2]=108855296;w[a+44>>2]=0;w[a+48>>2]=0;v[a+52>>1]=0;jb=c+16|0;return a|0}c=P()|0;break a}c=P()|0;b=w[a+12>>2];if(!b){break a}w[a+16>>2]=b;zb(b)}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(c|0);M()}function gJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;i=jb-416|0;jb=i;d=i+416|0;w[i+12>>2]=d;h=jb-144|0;jb=h;w[h+28>>2]=h+132;c=h+32|0;es(a+8|0,c,h+28|0,e,f,g);w[h+16>>2]=0;w[h+20>>2]=0;w[h+12>>2]=c;c=i+16|0;g=as(c,w[i+12>>2]);e=jb-16|0;jb=e;w[e+12>>2]=w[a+8>>2];f=be(e+8|0,e+12|0);w[114256]=0;a=Zl(c,h+12|0,g,h+16|0);g=w[114256];w[114256]=0;a:{if((g|0)!=1){Lc(f);jb=e+16|0;break a}a=P()|0;Lc(f);R(a|0);M()}if((a|0)==-1){hj(8352);M()}w[i+12>>2]=(a<<2)+c;jb=h+144|0;e=w[i+12>>2];a=jb-16|0;jb=a;w[a+8>>2]=b;while(1){if((c|0)!=(e|0)){pt(a+8|0,w[c>>2]);c=c+4|0;continue}break}jb=a+16|0;jb=d;return w[a+8>>2]}function xf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{e=w[a+28>>2];if((e|0)>=(b|0)){g=w[a+24>>2];break a}i=a+32|0;f=w[a+20>>2];d=w[a+16>>2];c=e;while(1){b:{if(d>>>0>=f>>>0){c=w[a>>2];f=ob[w[w[c>>2]+28>>2]](c,i,w[a+8>>2],1024)|0;w[a+20>>2]=f;w[a+16>>2]=0;w[a+8>>2]=w[a+8>>2]+f;if(!f){break b}d=0;c=w[a+28>>2]}h=d+1|0;w[a+16>>2]=h;d=x[(a+d|0)+32|0];e=c+8|0;w[a+28>>2]=e;g=w[a+24>>2]|d<<c;w[a+24>>2]=g;d=h;c=e;if((c|0)<(b|0)){continue}break a}break}c=ba(8)|0;w[114256]=0;b=V(132,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){a=P()|0;ca(c|0);R(a|0);M()}ka(b|0,75512,133);M()}w[a+28>>2]=e-b;w[a+24>>2]=g>>>b;return(-1<<b^-1)&g}function ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=w[a>>2];g=w[a+4>>2];if(d){i=b+24|0;b=w[a+8>>2];j=w[a+12>>2];k=w[a+24>>2];l=w[a+20>>2];m=w[a+16>>2];while(1){e=(g<<1)+m|0;f=(((h>>>16|0)+4&131064)<<1)+i|0;e=(((((C(v[e+4>>1],v[f+10>>1])+C(v[e+2>>1],v[f+8>>1])|0)+C(v[e+6>>1],v[f+12>>1])|0)+C(v[e+8>>1],v[f+14>>1])|0)/2|0)+((((C(v[e-4>>1],v[f+2>>1])+C(v[e-6>>1],v[f>>1])|0)+C(v[e-2>>1],v[f+4>>1])|0)+C(v[e>>1],v[f+6>>1])|0)/2|0)|0)/16384|0;w[c>>2]=w[c>>2]+C(e,l);w[c+4>>2]=w[c+4>>2]+C(e,k);g=g+j|0;e=b+h|0;g=e>>>0<b>>>0?g+1|0:g;h=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=h;w[a+4>>2]=g}
function cD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;a:{if(!b){break a}c=w[a>>2];if(!(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0)){break a}if(b>>>0<=3){c=jb-16|0;jb=c;b:{if(!b){break b}e=w[a>>2];if(!(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],b)|0)){break b}e=0;while(1){u[c+11|0]=0;c:{if(b>>>0>d>>>0){Xb(a,c+11|0);g=u[c+11|0];e=g>>>31|0;break c}g=0-e|0}u[(c+12|0)+d|0]=g;d=d+1|0;if((d|0)!=4){continue}break}d=w[c+12>>2]}jb=c+16|0;break a}c=Nc(a,f+8|0);d=c?w[f+8>>2]:0;c=w[a>>2];b=b-4|0;d:{if(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0){b=b+w[a+8>>2]|0;break d}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=f+16|0;return d|0}function Gz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=w[a>>2];f=w[a+4>>2];b=w[a+40>>2];i=w[a+36>>2];a:{if(!d){e=b>>12;j=i>>12;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){i=i+o|0;j=i>>12;e=(f<<1)+m|0;g=(h>>>21&2040)+32832|0;g=(((C(v[e>>1],v[g+2>>1])+C(v[e-2>>1],v[g>>1])|0)+C(v[e+2>>1],v[g+4>>1])|0)+C(v[e+4>>1],v[g+6>>1])|0)/16384|0;w[c>>2]=w[c>>2]+C(j,g);b=b+n|0;e=b>>12;w[c+4>>2]=w[c+4>>2]+C(g,e);f=f+l|0;h=h+k|0;f=h>>>0<k>>>0?f+1|0:f;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=i;w[a>>2]=h;w[a+4>>2]=f;w[a+40>>2]=b;w[a+20>>2]=j;w[a+24>>2]=e}function Um(a,b,c,d,e,f){var g=0,h=0,i=0,j=D(0);g=jb+-64|0;jb=g;i=w[a+24>>2];v[i+480214>>1]=0;u[i+1304512|0]=w[a+52>>2]!=0;w[g+44>>2]=f;w[g+40>>2]=e;w[g+36>>2]=d;w[g+32>>2]=c;while(1){a:{if(!w[(g+32|0)+(h<<2)>>2]){e=h;break a}e=4;h=h+1|0;if((h|0)!=4){continue}}break}j=A[a+48>>2];c=w[a+32>>2];f=0;w[g+24>>2]=0;w[g+20>>2]=b;w[g+16>>2]=e;w[g+8>>2]=c;w[g+4>>2]=0;A[g+28>>2]=j;w[g>>2]=82412;w[g+12>>2]=g+32;while(1){if(b){c=w[a+24>>2];w[g+56>>2]=82256;c=ki(c,b>>>0>=134217727?134217727:b,g,g+56|0);f=c+f|0;b=b-c|0;if(c){continue}}break}if(!(w[a+52>>2]!=1|f)){a=w[a+24>>2];w[a+480208>>2]=w[a+480208>>2]&-513}jb=g- -64|0;return f}function Tm(a,b,c,d,e,f){var g=0,h=0,i=0,j=D(0);g=jb+-64|0;jb=g;i=w[a+24>>2];v[i+480214>>1]=0;u[i+1304512|0]=w[a+52>>2]!=0;w[g+44>>2]=f;w[g+40>>2]=e;w[g+36>>2]=d;w[g+32>>2]=c;while(1){a:{if(!w[(g+32|0)+(h<<2)>>2]){e=h;break a}e=4;h=h+1|0;if((h|0)!=4){continue}}break}j=A[a+48>>2];c=w[a+32>>2];f=0;w[g+24>>2]=0;w[g+20>>2]=b;w[g+16>>2]=e;w[g+8>>2]=c;w[g+4>>2]=0;A[g+28>>2]=j;w[g>>2]=82468;w[g+12>>2]=g+32;while(1){if(b){c=w[a+24>>2];w[g+56>>2]=82256;c=ki(c,b>>>0>=134217727?134217727:b,g,g+56|0);f=c+f|0;b=b-c|0;if(c){continue}}break}if(!(w[a+52>>2]!=1|f)){a=w[a+24>>2];w[a+480208>>2]=w[a+480208>>2]&-513}jb=g- -64|0;return f}function Jw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;a:{d=w[b+4>>2];b:{if(!d){break b}c=d-1&65535;d=y[a+480190>>1];c=c>>>0<d>>>0?c:d;if(!c){break b}d=c;while(1){c:{if(w[w[b>>2]+(c>>>3&536870908)>>2]>>>c&1){break c}if(zn(a,c&65535)){g=Hb(e+8|0,17256);w[114256]=0;w[e+28>>2]=32;w[e+24>>2]=((c<<5)+a|0)+946304;Q(200,e+24|0,g|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}if(u[e+19|0]<0){zb(w[g>>2])}h=h+1|0}if(c>>>0<2){break c}f=y[a+480190>>1];if((f|0)!=(c|0)){break c}v[a+480190>>1]=f-1}c=c-1|0;d=d-1|0;if(d&65535){continue}break}}jb=e+32|0;return h&65535}a=P()|0;if(u[e+19|0]<0){zb(w[g>>2])}R(a|0);M()}function Xv(a){var b=0,c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;b=w[a>>2];c=w[a+4>>2]-b>>11;a:{b:{if(c>>>0>=w[a+8>>2]-b>>11>>>0){break b}w[114256]=0;c=Z(989,f+8|0,c|0,c|0,a+8|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){d=w[a+4>>2];b=w[a>>2];g=d-b|0;e=w[c+4>>2]-g|0;w[c+4>>2]=e;if((g|0)>0){Fb(e,b,g);d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=w[c+8>>2];w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+2047&-2048)+d}if(!b){break b}zb(b);break b}$(W(0)|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break a}}jb=f+32|0;return}W(0)|0;Eb();M()}function Fu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb-16|0;jb=e;a:{b:{c:{d=a+8|0;d:{if(!jg(d)){if((b|0)<0|(Rj(d)|0)<=(b|0)){break d}a=(w[a+32>>2]+C(b+1&65535,104)|0)+484414|0;v[a>>1]=y[a>>1]&64511|(c?1024:0);break b}d=jg(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}c=ba(8)|0;w[114256]=0;a=Q(5,e|0,2427)|0;b=w[114256];w[114256]=0;e:{if((b|0)!=1){b=Pb(c,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}b=P()|0;ca(c|0)}R(b|0);M()}a=w[(w[a+32>>2]+(b<<2)|0)+900384>>2];if(!a){break b}u[a+15|0]=x[a+15|0]&253|(c?2:0)}jb=e+16|0;return}M()}function Tt(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-208|0;jb=f;w[f+204>>2]=c;c=f+160|0;Cb(c,0,40);w[f+200>>2]=w[f+204>>2];a:{if((St(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=w[a+76>>2]>=0;g=w[a>>2];if(w[a+72>>2]<=0){w[a>>2]=g&-33}b:{c:{d:{if(!w[a+48>>2]){w[a+48>>2]=80;w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;h=w[a+44>>2];w[a+44>>2]=f;break d}if(w[a+16>>2]){break c}}c=-1;if(Vt(a)){break b}}c=St(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ob[w[a+36>>2]](a,0,0)|0;w[a+48>>2]=0;w[a+44>>2]=h;w[a+28>>2]=0;b=w[a+20>>2];w[a+16>>2]=0;w[a+20>>2]=0;c=b?c:-1}b=a;a=w[a>>2];w[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}jb=f+208|0;return e}function ys(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;jb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=x[b|0];e=d<<24>>24;if((e|0)>=0){w[a>>2]=d;e=(e|0)!=0;break a}d=u[b|0];if(!w[w[114126]>>2]){w[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=w[(d<<2)+61280>>2];if(d<<C(c,6)-6<0&c>>>0<=3){break b}c=x[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){w[a>>2]=c;e=2;break a}d=x[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){w[a>>2]=c;e=3;break a}b=x[b+3|0]-128|0;if(b>>>0>63){break b}w[a>>2]=b|c<<6;e=4;break a}w[114084]=25;e=-1}return e|0}function DR(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=rc(17256);break b}w[114256]=0;c=Q(5,b|0,a|0)|0;a=w[114256];w[114256]=0;c:{d:{if((a|0)!=1){w[114256]=0;T(1318,b+16|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break d}a=rc(u[b+27|0]<0?w[b+16>>2]:b+16|0);if(u[b+27|0]<0){zb(w[b+16>>2])}if(u[c+11|0]>=0){break b}zb(w[c>>2]);break b}a=W(0)|0;break c}a=W(0)|0;if(u[c+11|0]>=0){break c}zb(w[c>>2])}$(a|0)|0;a=0;w[114256]=0;na(1314,6914,0,0,0,0,0,0,0,0);c=w[114256];w[114256]=0;if((c|0)==1){break a}aa()}jb=b+32|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function CF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{d:{if((d|0)==1){break d}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break d}d=w[a+24>>2];w[c+8>>2]=b;b=ec(b);w[114256]=0;w[c+12>>2]=b;b=w[c+12>>2];w[c>>2]=w[c+8>>2];w[c+4>>2]=b;d=Ha(1397,d|0,c|0,1)|0;b=w[114256];w[114256]=0;e=kb;if((b|0)!=1){break c}}$(W(0)|0)|0;w[114256]=0;Y(1333,4829,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break b}aa();d=0;e=0}b=e;jb=c+16|0;a=d;break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}kb=b;return a|0}function Hz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=w[a>>2];f=w[a+4>>2];b=w[a+40>>2];i=w[a+36>>2];a:{if(!d){e=b>>12;j=i>>12;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){i=i+o|0;j=i>>12;e=f+m|0;g=(h>>>21&2040)+32832|0;g=(((C(u[e|0],v[g+2>>1])+C(u[e-1|0],v[g>>1])|0)+C(u[e+1|0],v[g+4>>1])|0)+C(u[e+2|0],v[g+6>>1])<<8)/16384|0;w[c>>2]=w[c>>2]+C(j,g);b=b+n|0;e=b>>12;w[c+4>>2]=w[c+4>>2]+C(g,e);f=f+l|0;h=h+k|0;f=h>>>0<k>>>0?f+1|0:f;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=i;w[a>>2]=h;w[a+4>>2]=f;w[a+40>>2]=b;w[a+20>>2]=j;w[a+24>>2]=e}function bw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=w[a+8>>2];e=w[a>>2];if(d-e>>2>>>0>=b>>>0){f=w[a+4>>2];g=f-e>>2;h=b>>>0>g>>>0?g:b;if(h){d=e;while(1){A[d>>2]=A[c>>2];d=d+4|0;h=h-1|0;if(h){continue}break}}if(b>>>0>g>>>0){b=(b-g<<2)+f|0;while(1){A[f>>2]=A[c>>2];f=f+4|0;if((b|0)!=(f|0)){continue}break}w[a+4>>2]=b;return}w[a+4>>2]=e+(b<<2);return}if(e){w[a+4>>2]=e;zb(e);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;d=0}if(b>>>0<1073741824){e=d>>1;Bh(a,d>>>0>=2147483644?1073741823:b>>>0<e>>>0?e:b);d=w[a+4>>2];b=d+(b<<2)|0;while(1){A[d>>2]=A[c>>2];d=d+4|0;if((b|0)!=(d|0)){continue}break}w[a+4>>2]=b;return}Mb(a);M()}function BF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;w[114256]=0;X(1335,a|0);f=w[114256];w[114256]=0;a:{b:{c:{d:{if((f|0)==1){break d}w[114256]=0;X(1361,b|0);f=w[114256];w[114256]=0;if((f|0)==1){break d}f=w[a+24>>2];w[e+8>>2]=b;b=ec(b);w[114256]=0;w[e+12>>2]=b;b=w[e+12>>2];w[e>>2]=w[e+8>>2];w[e+4>>2]=b;Ga(1402,f|0,e|0,c|0,d|0,1);c=w[114256];w[114256]=0;b=1;if((c|0)!=1){break c}}$(W(0)|0)|0;w[114256]=0;Y(1333,4798,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break b}aa();b=0}jb=e+16|0;break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}return b|0}function ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{c:{d=w[a>>2];if(w[a+4>>2]-d>>1>>>0<=b>>>0){break c}d=y[d+(b<<1)>>1];if(!nh(a,b)){break b}c=w[a+24>>2];e=w[c+484360>>2];g=w[c+484364>>2];if((e|0)==(g|0)){break b}while(1){c=w[e+4>>2]-w[e>>2]>>1;h=c>>>0>=65535?65535:c;if(h){f=0;while(1){d:{if(!((a|0)!=(e|0)|(b|0)!=(f|0))|(d|0)!=y[w[e>>2]+(f<<1)>>1]){break d}c=iw(w[a+24>>2]+484344|0,d,0);if((c|0)==65535){break d}d=w[a>>2];if(w[a+4>>2]-d>>1>>>0<=b>>>0){break c}v[d+(b<<1)>>1]=c;break a}f=f+1|0;if((h|0)!=(f|0)){continue}break}}e=e+32|0;if((g|0)!=(e|0)){continue}break}break b}Bc(a);M()}c=d}return c&65535}function ni(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=w[a>>2];h=w[a+4>>2];if((g|0)!=(h|0)){a=g;while(1){c=4194304;b=w[a>>2];a:{if(b>>>0>=4194304){c=67108864;if(b>>>0<67108865){break a}}w[a>>2]=c;b=c}c=d;d=b;c=c+b|0;b=e;b=c>>>0<d>>>0?b+1|0:b;d=c;e=b;a=a+4|0;if((h|0)!=(a|0)){continue}break}a=h-g|0;e=EV(d,e,a>>2,0);k=e;c=((nb&1)<<31|e>>>1)&2147483647;d=a<<22;e=0;a=g;while(1){f=w[a>>2];b=f>>>8|0;f=c+(f<<24)|0;b=b+l|0;b=EV(f,c>>>0>f>>>0?b+1|0:b,k,l);i=nb;j=!i&(b|0)==-1|(i|0)!=0;b=j?-1:b;w[a>>2]=b;f=d;d=f-b|0;e=e-((b>>>0>f>>>0)+(j?0:i)|0)|0;a=a+4|0;if((h|0)!=(a|0)){continue}break}w[g>>2]=d+w[g>>2]}}function GJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;w[f+40>>2]=b;a:{if(!(w[c+4>>2]&1)){c=ob[w[w[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Sb(a,c);w[114256]=0;a=V(1736,a|0)|0;b=w[114256];w[114256]=0;b:{if((b|0)!=1){Ab(f+24|0);c:{if(e){Ud(f+24|0,a);break c}Td(f+24|0,a)}g=f,h=zd(f+24|0),w[g+16>>2]=h;while(1){g=f,h=ff(f+24|0),w[g+8>>2]=h;if(!qe(f+16|0,f+8|0)){c=w[f+40>>2];$b(f+24|0);break a}a=w[w[f+16>>2]>>2];w[114256]=0;Q(1759,f+40|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){Oh(f+16|0);continue}break}c=P()|0;$b(f+24|0);break b}c=P()|0;Ab(f+24|0)}R(c|0);M()}jb=f+48|0;return c|0}function fz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=w[a>>2];g=w[a+4>>2];if(d){i=b+24|0;b=w[a+8>>2];j=w[a+12>>2];k=w[a+24>>2];l=w[a+20>>2];m=w[a+16>>2];while(1){e=g+m|0;f=(((h>>>16|0)+4&131064)<<1)+i|0;e=(((((C(u[e+2|0],v[f+10>>1])+C(u[e+1|0],v[f+8>>1])|0)+C(u[e+3|0],v[f+12>>1])|0)+C(u[e+4|0],v[f+14>>1])<<8)/2|0)+((((C(u[e-2|0],v[f+2>>1])+C(u[e-3|0],v[f>>1])|0)+C(u[e-1|0],v[f+4>>1])|0)+C(u[e|0],v[f+6>>1])<<8)/2|0)|0)/16384|0;w[c>>2]=w[c>>2]+C(e,l);w[c+4>>2]=w[c+4>>2]+C(e,k);g=g+j|0;e=b+h|0;g=e>>>0<b>>>0?g+1|0:g;h=e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=h;w[a+4>>2]=g}function Wv(a){var b=0,c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;b=w[a>>2];c=w[a+4>>2]-b>>2;a:{b:{if(c>>>0>=w[a+8>>2]-b>>2>>>0){break b}w[114256]=0;c=Z(990,f+8|0,c|0,c|0,a+8|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){d=w[a+4>>2];b=w[a>>2];g=d-b|0;e=w[c+4>>2]-g|0;w[c+4>>2]=e;if((g|0)>0){Fb(e,b,g);d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=w[c+8>>2];w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+3&-4)+d}if(!b){break b}zb(b);break b}$(W(0)|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break a}}jb=f+32|0;return}W(0)|0;Eb();M()}function Oe(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;u[a|0]=0;f=dg(w[w[b>>2]-12>>2]+b|0);e=w[w[b>>2]-12>>2]+b|0;a:{b:{if(f){if(w[e+72>>2]){sm(w[(w[w[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(w[(w[w[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=d+24|0;Sb(c,w[w[b>>2]-12>>2]+b|0);w[114256]=0;f=V(1561,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}Ab(d+24|0);c=Vd(d+16|0,b);e=Ne(d+8|0);while(1){d:{if(!Wh(c,e)){break d}if(!Ld(f,1,tf(c))){break d}eg(c);continue}break}if(!ue(c,e)){break c}Kd(w[w[b>>2]-12>>2]+b|0,6)}g=a,h=dg(w[w[b>>2]-12>>2]+b|0),u[g|0]=h;break b}Kd(e,4)}jb=d+32|0;return}a=P()|0;Ab(d+24|0);R(a|0);M()}function my(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){d=w[b+4>>2];while(1){d=d-32|0;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;c=c-32|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[d+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[d+20>>2]=w[c+20>>2];f=w[c+16>>2];w[d+12>>2]=w[c+12>>2];w[d+16>>2]=f;w[c+12>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;v[d+28>>1]=y[c+28>>1];w[d+24>>2]=w[c+24>>2];d=w[b+4>>2]-32|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function SJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;w[f+40>>2]=b;a:{if(!(w[c+4>>2]&1)){c=ob[w[w[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Sb(a,c);w[114256]=0;a=V(1704,a|0)|0;b=w[114256];w[114256]=0;b:{if((b|0)!=1){Ab(f+24|0);c:{if(e){Ud(f+24|0,a);break c}Td(f+24|0,a)}g=f,h=zd(f+24|0),w[g+16>>2]=h;while(1){g=f,h=hf(f+24|0),w[g+8>>2]=h;if(!qe(f+16|0,f+8|0)){c=w[f+40>>2];Gb(f+24|0);break a}a=u[w[f+16>>2]];w[114256]=0;Q(1585,f+40|0,a|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){Ph(f+16|0);continue}break}c=P()|0;Gb(f+24|0);break b}c=P()|0;Ab(f+24|0)}R(c|0);M()}jb=f+48|0;return c|0}function ML(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;w[114256]=0;Q(14,c+8|0,a|0)|0;d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)!=1){d:{if(!x[c+8|0]){break d}d=Vd(c,a);w[114256]=0;Q(1585,d|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){if(!qf(d)){break d}b=w[w[a>>2]-12>>2];w[114256]=0;T(1564,a+b|0,1);b=w[114256];w[114256]=0;if((b|0)!=1){break d}}b=W(0)|0;id(c+8|0);break c}id(c+8|0);break b}b=W(0)|0}$(b|0)|0;b=w[w[a>>2]-12>>2];w[114256]=0;X(17,a+b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}aa()}jb=c+16|0;return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function DD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=w[b+12>>2];w[d+8>>2]=w[b+8>>2];w[d+12>>2]=c;c=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=c;c=Xp(d);w[a+28>>2]=0;w[a+32>>2]=0;u[a+24|0]=0;w[a+12>>2]=0;w[a+16>>2]=0;u[a+8|0]=0;w[a+4>>2]=c;w[a+36>>2]=0;w[a+20>>2]=0;w[a>>2]=75232;f=a+40|0;c=0;while(1){e=f+C(c,12)|0;w[e>>2]=0;w[e+4>>2]=0;u[e+8|0]=0;c=c+1|0;if((c|0)!=16){continue}break}if(x[a+24|0]){e=a+232|0;c=0;while(1){w[e+(c<<2)>>2]=c;c=c+1|0;if((c|0)!=16){continue}break}}w[a>>2]=75348;c=w[b+4>>2];w[a+296>>2]=w[b>>2];w[a+300>>2]=c;c=w[b+12>>2];w[a+304>>2]=w[b+8>>2];w[a+308>>2]=c;jb=d+16|0;return a|0}function rx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0);d=w[a>>2];c=c>>>3|0;c=c>>>0>d>>>0?d:c;if(c){a=w[a+20>>2];d=c;while(1){f=_b(D(D(H(D(G((l(2,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24)),q()),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;f=_b(D(D(H(D(G((l(2,x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24)),q()),D(1))),D(-1)))*D(32768)));b:{if(D(E(f))<D(2147483648)){e=~~f;break b}e=-2147483648}e=(e|0)>=32767?32767:e;v[a+2>>1]=(e|0)<=-32768?-32768:e;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}return c<<3}function lc(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;c=w[a+20>>2];if(c){zb(c+-64|0)}w[a>>2]=0;w[a+4>>2]=0;v[a+32>>1]=64;w[a+24>>2]=8363;w[a+28>>2]=16777344;w[a+36>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;u[a+39|0]=0;u[a+40|0]=0;u[a+41|0]=0;u[a+42|0]=0;c=y[a+34>>1]&-25151;v[a+34>>1]=(b|0)==4?c|32:c;b=Hb(d+8|0,17256);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=a+43;Q(200,d+24|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}b=a+68|0;a=0;while(1){c=b+(a<<2)|0;a=a+1|0;w[c>>2]=a<<11;if((a|0)!=9){continue}break}jb=d+32|0;return}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}function Sm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a:{if(b>>>0>65535){break a}f=w[a+24>>2];a=w[f+484344>>2];if(((w[f+484348>>2]-a|0)/52&65535)>>>0<=(b&65535)>>>0){break a}g=C(b,52)+a|0;if(w[g>>2]==w[g+4>>2]|(c|0)<0|(d|0)<0){break a}b=C(b,52)+a|0;if(w[b+12>>2]<=(c|0)|e>>>0>5|y[f+480188>>1]<=d>>>0){break a}a=C(ld(b),c)+(d&65535)|0;b=w[b>>2];b:{c:{switch(e|0){case 0:a=b+C(a,6)|0;break b;case 1:a=(b+C(a,6)|0)+1|0;break b;case 2:a=(b+C(a,6)|0)+2|0;break b;case 3:a=(b+C(a,6)|0)+3|0;break b;case 4:a=(b+C(a,6)|0)+4|0;break b;case 5:break c;default:break a}}a=(b+C(a,6)|0)+5|0}h=x[a|0]}return h|0}function BA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=w[b+4>>2];if(e){d=32-e|0;g=d>>>0<c>>>0;h=g?d:c;f=-1<<e&-1>>>d-h;d=w[b>>2];f=f&(w[d>>2]^-1);if(f){w[a>>2]=d;i=a,j=AV(f),w[i+4>>2]=j;return}if(!g){b=c+e|0;w[a+4>>2]=b&31;w[a>>2]=(((c|0)>=0?b>>>5|0:(b-31|0)/32|0)<<2)+d;return}w[b>>2]=d+4;c=c-h|0}if(c>>>0>=32){d=w[b>>2];while(1){e=w[d>>2];if((e|0)!=-1){w[a>>2]=d;i=a,j=AV(e^-1),w[i+4>>2]=j;return}d=d+4|0;w[b>>2]=d;c=c-32|0;if(c>>>0>31){continue}break}}a:{if(!c){d=w[b>>2];break a}d=w[b>>2];b=(w[d>>2]^-1)&-1>>>32-c;if(!b){break a}w[a>>2]=d;i=a,j=AV(b),w[i+4>>2]=j;return}w[a+4>>2]=c;w[a>>2]=d}function jo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;w[f+12>>2]=c;a:{b:{if(y[a+28>>1]!=(b|0)){v[a+28>>1]=b;g=a+16|0;w[g>>2]=w[a+12>>2];h=a+12|0;break b}h=a+12|0;g=a+16|0;if(w[a+12>>2]!=w[g>>2]){break a}}i=1;d=w[a+24>>2];j=w[d+484360>>2];e=x[a+30|0];if(e>>>0>=(w[d+484364>>2]-j>>>5&255)>>>0){e=x[d+484376|0]}b=y[w[(e<<5)+j>>2]+(b<<1)>>1];e=w[d+484348>>2];d=w[d+484344>>2];c:{if(b>>>0>=((e-d|0)/52&65535)>>>0){break c}e=d+C(b,52)|0;if(w[e>>2]==w[e+4>>2]){break c}i=w[(d+C(b,52)|0)+12>>2]}Qh(h,i)}b=w[a+20>>2];a=w[a+16>>2];d:{if((b|0)!=(a|0)){w[a>>2]=c;w[g>>2]=a+4;break d}Di(h,f+12|0)}jb=f+16|0}function fF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;lc(b,0);c=d+8|0;Vb(c,1,a+33|0,13);w[114256]=0;w[d+28>>2]=22;w[d+24>>2]=b+43;Q(200,d+24|0,c|0)|0;c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}e=x[a+50|0]|x[a+51|0]<<8;w[b>>2]=e;w[b+24>>2]=x[a+52|0]|x[a+53|0]<<8;c=x[a+54|0];v[b+30>>1]=(c>>>0>=64?64:c)<<2;f=x[a+55|0]|x[a+56|0]<<8;w[b+4>>2]=f;c=x[a+57|0]|x[a+58|0]<<8;w[b+8>>2]=c;if((c|0)!=65535){break b}w[b+4>>2]=0;w[b+8>>2]=0;break a}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}if(!x[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}v[b+34>>1]=y[b+34>>1]|2}jb=d+32|0}function Ay(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if((b|0)==(c|0)){b=x[d+11|0];f=b<<24>>24<0;c=f?w[d+4>>2]:b;if(c>>>0>=4294967280){break b}h=w[d>>2];c:{d:{if(c>>>0>=11){g=(c|15)+1|0;b=Kb(g);w[a+8>>2]=g|-2147483648;w[a>>2]=b;w[a+4>>2]=c;a=b;break d}u[a+11|0]=c;if(!c){break c}}d=f?h:d;b=c+d|0;while(1){u[a|0]=x[d|0];a=a+1|0;d=d+1|0;if((b|0)!=(d|0)){continue}break}}u[a|0]=0;break a}No(e,c,d);w[114256]=0;U(73,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[e+11|0]>=0){break a}zb(w[e>>2]);break a}a=P()|0;if(u[e+11|0]<0){zb(w[e>>2])}R(a|0);M()}zc(a);M()}jb=e+16|0}function WI(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=Rr(b);cf(k,a);b=w[k>>2];u[c|0]=b;u[c+1|0]=b>>>8;u[c+2|0]=b>>>16;u[c+3|0]=b>>>24;bf(k,a);ne(i,k);$b(k);Td(k,a);ne(h,k);$b(k);l=d,m=se(a),w[l>>2]=m;l=e,m=re(a),w[l>>2]=m;Ad(k,a);_c(f,k);Gb(k);Ud(k,a);ne(g,k);$b(k);a=af(a);break a}a=Qr(b);cf(k,a);b=w[k>>2];u[c|0]=b;u[c+1|0]=b>>>8;u[c+2|0]=b>>>16;u[c+3|0]=b>>>24;bf(k,a);ne(i,k);$b(k);Td(k,a);ne(h,k);$b(k);l=d,m=se(a),w[l>>2]=m;l=e,m=re(a),w[l>>2]=m;Ad(k,a);_c(f,k);Gb(k);Ud(k,a);ne(g,k);$b(k);a=af(a)}w[j>>2]=a;jb=k+16|0}function $U(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=d+8|0;Vb(e,2,a+2|0,28);w[114256]=0;w[d+28>>2]=32;w[d+24>>2]=b+492;Q(200,d+24|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}e=b+236|0;f=c+1|0;c=0;while(1){v[e+(c<<1)>>1]=x[(a+c|0)+31|0]+f;c=c+1|0;if((c|0)!=120){continue}break}w[b>>2]=(x[a+223|0]|x[a+224|0]<<8)<<5;a=a+158|0;sw(x[a|0]&15,x[a+1|0]&15,x[a+2|0]&15,x[a+3|0]&15,x[a+4|0]&15,a+5|0,b+48|0);sw(x[a|0]>>>4|0,x[a+1|0]>>>4|0,x[a+2|0]>>>4|0,x[a+3|0]>>>4|0,x[a+4|0]>>>4|0,a+35|0,b+68|0);jb=d+32|0;return}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}function QF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(wd(a,w[b+8>>2],f)){ql(b,c,d,e);return}g=x[b+53|0];j=w[a+12>>2];u[b+53|0]=0;h=x[b+52|0];u[b+52|0]=0;m=a+16|0;ol(m,b,c,d,e,f);k=x[b+53|0];g=g|k;l=x[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(x[b+54|0]){break a}b:{if(l){if(w[b+24>>2]==1){break a}if(x[a+8|0]&2){break b}break a}if(!k){break b}if(!(u[a+8|0]&1)){break a}}v[b+52>>1]=0;ol(i,b,c,d,e,f);k=x[b+53|0];g=k|g;l=x[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}u[b+53|0]=(g&255)!=0;u[b+52|0]=(h&255)!=0}function hD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;a:{c=w[a+4>>2];b:{if((c|0)!=w[a+8>>2]){i=a,j=Fb(c,b,48)+48|0,w[i+4>>2]=j;break b}c=(c-w[a>>2]|0)/48|0;d=c+1|0;if(d>>>0>=89478486){break a}e=c<<1;c=bl(f+8|0,c>>>0>=44739242?89478485:d>>>0<e>>>0?e:d,c,a+8|0);d=Fb(w[c+8>>2],b,48)+48|0;w[c+8>>2]=d;g=w[a+4>>2];b=w[a>>2];h=g-b|0;e=w[c+4>>2]+C((h|0)/-48|0,48)|0;w[c+4>>2]=e;if((h|0)>0){Fb(e,b,h);d=w[c+8>>2];g=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=d;w[c+8>>2]=g;d=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=d;al(c)}jb=f+32|0;return}Mb(a);M()}function cJ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=Xr(b);cf(k,a);b=w[k>>2];u[c|0]=b;u[c+1|0]=b>>>8;u[c+2|0]=b>>>16;u[c+3|0]=b>>>24;bf(k,a);_c(i,k);Gb(k);Td(k,a);_c(h,k);Gb(k);l=d,m=se(a),u[l|0]=m;l=e,m=re(a),u[l|0]=m;Ad(k,a);_c(f,k);Gb(k);Ud(k,a);_c(g,k);Gb(k);a=af(a);break a}a=Wr(b);cf(k,a);b=w[k>>2];u[c|0]=b;u[c+1|0]=b>>>8;u[c+2|0]=b>>>16;u[c+3|0]=b>>>24;bf(k,a);_c(i,k);Gb(k);Td(k,a);_c(h,k);Gb(k);l=d,m=se(a),u[l|0]=m;l=e,m=re(a),u[l|0]=m;Ad(k,a);_c(f,k);Gb(k);Ud(k,a);_c(g,k);Gb(k);a=af(a)}w[j>>2]=a;jb=k+16|0}function ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],27)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+27;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+23|0]=0;u[b+24|0]=0;u[b+25|0]=0;u[b+26|0]=0;u[b+16|0]=0;u[b+17|0]=0;u[b+18|0]=0;u[b+19|0]=0;u[b+20|0]=0;u[b+21|0]=0;u[b+22|0]=0;u[b+23|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0}jb=c+16|0;return e|0}function WP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)==1){break c}w[114256]=0;X(1361,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}e=w[a+24>>2];w[d+8>>2]=b;b=ec(b);w[114256]=0;w[d+12>>2]=b;b=w[d+12>>2];w[d>>2]=w[d+8>>2];w[d+4>>2]=b;Y(1401,e|0,d|0,(c|0)!=0|0,1);c=w[114256];w[114256]=0;b=1;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5950,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Tp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=8;a:{b:{c:{d:{e:{f:{g:{d=x[a+3|0];switch(d|0){case 17:case 18:break b;case 9:break c;case 11:break d;case 10:break f;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break g;default:break a}}e=x[a|0];if(!e){break a}c=0;switch(d|0){case 9:break c;case 11:break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break e;case 10:break f;default:break b}}c=8;break b}c=e;if(!(e&7)){break b}}return C(b+1>>>1|0,x[a+1|0]==1?1:2)+(((d|0)==11)<<4)|0}c=16}f=C(C(c>>>3|0,b),x[a+1|0]==1?1:2)+(((d|0)==11)<<4)|0}return f|0}function DF(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-32|0;jb=k;m=w[c>>2];l=w[c+8>>2];c=w[c+4>>2];w[k+8>>2]=c;w[k+12>>2]=l;w[114256]=0;w[k+24>>2]=c;w[k+28>>2]=l;w[k+20>>2]=m;w[k+16>>2]=d;c=w[k+20>>2];w[k>>2]=w[k+16>>2];w[k+4>>2]=c;a=Ia(1328,a|0,b|0,k|0)|0;b=w[114256];w[114256]=0;a:{b:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,6355,e|0,f|0,g|0,h|0,0,0,i|0,j|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}aa();a=-255}jb=k+32|0;break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}return a|0}function kU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;c=w[a>>2];a:{if((c|0)!=w[a+4>>2]){while(1){c=w[(g<<2)+c>>2];b:{if(u[c+51|0]>=0){w[d+8>>2]=w[c+48>>2];f=w[c+44>>2];w[d>>2]=w[c+40>>2];w[d+4>>2]=f;break b}me(d,w[c+40>>2],w[c+44>>2])}c=x[d+11|0];f=c<<24>>24;h=x[b+11|0];i=h<<24>>24;c=(f|0)<0?w[d+4>>2]:c;e=0;c:{if((c|0)!=(((i|0)<0?w[b+4>>2]:h)|0)){break c}e=1;if(!c){break c}e=!Jb((f|0)<0?w[d>>2]:d,(i|0)<0?w[b>>2]:b,c)}c=e;if((f|0)<0){zb(w[d>>2])}e=w[w[a>>2]+(g<<2)>>2];if(c){break a}g=g+1|0;c=w[a>>2];if(g>>>0<w[a+4>>2]-c>>2>>>0){continue}break}}e=0}a=e;jb=d+16|0;return a|0}function Ek(a,b){var c=0,d=0,e=0,f=0,g=0;d=w[a>>2];e=w[a+4>>2];a:{if((d|0)==(e|0)){e=d;break a}v[d>>1]=0;if(x[d+2|0]>b>>>0){u[d+2|0]=b;e=w[a+4>>2];d=w[a>>2]}c=d+4|0;if((e|0)==(c|0)){break a}while(1){f=y[d+4>>1];g=y[d>>1];v[d+4>>1]=f>>>0>g>>>0?f:g;if(x[d+6|0]>b>>>0){u[d+6|0]=b;e=w[a+4>>2]}d=c;c=d+4|0;if((e|0)!=(c|0)){continue}break}d=w[a>>2]}c=x[a+14|0];b=(e-d>>>2|0)-1|0;if(c>>>0>(b&255)>>>0){u[a+14|0]=b;c=b}if(x[a+13|0]>(c&255)>>>0){u[a+13|0]=c}c=x[a+16|0];if(c>>>0>(b&255)>>>0){u[a+16|0]=b;c=b}if(x[a+15|0]>(c&255)>>>0){u[a+15|0]=c}c=x[a+17|0];if(!((c|0)==255|c>>>0<=(b&255)>>>0)){u[a+17|0]=b}}
function Ql(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;Sb(g,b);w[114256]=0;b=V(1735,g|0)|0;g=w[114256];w[114256]=0;a:{if((g|0)==1){break a}w[114256]=0;Z(1749,b|0,64768,64800,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}w[114256]=0;b=V(1736,f+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;c=V(1750,b|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}w[d>>2]=c;w[114256]=0;c=V(1746,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w[e>>2]=c;w[114256]=0;T(1747,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}Ab(f+8|0);jb=f+16|0;return}a=P()|0;Ab(f+8|0);R(a|0);M()}function oV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;a:{c=w[a>>2];if((w[a+8>>2]-c|0)/12>>>0<b>>>0){if(b>>>0>=357913942){break a}d=Re(f+8|0,b,(w[a+4>>2]-c|0)/12|0,a+8|0);e=w[d+4>>2];b=w[a+4>>2];c=w[a>>2];b:{if((b|0)==(c|0)){b=c;break b}while(1){b=b-12|0;g=w[b+4>>2];e=e-12|0;w[e>>2]=w[b>>2];w[e+4>>2]=g;w[e+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0;e=w[d+4>>2]-12|0;w[d+4>>2]=e;if((b|0)!=(c|0)){continue}break}c=w[a+4>>2];b=w[a>>2]}w[a>>2]=e;w[d+4>>2]=b;w[a+4>>2]=w[d+8>>2];w[d+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[d+12>>2];w[d>>2]=b;w[d+12>>2]=c;sc(d)}jb=f+32|0;return}Mb(a);M()}function Ul(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;Sb(g,b);w[114256]=0;b=V(1561,g|0)|0;g=w[114256];w[114256]=0;a:{if((g|0)==1){break a}w[114256]=0;Z(1728,b|0,64768,64800,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}w[114256]=0;b=V(1704,f+8|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[114256]=0;c=V(1729,b|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}u[d|0]=c;w[114256]=0;c=V(1719,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}u[e|0]=c;w[114256]=0;T(1720,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}Ab(f+8|0);jb=f+16|0;return}a=P()|0;Ab(f+8|0);R(a|0);M()}function cq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=x[e|0];if(!i|!b){break a}j=2240>>>d&d>>>0<12;g=C(c,-6);k=(d-2&255)>>>0>2;while(1){c=a+g|0;f=x[c+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(x[(a+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=a+g|0;if((x[h+2|0]-11&255)>>>0>2){break b}if(x[h+4|0]){break a}}d:{if(!j){break d}h=a+g|0;if((x[h+2|0]-3&255)>>>0>3){break d}if(x[h+4|0]){break a}}e:{if(!f){break e}a=x[(a+g|0)+5|0];if(a?(a|0)!=(i|0):0){break a}if((a|0)!=(i|0)){break e}u[e|0]=0;return}a=c;b=b-1|0;if(b){continue}break}}}function QG(a){a=a|0;if(x[460528]){return w[115131]}if(!x[461632]){a=461344;while(1){a=Wb(a)+12|0;if((a|0)!=461632){continue}break}u[461632]=1}cc(461344,71032);cc(461356,71064);cc(461368,71100);cc(461380,71124);cc(461392,71148);cc(461404,71164);cc(461416,71184);cc(461428,71204);cc(461440,71232);cc(461452,71272);cc(461464,71304);cc(461476,71340);cc(461488,71376);cc(461500,71392);cc(461512,71408);cc(461524,71424);cc(461536,71148);cc(461548,71440);cc(461560,71456);cc(461572,71472);cc(461584,71488);cc(461596,71504);cc(461608,71520);cc(461620,71536);u[460528]=1;w[115131]=461344;return 461344}function ox(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;d=w[a>>2];c=c>>>3|0;e=c>>>0>d>>>0?d:c;if(e){a=w[a+20>>2];f=e;while(1){c=0;d=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);h=c;c=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);l(0,h|(((c&255)<<24|d>>>8)&-16777216|((c&16777215)<<8|d>>>24)&16711680|(c>>>8&65280|c>>>24)));l(1,d<<24|d<<8&16711680|((c<<24|d>>>8)&65280|(c<<8|d>>>24)&255));g=Tb(H(G(+n(),1),-1)*32768);a:{if(E(g)<2147483648){c=~~g;break a}c=-2147483648}c=(c|0)>=32767?32767:c;v[a>>1]=(c|0)<=-32768?-32768:c;a=a+2|0;b=b+8|0;f=f-1|0;if(f){continue}break}}return e<<3}function VP(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=jb-16|0;jb=d;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{c:{if((e|0)==1){break c}w[114256]=0;X(1361,b|0);e=w[114256];w[114256]=0;if((e|0)==1){break c}e=w[a+24>>2];w[d+8>>2]=b;b=ec(b);w[114256]=0;w[d+12>>2]=b;b=w[d+12>>2];w[d>>2]=w[d+8>>2];w[d+4>>2]=b;gb(1403,e|0,d|0,+c,1);e=w[114256];w[114256]=0;b=1;if((e|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2353,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}jb=d+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Eu(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{c=a+8|0;d:{if(!jg(c)){if((b|0)<0|(Rj(c)|0)<=(b|0)){break d}c=(x[(w[a+32>>2]+C(b+1&65535,104)|0)+484415|0]&4)>>>2|0;break b}c=jg(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}c=ba(8)|0;w[114256]=0;a=Q(5,d|0,2427)|0;b=w[114256];w[114256]=0;e:{if((b|0)!=1){b=Pb(c,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break e}zb(w[a>>2]);break e}b=P()|0;ca(c|0)}R(b|0);M()}a=w[(w[a+32>>2]+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(x[a+15|0]&2)>>>1|0}jb=d+16|0;return c|0}M()}function Yf(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function Ai(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=y[a+34>>1];a:{if(!b){if(!(d&512)){break a}b=a+68|0;c=0;while(1){e=b+(c<<2)|0;c=c+1|0;w[e>>2]=c<<11;if((c|0)!=9){continue}break}break a}w[a>>2]=4;v[a+34>>1]=d&64958|512;Ck(a);b=x[c+8|0]|x[c+9|0]<<8|(x[c+10|0]<<16|x[c+11|0]<<24);u[a+76|0]=b;u[a+77|0]=b>>>8;u[a+78|0]=b>>>16;u[a+79|0]=b>>>24;b=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);c=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[a+68|0]=c;u[a+69|0]=c>>>8;u[a+70|0]=c>>>16;u[a+71|0]=c>>>24;u[a+72|0]=b;u[a+73|0]=b>>>8;u[a+74|0]=b>>>16;u[a+75|0]=b>>>24;return}v[a+34>>1]=d&65023}function hO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{c:{if(b>>>0<4294967280){c=x[a+11|0];e=c<<24>>24;h=(e|0)<0;d=h?(w[a+8>>2]&2147483647)-1|0:10;if(d>>>0>=b>>>0){break a}c=(e|0)<0?w[a+4>>2]:c;f=b>>>0<c>>>0?c:b;g=f>>>0<=10?10:f|15;if((d|0)==(g|0)){break a}if(f>>>0<=10){h=1;b=a;e=w[a>>2];break b}b=g+1|0;if(d>>>0<g>>>0){b=Kb(b);break c}w[114256]=0;b=V(22,b|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break c}$(W(0)|0)|0;aa();return}zc(a);M()}e=(e|0)<0?w[a>>2]:a}d=c+1|0;if(d){Fb(b,e,d)}if(h){zb(e)}if(f>>>0>=11){w[a+4>>2]=c;w[a>>2]=b;w[a+8>>2]=g+1|-2147483648;return}u[a+11|0]=c}}function gM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[a+4>>2];f=w[a>>2];if((c|0)!=(f|0)){d=w[b+4>>2];while(1){c=c-32|0;e=w[c+4>>2];d=d-32|0;w[d>>2]=w[c>>2];w[d+4>>2]=e;w[d+8>>2]=w[c+8>>2];w[c>>2]=0;w[c+4>>2]=0;w[c+8>>2]=0;w[d+12>>2]=w[c+12>>2];w[d+16>>2]=w[c+16>>2];w[c+12>>2]=0;w[c+16>>2]=0;e=w[c+24>>2];w[d+20>>2]=w[c+20>>2];w[d+24>>2]=e;e=w[c+28>>2];w[c+28>>2]=0;w[d+28>>2]=e;d=w[b+4>>2]-32|0;w[b+4>>2]=d;if((c|0)!=(f|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function Ni(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=x[b+11|0];d=c<<24>>24;if(u[a+11|0]>=0){if((d|0)>=0){d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;w[a+8>>2]=w[b+8>>2];return a|0}e=w[b>>2];d=jb-16|0;jb=d;b=w[b+4>>2];a:{if(b>>>0<=10){Zc(a,b);Dd(a,e,b);u[d+15|0]=0;Sc(a+b|0,d+15|0);break a}c=x[a+11|0];Dh(a,10,b-10|0,c,0,c,b,e)}jb=d+16|0;return a|0}f=(d|0)<0;e=f?w[b>>2]:b;d=jb-16|0;jb=d;b=f?w[b+4>>2]:c;c=Ke(a);b:{if(b>>>0<c>>>0){c=w[a>>2];Yc(a,b);Dd(c,e,b);u[d+15|0]=0;Sc(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=w[a+4>>2];Dh(a,f,g,c,0,c,b,e)}jb=d+16|0}return a|0}function ZP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)==1){break c}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}d=w[a+24>>2];w[c+8>>2]=b;b=ec(b);w[114256]=0;w[c+12>>2]=b;b=w[c+12>>2];w[c>>2]=w[c+8>>2];w[c+4>>2]=b;e=+ra(1398,d|0,c|0,1);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2390,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}jb=c+16|0;return+e}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function _P(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{c:{if((d|0)==1){break c}w[114256]=0;X(1361,b|0);d=w[114256];w[114256]=0;if((d|0)==1){break c}d=w[a+24>>2];w[c+8>>2]=b;b=ec(b);w[114256]=0;w[c+12>>2]=b;b=w[c+12>>2];w[c>>2]=w[c+8>>2];w[c+4>>2]=b;b=S(1396,d|0,c|0,1)|0;d=w[114256];w[114256]=0;if((d|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5981,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}jb=c+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function LE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;a:{if(gl(c,a)){e=C(x[a+4|0],3);break a}u[a|0]=0;u[a+1|0]=0;u[a+2|0]=0;u[a+3|0]=0;u[a+4|0]=0;e=0}qq(c,d,e);c=x[a+4|0];b:{if(c>>>0<2){break b}Hd(b,c>>>0>=64?64:c);u[b+13|0]=x[a+2|0];u[b+14|0]=x[a+3|0];a=x[a+1|0];u[b+15|0]=a;u[b+16|0]=a;a=w[b+4>>2];f=w[b>>2];if((a|0)==(f|0)){break b}a=a-f>>2;c=a>>>0<=1?1:a;a=0;while(1){if(a){b=f+(a<<2)|0;e=b;g=y[b-4>>1];b=C(a,3)+d|0;b=(u[b+1|0]&1)<<8|x[b|0];v[e>>1]=g+(b>>>0<=1?1:b)}u[(f+(a<<2)|0)+2|0]=x[(C(a,3)+d|0)+2|0];a=a+1|0;if((c|0)!=(a|0)){continue}break}}jb=d+192|0}function xl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;w[c+12>>2]=b;if(b>>>0<=4294967279){a:{if(Yb(a)>>>0>=b>>>0){break a}i=c,j=Db(a),w[i+8>>2]=j;d=_f(w[of(c+12|0,c+8|0)>>2]);if((d|0)==(Yb(a)|0)){break a}f=Yb(a);g=Db(a);b:{c:{if((d|0)==10){h=1;b=a;e=w[a>>2];break c}b=d+1|0;d:{if(d>>>0>f>>>0){b=nf(a,b);break d}w[114256]=0;b=Q(2120,a|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break d}$(W(0)|0)|0;aa();break b}h=dd(a);e=Qb(a)}Dd(b,e,Db(a)+1|0);if(h){Th(e,f+1|0)}e:{if((d|0)!=10){Cd(a,d+1|0);Yc(a,g);hd(a,b);break e}Zc(a,g)}}}jb=c+16|0;return}zc(a);M()}function ju(a,b){var c=0,d=0,e=0,f=0,g=0;if(!x[456340]){f=456341,g=_a()|0,u[f|0]=g;u[456340]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!x[456341]){break c}d=+Za();break a}w[114084]=28;return-1}d=+$a()}c=d/1e3;e:{if(E(c)<0x8000000000000000){e=E(c)>=1?~~(c>0?G(I(c*2.3283064365386963e-10),4294967295):J((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}e=-2147483648;a=0}w[b>>2]=a;w[b+4>>2]=e;c=(d-(+(BV(a,e,1e3,0)>>>0)+ +(nb|0)*4294967296))*1e3*1e3;f:{if(E(c)<2147483648){a=~~c;break f}a=-2147483648}w[b+8>>2]=a;return 0}function fk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;d=w[a>>2];e=w[a+4>>2]-d>>2;c=e+1|0;if(c>>>0<1073741824){d=w[a+8>>2]-d|0;f=d>>1;c=ud(g+8|0,d>>>0>=2147483644?1073741823:c>>>0<f>>>0?f:c,e,a+8|0);w[w[c+8>>2]>>2]=w[b>>2];f=w[c+8>>2]+4|0;w[c+8>>2]=f;d=w[a+4>>2];b=w[a>>2];h=d-b|0;e=w[c+4>>2]-h|0;w[c+4>>2]=e;if((h|0)>0){Fb(e,b,h);f=w[c+8>>2];d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=f;w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+3&-4)+d}if(b){zb(b)}jb=g+32|0;return}Mb(a);M()}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;c=jb-32|0;jb=c;f=mo(a,1<<b-1);w[f+12>>2]=b;a=1<<b;g=a>>>2|0;if(b>>>0>=2){i=1/+(a>>>0);b=g;a=1;while(1){d=+(b>>>0)*-6.283185307179586*i;a:{if(d==0){o(0);k=j(1)|0;m=j(0)|0;o(+d);e=j(1)|0;j(0)|0;l(0,m|0);l(1,k&2147483647|e&-2147483648);h=+n();d=1;break a}h=ee(d);d=Fc(d)}e=w[f>>2]+(a<<4)|0;B[e+8>>3]=h;B[e>>3]=d;a=a<<1;e=b>>>0<2;b=b>>>1|0;if(!e){continue}break}}w[c+24>>2]=0;w[c+28>>2]=0;w[c+8>>2]=0;w[c+12>>2]=0;w[c+16>>2]=0;w[c+20>>2]=1072693248;w[c>>2]=0;w[c+4>>2]=1072693248;ww(f,0,g,c);jb=c+32|0;return f|0}function Yk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(c<<3)+a|0;e=x[d+356|0];u[b+12|0]=x[b+12|0]&248|e&1|e<<1&4|e>>>1&2;e=x[d+352|0];e=e>>>0>=16?16:e;Hd(b,e>>>0<=2?2:e);u[b+13|0]=x[d+354|0];u[b+14|0]=x[d+355|0];d=x[d+353|0];u[b+15|0]=d;u[b+16|0]=d;d=w[b+4>>2];e=w[b>>2];if((d|0)!=(e|0)){d=d-e>>2;h=d>>>0<=1?1:d;d=0;i=((c|0)!=0)<<1;j=(c<<6)+a|0;k=((c|0)==2?-1:0)&255;c=0;while(1){a=d<<2;f=a+e|0;c=c&65535;a=a+j|0;g=x[a+160|0]|x[a+161|0]<<8;c=c>>>0>g>>>0?c:g;v[f>>1]=c;a=(x[a+162|0]^k)>>>i|0;u[f+2|0]=a>>>0>=64?64:a;c=c+1|0;d=d+1|0;if((h|0)!=(d|0)){continue}break}}Fk(b,4,32)}function XK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=Kc(b,-1);d=x[a+52|0];a:{if(e){if(d){break a}b=w[a+48>>2];f=a,g=Kc(b,-1)^1,u[f+52|0]=g;break a}b:{if(!d){break b}f=c,g=Ng(w[a+48>>2]),u[f+19|0]=g;c:{d:{e:{d=c+20|0;switch(uj(w[a+36>>2],w[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=w[a+48>>2];w[c+20>>2]=c+25;u[c+24|0]=d}while(1){d=w[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;w[c+20>>2]=d;if((rj(u[d|0],w[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}u[a+52|0]=1;w[a+48>>2]=b}jb=c+32|0;return b|0}function rJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{b:{e=w[d+4>>2];a=((b|0)/8|0)+a|0;if(e>>>0<=a>>>0){a=ba(8)|0;w[114256]=0;c=V(195,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}break b}f=a+1|0;if(f>>>0>=e>>>0){a=ba(8)|0;w[114256]=0;c=V(195,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}break b}c:{g=e;e=a+2|0;if(g>>>0<=e>>>0){a=ba(8)|0;w[114256]=0;c=V(195,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break c}break b}d=w[d>>2];return((x[d+f|0]<<8|x[a+d|0]<<16|x[d+e|0])<<(b&7)&16777215)>>>24-c|0}break a}b=P()|0;ca(a|0);R(b|0);M()}ka(c|0,75856,133);M()}function $E(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;u[e+47|0]=x[c|0];c=e+47|0;bh(e+16|0,c);d=x[d|0];w[114256]=0;u[e+47|0]=d;T(234,e+28|0,c|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[114256]=0;d=e+40|0;w[e+12>>2]=d;w[e+8>>2]=e+16;U(51,a|0,b|0,e+8|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+16|0)){continue}break}jb=e+48|0;return}b=P()|0;if(u[e+27|0]>=0){break a}zb(w[e+16>>2]);break a}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+16|0)){continue}break}}R(b|0);M()}function lU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;d=w[a>>2];e=w[a+4>>2]-d>>2;c=e+1|0;if(c>>>0<1073741824){d=w[a+8>>2]-d|0;f=d>>1;c=ud(g+8|0,d>>>0>=2147483644?1073741823:c>>>0<f>>>0?f:c,e,a+8|0);d=w[c+8>>2];A[d>>2]=A[b>>2];f=d+4|0;w[c+8>>2]=f;d=w[a+4>>2];b=w[a>>2];h=d-b|0;e=w[c+4>>2]-h|0;w[c+4>>2]=e;if((h|0)>0){Fb(e,b,h);f=w[c+8>>2];d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=f;w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+3&-4)+d}if(b){zb(b)}jb=g+32|0;return}Mb(a);M()}function iG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;w[c+12>>2]=b;if(b>>>0<=1073741807){a:{if(Ag(a)>>>0>=b>>>0){break a}i=c,j=Db(a),w[i+8>>2]=j;d=Rf(w[of(c+12|0,c+8|0)>>2]);if((d|0)==(Ag(a)|0)){break a}e=1;g=Ag(a);h=Db(a);b:{c:{if((d|0)==1){b=a;f=w[a>>2];break c}b=d+1|0;d:{if(d>>>0>g>>>0){b=br(b);break d}w[114256]=0;b=Q(2123,a|0,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){break d}$(W(0)|0)|0;aa();break b}e=dd(a);f=Qb(a)}de(b,f,Db(a)+1|0);if(e){Gh(f,g+1|0)}e:{if((d|0)!=1){Cd(a,d+1|0);Yc(a,h);hd(a,b);break e}Zc(a,h)}}}jb=c+16|0;return}Qf();M()}function MU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=w[b+4>>2];e=w[a>>2];d=c-e|0;f=g+C((d|0)/-6|0,6)|0;w[b+4>>2]=f;if((d|0)>0){Fb(f,e,d)}f=w[a+4>>2];if((f|0)!=(c|0)){d=w[b+8>>2];while(1){e=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[d|0]=e;u[d+1|0]=e>>>8;u[d+2|0]=e>>>16;u[d+3|0]=e>>>24;e=x[c+4|0]|x[c+5|0]<<8;u[d+4|0]=e;u[d+5|0]=e>>>8;d=w[b+8>>2]+6|0;w[b+8>>2]=d;c=c+6|0;if((f|0)!=(c|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2];return g|0}function Di(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;d=w[a>>2];e=w[a+4>>2]-d>>2;c=e+1|0;if(c>>>0<1073741824){d=w[a+8>>2]-d|0;f=d>>1;c=ud(g+8|0,d>>>0>=2147483644?1073741823:c>>>0<f>>>0?f:c,e,a+8|0);d=w[c+8>>2];w[d>>2]=w[b>>2];f=d+4|0;w[c+8>>2]=f;d=w[a+4>>2];b=w[a>>2];h=d-b|0;e=w[c+4>>2]-h|0;w[c+4>>2]=e;if((h|0)>0){Fb(e,b,h);f=w[c+8>>2];d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=f;w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+3&-4)+d}if(b){zb(b)}jb=g+32|0;return}Mb(a);M()}function GC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(Gp(a,b)){e=x[b+8|0]|x[b+9|0]<<8|(x[b+10|0]<<16|x[b+11|0]<<24);break a}Cb(b,0,52);e=0}e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+504|0;b:{if(e>>>0>z[a+8>>2]){f=w[a>>2];if(ob[w[w[f>>2]+24>>2]](f)>>>0<e>>>0){break b}}w[a+8>>2]=e}if(!Fp(a,d)){Cb(d,0,284)}c:{d:{b=x[b+32|0]|x[b+33|0]<<8|(x[b+34|0]<<16|x[b+35|0]<<24);if(!b){break d}b=b<<8&16711680|b<<24|(b>>>8&65280|b>>>24);if(b>>>0>z[a+8>>2]){d=w[a>>2];if(ob[w[w[d>>2]+24>>2]](d)>>>0<b>>>0){break d}}w[a+8>>2]=b;if(wg(a,c)){break c}Cb(c,0,80);return}Cb(c,0,80)}}function Ro(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}b:{if(u[a+11|0]<0){u[w[a>>2]]=0;w[a+4>>2]=0;break b}u[a+11|0]=0;u[a|0]=0}xl(a,c);if(!c){break a}while(1){j=c-f|0;i=d>>>0>j>>>0?j:d;Vi(a,b+f|0,i);vl(a,1,13);h=g+i|0;if(h>>>0>g>>>0){while(1){c:{d:{e:{k=u[Pq(a,g)|0];switch(k-10|0){case 1:case 2:break c;case 0:case 3:break d;default:break e}}if(k){break c}}l=Pq(a,g),m=32,u[l|0]=m}g=g+1|0;if((h|0)!=(g|0)){continue}break}}g=h+1|0;h=f+i|0;f=j-i|0;f=h+(e>>>0>f>>>0?f:e)|0;if(f>>>0<c>>>0){continue}break}}return(d|0)!=0|0}function IO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;a:{b:{c:{b=w[a+36>>2];d=w[a+40>>2];if((b|0)==(d|0)){Vg(c+8|0,a);w[114256]=0;e=V(22,12)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}w[e>>2]=w[c+8>>2];w[e+4>>2]=w[c+12>>2];w[e+8>>2]=w[c+16>>2];d=w[a+40>>2];b=w[a+36>>2]}d=(b|0)==(d|0)?e:a+36|0;b=w[d>>2];a=w[a+8>>2];if((a|0)!=-1){break b}a=w[d+4>>2];if((a|0)==(b|0)){break a}while(1){f=B[b>>3]+f;b=b+24|0;if((a|0)!=(b|0)){continue}break}break a}b=P()|0;a=w[c+8>>2];if(a){w[c+12>>2]=a;zb(a)}R(b|0);M()}f=B[C(a,24)+b>>3]}w[c+24>>2]=0;if(e){kd(e)}jb=c+32|0;return+f}function Zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=jb-16|0;f=w[a>>2];e=w[a+4>>2];if(d){j=w[a+8>>2];m=w[a+12>>2];n=w[a+24>>2];o=w[a+20>>2];p=w[a+16>>2];while(1){q=f>>>18|0;k=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;i=0;b=1;while(1){l=i<<1;g=v[l+k>>1];w[(h+8|0)+(i<<2)>>2]=g+((C(v[(l|4)+k>>1]-g|0,q)|0)/16384|0);g=b;b=0;i=1;if(g){continue}break}w[c>>2]=w[c>>2]+C(w[h+8>>2],o);w[c+4>>2]=w[c+4>>2]+C(w[h+12>>2],n);e=e+m|0;b=f+j|0;e=b>>>0<j>>>0?e+1|0:e;f=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function UK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{if(Kc(b,-1)){break c}i=c,j=Ng(b),u[i+23|0]=j;if(x[a+44|0]){if((Pe(c+23|0,1,1,w[a+32>>2])|0)!=1){break b}break c}f=c+24|0;w[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=uj(w[a+36>>2],w[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(w[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Pe(d,1,1,w[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=w[c+16>>2]-g|0;if((Pe(g,1,d,w[a+32>>2])|0)!=(d|0)){break b}d=w[c+12>>2];if((e|0)==1){continue}break}}a=vj(b);break a}a=-1}jb=c+32|0;return a|0}function SG(a){a=a|0;if(x[460520]){return w[115129]}if(!x[461328]){a=461040;while(1){a=Wb(a)+12|0;if((a|0)!=461328){continue}break}u[461328]=1}dc(461040,1541);dc(461052,1532);dc(461064,6774);dc(461076,6530);dc(461088,1751);dc(461100,7455);dc(461112,1608);dc(461124,2095);dc(461136,4971);dc(461148,4954);dc(461160,4962);dc(461172,4981);dc(461184,6018);dc(461196,9073);dc(461208,5044);dc(461220,3926);dc(461232,1751);dc(461244,5633);dc(461256,6418);dc(461268,6786);dc(461280,5179);dc(461292,2817);dc(461304,1978);dc(461316,8982);u[460520]=1;w[115129]=461040;return 461040}function ZO(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;e=w[a>>2];f=w[a+4>>2];g=w[a+12>>2];a=w[a+8>>2];w[d+8>>2]=a;w[d+12>>2]=g;w[114256]=0;w[d+24>>2]=a;w[d+28>>2]=g;w[d+16>>2]=e;w[d+20>>2]=f;w[d>>2]=e;w[d+4>>2]=f;U(1457,d+32|0,d|0,0);a=w[114256];w[114256]=0;a:{if((a|0)!=1){w[114256]=0;b=+za(1458,d+32|0,+b,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){a=w[d+36>>2];b:{if(!a){break b}c=w[a+4>>2];w[a+4>>2]=c-1;if(c){break b}ob[w[w[a>>2]+8>>2]](a);Ib(a)}jb=d+48|0;return+b}a=P()|0;Bb(d+32|0);break a}a=P()|0;if(!c){break a}ob[w[w[c>>2]+4>>2]](c)}R(a|0);M()}function wV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;g=co(b,e+12|0,c);c=w[g>>2];if(!c){c=Kb(28);u[e+8|0]=0;w[e+4>>2]=b+4;w[e>>2]=c;f=c+16|0;a:{b:{c:{if(u[d+11|0]>=0){c=w[d+4>>2];w[f>>2]=w[d>>2];w[f+4>>2]=c;w[f+8>>2]=w[d+8>>2];break c}h=w[d+4>>2];d=w[d>>2];w[114256]=0;U(3,f|0,d|0,h|0);d=w[114256];w[114256]=0;if((d|0)==1){break b}}u[e+8|0]=1;break a}a=P()|0;w[e>>2]=0;d:{e:{if(x[e+8|0]){if(u[c+27|0]>=0){break e}zb(w[c+16>>2]);break e}if(!c){break d}}zb(c)}R(a|0);M()}Xe(b,w[e+12>>2],g,w[e>>2]);f=1;c=w[e>>2]}u[a+4|0]=f;w[a>>2]=c;jb=e+16|0}function PK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=Kc(b,-1);d=x[a+52|0];a:{if(e){if(d){break a}b=w[a+48>>2];f=a,g=Kc(b,-1)^1,u[f+52|0]=g;break a}b:{if(!d){break b}w[c+16>>2]=w[a+48>>2];c:{d:{e:{d=c+20|0;switch(uj(w[a+36>>2],w[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=w[a+48>>2];w[c+20>>2]=c+25;u[c+24|0]=d}while(1){d=w[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;w[c+20>>2]=d;if((rj(u[d|0],w[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}u[a+52|0]=1;w[a+48>>2]=b}jb=c+32|0;return b|0}function rq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-32|0;jb=f;c=w[a>>2];d=w[a+4>>2]-c|0;if((d|0)>-3){c=w[a+8>>2]-c|0;d=d>>1;e=d+1|0;c=Vf(f+8|0,c>>>0>=2147483646?2147483647:c>>>0>e>>>0?c:e,d,a+8|0);d=w[c+8>>2];v[d>>1]=y[b>>1];g=d+2|0;w[c+8>>2]=g;d=w[a+4>>2];b=w[a>>2];h=d-b|0;e=w[c+4>>2]-h|0;w[c+4>>2]=e;if((h|0)>0){Fb(e,b,h);g=w[c+8>>2];d=w[a+4>>2];e=w[c+4>>2];b=w[a>>2]}w[a>>2]=e;w[c+4>>2]=b;w[a+4>>2]=g;w[c+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[c+12>>2];w[c>>2]=b;w[c+12>>2]=e;if((b|0)!=(d|0)){w[c+8>>2]=((b-d|0)+1&-2)+d}if(b){zb(b)}jb=f+32|0;return}Mb(a);M()}function Ip(a){var b=0,c=0;a:{if(Jb(a,9894,3)|(x[a+3|0]-52&255)>>>0<252){break a}b=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))+788>>>0<840){break a}b=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=x[a+24|0]|x[a+25|0]<<8|(x[a+26|0]<<16|x[a+27|0]<<24);if((b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))>>>0<52?b:0){break a}a=x[a+32|0]|x[a+33|0]<<8|(x[a+34|0]<<16|x[a+35|0]<<24);c=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return c}function nw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{b:{while(1){h=g&255;if(fn(b,c,h>>>0>1)){break b}f=x[b|0];u[b|0]=x[d|0];u[d|0]=f;f=x[c|0];u[c|0]=x[e|0];u[e|0]=f;g=g+1|0;if(h>>>0<3){continue}break}g=0;h=x[b|0];c:{while(1){if((h|0)==x[g+35760|0]){break c}g=g+1|0;if((g|0)!=43){continue}break}g=0}f=0;i=x[d|0];d:{while(1){if(x[f+35760|0]==(i|0)){break d}f=f+1|0;if((f|0)!=43){continue}break}f=0}if(f>>>0<g>>>0){u[b|0]=i;u[d|0]=h;d=x[c|0];u[c|0]=x[e|0];u[e|0]=d;h=x[b|0]}u[a|0]=h;u[a+1|0]=x[c|0];u[b|0]=0;break a}u[a|0]=0;c=a+1|0}u[c|0]=0}function FA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;f=-1;c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=d;w[c+12>>2]=d+80;e=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((e|0)==80){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],80)|0){g=w[a+12>>2]+80|0;break a}g=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=g}jb=c+16|0;b:{if((e|0)!=80){break b}f=0;if((y[d+68>>1]-128&65535)>>>0<65409){break b}if(Jb(d,13413,17)){break b}e=a;f=b;c=y[d+70>>1];a=c+y[d+72>>1]|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=c+y[d+64>>1]|0;f=Uc(e,f,b,b>>>0<c>>>0?a+1|0:a)}jb=d+80|0;return f|0}function zU(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;v[a>>1]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[a+36>>2]=0;w[a+40>>2]=0;v[a+28>>1]=65472;c=a+56|0;w[c>>2]=0;w[c+4>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+24>>2]=0;w[a+44>>2]=0;w[a+48>>2]=0;w[a+52>>2]=c;w[114256]=0;w[b+12>>2]=1065353216;U(958,a+4|0,128,b+12|0);c=w[114256];w[114256]=0;if((c|0)==1){c=P()|0;Gi(a+52|0,w[a+56>>2]);if(u[a+51|0]<0){zb(w[a+40>>2])}b=w[a+16>>2];if(b){w[a+20>>2]=b;zb(b)}b=w[a+4>>2];if(b){w[a+8>>2]=b;zb(b)}R(c|0);M()}w[a+32>>2]=0;v[a+30>>1]=0;w[a+20>>2]=w[a+16>>2];jb=b+16|0;return a|0}function qt(a){var b=0,c=0;a:{b=w[a+4>>2];b:{if(!w[(w[w[b>>2]-12>>2]+b|0)+24>>2]){break b}b=w[a+4>>2];if(!dg(w[w[b>>2]-12>>2]+b|0)){break b}b=w[a+4>>2];if(!(w[(w[w[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(Lt()){break b}b=w[a+4>>2];b=w[(w[w[b>>2]-12>>2]+b|0)+24>>2];w[114256]=0;b=V(1588,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=w[a+4>>2];b=w[w[a>>2]-12>>2];w[114256]=0;T(1589,a+b|0,1);a=w[114256];w[114256]=0;if((a|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function _z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=jb-16|0;f=w[a>>2];e=w[a+4>>2];if(d){j=w[a+8>>2];l=w[a+12>>2];m=w[a+24>>2];n=w[a+20>>2];o=w[a+16>>2];while(1){p=f>>>10&4194048;k=(((e&2147483647)<<1|f>>>31)&-2)+o|0;g=0;b=1;while(1){h=u[g+k|0];w[(i+8|0)+(g<<2)>>2]=((C(u[(g|2)+k|0]-h|0,p)|0)/16384|0)+(h<<8);h=b;b=0;g=1;if(h){continue}break}w[c>>2]=w[c>>2]+C(w[i+8>>2],n);w[c+4>>2]=w[c+4>>2]+C(w[i+12>>2],m);e=e+l|0;b=f+j|0;e=b>>>0<j>>>0?e+1|0:e;f=b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function cQ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;w[114256]=0;X(1335,a|0);h=w[114256];w[114256]=0;a:{b:{if((h|0)!=1){c:{h=w[a+24>>2];w[114256]=0;ma(1392,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=rc(u[g+11|0]<0?w[g>>2]:g);if(u[g+11|0]>=0){break b}zb(w[g>>2]);break b}}$(W(0)|0)|0;b=0;w[114256]=0;Y(1333,6604,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=g+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function bQ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;w[114256]=0;X(1335,a|0);h=w[114256];w[114256]=0;a:{b:{if((h|0)!=1){c:{h=w[a+24>>2];w[114256]=0;ma(1393,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=rc(u[g+11|0]<0?w[g>>2]:g);if(u[g+11|0]>=0){break b}zb(w[g>>2]);break b}}$(W(0)|0)|0;b=0;w[114256]=0;Y(1333,6559,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=g+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function bP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-48|0;jb=f;ah(f+8|0,c);w[114256]=0;c=f+20|0;T(116,c|0,d|0);d=w[114256];w[114256]=0;if((d|0)!=1){a:{w[114256]=0;c=f+32|0;T(116,c|0,e|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}w[114256]=0;c=f+44|0;w[f+4>>2]=c;w[f>>2]=f+8;U(51,a|0,b|0,f|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(f+8|0)){continue}break}jb=f+48|0;return}}b=P()|0;while(1){a=c-12|0;if(u[c-1|0]<0){zb(w[a>>2])}c=a;if((c|0)!=(f+8|0)){continue}break}R(b|0);M()}function Yz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];h=w[a+36>>2];a:{if(!d){f=b>>12;j=h>>12;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){i=e+m|0;f=u[i|0];h=h+o|0;j=h>>12;i=((C(u[i+1|0]-f|0,g>>>10&4194048)|0)/16384|0)+(f<<8)|0;w[c>>2]=w[c>>2]+C(j,i);b=b+n|0;f=b>>12;w[c+4>>2]=w[c+4>>2]+C(i,f);e=e+l|0;g=g+k|0;e=g>>>0<k>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=j;w[a+24>>2]=f}function MK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;a:{b:{c:{if(Kc(b,-1)){break c}w[c+20>>2]=b;if(x[a+44|0]){if((Pe(c+20|0,4,1,w[a+32>>2])|0)!=1){break b}break c}f=c+24|0;w[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=uj(w[a+36>>2],w[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(w[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Pe(d,1,1,w[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=w[c+16>>2]-g|0;if((Pe(g,1,d,w[a+32>>2])|0)!=(d|0)){break b}d=w[c+12>>2];if((e|0)==1){continue}break}}a=vj(b);break a}a=-1}jb=c+32|0;return a|0}function kA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];h=w[a+36>>2];a:{if(!d){f=b>>12;i=h>>12;break a}j=w[a+8>>2];k=w[a+12>>2];l=w[a+16>>2];m=w[a+32>>2];n=w[a+28>>2];while(1){f=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;o=v[f+2>>1];h=h+n|0;i=h>>12;w[c>>2]=w[c>>2]+C(i,v[f>>1]);b=b+m|0;f=b>>12;w[c+4>>2]=w[c+4>>2]+C(o,f);e=e+k|0;g=g+j|0;e=g>>>0<j>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=i;w[a+24>>2]=f}function Yw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=jb-16|0;jb=d;f=b+4|0;g=w[b+4>>2];a:{if(!g){c=f;break a}h=x[c|0];i=y[c+2>>1];while(1){b:{c:{c=g;g=x[c+14|0];if(g>>>0<=h>>>0){if(g>>>0<h>>>0){break b}if(y[c+16>>1]<=i>>>0){break c}}f=c;g=w[c>>2];if(g){continue}break a}if(y[c+16>>1]>=i>>>0){break a}}f=c+4|0;g=w[c+4>>2];if(g){continue}break}}w[d+12>>2]=c;c=w[f>>2];if(c){b=0}else{c=Kb(20);e=w[e>>2];e=y[e>>1]|y[e+2>>1]<<16;v[c+18>>1]=0;v[c+14>>1]=e;v[c+16>>1]=e>>>16;Xe(b,w[d+12>>2],f,c);b=1}u[a+4|0]=b;w[a>>2]=c;jb=d+16|0}function Xz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];h=w[a+36>>2];a:{if(!d){f=b>>12;j=h>>12;break a}k=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){i=(e<<1)+m|0;f=v[i>>1];h=h+o|0;j=h>>12;i=f+((C(v[i+2>>1]-f|0,g>>>18|0)|0)/16384|0)|0;w[c>>2]=w[c>>2]+C(j,i);b=b+n|0;f=b>>12;w[c+4>>2]=w[c+4>>2]+C(i,f);e=e+l|0;g=g+k|0;e=g>>>0<k>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=j;w[a+24>>2]=f}function CD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-192|0;jb=d;c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=d;w[c+12>>2]=d+192;e=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((e|0)==192){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],192)|0){f=w[a+12>>2]+192|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=192){break b}c=0;if(!Up(d)){break b}e=a;f=b;c=y[d+34>>1];b=c+y[d+36>>1]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=c+y[d+38>>1]|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=c+y[d+32>>1]|0;c=Uc(e,f,b,b>>>0<c>>>0?a+1|0:a)}jb=d+192|0;return c|0}function iD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;w[c+28>>2]=22;w[c+24>>2]=a;bj(c+8|0,c+24|0);d=x[b+11|0];a=d<<24>>24;g=(a|0)<0?w[b+4>>2]:d;d=u[c+19|0];h=d&255;f=(d|0)<0?w[c+12>>2]:h;a:{b:{c:{if((g|0)!=(f|0)){break c}b=(a|0)<0?w[b>>2]:b;d:{e=(d|0)<0;if(!e){if(d){break d}e=1;break a}a=w[c+8>>2];if(!f){e=1;break b}e=!Jb(e?a:c+8|0,b,f);break b}a=c+8|0;while(1){f=x[b|0];g=x[a|0];e=(f|0)==(g|0);if((f|0)!=(g|0)){break c}b=b+1|0;a=a+1|0;h=h-1|0;if(h){continue}break}}if((d|0)>=0){break a}a=w[c+8>>2]}zb(a)}jb=c+32|0;return e|0}function ZA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;w[c+28>>2]=32;w[c+24>>2]=a;bj(c+8|0,c+24|0);d=x[b+11|0];a=d<<24>>24;g=(a|0)<0?w[b+4>>2]:d;d=u[c+19|0];h=d&255;f=(d|0)<0?w[c+12>>2]:h;a:{b:{c:{if((g|0)!=(f|0)){break c}b=(a|0)<0?w[b>>2]:b;d:{e=(d|0)<0;if(!e){if(d){break d}e=1;break a}a=w[c+8>>2];if(!f){e=1;break b}e=!Jb(e?a:c+8|0,b,f);break b}a=c+8|0;while(1){f=x[b|0];g=x[a|0];e=(f|0)==(g|0);if((f|0)!=(g|0)){break c}b=b+1|0;a=a+1|0;h=h-1|0;if(h){continue}break}}if((d|0)>=0){break a}a=w[c+8>>2]}zb(a)}jb=c+32|0;return e|0}function Rp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+24|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d+8|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+4>>2]=32;w[d>>2]=b;Q(200,d|0,d+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+19|0]<0){zb(w[d+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+19|0]>=0){break a}zb(w[d+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function PC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+24|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d+8|0,3,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+4>>2]=17;w[d>>2]=b;Q(200,d|0,d+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+19|0]<0){zb(w[d+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+19|0]>=0){break a}zb(w[d+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function BE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+24|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d+8|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+4>>2]=44;w[d>>2]=b;Q(200,d|0,d+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+19|0]<0){zb(w[d+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+19|0]>=0){break a}zb(w[d+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function vD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=20;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function pq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,3,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=32;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function oq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,3,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=20;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function gq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=32;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function bE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,3,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=22;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function RA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a=Vc(d+16|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){w[114256]=0;w[d+44>>2]=22;w[d+40>>2]=b;Q(200,d+40|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[d+11|0]<0){zb(w[d>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}b=P()|0;break a}b=P()|0;if(u[d+11|0]>=0){break a}zb(w[d>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function lA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];h=w[a+36>>2];a:{if(!d){f=b>>12;i=h>>12;break a}j=w[a+8>>2];k=w[a+12>>2];l=w[a+16>>2];m=w[a+32>>2];n=w[a+28>>2];while(1){f=(((e&2147483647)<<1|g>>>31)&-2)+l|0;o=u[f+1|0];h=h+n|0;i=h>>12;w[c>>2]=w[c>>2]+(C(i,u[f|0])<<8);b=b+m|0;f=b>>12;w[c+4>>2]=w[c+4>>2]+(C(o,f)<<8);e=e+k|0;g=g+j|0;e=g>>>0<j>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=h;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=i;w[a+24>>2]=f}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=v[b>>1];b=v[a+30>>1];a:{if(!b){break a}if((e|0)>=0){e=(e|0)%(b|0)|0;break a}e=b+((e^-1)%(b|0)^-1)|0}v[d+6>>1]=e;f=a+52|0;b=x[c+11|0];b:{if(b<<24>>24<0?w[c+4>>2]:b){a=d+6|0;w[d+16>>2]=a;cw(d+24|0,f,a,35814,d+16|0,d+8|0);Wm(w[d+24>>2]+20|0,c);break b}b=a+56|0;c=w[b>>2];if(!c){break b}a=b;while(1){g=v[c+16>>1]<e<<16>>16;a=g?a:c;c=w[(g?c+4|0:c)>>2];if(c){continue}break}if((a|0)==(b|0)|v[a+16>>1]>e<<16>>16){break b}_v(f,a);if(u[a+31|0]<0){zb(w[a+20>>2])}zb(a)}jb=d+32|0}function sw(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;Hd(g,b>>>0>=10?10:b);u[g+15|0]=c;u[g+16|0]=c;u[g+14|0]=e;u[g+13|0]=d;k=w[g>>2];b=w[g+4>>2]-k|0;j=b>>2;if(b>>>0>=4){n=j>>>0<=1?1:j;b=0;while(1){h=(b<<2)+k|0;l=C(b,3)+f|0;i=(x[l|0]|x[l+1|0]<<8)>>>4|0;v[h>>1]=i;a:{if(!b){v[k>>1]=0;break a}m=i;i=y[h-4>>1];if(m>>>0>=i>>>0){break a}v[h>>1]=i+1}m=h;h=x[l+2|0];u[m+2|0]=h>>>0>=64?64:h;b=b+1|0;if((n|0)!=(b|0)){continue}break}}b=x[g+12|0]&-2|a&1;b=a&2?b&-5|(c>>>0<=j>>>0)<<2:b&251;u[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=j>>>0)<<1:b&253}function Dw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;a:{if(y[a+480192>>1]<b>>>0){break a}b=w[((b<<2)+a|0)+900380>>2];if(!b){break a}Do(h,b);b=w[h>>2];i=h|4;if((b|0)!=(i|0)){j=y[a+480190>>1];while(1){g=y[b+14>>1];if(g>>>0<=j>>>0){g=C(g,104)+a|0;u[g+484421|0]=f;u[g+484418|0]=c;u[g+484420|0]=e;u[g+484419|0]=d}g=w[b+4>>2];b:{if(g){while(1){b=g;g=w[b>>2];if(g){continue}break b}}while(1){g=b;b=w[b+8>>2];if((g|0)!=w[b>>2]){continue}break}}if((b|0)!=(i|0)){continue}break}}th(h,w[h+4>>2])}jb=h+16|0}function np(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=w[b+4>>2];f=w[c+4>>2]-e|0;g=w[c>>2];c=w[b>>2];b=f+(g-c<<3)|0;a:{if((b|0)<=0){e=w[d>>2];break a}b:{if(!e){e=w[d>>2];break b}f=32-e|0;g=(b|0)<(f|0)?b:f;h=w[d>>2];e=-1<<e&-1>>>f-g;w[h>>2]=w[h>>2]&(e^-1)|e&w[c>>2];e=g+w[d+4>>2]|0;w[d+4>>2]=e&31;e=h+(e>>>3&536870908)|0;w[d>>2]=e;b=b-g|0;c=c+4|0}f=(b|0)/32|0;g=f<<2;hc(e,c,g);e=g+w[d>>2]|0;w[d>>2]=e;b=b-(f<<5)|0;if((b|0)<=0){break a}f=-1>>>32-b|0;w[e>>2]=w[e>>2]&(f^-1)|f&w[c+g>>2];w[d+4>>2]=b}w[a>>2]=e;w[a+4>>2]=w[d+4>>2]}function fQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;w[114256]=0;X(1335,a|0);g=w[114256];w[114256]=0;a:{b:{if((g|0)!=1){c:{g=w[a+24>>2];w[114256]=0;ia(1390,f|0,g|0,b|0,c|0,d|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=rc(u[f+11|0]<0?w[f>>2]:f);if(u[f+11|0]>=0){break b}zb(w[f>>2]);break b}}$(W(0)|0)|0;b=0;w[114256]=0;Y(1333,8239,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=f+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function eQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;w[114256]=0;X(1335,a|0);g=w[114256];w[114256]=0;a:{b:{if((g|0)!=1){c:{g=w[a+24>>2];w[114256]=0;ia(1391,f|0,g|0,b|0,c|0,d|0,e|0);b=w[114256];w[114256]=0;if((b|0)==1){break c}b=rc(u[f+11|0]<0?w[f>>2]:f);if(u[f+11|0]>=0){break b}zb(w[f>>2]);break b}}$(W(0)|0)|0;b=0;w[114256]=0;Y(1333,8139,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}jb=f+16|0;return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Pk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-1024|0;jb=f;e=jb-16|0;jb=e;h=w[a+8>>2];d=w[a>>2];w[e+8>>2]=f;w[e+12>>2]=f+1024;h=ob[w[w[d>>2]+32>>2]](d,h,e+8|0)|0;if((h|0)==1024){d=w[a>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],1024)|0){d=w[a+8>>2]+1024|0;break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[a+8>>2]=d}jb=e+16|0;jb=f+1024|0;if((h|0)==1024){e=c?224:240;c=f;a=0;while(1){g=0;while(1){a=((e&x[(g<<2)+c|0])!=0)+a|0;g=g+1|0;if((g|0)!=4){continue}break}i=i+1|0;c=(i<<4)+f|0;if((i|0)!=64){continue}break}g=a>>>0<=b>>>0}return g}function XU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=d+8|0;Vb(e,2,a+6|0,32);w[114256]=0;w[d+28>>2]=32;w[d+24>>2]=b+492;Q(200,d+24|0,e|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){if(u[d+19|0]<0){zb(w[d+8>>2])}e=b+236|0;f=c+1|0;c=0;while(1){v[e+(c<<1)>>1]=x[(a+c|0)+38|0]+f;c=c+1|0;if((c|0)!=128){continue}break}w[b>>2]=(x[a+226|0]|x[a+227|0]<<8)<<5;hn(a+180|0,b+48|0,0);hn(a+228|0,b+88|0,2);hn(a+276|0,b+68|0,1);if(!(x[a+324|0]|x[a+325|0]<<8)){Cb(e,0,256)}jb=d+32|0;return}a=P()|0;if(u[d+19|0]<0){zb(w[d+8>>2])}R(a|0);M()}function kn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=b*b;g=1;e=1;while(1){d=d+2;e=i*e/(d*d);g=e+g;if(g*1e-7<e){continue}break}c=G(c,.999);i=c*32768;k=c*3.141592653589793;while(1){f=((h^-1)<<12&28672)+(h>>>3|0)|0;if((f|0)!=16384){c=1;d=+(f-16384|0);e=d*.000244140625;d=L(d*-152587890625e-16*e+1)*b;l=d*d;j=k*e;d=0;e=1;while(1){d=d+2;e=l*e/(d*d);c=e+c;if(c*1e-7<e){continue}break}c=c*ee(j)/(j*g)}else{c=1}c=I(i*c+.5);a:{if(E(c)<2147483648){f=~~c;break a}f=-2147483648}v[a>>1]=f;a=a+2|0;h=h+1|0;if((h|0)!=32768){continue}break}}function eT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;w[a+4>>2]=b;w[a>>2]=0;b=a+8|0;a:{if(u[e+11|0]>=0){f=w[e+4>>2];w[b>>2]=w[e>>2];w[b+4>>2]=f;w[b+8>>2]=w[e+8>>2];break a}Ge(b,w[e>>2],w[e+4>>2])}e=a+20|0;b:{if(u[d+11|0]>=0){b=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=b;w[e+8>>2]=w[d+8>>2];break b}f=w[d+4>>2];d=w[d>>2];w[114256]=0;U(76,e|0,d|0,f|0);d=w[114256];w[114256]=0;if((d|0)!=1){break b}c=P()|0;if(u[a+19|0]<0){zb(w[b>>2])}R(c|0);M()}w[a+32>>2]=0;w[a+36>>2]=0;u[a+42|0]=0;u[a+40|0]=0;u[a+41|0]=x[a+41|0]&240|c|8;return a|0}function Wm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){e=x[b+11|0];d=e<<24>>24;if(u[a+11|0]>=0){if((d|0)>=0){d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;w[a+8>>2]=w[b+8>>2];return a|0}d=w[b>>2];b=w[b+4>>2];a:{if(b>>>0<=10){u[a+11|0]=b;if(b){Fb(a,d,b)}u[a+b|0]=0;break a}c=x[a+11|0];ak(a,10,b-10|0,c,0,c,b,d)}return a|0}f=(d|0)<0;d=f?w[b>>2]:b;c=w[a+8>>2]&2147483647;b=f?w[b+4>>2]:e;b:{if(c>>>0>b>>>0){w[a+4>>2]=b;c=w[a>>2];if(b){Fb(c,d,b)}u[b+c|0]=0;break b}e=c-1|0;f=(b-c|0)+1|0;c=w[a+4>>2];ak(a,e,f,c,0,c,b,d)}}return a|0}function Ck(a){a=a|0;var b=0,c=0,d=0,e=0;b=w[a+20>>2];if(b){zb(b+-64|0)}w[a+20>>2]=0;b=y[a+34>>1];b=C(b&1?2:1,b&64?2:1);c=w[a>>2];a:{if(c-268435457>>>0<4026531840){break a}c=c+208|0;BV(b,0,c,0);if(nb){break a}c=C(b,c);if(!c){break a}w[114256]=0;b=V(2116,c|0)|0;d=w[114256];w[114256]=0;b:{c:{if((d|0)==1){$(W(0)|0)|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;b=0;if((d|0)==1){break c}}break b}W(0)|0;Eb();M()}if(!b){break a}e=Cb(b,0,c)- -64|0}w[a+20>>2]=e;if(e){b=w[a>>2];a=y[a+34>>1];a=C(C(b,a&64?2:1),a&1?2:1)}else{a=0}return a|0}function an(a){var b=D(0),c=0,d=D(0),e=0,f=D(0);d=D(z[w[a+16>>2]+24620>>2]);b=D(D(ob[w[w[a>>2]+200>>2]](a))*d);e=a,f=D(D(b*D(2.0480000972747803))*D(ob[w[w[a>>2]+192>>2]](a))),A[e+4248>>2]=f;b=_b(D(D(b*D(4.0960001945495605))+D(8192)));c=2147483647;a:{if(b>=D(2147483648)){break a}c=-2147483648;if(b<=D(-2147483648)){break a}c=~~b;if(D(E(b))<D(2147483648)){break a}c=-2147483648}w[a+4256>>2]=c;b=D(ob[w[w[a>>2]+204>>2]](a));A[a+4252>>2]=b;b=D(b/d);if(!(ob[w[w[a>>2]+188>>2]](a)|0)){b=Wt(D(b*D(3.1415927410125732)))}A[a+4244>>2]=b+b}function TI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=Db(a);f=Ag(a);g=Sr(b,c);a:{if(!g){break a}b:{if(Qb(a)>>>0<=b>>>0){h=Qb(a)+(Db(a)<<2)>>>0>=b>>>0}else{h=0}if(!h){if(f-e>>>0<g>>>0){Mq(a,f,(e+g|0)-f|0,e,e)}f=Qb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}xd(f,b);b=b+4|0;f=f+4|0;continue}}e=jb-16|0;jb=e;ts(d,b,c);jb=e+16|0;b=Qb(d);c=Db(d);w[114256]=0;S(1786,a|0,b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){$b(d);break a}a=P()|0;$b(d);R(a|0);M()}w[d>>2]=0;xd(f,d);He(a,e+g|0)}jb=d+16|0;return a|0}function Lj(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=jb-240|0;jb=h;g=w[c>>2];w[h+232>>2]=g;c=w[c+4>>2];w[h>>2]=a;w[h+236>>2]=c;j=1;a:{b:{c:{if(!(c|(g|0)!=1)){c=a;break c}g=a;while(1){i=(d<<2)+f|0;c=g-w[i>>2]|0;if((ob[b|0](c,a)|0)<=0){c=g;break c}d:{if(!((d|0)<2|e)){e=w[i-8>>2];i=g-4|0;if((ob[b|0](i,c)|0)>=0){break d}if((ob[b|0](i-e|0,c)|0)>=0){break d}}w[(j<<2)+h>>2]=c;g=h+232|0;e=Zt(g);Mj(g,e);j=j+1|0;d=d+e|0;e=0;g=c;if(w[h+236>>2]|w[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}Yt(h,j);Am(c,b,d,f)}jb=h+240|0}function te(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?F(c):F(d)+32|0;$c(f,d,e,0,0,c+49|0);i=w[f>>2];h=w[f+4>>2];e=15372-c<<16;c=w[f+8>>2];d=e|w[f+12>>2]^65536}w[a>>2]=i;w[a+4>>2]=h;w[a+8>>2]=c;w[a+12>>2]=g&-2147483648|d;jb=f+16|0}function dE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;lc(b,0);g=x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24);w[b>>2]=g;e=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);w[b+12>>2]=e;f=x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24);w[b+16>>2]=f;c=x[a+12|0]|x[a+13|0]<<8;v[b+32>>1]=64;w[b+24>>2]=c;c=x[a+14|0];v[b+30>>1]=c?c+1|0:256;d=y[b+34>>1]&32767|!x[a+14|0]<<15;v[b+34>>1]=d;c=x[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;v[b+34>>1]=d;c=x[a+15|0]}if(c&2){w[b+16>>2]=f>>>1;w[b+12>>2]=e>>>1;w[b>>2]=g>>>1;v[b+34>>1]=d|1}}function ID(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-576|0;jb=d;c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=d;w[c+12>>2]=d+576;e=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((e|0)==576){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],576)|0){f=w[a+12>>2]+576|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=576){break b}c=0;if(!Vp(d)){break b}f=a;g=b;b=BV(y[d+36>>1],0,384,0);a=y[d+34>>1];c=a>>>30|0;e=a<<2;b=b+e|0;a=c+nb|0;a=b>>>0<e>>>0?a+1|0:a;b=b+256|0;a=b>>>0<256?a+1|0:a;c=Uc(f,g,b,a)}jb=d+576|0;return c|0}function Vc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[114256]=0;U(253,a|0,b|0,c|0);c=w[114256];w[114256]=0;a:{if((c|0)==1){break a}if(d){d=w[b+8>>2];c=w[a>>2];e=w[b>>2];f=w[w[e>>2]+36>>2];w[114256]=0;d=S(f|0,e|0,d|0,c|0)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}b:{if(d){c=c+w[b+8>>2]|0;break b}c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}}w[b+8>>2]=c}return a|0}c=P()|0;b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}R(c|0);M()}function BS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4240>>2]=0;w[a+4244>>2]=0;w[a+4208>>2]=0;w[a+4212>>2]=0;w[a+4216>>2]=0;w[a>>2]=79424;b=w[c+24620>>2];w[a+4260>>2]=0;w[a+4256>>2]=b;w[a+4236>>2]=0;b=a+4228|0;w[b>>2]=1048576e3;w[b+4>>2]=1048576e3;w[a+4220>>2]=1056964608;w[a+4224>>2]=1056964608;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)!=1){w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+4208>>2];if(b){w[a+4212>>2]=b;zb(b)}Oc(a);R(c|0);M()}return a|0}function mT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=D(0);e=jb-4096|0;jb=e;g=ob[w[w[a>>2]+112>>2]](a)|0;if(!g){ob[w[w[a>>2]+116>>2]](a)}d=w[a+48>>2];c=w[a+44>>2];if((d|0)!=(c|0)){f=c;c=d-c>>11;Cb(f,0,(c>>>0<=1?1:c)<<11)}if(b){f=e+2048|0;while(1){c=0;h=Cb(e,0,4096);d=b>>>0>=512?512:b;ob[w[w[a>>2]+60>>2]](a,h,f,d);while(1){i=(c<<2)+h|0;j=D(H(D(H(D(E(A[i>>2])),j)),D(E(A[i+2048>>2]))));c=c+1|0;if((d|0)!=(c|0)){continue}break}b=b-d|0;if(b){continue}break}}if(!g){ob[w[w[a>>2]+120>>2]](a)}jb=e+4096|0;return D(j)}function Li(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}a=Vc(d+24|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d+8|0,3,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;if((e|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}e=w[d+12>>2];w[b>>2]=w[d+8>>2];w[b+4>>2]=e;w[b+8>>2]=w[d+16>>2];b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}c=P()|0;b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}R(c|0);M()}function Kw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{e=w[a+8>>2];d=w[a>>2];if(e-d>>>0>=b>>>0){f=w[a+4>>2]-d|0;e=b>>>0>f>>>0?f:b;if(e){while(1){u[d|0]=x[c|0];d=d+1|0;e=e-1|0;if(e){continue}break}}if(b>>>0>f>>>0){d=w[a+4>>2];b=d+(b-f|0)|0;break a}w[a+4>>2]=w[a>>2]+b;return}if(d){w[a+4>>2]=d;zb(d);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;e=0}if((b|0)>=0){d=e<<1;Wf(a,e>>>0>=1073741823?2147483647:b>>>0<d>>>0?d:b);d=w[a+4>>2];b=d+b|0;break a}Mb(a);M()}while(1){u[d|0]=x[c|0];d=d+1|0;if((d|0)!=(b|0)){continue}break}w[a+4>>2]=b}function Ki(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}a=Vc(d+24|0,a,c,1);f=w[a>>2];e=w[a+4>>2];h=w[a+12>>2];g=w[a+8>>2];w[114256]=0;Y(209,d+8|0,2,(e?e:(g|0)!=(h|0)?g:0)|0,f|0);e=w[114256];w[114256]=0;if((e|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}e=w[d+12>>2];w[b>>2]=w[d+8>>2];w[b+4>>2]=e;w[b+8>>2]=w[d+16>>2];b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=d+48|0;return!c|(f|0)!=0}c=P()|0;b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}R(c|0);M()}function jy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;sk(e+8|0,c);w[114256]=0;T(387,e+20|0,d|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(290,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function oy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){sh(a,c-d>>1);c=w[a+4>>2];e=w[b>>2];d=w[b+4>>2]-e|0;if((d|0)>0){c=Fb(c,e,d)+d|0}w[a+4>>2]=c}c=a+12|0;a:{if(u[b+23|0]>=0){d=w[b+16>>2];w[c>>2]=w[b+12>>2];w[c+4>>2]=d;w[c+8>>2]=w[b+20>>2];break a}d=w[b+16>>2];e=w[b+12>>2];w[114256]=0;U(3,c|0,e|0,d|0);c=w[114256];w[114256]=0;if((c|0)!=1){break a}c=P()|0;b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(c|0);M()}w[a+24>>2]=w[b+24>>2];v[a+28>>1]=y[b+28>>1];return a|0}function mE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;ah(e+8|0,c);w[114256]=0;T(116,e+20|0,d|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(51,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function xB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;Fn(e+8|0,c);w[114256]=0;T(54,e+20|0,d|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[114256]=0;d=e+32|0;w[e+4>>2]=d;w[e>>2]=e+8;U(51,a|0,b|0,e|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}jb=e+32|0;return}b=P()|0;if(u[e+19|0]>=0){break a}zb(w[e+8>>2]);break a}b=P()|0;while(1){a=d-12|0;if(u[d-1|0]<0){zb(w[a>>2])}d=a;if((d|0)!=(e+8|0)){continue}break}}R(b|0);M()}function JP(a,b){a=a|0;b=b|0;var c=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;a:{if(x[b+16|0]){w[114256]=0;S(2,a|0,1452,6)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}}if(x[b+17|0]){w[114256]=0;S(2,a|0,8314,6)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}}c=x[a+11|0];if(!(c<<24>>24<0?w[a+4>>2]:c)){w[114256]=0;S(2,a|0,6012,5)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}}if(x[b+18|0]){w[114256]=0;S(2,a|0,6965,4)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}}return}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function fp(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-48|0;jb=c;a=Vc(c+24|0,a,4,1);f=w[a>>2];d=w[a+4>>2];g=w[a+12>>2];e=w[a+8>>2];w[114256]=0;Y(209,c+8|0,3,(d?d:(e|0)!=(g|0)?e:0)|0,f|0);d=w[114256];w[114256]=0;a:{b:{if((d|0)!=1){w[114256]=0;w[c+4>>2]=5;w[c>>2]=b;Q(200,c|0,c+8|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}if(u[c+19|0]<0){zb(w[c+8>>2])}b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}jb=c+48|0;return}b=P()|0;break a}b=P()|0;if(u[c+19|0]>=0){break a}zb(w[c+8>>2])}c=w[a+8>>2];if(c){w[a+12>>2]=c;zb(c)}R(b|0);M()}function SF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(wd(a,w[b+8>>2],e)){pl(b,c,d);return}a:{if(wd(a,w[b>>2],e)){if(!(w[b+16>>2]!=(c|0)&w[b+20>>2]!=(c|0))){if((d|0)!=1){break a}w[b+32>>2]=1;return}w[b+32>>2]=d;b:{if(w[b+44>>2]==4){break b}v[b+52>>1]=0;a=w[a+8>>2];ob[w[w[a>>2]+20>>2]](a,b,c,c,1,e);if(x[b+53|0]){w[b+44>>2]=3;if(!x[b+52|0]){break b}break a}w[b+44>>2]=4}w[b+20>>2]=c;w[b+40>>2]=w[b+40>>2]+1;if(w[b+36>>2]!=1|w[b+24>>2]!=2){break a}u[b+54|0]=1;return}a=w[a+8>>2];ob[w[w[a>>2]+24>>2]](a,b,c,d,e)}}function Qn(a,b,c){var d=0,e=0,f=0;a:{if(b){u[c|0]=b;break a}b=x[c|0]}d=w[a+480180>>2];c=d&1048580?(b&240?-16:15)&b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(x[a+480209|0]&16)){break b}b=b>>>3&30;break d}e=w[a+480208>>2]&4096;f=b&240;if(!(!c|(f|0)!=240)){if(!e){break b}b=0-(c<<1)|0;break c}if(e){break b}if(f){if(c?d&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}c=0;b=w[a+1074444>>2]+(b<<!(d&59314208))|0;e:{if((b|0)>=0){c=256;if(b>>>0<257){break e}}b=c}w[a+1074444>>2]=b}}function cT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4260>>2]=0;w[a+4264>>2]=0;w[a+4208>>2]=1056964608;w[a+4212>>2]=1036831949;w[a+4268>>2]=0;w[a>>2]=78784;w[a+4232>>2]=1061997773;b=a+4224|0;w[b>>2]=1061158912;w[b+4>>2]=1059082943;b=a+4216|0;w[b>>2]=1038174126;w[b+4>>2]=1065353216;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)!=1){w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+4260>>2];if(b){w[a+4264>>2]=b;zb(b)}Oc(a);R(c|0);M()}return a|0}function Uk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=c-b|0;g=e>>2;f=w[a+8>>2];d=w[a>>2];if(g>>>0<=f-d>>2>>>0){e=w[a+4>>2]-d|0;f=e>>2;e=f>>>0<g>>>0?b+e|0:c;h=e-b|0;if((b|0)!=(e|0)){hc(d,b,h)}if(f>>>0<g>>>0){b=w[a+4>>2];c=c-e|0;if((c|0)>0){b=Fb(b,e,c)+c|0}w[a+4>>2]=b;return}w[a+4>>2]=d+h;return}if(d){w[a+4>>2]=d;zb(d);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;f=0}if((e|0)>=0){d=f>>1;Bh(a,f>>>0>=2147483644?1073741823:d>>>0>g>>>0?d:g);d=w[a+4>>2];if((b|0)!=(c|0)){d=Fb(d,b,e)+e|0}w[a+4>>2]=d;return}Mb(a);M()}function ZI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[w[a+1056>>2]>>2]-w[a+1060>>2]|0;c=c>>>0>=16384?16384:c;w[a+1068>>2]=c;a:{if(!c){break a}c=17;while(1){e=1<<c-1;d=xf(a,c);b:{c:{d:{if((c|0)<=6){if((d|0)!=(e|0)){break d}d=xf(a,4);e=d+1|0;c=(c|0)>(e|0)?e:d+2|0;break b}if(c>>>0>16){break c}f=e-8|0;if((d|0)<(f|0)|(d|0)>(e+7|0)){break d}d=d-f|0;e=d+1|0;c=(c|0)>(e|0)?e:d+2|0;break b}Or(a,d,e,b);break b}c=d&(e^-1);if(d&e){c=c+1|0;break b}Or(a,c,0,b);c=17}if(!w[a+1068>>2]){break a}if((c|0)<18){continue}break}}}function jG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-512|0;jb=e;c=jb-16|0;jb=c;g=w[a+12>>2];d=e+8|0;w[c+8>>2]=d;w[c+12>>2]=d+497;d=ob[w[w[a>>2]+32>>2]](a,g,c+8|0)|0;if((d|0)==497){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],497)|0){f=w[a+12>>2]+497|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((d|0)!=497){break b}c=0;if(!Kq(e+8|0)){break b}c=BV(x[e+119|0],0,1536,0);g=nb;d=a;f=b;a=c;c=BV(x[e+118|0],0,25,0);b=a+c|0;a=nb+g|0;c=Uc(d,f,b,b>>>0<c>>>0?a+1|0:a)}jb=e+512|0;return c|0}function _T(a){a=a|0;var b=0,c=0,d=0;d=w[a+20>>2];w[d+148>>2]=-1;a:{c=w[d+4>>2];b=w[d+8>>2]-c|0;b:{if(b>>>0<=7){w[114256]=0;T(991,d+4|0,8-b|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}c=w[w[a+20>>2]+4>>2];break b}if((b|0)==8){break b}w[d+8>>2]=c+8}b=w[a+4264>>2];a=w[a+4260>>2];u[c|0]=a;u[c+1|0]=a>>>8;u[c+2|0]=a>>>16;u[c+3|0]=a>>>24;u[c+4|0]=b;u[c+5|0]=b>>>8;u[c+6|0]=b>>>16;u[c+7|0]=b>>>24;return}b=W(74720)|0;if((kb|0)==(fa(74720)|0)){$(b|0)|0;a=w[a+20>>2];w[a+8>>2]=w[a+4>>2];aa();return}R(b|0);M()}function SI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[w[a+1056>>2]>>2]-w[a+1060>>2]|0;c=c>>>0>=32768?32768:c;w[a+1068>>2]=c;a:{if(!c){break a}c=9;while(1){e=1<<c-1;d=xf(a,c);b:{c:{d:{if((c|0)<=6){if((d|0)!=(e|0)){break d}d=xf(a,3);e=d+1|0;c=(c|0)>(e|0)?e:d+2|0;break b}if(c>>>0>8){break c}f=e-4|0;if((d|0)<(f|0)|(d|0)>(e+3|0)){break d}d=d-f|0;e=d+1|0;c=(c|0)>(e|0)?e:d+2|0;break b}Lr(a,d,e,b);break b}c=d&(e^-1);if(d&e){c=c+1|0;break b}Lr(a,c,0,b);c=9}if(!w[a+1068>>2]){break a}if((c|0)<10){continue}break}}}function _I(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;d=Db(a);e=Yb(a);g=dt(b,c);a:{if(!g){break a}b:{if(Qb(a)>>>0<=b>>>0){h=Qb(a)+Db(a)>>>0>=b>>>0}else{h=0}if(!h){if(e-d>>>0<g>>>0){yg(a,e,(d+g|0)-e|0,d,d,0,0)}e=Qb(a)+d|0;while(1){if((b|0)==(c|0)){break b}Sc(e,b);b=b+1|0;e=e+1|0;continue}}b=jm(f,b,c);c=Qb(b);d=Db(b);w[114256]=0;S(92,a|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){Gb(b);break a}a=P()|0;Gb(b);R(a|0);M()}u[f+15|0]=0;Sc(e,f+15|0);He(a,d+g|0)}jb=f+16|0;return a|0}function Nu(a,b){a=a|0;b=+b;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{if(!(!(b<=0)&b<=4)){c=ba(8)|0;w[114256]=0;a=Q(5,d|0,4066)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}c=Pb(c,a);w[114256]=0;U(194,c|0,82064,1337);c=w[114256];w[114256]=0;if((c|0)!=1){break a}d=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}b=Tb(65536/b);c=-1;d:{if(b>=4294967295){break d}c=0;if(b<=0){break d}c=~~b>>>0;if(b<4294967296&b>=0){break d}c=0}a=w[a+32>>2];w[a+480244>>2]=c;_g(a);jb=d+16|0;return}d=P()|0;ca(c|0)}R(d|0)}M()}function Mu(a,b){a=a|0;b=+b;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{if(!(!(b<=0)&b<=4)){c=ba(8)|0;w[114256]=0;a=Q(5,d|0,4087)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}c=Pb(c,a);w[114256]=0;U(194,c|0,82064,1337);c=w[114256];w[114256]=0;if((c|0)!=1){break a}d=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}b=Tb(b*65536);c=-1;d:{if(b>=4294967295){break d}c=0;if(b<=0){break d}c=~~b>>>0;if(b<4294967296&b>=0){break d}c=0}a=w[a+32>>2];w[a+480240>>2]=c;_g(a);jb=d+16|0;return}d=P()|0;ca(c|0)}R(d|0)}M()}function yo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=w[a+8>>2];c=f-1|0;d=w[a+12>>2];g=w[a>>2]+C(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){u[b+g|0]=x[w[a+4>>2]+(C(c,d)+b|0)|0];b=b+1|0;d=w[a+12>>2];if((b|0)<(d|0)){continue}break}f=w[a+8>>2]}b=C(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!x[a+16|0]){e=1;c=0;break a}e=-1;c=c-(x[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=x[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function SA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;c=x[c|0]|x[c+1|0]<<8;v[d+30>>1]=c<<8|c>>>8;c=jb-16|0;jb=c;bo(c,d+30|0);w[114256]=0;e=d+16|0;U(6,e|0,0,c|0);f=w[114256];w[114256]=0;a:{if((f|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}jb=c+16|0;break a}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=e;U(51,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function Qh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;a:{c=w[a>>2];b:{if(w[a+8>>2]-c>>2>>>0>=b>>>0){break b}if(b>>>0>=1073741824){break a}b=ud(f+8|0,b,w[a+4>>2]-c>>2,a+8|0);d=w[a+4>>2];c=w[a>>2];g=d-c|0;e=w[b+4>>2]-g|0;w[b+4>>2]=e;if((g|0)>0){Fb(e,c,g);d=w[a+4>>2];e=w[b+4>>2];c=w[a>>2]}w[a>>2]=e;w[b+4>>2]=c;w[a+4>>2]=w[b+8>>2];w[b+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=e;if((c|0)!=(d|0)){w[b+8>>2]=((c-d|0)+3&-4)+d}if(!c){break b}zb(c)}jb=f+32|0;return}Mb(a);M()}function fg(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=d;w[a+12>>2]=e}function ck(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=w[b+656>>2];a:{b:{if(!(!e|!w[e+44>>2])){d=w[b+700>>2];break b}d=Hn(a,c,w[b+704>>2],d);e=w[b+656>>2];if(!e){break a}}b=w[e+40>>2];if(!b){break a}c=(b|0)/2|0;e=w[a+1074420>>2];e=BV(e,e>>31,d,d>>31);d=c+e|0;c=nb+(c>>31)|0;c=CV(d,d>>>0<e>>>0?c+1|0:c,b,b>>31);d=c;b=nb;c=(b|0)>=0&c>>>0>=2147483647|(b|0)>0;d=c?2147483647:d;b=c?0:b;d=(b|0)<0&d>>>0<=2147483648|(b|0)<-1?-2147483648:d}a=EV(0,d>>>0>=2147483647?2147483647:d,w[a+24620>>2]<<4,0);return a|0}function zo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=b?33:32;c=x[a+16|0];j=c?-1:1;k=c?1:-1;e=w[a+8>>2]-1|0;l=c?e-(x[a+17|0]!=0&(e|0)!=0)|0:0;m=c?0:e;f=w[a+12>>2];g=w[a>>2]+C(f,62)|0;n=w[a+4>>2];d=b?1:-1;o=C(f,d)<<1;b=e;while(1){if((f|0)>0){c=C(b,f);a=0;while(1){v[(a<<1)+g>>1]=y[(a+c<<1)+n>>1];a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+o|0;a:{if((b|0)==(e|0)){a=l;c=j;if((d|0)>0){break a}}a=b+d|0;b=!b&(d|0)<0;a=b?m:a;c=b?k:d}d=c;b=a;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function zn(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;f=b-4e3&65535;a:{if(f>>>0<61537){break a}c=C(b,104)+a|0;if(!w[c+484400>>2]){break a}e=c+484380|0;if(!w[e>>2]){break a}g=a+1304360|0;c=a+1074984|0;while(1){if(w[c+104>>2]==(e|0)){w[c+76>>2]=0;w[c>>2]=0;w[c+4>>2]=0;w[c+16>>2]=0}c=c+896|0;if((g|0)!=(c|0)){continue}break}zi(e);w[e>>2]=0;a=(C(b,104)+a|0)+484414|0;v[a>>1]=y[a>>1]&65470;w[d+24>>2]=0;w[d+8>>2]=0;w[d+16>>2]=0;w[d+20>>2]=0;w[d>>2]=0;w[d+4>>2]=0;Ai(e,0,d)}jb=d+32|0;return f>>>0>61536}function oo(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=xw(b);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=Kb(16384);w[a>>2]=c;e=c+16384|0;w[a+8>>2]=e;f=Cb(c,0,16384);w[a+4>>2]=e;c=0;a:{while(1){h=(c<<3)+f|0;if((c|0)!=1024){w[114256]=0;d=+(c-1024|0);i=+ib(728,+(L(d*d*-9.5367431640625e-7+1)*b));e=w[114256];w[114256]=0;if((e|0)==1){break a}d=d*.0372006759294457;d=i*ee(d)/(d*g)}else{d=1}B[h>>3]=d*.011841342921061943;c=c+1|0;if((c|0)!=2048){continue}break}return}c=P()|0;w[a+4>>2]=f;zb(f);R(c|0);M()}function mA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];f=w[a+36>>2];a:{if(!d){h=b>>12;i=f>>12;break a}j=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){k=v[(e<<1)+m>>1];f=f+o|0;i=f>>12;w[c>>2]=w[c>>2]+C(k,i);b=b+n|0;h=b>>12;w[c+4>>2]=w[c+4>>2]+C(k,h);e=e+l|0;g=g+j|0;e=g>>>0<j>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=f;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=i;w[a+24>>2]=h}function Dg(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=w[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((mm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=ms(i,b,f);h=Qb(f);w[114256]=0;h=S(1763,a|0,h|0,b|0)|0;g=w[114256];w[114256]=0;if((g|0)==1){break a}$b(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((mm(a,c,b)|0)!=(b|0)){break b}}w[e+12>>2]=0;j=a}jb=i+16|0;return j|0}a=P()|0;$b(f);R(a|0);M()}function mq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{d=w[b>>2];e=w[b+4>>2];if((d|0)==(e|0)){break b}while(1){b=w[d>>2];if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))==(c|0)){break b}d=d+24|0;if((e|0)!=(d|0)){continue}break}break a}if((d|0)==(e|0)){break a}w[a>>2]=w[d+8>>2];b=w[d+12>>2];w[a+4>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[d+20>>2];w[a+8>>2]=w[d+16>>2];w[a+12>>2]=b;return}b=Kb(16);w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=75696;w[b>>2]=75656;w[a+8>>2]=0;w[a+12>>2]=0;w[a+4>>2]=b;w[a>>2]=b+12}function sg(a){var b=0,c=0,d=0,e=0;d=y[w[a+4>>2]+28>>1]>>>(!x[a+77|0]<<1)|0;b=((d&3)<<4)+24224|0;w[a+40>>2]=b;e=y[a+24>>1];d=d>>>2|0;c=e+d|0;v[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;v[a+32>>1]=c;v[a+34>>1]=-1<<c^-1;if((e|0)==15){v[a+36>>1]=4095}w[a+52>>2]=b;w[a+64>>2]=b;b=d+y[a+26>>1]|0;v[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;v[a+44>>1]=c;b=d+y[a+30>>1]|0;v[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;v[a+56>>1]=b;v[a+46>>1]=-1<<c^-1;v[a+58>>1]=-1<<b^-1}function bs(a,b){var c=0,d=0,e=0,f=0;f=w[b+16>>2];w[a+4>>2]=0;w[a>>2]=f;a:{if(!f){break a}e=w[b+84>>2];if(e>>>0<=15){c=w[b+80>>2]}else{c=w[b+80>>2];d=e-16|0;c=c>>>0>d>>>0?c:d}w[a+8>>2]=c;d=w[b+88>>2];if(!(d&2)|!x[b+816|0]){break a}c=w[b+104>>2];b:{c:{d:{if((d&2050)!=2){break d}d=y[c+34>>1];if(!(d&8)|w[b+80>>2]!=w[c+12>>2]){break d}if(w[c+16>>2]==(e|0)){break c}}if(w[c+8>>2]!=(e|0)){break a}d=y[c+34>>1];b=(w[c>>2]-e|0)+48|0;break b}b=(w[c>>2]-e|0)+112|0}w[a+4>>2]=C(C(b,d&64?2:1),d&1?2:1)+f}}function nA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=w[a>>2];e=w[a+4>>2];b=w[a+40>>2];f=w[a+36>>2];a:{if(!d){h=b>>12;i=f>>12;break a}j=w[a+8>>2];l=w[a+12>>2];m=w[a+16>>2];n=w[a+32>>2];o=w[a+28>>2];while(1){f=f+o|0;i=f>>12;k=u[e+m|0]<<8;w[c>>2]=w[c>>2]+C(i,k);b=b+n|0;h=b>>12;w[c+4>>2]=w[c+4>>2]+C(k,h);e=e+l|0;g=g+j|0;e=g>>>0<j>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a+36>>2]=f;w[a>>2]=g;w[a+4>>2]=e;w[a+40>>2]=b;w[a+20>>2]=i;w[a+24>>2]=h}function AE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=w[b>>2];h=ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],c<<1)|0;a:{if(!h){break a}v[f+14>>1]=65535;$d(a,c>>>0>=65535?65535:c,f+14|0);c=w[a>>2];i=w[a+4>>2];if((c|0)==(i|0)){break a}while(1){b:{if(cd(b,f+8|0)){a=y[f+8>>1];break b}v[f+8>>1]=0;a=0}a=a<<8|(a&65280)>>>8;v[c>>1]=a;g=65535;c:{if((a&65535)!=(d|0)){g=65534;if((a&65535)!=(e|0)){break c}}v[c>>1]=g}c=c+2|0;if((i|0)!=(c|0)){continue}break}}jb=f+16|0;return h|0}function BC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;a:{c=w[a>>2];b:{if(w[a+8>>2]-c>>1>>>0>=b>>>0){break b}if((b|0)<0){break a}b=Vf(f+8|0,b,w[a+4>>2]-c>>1,a+8|0);d=w[a+4>>2];c=w[a>>2];g=d-c|0;e=w[b+4>>2]-g|0;w[b+4>>2]=e;if((g|0)>0){Fb(e,c,g);d=w[a+4>>2];e=w[b+4>>2];c=w[a>>2]}w[a>>2]=e;w[b+4>>2]=c;w[a+4>>2]=w[b+8>>2];w[b+8>>2]=d;e=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=e;if((c|0)!=(d|0)){w[b+8>>2]=((c-d|0)+1&-2)+d}if(!c){break b}zb(c)}jb=f+32|0;return}Mb(a);M()}function wf(a){var b=0,c=0,d=0;if(!a){if(w[20830]){b=wf(w[20830])}if(w[20754]){b=wf(w[20754])|b}a=w[114087];if(a){while(1){if(w[a+20>>2]!=w[a+28>>2]){b=wf(a)|b}a=w[a+56>>2];if(a){continue}break}}return b}d=w[a+76>>2]>=0;a:{b:{if(w[a+20>>2]==w[a+28>>2]){break b}ob[w[a+36>>2]](a,0,0)|0;if(w[a+20>>2]){break b}b=-1;break a}b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){b=c-b|0;ob[w[a+40>>2]](a,b,b>>31,1)|0}b=0;w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;if(!d){break a}}return b}function uo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;f=yf(a,c);rd(d,w[a+28>>2]);e=w[d+12>>2];w[d+16>>2]=w[d+8>>2];w[d+20>>2]=e;a:{b:{if(!f){if(x[a+24|0]&32){break a}e=w[a+28>>2];break b}e=w[a+28>>2];c:{g=w[f+8>>2];switch(g+1|0){case 0:case 3:break b;default:break c}}v[d+30>>1]=0;h=d+30|0;w[d+4>>2]=h+(g>>>0>=2?2:g);w[d>>2]=h;Ob(e,d);v[b>>1]=y[d+30>>1];break a}v[d+30>>1]=0;w[d+4>>2]=d+32;w[d>>2]=d+30;Ob(e,d);v[b>>1]=y[d+30>>1]}a=zf(a,f,c,d+16|0);jb=d+32|0;return a|0}function lK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=x[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=w[114084];w[114084]=0;Cc();a=Bl(a,e+12|0,d);d=nb;g=w[114084];f:{if(g){if(w[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}w[114084]=h;if(w[e+12>>2]==(b|0)){break b}}}}w[c>>2]=4;b=0;a=0;break a}w[c>>2]=4;b=-1;a=-1;break a}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d}jb=e+16|0;nb=a;return b|0}function Lu(a,b){a=a|0;b=+b;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{if(!(!(b<0)&b<=1)){c=ba(8)|0;w[114256]=0;a=Q(5,d|0,7555)|0;d=w[114256];w[114256]=0;if((d|0)==1){break c}c=Pb(c,a);w[114256]=0;U(194,c|0,82064,1337);c=w[114256];w[114256]=0;if((c|0)!=1){break a}d=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}b=Tb(b*256);c=-1;d:{if(b>=4294967295){break d}c=0;if(b<=0){break d}c=~~b>>>0;if(b<4294967296&b>=0){break d}c=0}w[w[a+32>>2]+1074444>>2]=c;jb=d+16|0;return}d=P()|0;ca(c|0)}R(d|0)}M()}function rn(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(x[b+813|0]!=27){c=u[b+851|0];break a}c=x[b+841|0];c=on(a,x[b+848|0],w[a+1074312>>2]&2097152?c:c+16>>>2|0);d=w[a+1074316>>2];b:{if(!(!(d&8192)|x[b+848|0]!=3)){a=x[b+841|0];c:{if(!(!a|a>>>0>=x[b+849|0])){c=x[b+852|0];a=a+1|0;break c}u[b+852|0]=c;a=1}u[b+841|0]=a;c=c<<24>>24;break b}u[b+841|0]=x[b+841|0]+x[b+849|0]}if(!(d&32768)){break a}u[b+851|0]=c}if(c){a=w[b+684>>2]+((C(x[b+850|0],c)+2|0)/8|0)|0;a=(a|0)>=256?256:a;w[b+684>>2]=(a|0)>0?a:0}}function Hf(a,b,c,d){a:{if(x[a+1074322|0]&16){break a}if(!(x[a+480209|0]&64|!(x[a+1074313|0]&4)&(d|0)!=8)){w[b+88>>2]=w[b+88>>2]&-257}b:{c:{d:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break c;case 2:c=(c>>>0>=64?64:c)<<2;break c;default:break d}}if(!(w[a+480180>>2]&2107410)){break c}if(c>>>0<=128){c=c<<1;break c}if((c|0)!=164){break b}w[b+88>>2]=w[b+88>>2]|256;c=128}w[b+692>>2]=c}v[b+796>>1]=0;w[b+88>>2]=w[b+88>>2]|2097152;if(!(x[a+1074313|0]&4)){break a}u[b+851|0]=0;v[b+790>>1]=0}}function pF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-48|0;jb=e;g=-1;c=jb-16|0;jb=c;f=w[a+12>>2];d=e+8|0;w[c+8>>2]=d;w[c+12>>2]=d+38;d=ob[w[w[a>>2]+32>>2]](a,f,c+8|0)|0;if((d|0)==38){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],38)|0){f=w[a+12>>2]+38|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;b:{if((d|0)!=38){break b}g=0;if(Jb(e+8|0,23168,25)|x[e+42|0]>64){break b}c=a;d=b;b=x[e+43|0];a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;g=Uc(c,d,b,a)}jb=e+48|0;return g|0}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}u[d+7|0]=0;e=d+8|0;w[d+12>>2]=e;w[d+8>>2]=d+7;b:{if((Ob(a,e)|0)!=1|nb){break b}e=c;f=x[d+7|0];c=f;if(e>>>0<c>>>0){break b}if(!c){g=1;break b}i=d+8|0;c=0;while(1){u[d+7|0]=0;w[d+12>>2]=i;w[d+8>>2]=d+7;e=Ob(a,d+8|0);h=nb;g=!h&(e|0)==1;if((e|0)!=1|h){break b}Ui(b,u[d+7|0]);c=c+1|0;if((f|0)!=(c&255)){continue}break}}jb=d+16|0;return g|0}function SS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4256>>2]=0;w[a+4260>>2]=0;w[a+4208>>2]=1056964608;w[a+4212>>2]=1017370378;w[a+4264>>2]=0;w[a>>2]=79016;b=a+4224|0;w[b>>2]=1017370378;w[b+4>>2]=1065353216;b=a+4216|0;w[b>>2]=1028670828;w[b+4>>2]=1059760811;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)!=1){w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+4256>>2];if(b){w[a+4260>>2]=b;zb(b)}Oc(a);R(c|0);M()}return a|0}function ww(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;a:{if(!c){i=w[a>>2];break a}j=B[d+8>>3];g=B[d>>3];while(1){f=w[d+12>>2];w[e+8>>2]=w[d+8>>2];w[e+12>>2]=f;f=w[d+4>>2];w[e>>2]=w[d>>2];w[e+4>>2]=f;f=c>>>1|0;ww(a,b,f,e);i=w[a>>2];h=i+(c<<4)|0;k=B[h+8>>3];l=B[h>>3];m=k*g+l*j;B[d+8>>3]=m;g=l*g-k*j;B[d>>3]=g;b=b|c;h=c>>>0<2;j=m;c=f;if(!h){continue}break}}a=(b<<4)+i|0;b=w[d+4>>2];w[a>>2]=w[d>>2];w[a+4>>2]=b;b=w[d+12>>2];w[a+8>>2]=w[d+8>>2];w[a+12>>2]=b;jb=e+16|0}function pK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=x[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=w[114084];w[114084]=0;Cc();a=Bl(a,e+12|0,d);d=nb;g=w[114084];g:{if(g){if(w[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}w[114084]=h;if(w[e+12>>2]==(b|0)){break d}}}}w[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}w[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function tK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=w[114084];w[114084]=0;Cc();a=Zq(a,e+12|0,d);d=nb;f=w[114084];d:{if(f){if(w[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}w[114084]=g;if(w[e+12>>2]==(b|0)){break c}}}w[c>>2]=4;b=0;break a}if((d|0)<0&a>>>0<2147483648|(d|0)<-1|(a>>>0>2147483647&(d|0)>=0|(d|0)>0)){break b}b=a;break a}w[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}b=-2147483648}jb=e+16|0;return b|0}function kT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=w[a+8>>2];g=w[a+12>>2];a:{if((g|0)<0){break a}i=w[a>>2];c=w[a+4>>2]-i|0;if(!g&c>>>0<d>>>0|g){break a}e=0-(g+(d>>>0>c>>>0)|0)|0;f=c-d|0;j=w[b+4>>2];c=w[b>>2];h=j-c|0;b=f>>>0<h>>>0&(e|0)<=0|(e|0)<0;f=b?f:h;k=f;e=b?e:0;f=!!f&(e|0)>=0|(e|0)>0;b=f?k:0;e=f?e:0;if((b|0)!=(h|0)){break a}if((c|0)!=(j|0)){hc(d+i|0,c,h);d=w[a+8>>2];g=w[a+12>>2]}c=b+d|0;d=e+g|0;w[a+8>>2]=c;w[a+12>>2]=b>>>0>c>>>0?d+1|0:d;l=1}return l|0}function Rm(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(e){i=w[a+12>>2];j=w[a>>2];k=w[b+4>>2];l=w[b>>2];while(1){if(d){m=g+i|0;n=C(g,k);b=w[c+8>>2];h=w[c+4>>2];a=0;while(1){f=w[(a+n<<2)+l>>2];h=((FV(h,1)^270549120)+(b<<2)|0)+2019860093|0;w[c+4>>2]=h;b=C(FV(h,16),5)+b|0;w[c+8>>2]=b;f=(f+(b>>21)|0)-2147481600>>>12|0;f=f>>>0<=491520?491520:f;v[w[(a<<2)+j>>2]+(m<<1)>>1]=(f|0)>=557055?557055:f;a=a+1|0;if((d|0)!=(a|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Ok(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=w[a>>2];a:{if(!(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],1024)|0)){a=64;while(1){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0;b=b+16|0;a=a-1|0;if(a){continue}break}break a}e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+1024;f=a,g=(ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0)+w[a+8>>2]|0,w[f+8>>2]=g}jb=c+16|0}function En(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=c-b|0;d=w[a+8>>2];f=w[a>>2];if(e>>>0<=d-f>>>0){g=w[a+4>>2]-f|0;d=e>>>0>g>>>0?g+b|0:c;h=d-b|0;if((b|0)!=(d|0)){hc(f,b,h)}if(e>>>0>g>>>0){b=w[a+4>>2];c=c-d|0;if((c|0)>0){b=Fb(b,d,c)+c|0}w[a+4>>2]=b;return}w[a+4>>2]=f+h;return}if(f){w[a+4>>2]=f;zb(f);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;d=0}if((e|0)>=0){c=d<<1;Wf(a,d>>>0>=1073741823?2147483647:c>>>0>e>>>0?c:e);i=a,j=Fb(w[a+4>>2],b,e)+e|0,w[i+4>>2]=j;return}Mb(a);M()}function Ji(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){c=c-24|0;f=w[c+4>>2];d=d-24|0;w[d>>2]=w[c>>2];w[d+4>>2]=f;w[d+8>>2]=w[c+8>>2];w[d+12>>2]=w[c+12>>2];w[c+8>>2]=0;w[c+12>>2]=0;f=w[c+20>>2];w[d+16>>2]=w[c+16>>2];w[d+20>>2]=f;d=w[b+4>>2]-24|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function HU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;g=yf(a,c);rd(d,w[a+28>>2]);e=w[d+12>>2];w[d+16>>2]=w[d+8>>2];w[d+20>>2]=e;a:{b:{c:{if(!g){if(x[a+24|0]&32){break a}e=w[a+28>>2];break c}e=w[a+28>>2];f=w[g+8>>2];if((f|0)==4){break c}if((f|0)!=-1){break b}}w[d+28>>2]=0;w[d+4>>2]=d+32;w[d>>2]=d+28;Ob(e,d);w[b>>2]=w[d+28>>2];break a}w[d+28>>2]=0;h=d+28|0;w[d+4>>2]=h+(f>>>0>=4?4:f);w[d>>2]=h;Ob(e,d);w[b>>2]=w[d+28>>2]}a=zf(a,g,c,d+16|0);jb=d+32|0;return a|0}function Ep(a,b,c,d){var e=0;a:{if(!(!c|b)){b=-1;e=Tb(+(C(a,d)>>>0)*2500);if(e>=4294967295){break a}b=0;if(!(e<4294967296&e>=0)|e<=0){break a}return~~e>>>0}b:{if(!(!a|!b)){a=x[(a>>>0>=10?10:a)+23727|0];break b}b=-1;if(a-1>>>0>9){break b}e=Tb(7338401.379310345/+(a>>>0));if(e>=4294967295){break a}b=0;if(!(e<4294967296&e>=0)|e<=0){break a}return~~e>>>0}b=-1;e=Tb(+(a>>>0)*37878.78787878787);if(e>=4294967295){break a}b=0;if(e<=0){break a}if(e<4294967296&e>=0){return~~e>>>0}}return b}function Op(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;f=yf(a,c);rd(d,w[a+28>>2]);e=w[d+12>>2];w[d+16>>2]=w[d+8>>2];w[d+20>>2]=e;a:{b:{if(!f){if(x[a+24|0]&32){break a}e=w[a+28>>2];break b}e=w[a+28>>2];c:{g=w[f+8>>2];switch(g+1|0){case 0:case 2:break b;default:break c}}u[d+31|0]=0;h=d+31|0;w[d+4>>2]=h+((g|0)!=0);w[d>>2]=h;Ob(e,d);u[b|0]=x[d+31|0];break a}u[d+31|0]=0;w[d+4>>2]=d+32;w[d>>2]=d+31;Ob(e,d);u[b|0]=x[d+31|0]}a=zf(a,f,c,d+16|0);jb=d+32|0;return a|0}function $c(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=d;w[a+12>>2]=e}function YQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{if((d|0)==1){break a}w[114256]=0;X(1346,c|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}d=w[a+24>>2];w[114256]=0;b=Q(1347,d|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}w[c>>2]=b;return 1}$(W(0)|0)|0;w[114256]=0;Y(1333,6293,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return 0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function nU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;a:{if(u[b+11|0]<0){u[w[b>>2]]=0;w[b+4>>2]=0;break a}u[b+11|0]=0;u[b|0]=0}w[d+4>>2]=0;e=d+8|0;w[d+12>>2]=e;w[d+8>>2]=d+4;b:{if((Ob(a,e)|0)!=4|nb){break b}e=w[d+4>>2];if(e>>>0>c>>>0){break b}if(!e){f=1;break b}i=d+5|0;c=0;while(1){u[d+4|0]=0;w[d+12>>2]=i;w[d+8>>2]=d+4;g=Ob(a,d+8|0);h=nb;f=!h&(g|0)==1;if((g|0)!=1|h){break b}Ui(b,u[d+4|0]);c=c+1|0;if((e|0)!=(c|0)){continue}break}}jb=d+16|0;return f|0}function qU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;g=yf(a,c);rd(d,w[a+28>>2]);f=w[d+12>>2];w[d+16>>2]=w[d+8>>2];w[d+20>>2]=f;a:{b:{c:{if(!g){if(x[a+24|0]&32){break a}f=w[a+28>>2];break c}f=w[a+28>>2];e=w[g+8>>2];if((e|0)==4){break c}if((e|0)!=-1){break b}}w[d+24>>2]=0;e=d+24|0;w[d+4>>2]=e|4;w[d>>2]=e;Ob(f,d);A[b>>2]=A[d+24>>2];break a}w[d+24>>2]=0;h=d+24|0;w[d+4>>2]=h+(e>>>0>=4?4:e);w[d>>2]=h;Ob(f,d);w[b>>2]=0}a=zf(a,g,c,d+16|0);jb=d+32|0;return a|0}function NC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-24|0;c=c-24|0;w[d>>2]=w[c>>2];v[d+4>>1]=y[c+4>>1];w[d+8>>2]=w[c+8>>2];w[d+12>>2]=w[c+12>>2];w[c+8>>2]=0;w[c+12>>2]=0;f=w[c+20>>2];w[d+16>>2]=w[c+16>>2];w[d+20>>2]=f;d=w[b+4>>2]-24|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function Kz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];b=w[a+4>>2];if(d){h=w[a+8>>2];i=w[a+12>>2];j=w[a+24>>2];k=w[a+20>>2];l=w[a+16>>2];while(1){e=(b<<1)+l|0;g=(f>>>21&2040)+32832|0;e=(((C(v[e>>1],v[g+2>>1])+C(v[e-2>>1],v[g>>1])|0)+C(v[e+2>>1],v[g+4>>1])|0)+C(v[e+4>>1],v[g+6>>1])|0)/16384|0;w[c>>2]=w[c>>2]+C(e,k);w[c+4>>2]=w[c+4>>2]+C(e,j);b=b+i|0;f=f+h|0;b=f>>>0<h>>>0?b+1|0:b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=b}function Iv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=w[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=w[c>>2];c=w[c+4>>2];h=w[a+96>>2];i=w[a+100>>2];a:{if(!(h|i)){b=w[e+4>>2];d=w[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=w[e+4>>2];d=w[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;w[e>>2]=f-d;w[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;w[a+104>>2]=(g+1>>>0)%12;w[a+96>>2]=j;w[a+100>>2]=0;nb=w[e+4>>2];return w[e>>2]}function Nq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Qb(a);a:{if(b>>>0<536870887){w[i+8>>2]=b<<1;w[i+12>>2]=b+c;c=Rf(w[of(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=br(k);if(e){de(c,j,e)}if(g){de(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;de((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){Gh(j,b)}hd(a,c);Cd(a,k);b=a;a=h+(e+g|0)|0;Yc(b,a);w[i+4>>2]=0;xd(c+(a<<2)|0,i+4|0);jb=i+16|0;return}Qf();M()}function Pm(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(e){i=w[a+4>>2];j=w[a>>2];k=w[b+4>>2];l=w[b>>2];while(1){if(d){m=C(g,i);n=C(g,k);b=w[c+8>>2];h=w[c+4>>2];a=0;while(1){f=w[(a+n<<2)+l>>2];h=((FV(h,1)^270549120)+(b<<2)|0)+2019860093|0;w[c+4>>2]=h;b=C(FV(h,16),5)+b|0;w[c+8>>2]=b;f=(f+(b>>21)|0)-2147481600>>>12|0;f=f>>>0<=491520?491520:f;v[(a+m<<1)+j>>1]=(f|0)>=557055?557055:f;a=a+1|0;if((d|0)!=(a|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function yD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=w[b>>2];h=ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],c<<2)|0;a:{if(!h){break a}v[f+14>>1]=65535;$d(a,c>>>0>=65535?65535:c,f+14|0);c=w[a>>2];i=w[a+4>>2];if((c|0)==(i|0)){break a}while(1){b:{if(Nc(b,f+8|0)){a=w[f+8>>2];break b}w[f+8>>2]=0;a=0}v[c>>1]=a;g=65535;c:{if((a&65535)!=(d|0)){g=65534;if((a&65535)!=(e|0)){break c}}v[c>>1]=g}c=c+2|0;if((i|0)!=(c|0)){continue}break}}jb=f+16|0;return h|0}function on(a,b,c){if(x[a+1074314|0]&32){c=c&255;a:{switch((b&3)-1|0){default:return u[c+26560|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}b=a;a=w[a+1074328>>2];w[b+1074328>>2]=C(a,214013)+2531011;return(a>>>16&127)+-64|0}if(y[a+480182>>1]&1032){return u[(c>>>1&31)+25680|0]}a=c&63;b:{switch((b&3)-1|0){default:return u[a+26432|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return u[a+26496|0]}function SE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=w[b>>2];h=ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],c<<1)|0;a:{if(!h){break a}v[f+14>>1]=65535;$d(a,c>>>0>=65535?65535:c,f+14|0);c=w[a>>2];i=w[a+4>>2];if((c|0)==(i|0)){break a}while(1){b:{if(cd(b,f+8|0)){a=y[f+8>>1];break b}v[f+8>>1]=0;a=0}v[c>>1]=a;g=65535;c:{if((a&65535)!=(d|0)){g=65534;if((a&65535)!=(e|0)){break c}}v[c>>1]=g}c=c+2|0;if((i|0)!=(c|0)){continue}break}}jb=f+16|0;return h|0}function qh(a,b,c){var d=0,e=0,f=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;e=w[b+4>>2];d=x[b+11|0];w[114256]=0;T(70,a|0,(d<<24>>24<0?e:d)|0);d=w[114256];w[114256]=0;if((d|0)!=1){a:{e=x[b+11|0];d=e<<24>>24<0;if(d?w[b+4>>2]:e){while(1){d=w[(x[(d?w[b>>2]:b)+f|0]<<2)+c>>2];w[114256]=0;T(69,a|0,d|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}e=x[b+11|0];d=e<<24>>24<0;f=f+1|0;if(f>>>0<(d?w[b+4>>2]:e)>>>0){continue}break}}return}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function io(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=w[a+24>>2];e=w[f+484360>>2];g=x[a+30|0];if(g>>>0>=(w[f+484364>>2]-e>>>5&255)>>>0){g=x[f+484376|0]}f=0;e=e+(g<<5)|0;a:{if(w[e+4>>2]-w[e>>2]>>1>>>0<=b>>>0){break a}e=w[a>>2];if(!((w[a+4>>2]-e|0)/12>>>0>b>>>0&z[(e+C(b,12)|0)+4>>2]>c>>>0)){if(!d){break a}ti(a,b,c,1);return 0}g=1<<c;e=w[e+C(b,12)>>2]+(c>>>3&536870908)|0;h=w[e>>2];i=g&h;f=(i|0)!=0;if(!d|i){break a}w[e>>2]=g|h;jo(a,b,c);f=0}return f|0}function gy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;w[e+24>>2]=d;g=yf(a,c);rd(e,w[a+28>>2]);d=w[e+12>>2];w[e+16>>2]=w[e+8>>2];w[e+20>>2]=d;a:{if(!g){if(x[a+24|0]&32){break a}}h=w[a+28>>2];d=jb-16|0;jb=d;kl(b,w[e+24>>2]);if(w[e+24>>2]){i=d+8|0;while(1){j=w[b>>2];v[d+6>>1]=0;w[d+12>>2]=i;w[d+8>>2]=d+6;Ob(h,d+8|0);v[(f<<1)+j>>1]=y[d+6>>1];f=f+1|0;if(f>>>0<z[e+24>>2]){continue}break}}jb=d+16|0}a=zf(a,g,c,e+16|0);jb=e+32|0;return a|0}function fH(a,b){a=a|0;b=b|0;var c=0;b=Cb(b,0,44);c=x[a|0]|x[a+1|0]<<8;if(c|(x[a+2|0]|x[a+3|0]<<8)){w[b+20>>2]=((c&65024)>>>9|0)+80;c=(x[a|0]|x[a+1|0]<<8)>>>5&15;w[b+16>>2]=c?(c>>>0>=12?12:c)-1|0:0;c=(x[a|0]|x[a+1|0]<<8)&31;w[b+12>>2]=c?c:1;c=(x[a+2|0]|x[a+3|0]<<8)>>>11|0;w[b+8>>2]=c>>>0>=23?23:c;c=(x[a+2|0]|x[a+3|0]<<8)>>>5&63;w[b+4>>2]=c>>>0>=59?59:c;c=(x[a+2|0]|x[a+3|0]<<8)<<1&62;w[b>>2]=c>>>0>=59?59:c}w[b+44>>2]=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24)}function Lz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];b=w[a+4>>2];if(d){h=w[a+8>>2];i=w[a+12>>2];j=w[a+24>>2];k=w[a+20>>2];l=w[a+16>>2];while(1){e=b+l|0;g=(f>>>21&2040)+32832|0;e=(((C(u[e|0],v[g+2>>1])+C(u[e-1|0],v[g>>1])|0)+C(u[e+1|0],v[g+4>>1])|0)+C(u[e+2|0],v[g+6>>1])<<8)/16384|0;w[c>>2]=w[c>>2]+C(e,k);w[c+4>>2]=w[c+4>>2]+C(e,j);b=b+i|0;f=f+h|0;b=f>>>0<h>>>0?b+1|0:b;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=b}function qs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=x[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=w[114084];w[114084]=0;Cc();a=Bl(a,e+12|0,d);d=nb;g=w[114084];g:{if(g){if(w[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}w[114084]=h;if(w[e+12>>2]==(b|0)){break d}}}}w[c>>2]=4;a=0;break a}if(!d){break b}}w[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a|0}function Od(a){var b=0,c=0,d=0;b=w[15001];w[a>>2]=b;w[a+56>>2]=59992;w[w[b-12>>2]+a>>2]=w[15002];b=w[w[a>>2]-12>>2];w[114256]=0;b=a+b|0;c=a+4|0;T(83,b|0,c|0);d=w[114256];w[114256]=0;a:{b:{if((d|0)!=1){w[b+72>>2]=0;w[b+76>>2]=-1;w[a+56>>2]=59992;w[a>>2]=59972;w[114256]=0;b=V(84,c|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}w[b>>2]=59272;w[a+44>>2]=0;w[a+48>>2]=0;w[a+36>>2]=0;w[a+40>>2]=0;w[a+52>>2]=16;return a}b=P()|0;break a}b=P()|0}pc(a+56|0);R(b|0);M()}function Ij(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!w[w[114126]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){u[a+1|0]=b&63|128;u[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){u[a+2|0]=b&63|128;u[a|0]=b>>>12|224;u[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){u[a+3|0]=b&63|128;u[a|0]=b>>>18|240;u[a+2|0]=b>>>6&63|128;u[a+1|0]=b>>>12&63|128;return 4}}w[114084]=25;a=-1}else{a=1}return a|0}u[a|0]=b;return 1}function Gx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=w[a>>2]<<1;e=c>>>0>h>>>0?h:c;c=c-e|0;i=c>>>0<h>>>0?c:h;j=e>>>1|0;c=w[a+20>>2];if(e>>>0>=2){f=b;e=j;g=d;while(1){k=g;g=x[f|0]|x[f+1|0]<<8;g=k+(g<<8|g>>>8)|0;v[c>>1]=g;c=c+4|0;f=f+2|0;e=e-1|0;if(e){continue}break}c=w[a+20>>2]}a=i>>>1|0;if(i>>>0>=2){f=b+h|0;c=c+2|0;e=a;while(1){b=x[f|0]|x[f+1|0]<<8;d=(b<<8|b>>>8)+d|0;v[c>>1]=d;c=c+4|0;f=f+2|0;e=e-1|0;if(e){continue}break}}return a+j<<1}function uc(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==x[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(x[a|0]==(b&255)|c>>>0<4)){d=C(b&255,16843009);while(1){e=d^w[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==x[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Rc(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=BV(b,c,h,i);i=nb;j=h;h=BV(d,e,f,g);e=j+h|0;d=nb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=BV(g,e,c,d);g=j+i|0;c=nb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=BV(h,0,i,0);b=nb;c=0;d=BV(h,c,l,d);b=b+d|0;c=nb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=BV(i,m,k,e)+b|0;e=nb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;w[g+8>>2]=h;w[g+12>>2]=h>>>0<i>>>0?c+1|0:c;w[g>>2]=f;w[g+4>>2]=d}function wh(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=w[b>>2];h=ob[w[w[g>>2]+36>>2]](g,w[b+8>>2],c)|0;a:{if(!h){break a}v[f+14>>1]=65535;$d(a,c>>>0>=65535?65535:c,f+14|0);c=w[a>>2];i=w[a+4>>2];if((c|0)==(i|0)){break a}while(1){b:{if(Xb(b,f+13|0)){a=x[f+13|0];break b}u[f+13|0]=0;a=0}v[c>>1]=a;g=65535;c:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break c}}v[c>>1]=g}c=c+2|0;if((i|0)!=(c|0)){continue}break}}jb=f+16|0;return h|0}function cx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=D(0);e=w[a>>2];c=c>>>2|0;e=c>>>0>e>>>0?e:c;if(e){g=A[d>>2];c=w[a+20>>2];d=e;while(1){a=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);f=_b(D(D(H(D(G(D(g*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q())),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){a=~~f;break a}a=-2147483648}a=(a|0)>=32767?32767:a;v[c>>1]=(a|0)<=-32768?-32768:a;c=c+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}return e<<2}function Nb(a,b){var c=0,d=0,e=0;a:{b:{c=w[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return Nb(a,24)+(Nb(a,b-24|0)<<24)|0}if(!c){w[a+1392>>2]=0}while(1){d=Dc(a);if((d|0)==-1){break b}e=w[a+1396>>2];c=e+8|0;w[a+1396>>2]=c;w[a+1392>>2]=w[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}w[a+1396>>2]=c-b;c=a;a=w[a+1392>>2];w[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}w[a+1396>>2]=-1;return 0}ha(6022,9008,1632,3155);M()}function cv(a,b,c,d){var e=0,f=0,g=0,h=D(0);e=jb-48|0;jb=e;f=w[a+24>>2];v[f+480214>>1]=0;u[f+1304512|0]=w[a+52>>2]!=0;h=A[a+48>>2];f=w[a+32>>2];w[e+28>>2]=b;w[e+24>>2]=c;w[e+20>>2]=d;w[e+16>>2]=f;w[e+12>>2]=0;A[e+32>>2]=h;w[e+8>>2]=82516;while(1){if(b){c=w[a+24>>2];w[e+40>>2]=82256;c=ki(c,b>>>0>=134217727?134217727:b,e+8|0,e+40|0);g=c+g|0;b=b-c|0;if(c){continue}}break}if(!(w[a+52>>2]!=1|g)){a=w[a+24>>2];w[a+480208>>2]=w[a+480208>>2]&-513}jb=e+48|0;return g}function bv(a,b,c,d){var e=0,f=0,g=0,h=D(0);e=jb-48|0;jb=e;f=w[a+24>>2];v[f+480214>>1]=0;u[f+1304512|0]=w[a+52>>2]!=0;h=A[a+48>>2];f=w[a+32>>2];w[e+28>>2]=b;w[e+24>>2]=c;w[e+20>>2]=d;w[e+16>>2]=f;w[e+12>>2]=0;A[e+32>>2]=h;w[e+8>>2]=82564;while(1){if(b){c=w[a+24>>2];w[e+40>>2]=82256;c=ki(c,b>>>0>=134217727?134217727:b,e+8|0,e+40|0);g=c+g|0;b=b-c|0;if(c){continue}}break}if(!(w[a+52>>2]!=1|g)){a=w[a+24>>2];w[a+480208>>2]=w[a+480208>>2]&-513}jb=e+48|0;return g}function RO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){c=ba(8)|0;w[114256]=0;b=Q(5,h|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,4);c=Um(a,c,d,e,f,g);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=h+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function OO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){c=ba(8)|0;w[114256]=0;b=Q(5,h|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,4);c=Tm(a,c,d,e,f,g);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=h+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function LU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;a:{if(!b){break a}e=C(y[w[w[a+48>>2]+12>>2]+480188>>1],b);b:{if(w[a+12>>2]!=(b|0)){break b}f=w[a>>2];c=w[a+4>>2]-f|0;if((e|0)!=((c|0)/6|0)){break b}if((c|0)<=0){break a}Cb(f,0,C(((c>>>0)/6|0)-(c>>>0>5)|0,6)+6|0);break a}v[d+12>>1]=0;w[d+8>>2]=0;c=Pp(d+16|0,e,d+8|0);e=w[a>>2];if(e){w[a+4>>2]=e;zb(e)}w[a>>2]=w[c>>2];w[a+4>>2]=w[c+4>>2];w[a+8>>2]=w[c+8>>2];w[a+12>>2]=b}jb=d+32|0;return(b|0)!=0|0}function uk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=c>>>0>e>>>0?e:c;a:{b:{if(!g){e=b;break b}f=g;e=b;while(1){h=x[d|0];u[e|0]=h;if(!h){break a}d=d+1|0;e=e+1|0;f=f-1|0;if(f){continue}break}}f=0}c:{if((a-1&255)>>>0<=1){d=(((c+e|0)-g|0)+f|0)-e|0;if((d|0)<=0){break c}Cb(e,0,d);break c}if((a-3&255)>>>0>1){break c}d=(((c+e|0)-g|0)+f|0)-e|0;if((d|0)<=0){break c}Cb(e,32,d)}d:{switch(a-1|0){case 0:case 3:u[(b+c|0)-1|0]=0;break;default:break d}}}function gd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;w[d+8>>2]=0;w[d+12>>2]=0;w[d>>2]=0;w[d+4>>2]=0;a:{if(c){e=c;while(1){f=e>>>0>=16?16:e;h=w[a>>2];if((f|0)!=(ob[w[w[h>>2]+28>>2]](h,d,w[a+8>>2]+g|0,f)|0)){break a}if(Jb(d,b+g|0,f)){break a}g=f+g|0;e=e-f|0;if(e){continue}break}}b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;i=1}jb=d+16|0;return i|0}function yy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=w[b+4>>2];e=w[a>>2];d=c-e|0;f=g-d|0;w[b+4>>2]=f;if((d|0)>0){Fb(f,e,d)}e=w[a+4>>2];if((e|0)!=(c|0)){d=w[b+8>>2];while(1){f=y[c>>1]|y[c+2>>1]<<16;v[d>>1]=f;v[d+2>>1]=f>>>16;d=w[b+8>>2]+4|0;w[b+8>>2]=d;c=c+4|0;if((e|0)!=(c|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2];return g|0}function jd(a){var b=0,c=0,d=D(0),e=0,f=0,g=0,h=0;a:{b:{b=Sg(a)&2047;if(b>>>0<Sg(D(128))>>>0){break b}d=D(0);if(((p(a),j(2))|0)==-8388608){break a}if(Sg(D(O))>>>0<=b>>>0){return D(a+a)}if(a>D(0)){return Cm(0)}if(!(a<=D(-150))){break b}return Bm(0)}c=+a;f=B[6420];g=c+f;c=c-(g-f);c=(B[6421]*c+B[6422])*(c*c)+(B[6423]*c+1);o(+g);j(1)|0;b=j(0)|0;h=b<<15;b=((b&31)<<3)+51104|0;e=w[b>>2];b=w[b+4>>2]+h|0;l(0,e|0);l(1,(e>>>0<e>>>0?b+1|0:b)|0);d=D(c*+n())}return d}function xq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],16)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+16;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;u[b+12|0]=0;u[b+13|0]=0;u[b+14|0]=0;u[b+15|0]=0}jb=c+16|0;return e|0}function OA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;a:{c=w[a>>2];if((w[a+8>>2]-c|0)/12>>>0<b>>>0){if(b>>>0>=357913942){break a}b=Re(e+8|0,b,(w[a+4>>2]-c|0)/12|0,a+8|0);f=w[a+4>>2];c=w[a>>2];g=f-c|0;d=w[b+4>>2]+C((g|0)/-12|0,12)|0;w[b+4>>2]=d;if((g|0)>0){Fb(d,c,g);f=w[a+4>>2];d=w[b+4>>2];c=w[a>>2]}w[a>>2]=d;w[b+4>>2]=c;w[a+4>>2]=w[b+8>>2];w[b+8>>2]=f;d=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b>>2]=c;w[b+12>>2]=d;Kk(b)}jb=e+32|0;return}Mb(a);M()}function SQ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;w[114256]=0;X(1335,a|0);h=w[114256];w[114256]=0;a:{b:{if((h|0)!=1){h=w[a+24>>2];w[114256]=0;b=va(1352,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8776,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function PQ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;w[114256]=0;X(1335,a|0);h=w[114256];w[114256]=0;a:{b:{if((h|0)!=1){h=w[a+24>>2];w[114256]=0;b=va(1355,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8708,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function iC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+11|0];d=e<<24>>24;if(((d|0)<0?w[a+4>>2]:e)>>>0>=b>>>0){if((c|0)==-1){a:{if((d|0)<0){w[a+4>>2]=b;c=w[a>>2];break a}u[a+11|0]=b;c=a}u[c+b|0]=0;return a|0}if(c){d=x[a+11|0];g=d<<24>>24;f=(g|0)<0;h=f?w[a+4>>2]:d;d=h-b|0;e=c>>>0>d>>>0?d:c;f=f?w[a>>2]:a;if(c>>>0<d>>>0){b=b+f|0;hc(b,b+e|0,d-e|0);g=u[a+11|0]}b=h-e|0;b:{if((g|0)<0){w[a+4>>2]=b;break b}u[a+11|0]=b}u[b+f|0]=0}return a|0}Bf();M()}function bq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=w[a+1060>>2];if((b|0)>255){break a}while(1){f=(C(b,6)+a|0)+1068|0,g=xf(a,7),u[f|0]=g;d=xf(a,1);e=xf(a,1);c=w[a+1056>>2];if((c|0)>255){break a}b=w[a+1060>>2]+1|0;w[a+1056>>2]=b;w[a+1060>>2]=b;b:{if(d){v[(C(c,6)+a|0)+1064>>1]=b;bq(a);b=w[a+1060>>2];break b}v[(C(c,6)+a|0)+1064>>1]=65535}w[a+1056>>2]=b;if(e){v[(C(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}v[(C(c,6)+a|0)+1066>>1]=65535}}function rE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=w[b+4>>2];e=w[a>>2];d=c-e|0;f=g-d|0;w[b+4>>2]=f;if((d|0)>0){Fb(f,e,d)}e=w[a+4>>2];if((e|0)!=(c|0)){d=w[b+8>>2];while(1){f=x[c|0]|x[c+1|0]<<8;u[d|0]=f;u[d+1|0]=f>>>8;d=w[b+8>>2]+2|0;w[b+8>>2]=d;c=c+2|0;if((e|0)!=(c|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2];return g|0}function DJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-256|0;jb=a;w[a+248>>2]=37;w[a+252>>2]=0;g=a+248|0;gf(g|1,6527,1,w[c+4>>2]);h=Cc();w[a>>2]=e;w[a+4>>2]=f;e=a+224|0;f=Xc(e,24,h,g,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1760,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Dg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+256|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function BJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-256|0;jb=a;w[a+248>>2]=37;w[a+252>>2]=0;g=a+248|0;gf(g|1,6527,0,w[c+4>>2]);h=Cc();w[a>>2]=e;w[a+4>>2]=f;e=a+224|0;f=Xc(e,24,h,g,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1760,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Dg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+256|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function OJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-112|0;jb=a;w[a+104>>2]=37;w[a+108>>2]=0;g=a+104|0;gf(g|1,6527,1,w[c+4>>2]);h=Cc();w[a>>2]=e;w[a+4>>2]=f;e=a+80|0;f=Xc(e,24,h,g,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1751,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Wg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+112|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function MJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-112|0;jb=a;w[a+104>>2]=37;w[a+108>>2]=0;g=a+104|0;gf(g|1,6527,0,w[c+4>>2]);h=Cc();w[a>>2]=e;w[a+4>>2]=f;e=a+80|0;f=Xc(e,24,h,g,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1751,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Wg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+112|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function KP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;w[114256]=0;X(1407,a|0);f=w[114256];w[114256]=0;a:{b:{if((f|0)!=1){f=w[a+28>>2];g=w[w[f>>2]+72>>2];w[114256]=0;b=db(g|0,f|0,b|0,c|0,+d,+e)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7137,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function wM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;w[d+16>>2]=b;e=w[a+48>>2];w[d+20>>2]=c-((e|0)!=0);g=w[a+44>>2];w[d+28>>2]=e;w[d+24>>2]=g;a:{b:{if(Jj(Ua(w[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=w[d+12>>2];if((e|0)>0){break b}b=e?32:16}w[a>>2]=b|w[a>>2];break a}f=e;g=w[d+20>>2];if(g>>>0>=e>>>0){break a}f=w[a+44>>2];w[a+4>>2]=f;w[a+8>>2]=f+(e-g|0);if(w[a+48>>2]){w[a+4>>2]=f+1;u[(b+c|0)-1|0]=x[f|0]}f=c}jb=d+32|0;return f|0}function Qo(a,b){var c=0,d=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;d=w[b+4>>2];c=x[b+11|0];w[114256]=0;T(72,a|0,(c<<24>>24<0?d:c)|0);c=w[114256];w[114256]=0;if((c|0)!=1){a:{d=x[b+11|0];c=d<<24>>24<0;d=c?w[b+4>>2]:d;if(d){b=c?w[b>>2]:b;d=d+b|0;while(1){c=x[b|0];if((c|0)==13){c=10}w[114256]=0;T(71,a|0,c<<24>>24);c=w[114256];w[114256]=0;if((c|0)==1){break a}b=b+1|0;if((d|0)!=(b|0)){continue}break}}return}}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function mV(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=_d(a),w[g>>2]=h;_d(a);if(f>>>0>=60){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],4)|0){b=w[a+8>>2]+4|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}g=e,h=_d(a),w[g>>2]=h;b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],4)|0){b=w[a+8>>2]+4|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;b=_d(a);w[d>>2]=b;if((b|0)>0){g=c,h=_d(a),w[g>>2]=h}}function dU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4208>>2]=0;w[a+4212>>2]=0;w[a>>2]=77896;b=a+4216|0;w[b>>2]=0;w[b+4>>2]=0;w[a+4224>>2]=0;b=w[c+24620>>2];w[a+4260>>2]=1869112133;w[a+4264>>2]=-11495856;w[a+4232>>2]=b;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)!=1){w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+4208>>2];if(b){w[a+4212>>2]=b;zb(b)}Oc(a);R(c|0);M()}return a|0}function ZS(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;b=w[w[a+16>>2]+24620>>2];c=CV(BV(b,b>>31,3840,0),nb,1e3,0);e=c;b=nb;c=(b|0)>=0&c>>>0>=2147483647|(b|0)>0;e=c?2147483647:e;b=c?0:b;b=(b|0)<0&e>>>0<=2147483648|(b|0)<-1?-2147483648:e;w[a+4276>>2]=b;w[114256]=0;w[d+12>>2]=0;U(992,a+4260|0,b|0,d+12|0);b=w[114256];w[114256]=0;a:{if((b|0)==1){b=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;w[a+4276>>2]=0;aa()}jb=d+16|0;return}R(b|0);M()}function MA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-12|0;w[d>>2]=0;w[d+4>>2]=0;w[d+8>>2]=0;c=c-12|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[d+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;d=w[b+4>>2]-12|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function VC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{d=w[b>>2];b=w[b+4>>2];if((d|0)==(b|0)){break b}while(1){if(y[d>>1]==(c|0)){break b}d=d+24|0;if((b|0)!=(d|0)){continue}break}break a}if((b|0)==(d|0)){break a}w[a>>2]=w[d+8>>2];b=w[d+12>>2];w[a+4>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[d+20>>2];w[a+8>>2]=w[d+16>>2];w[a+12>>2]=b;return}b=Kb(16);w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=75696;w[b>>2]=75656;w[a+8>>2]=0;w[a+12>>2]=0;w[a+4>>2]=b;w[a>>2]=b+12}function $k(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{d=w[b>>2];b=w[b+4>>2];if((d|0)==(b|0)){break b}while(1){if(w[d>>2]==(c|0)){break b}d=d+24|0;if((b|0)!=(d|0)){continue}break}break a}if((b|0)==(d|0)){break a}w[a>>2]=w[d+8>>2];b=w[d+12>>2];w[a+4>>2]=b;if(b){w[b+4>>2]=w[b+4>>2]+1}b=w[d+20>>2];w[a+8>>2]=w[d+16>>2];w[a+12>>2]=b;return}b=Kb(16);w[b+4>>2]=0;w[b+8>>2]=0;w[b+12>>2]=75696;w[b>>2]=75656;w[a+8>>2]=0;w[a+12>>2]=0;w[a+4>>2]=b;w[a>>2]=b+12}function Kq(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((x[a|0]|x[a+1|0]<<8)!=26217){if((x[a|0]|x[a+1|0]<<8)!=20042){break a}if(x[a+110|0]<=64){break b}break a}if(x[a+110|0]>64){break a}}if(u[a+112|0]<0|x[a+111|0]>128){break a}d=1;c=u[a+113|0];c:{if((c|0)<-2){break c}while(1){e=a+b|0;f=x[e+241|0];if(!f&(c|0)>=0|f>>>0>15|x[e+369|0]>=64){break c}d=b>>>0<127;b=b+1|0;if((b|0)==128){break c}c=u[(a+b|0)+113|0];if((c|0)>=-2){continue}break}}b=!d}return b&1}function rc(a){var b=0,c=0,d=0;d=Zh(ec(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=x[a|0];break b}if(a&3){while(1){b=x[a|0];u[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=w[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){w[c>>2]=b;b=w[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}u[c|0]=b;if(!(b&255)){break a}while(1){b=x[a+1|0];u[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function av(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;w[b+24>>2]=e;w[b+28>>2]=f;w[b+16>>2]=c;w[b+20>>2]=c+d;a:{a=hk(a,b+16|0,b+24|0);if(a+1>>>0>=3){d=ba(8)|0;w[114256]=0;a=Q(5,b|0,4242)|0;b=w[114256];w[114256]=0;b:{if((b|0)!=1){b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}c=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}c=P()|0;ca(d|0)}R(c|0);M()}jb=b+32|0;return a|0}M()}function lB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=bp(b,c);w[114256]=0;d=Q(556,a+12|0,c+12|0)|0;b=w[114256];w[114256]=0;a:{if((b|0)!=1){w[114256]=0;Q(557,a+24|0,c+24|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){b=P()|0;c=w[d>>2];if(!c){break a}w[a+16>>2]=c;zb(c);break a}b=w[c+40>>2];w[a+36>>2]=w[c+36>>2];w[a+40>>2]=b;v[a+52>>1]=y[c+52>>1];b=w[c+48>>2];w[a+44>>2]=w[c+44>>2];w[a+48>>2]=b;return}b=P()|0}c=w[a>>2];if(c){w[a+4>>2]=c;zb(c)}R(b|0);M()}function NP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;w[114256]=0;X(1407,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+28>>2];f=w[w[e>>2]+12>>2];w[114256]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7282,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function sx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0);d=w[a>>2];c=c>>>2|0;d=c>>>0>d>>>0?d:c;if(d){c=w[a+20>>2];a=d;while(1){e=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);f=_b(D(D(H(D(G((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[c>>1]=(e|0)<=-32768?-32768:e;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}return d<<2}function MP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;w[114256]=0;X(1407,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+28>>2];f=w[w[e>>2]+8>>2];w[114256]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7318,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Hx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=w[a>>2]<<1;d=c>>>0>f>>>0?f:c;c=c-d|0;g=c>>>0<f>>>0?c:f;h=d>>>1|0;c=w[a+20>>2];if(d>>>0>=2){e=b;d=h;while(1){i=x[e|0]|x[e+1|0]<<8;v[c>>1]=(i<<8|i>>>8)^32768;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}c=w[a+20>>2]}a=g>>>1|0;if(g>>>0>=2){e=b+f|0;c=c+2|0;d=a;while(1){b=x[e|0]|x[e+1|0]<<8;v[c>>1]=(b<<8|b>>>8)^32768;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}}return a+h<<1}function HP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;w[114256]=0;X(1407,a|0);d=w[114256];w[114256]=0;e=1;a:{b:{if((d|0)!=1){d=w[a+28>>2];f=w[w[d>>2]+64>>2];w[114256]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2989,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function HL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;w[114256]=0;w[e+16>>2]=d;w[e+20>>2]=c;ga(136,e+8|0,e+24|0,b|0,e+20|0,e+16|0);c=w[114256];w[114256]=0;if((c|0)!=1){f=w[e+8>>2];d=w[e+12>>2];a:{if(!d){w[a+4>>2]=0;w[a>>2]=f;break a}w[d+4>>2]=w[d+4>>2]+1;c=w[e+12>>2];w[a+4>>2]=d;w[a>>2]=f;if(!c){break a}a=w[c+4>>2];w[c+4>>2]=a-1;if(a){break a}ob[w[w[c>>2]+8>>2]](c);Ib(c)}Bb(b);jb=e+32|0;return}a=P()|0;Bb(b);R(a|0);M()}function FP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;w[114256]=0;X(1407,a|0);d=w[114256];w[114256]=0;e=1;a:{b:{if((d|0)!=1){d=w[a+28>>2];f=w[w[d>>2]+56>>2];w[114256]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3043,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function SO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){c=ba(8)|0;w[114256]=0;b=Q(5,f|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,2);c=Um(a,c,d,e,0,0);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=f+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function PO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){c=ba(8)|0;w[114256]=0;b=Q(5,f|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,2);c=Tm(a,c,d,e,0,0);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=f+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function Oc(a){a=a|0;var b=0,c=0;w[a>>2]=78304;b=w[a+12>>2];if(w[b>>2]==(a|0)){w[b>>2]=w[a+4>>2]}b=w[a+20>>2];if(b){w[b>>2]=0;w[a+20>>2]=0}b=w[a+4>>2];if(b){w[b+8>>2]=w[a+8>>2]}c=w[a+8>>2];if(c){w[c+4>>2]=b}w[a+4>>2]=0;w[a+8>>2]=0;b=w[a+16>>2];w[b+946300>>2]=w[b+946300>>2]-1;b=w[a+80>>2];if(b){w[a+84>>2]=b;zb(b)}b=w[a+68>>2];if(b){w[a+72>>2]=b;zb(b)}b=w[a+56>>2];if(b){w[a+60>>2]=b;zb(b)}b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}return a|0}function Ik(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;h=b;f=w[b>>2];b=(ob[w[w[f>>2]+24>>2]](f)|0)-w[b+8>>2]|0;b=Vc(g+8|0,h,b>>>0<c>>>0?b:c,1);h=w[b>>2];c=w[b+4>>2];f=w[b+8>>2];i=w[b+12>>2];w[114256]=0;c=da(230,a|0,(c?c:(f|0)!=(i|0)?f:0)|0,h|0,d|0,e|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=w[b+8>>2];if(a){w[b+12>>2]=a;zb(a)}jb=g+32|0;return c|0}c=P()|0;a=w[b+8>>2];if(a){w[b+12>>2]=a;zb(a)}R(c|0);M()}function FF(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;w[114256]=0;m=a;a=0;a=Cq(1326,m|a,b,c,d,a|e,f);b=w[114256];w[114256]=0;a:{b:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,4928,g|0,h|0,i|0,j|0,0,0,k|0,l|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}aa();a=-255}break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}return a|0}function Dh(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if((b^-1)-17>>>0>=c>>>0){j=Qb(a);a:{if(b>>>0<2147483623){w[i+8>>2]=b<<1;w[i+12>>2]=b+c;c=_f(w[of(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=nf(a,k);if(e){Dd(c,j,e)}if(g){Dd(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Dd((c+e|0)+g|0,(e+j|0)+f|0,h)}b=b+1|0;if((b|0)!=11){Th(j,b)}hd(a,c);Cd(a,k);b=a;a=h+(e+g|0)|0;Yc(b,a);u[i+7|0]=0;Sc(a+c|0,i+7|0);jb=i+16|0;return}zc(a);M()}function AR(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;a:{b:{if(!a){break b}w[b+8>>2]=a;a=ec(a);w[114256]=0;w[b+12>>2]=a;a=w[b+12>>2];w[b>>2]=w[b+8>>2];w[b+4>>2]=a;a=V(1320,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}$(W(0)|0)|0;w[114256]=0;na(1314,8321,0,0,0,0,0,0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();break b}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}a=0}jb=b+16|0;return a|0}function FJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-160|0;jb=a;w[a+152>>2]=37;w[a+156>>2]=0;f=a+152|0;gf(f|1,6686,1,w[c+4>>2]);g=Cc();w[a>>2]=e;e=a+139|0;f=Xc(e,13,g,f,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1760,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Dg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+160|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function CJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-160|0;jb=a;w[a+152>>2]=37;w[a+156>>2]=0;f=a+152|0;gf(f|1,6686,0,w[c+4>>2]);g=Cc();w[a>>2]=e;e=a+139|0;f=Xc(e,13,g,f,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1760,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Dg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+160|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function Ns(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function iH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=jb-16|0;jb=f;w[f+12>>2]=w[a+8>>2];i=be(f+8|0,f+12|0);w[114256]=0;j=ws(c,d-c|0,b);l=w[114256];w[114256]=0;b:{if((l|0)!=1){Lc(i);jb=f+16|0;break b}a=P()|0;Lc(i);R(a|0);M()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function Ju(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((fi(a+8|0)|0)>(b|0)){break d}}d=ba(8)|0;w[114256]=0;a=Q(5,c|0,6646)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}jb=c+16|0;return+(+w[(w[a+32>>2]+C(b,896)|0)+1075744>>2]*.015625)}b=P()|0;ca(d|0)}R(b|0)}M()}function gQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;w[114256]=0;X(1335,a|0);f=w[114256];w[114256]=0;a:{b:{if((f|0)!=1){f=w[a+24>>2];w[114256]=0;b=da(1389,f|0,b|0,c|0,d|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8192,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function TQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;w[114256]=0;X(1335,a|0);f=w[114256];w[114256]=0;a:{b:{if((f|0)!=1){f=w[a+24>>2];w[114256]=0;b=da(1351,f|0,b|0,c|0,d|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5569,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function QQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;w[114256]=0;X(1335,a|0);f=w[114256];w[114256]=0;a:{b:{if((f|0)!=1){f=w[a+24>>2];w[114256]=0;b=da(1354,f|0,b|0,c|0,d|0,e|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5497,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function ND(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-16|0;c=c-16|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[c>>2]=0;w[c+4>>2]=0;f=w[c+12>>2];w[d+8>>2]=w[c+8>>2];w[d+12>>2]=f;d=w[b+4>>2]-16|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function MD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-112|0;jb=d;c=jb-16|0;jb=c;f=w[a+12>>2];e=d+8|0;w[c+8>>2]=e;w[c+12>>2]=e+98;e=ob[w[w[a>>2]+32>>2]](a,f,c+8|0)|0;if((e|0)==98){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],98)|0){f=w[a+12>>2]+98|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=98){break b}c=0;if(!Yp(d+8|0)){break b}c=a;a=(x[d+55|0]|x[d+56|0]<<8)-98|0;c=Uc(c,b,a,0)}jb=d+112|0;return c|0}function DP(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;w[114256]=0;X(1407,a|0);d=w[114256];w[114256]=0;e=1;a:{b:{if((d|0)!=1){d=w[a+28>>2];f=w[w[d>>2]+48>>2];w[114256]=0;fb(f|0,d|0,b|0,+c);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7481,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Jx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=w[a>>2]<<1;e=c>>>0>g>>>0?g:c;c=c-e|0;i=c>>>0<g>>>0?c:g;j=e>>>1|0;c=w[a+20>>2];if(e>>>0>=2){f=b;e=j;h=d;while(1){h=(x[f|0]|x[f+1|0]<<8)+h|0;v[c>>1]=h;c=c+4|0;f=f+2|0;e=e-1|0;if(e){continue}break}c=w[a+20>>2]}a=i>>>1|0;if(i>>>0>=2){f=b+g|0;c=c+2|0;e=a;while(1){d=(x[f|0]|x[f+1|0]<<8)+d|0;v[c>>1]=d;c=c+4|0;f=f+2|0;e=e-1|0;if(e){continue}break}}return a+j<<1}function Gu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((fi(a+8|0)|0)>(b|0)){break d}}d=ba(8)|0;w[114256]=0;a=Q(5,c|0,6646)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}jb=c+16|0;return(x[(w[a+32>>2]+C(b,896)|0)+1075073|0]&4)>>>2|0}b=P()|0;ca(d|0)}R(b|0)}M()}function px(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=w[a>>2];c=c>>>3|0;c=c>>>0>d>>>0?d:c;if(c){a=w[a+20>>2];d=c;while(1){e=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);l(0,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24));l(1,e|0);f=Tb(H(G(+n(),1),-1)*32768);a:{if(E(f)<2147483648){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;a=a+2|0;b=b+8|0;d=d-1|0;if(d){continue}break}}return c<<3}function bj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[b>>2];d=c;b=w[b+4>>2];a:{if(!b){break a}b=b+c|0;d=c;while(1){if(!x[d|0]){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=b}e=d-c|0;if(e>>>0<4294967280){b:{if(e>>>0<=10){u[a+11|0]=e;break b}f=(e|15)+1|0;b=Kb(f);w[a+8>>2]=f|-2147483648;w[a>>2]=b;w[a+4>>2]=e;a=b}if((d|0)!=(c|0)){while(1){u[a|0]=x[c|0];a=a+1|0;c=c+1|0;if((c|0)!=(d|0)){continue}break}}u[a|0]=0;return}zc(a);M()}function QJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-80|0;jb=a;w[a+72>>2]=37;w[a+76>>2]=0;f=a+72|0;gf(f|1,6686,1,w[c+4>>2]);g=Cc();w[a>>2]=e;e=a+59|0;f=Xc(e,13,g,f,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1751,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Wg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+80|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function NJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-80|0;jb=a;w[a+72>>2]=37;w[a+76>>2]=0;f=a+72|0;gf(f|1,6686,0,w[c+4>>2]);g=Cc();w[a>>2]=e;e=a+59|0;f=Xc(e,13,g,f,a)+e|0;g=yd(e,f,c);h=a+16|0;Sb(h,c);w[114256]=0;ma(1751,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=w[114256];w[114256]=0;a:{if((e|0)!=1){Ab(a+16|0);b=Wg(b,a+32|0,w[a+28>>2],w[a+24>>2],c,d);jb=a+80|0;break a}b=P()|0;Ab(a+16|0);R(b|0);M()}return b|0}function Zg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=w[15046];w[a>>2]=d;w[a+60>>2]=60172;w[w[d-12>>2]+a>>2]=w[15047];w[a+4>>2]=0;d=w[w[a>>2]-12>>2];w[114256]=0;d=a+d|0;e=a+8|0;T(83,d|0,e|0);f=w[114256];w[114256]=0;a:{b:{if((f|0)!=1){w[d+72>>2]=0;w[d+76>>2]=-1;w[a+60>>2]=60172;w[a>>2]=60152;w[114256]=0;S(95,e|0,b|0,c|8)|0;b=w[114256];w[114256]=0;if((b|0)==1){break b}return a|0}b=P()|0;break a}b=P()|0}pc(a+60|0);R(b|0);M()}function RH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{if(!b){break a}$i(a,b);g=x[c|0];c=w[a+4>>2];e=c+b|0;w[a+4>>2]=e;b:{c:{if(!c){f=e-1|0;break c}f=e-1|0;if((f^c-1)>>>0<32){break b}}w[w[a>>2]+((e>>>0>=33?f>>>5|0:0)<<2)>>2]=0}e=c&31;c=w[a>>2]+(c>>>3&536870908)|0;if(g){w[d+12>>2]=e;w[d+8>>2]=c;Kl(d+8|0,b);break a}w[d+12>>2]=e;w[d+8>>2]=c;Jh(d+8|0,b)}jb=d+16|0;return a|0}function sM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=w[a+16>>2];g=w[a+12>>2];b:{if(d>>>0>g>>>0){w[e+12>>2]=2147483647;w[e+8>>2]=d-g;w[e+4>>2]=c-f;d=w[Og(e+12|0,Og(e+8|0,e+4|0))>>2];Dd(b,w[a+12>>2],d);w[a+12>>2]=w[a+12>>2]+d;break b}d=ob[w[w[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Ng(d),u[h|0]=i;d=1}b=b+d|0;f=d+f|0;continue}break}jb=e+16|0;return f|0}function TO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,1);c=Um(a,c,d,0,0,0);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function QO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,1);c=Tm(a,c,d,0,0,0);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function Ix(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=w[a>>2]<<1;d=c>>>0>f>>>0?f:c;c=c-d|0;g=c>>>0<f>>>0?c:f;h=d>>>1|0;c=w[a+20>>2];if(d>>>0>=2){e=b;d=h;while(1){i=x[e|0]|x[e+1|0]<<8;v[c>>1]=i<<8|i>>>8;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}c=w[a+20>>2]}a=g>>>1|0;if(g>>>0>=2){e=b+f|0;c=c+2|0;d=a;while(1){b=x[e|0]|x[e+1|0]<<8;v[c>>1]=b<<8|b>>>8;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}}return a+h<<1}function Yj(a){var b=0,c=0,d=0;b=x[a+4266|0];A[a+4236>>2]=D(b>>>0)*D(.00390625);A[a+4240>>2]=D(256-b|0)*D(.00390625);c=x[a+4267|0];b=x[a+4265|0];A[a+4244>>2]=D(C(c,b)|0)*D(152587890625e-16);d=c|-256;A[a+4256>>2]=D(C(d,b|-256)|0)*D(152587890625e-16);A[a+4252>>2]=D(C(b,d)|0)*D(152587890625e-16);A[a+4248>>2]=D(C(256-b|0,c)|0)*D(152587890625e-16);b=a;c=w[a+4232>>2];a=x[a+4264|0];w[b+4228>>2]=(C(c,(a?a:-89)&255)+250>>>0)/500}function UU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;g=-1;d=jb-16|0;jb=d;f=w[a+12>>2];e=c+8|0;w[d+8>>2]=e;w[d+12>>2]=e+24;e=ob[w[w[a>>2]+32>>2]](a,f,d+8|0)|0;if((e|0)==24){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],24)|0){f=w[a+12>>2]+24|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=d+16|0;b:{if((e|0)!=24){break b}g=0;if(!tw(c+8|0)|(w[c+16>>2]!=w[b>>2]|w[b+4>>2]?b:0)){break b}g=1}jb=c+32|0;return g|0}function KL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=w[a+12>>2];f=w[a+16>>2];b:{if(d>>>0<f>>>0){w[e+12>>2]=2147483647;w[e+8>>2]=f-d>>2;w[e+4>>2]=c-g;d=w[Og(e+12|0,Og(e+8|0,e+4|0))>>2];de(b,w[a+12>>2],d);f=d<<2;w[a+12>>2]=f+w[a+12>>2];b=b+f|0;break b}d=ob[w[w[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}w[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}jb=e+16|0;return g|0}function HB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;c=-1;a:{if(!eq(a,d+8|0)){break a}c=0;if(!pp(d+8|0)){break a}c=a;h=y[d+36>>1];a=BV(x[d+38|0],0,37,0);g=nb;e=BV(y[d+32>>1],0,192,0);f=e+a|0;a=nb+g|0;g=f;f=f>>>0<e>>>0?a+1|0:a;i=c;e=b;b=x[d+34|0];a=b>>>26|0;c=b<<6;b=c+g|0;a=a+f|0;a=b>>>0<c>>>0?a+1|0:a;c=b;b=b+h|0;a=b>>>0<c>>>0?a+1|0:a;b=b+192|0;a=b>>>0<192?a+1|0:a;c=Uc(i,e,b,a)}jb=d+80|0;return c|0}function Xx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=x[a+11|0];f=e<<24>>24;if(((f|0)<0?w[a+4>>2]:e)>>>0>=b>>>0){if((c|0)==-1){a:{if((f|0)<0){w[a+4>>2]=b;c=w[a>>2];break a}u[a+11|0]=b;c=a}u[c+b|0]=0;return a|0}d=jb-16|0;jb=d;w[d+12>>2]=c;if(c){f=Db(a);e=Qb(a);c=f-b|0;w[d+8>>2]=c;g=w[ag(d+12|0,d+8|0)>>2];w[d+12>>2]=g;if((c|0)!=(g|0)){b=b+e|0;Eh(b,b+g|0,c-g|0);c=w[d+12>>2]}Cl(a,e,f-c|0)}jb=d+16|0;return a|0}Bf();M()}function UG(a){a=a|0;if(x[460512]){return w[115127]}if(!x[461032]){a=460864;while(1){a=Wb(a)+12|0;if((a|0)!=461032){continue}break}u[461032]=1}cc(460864,70692);cc(460876,70720);cc(460888,70748);cc(460900,70780);cc(460912,70820);cc(460924,70856);cc(460936,70884);cc(460948,70920);cc(460960,70936);cc(460972,70952);cc(460984,70968);cc(460996,70984);cc(461008,71e3);cc(461020,71016);u[460512]=1;w[115127]=460864;return 460864}function lh(a,b,c,d){var e=0,f=0,g=0;a:{b=u[(a+b|0)+58|0];if((b|0)<0){break a}e=w[a>>2];if(!e){break a}f=(b|0)<0?-1:b;b=f&255;g=C(b,12)+a|0;if(f>>>0<=8){b=x[b+25584|0]}else{b=x[b+25575|0]|256}if(u[g+324|0]&1|d){f=e;e=x[g+316|0];Pd(f,b- -64|0,(c>>>0<=62?63-(C((e^-1)&63,(c?c+1|0:0)&255)>>>6|0)|e&192:e)&255)}if(d){break a}d=w[a>>2];a=x[g+317|0];Pd(d,b+67|0,(c>>>0<=62?63-(C((a^-1)&63,(c?c+1|0:0)&255)>>>6|0)|a&192:a)&255)}}function Jk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-32|0;jb=f;g=b;e=w[b>>2];b=(ob[w[w[e>>2]+24>>2]](e)|0)-w[b+8>>2]|0;b=Vc(f+8|0,g,b>>>0<c>>>0?b:c,1);g=w[b>>2];c=w[b+4>>2];e=w[b+8>>2];h=w[b+12>>2];w[114256]=0;Z(603,a|0,(c?c:(e|0)!=(h|0)?e:0)|0,g|0,d|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){a=w[b+8>>2];if(a){w[b+12>>2]=a;zb(a)}jb=f+32|0;return 1}c=P()|0;a=w[b+8>>2];if(a){w[b+12>>2]=a;zb(a)}R(c|0);M()}function HE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;w[a>>2]=0;w[a+4>>2]=0;d=w[b>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[b+8>>2],c)|0)){c=w[b>>2];c=(ob[w[w[c>>2]+24>>2]](c)|0)-w[b+8>>2]|0}w[a>>2]=c;d=w[b>>2];if(ob[w[w[d>>2]+16>>2]](d)|0){c=a;a=w[b>>2];e=c,f=(ob[w[w[a>>2]+20>>2]](a)|0)+w[b+8>>2]|0,w[e+4>>2]=f;return}$e(a+8|0,w[a>>2]);d=w[a+12>>2];a=w[a+8>>2];if((d|0)!=(a|0)){d=w[b>>2];ob[w[w[d>>2]+28>>2]](d,a,w[b+8>>2],c)|0}}function BL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+4>>2]=0;w[a+8>>2]=0;w[a>>2]=75760;e=w[b>>2];b=w[b+4>>2];if(!b){b=w[c>>2];w[a+28>>2]=w[d>>2];w[a+24>>2]=b;w[a+20>>2]=0;w[a+16>>2]=e;w[a+12>>2]=75800;return a|0}w[b+4>>2]=w[b+4>>2]+1;c=w[c>>2];d=w[d>>2];w[a+20>>2]=b;w[a+16>>2]=e;w[a+12>>2]=75800;w[b+4>>2]=w[b+4>>2]+1;w[a+28>>2]=d;w[a+24>>2]=c;c=w[b+4>>2];w[b+4>>2]=c-1;if(!c){ob[w[w[b>>2]+8>>2]](b);Ib(b)}return a|0}function wP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+20>>2];w[114256]=0;T(e|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5228,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function vP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+16>>2];w[114256]=0;T(e|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8578,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function jO(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{b:{if(w[a+36>>2]!=w[a+40>>2]){c=w[a+40>>2];a=w[a+36>>2];break b}Vg(b+8|0,a);w[114256]=0;d=V(22,12)|0;c=w[114256];w[114256]=0;if((c|0)==1){break a}w[d>>2]=w[b+8>>2];w[d+4>>2]=w[b+12>>2];w[d+8>>2]=w[b+16>>2];c=w[a+36>>2]==w[a+40>>2]?d:a+36|0;a=w[c>>2];c=w[c+4>>2];w[b+24>>2]=0;kd(d)}jb=b+32|0;return(c-a|0)/24|0}d=P()|0;a=w[b+8>>2];if(a){w[b+12>>2]=a;zb(a)}R(d|0);M()}function fC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=w[b+4>>2];e=w[a>>2];d=c-e|0;g=f-d|0;w[b+4>>2]=g;if((d|0)>0){Fb(g,e,d)}e=w[a+4>>2];if((e|0)!=(c|0)){d=w[b+8>>2];while(1){u[d|0]=x[c|0];d=w[b+8>>2]+1|0;w[b+8>>2]=d;c=c+1|0;if((e|0)!=(c|0)){continue}break}}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2];return f|0}function NO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,2);c=cv(a,c,2,d);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function MO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,4);c=cv(a,c,4,d);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function LP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+76>>2];w[114256]=0;T(e|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7147,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function KO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,2);c=bv(a,c,2,d);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function JO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){c=ba(8)|0;w[114256]=0;b=Q(5,e|0,4385)|0;a=w[114256];w[114256]=0;if((a|0)==1){break c}a=Pb(c,b);w[114256]=0;U(194,a|0,82064,1337);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;if(u[b+11|0]>=0){break b}zb(w[b>>2]);break b}xe(a,b,4);c=bv(a,c,4,d);B[a+16>>3]=+(c>>>0)/+(b|0)+B[a+16>>3];jb=e+16|0;return c|0}a=P()|0;ca(c|0)}R(a|0)}M()}function AC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;w[c+16>>2]=b;d=b;f=a;b=w[a+4>>2];a:{b:{if(!b){d=f+4|0;a=d;break b}e=y[d>>1];while(1){a=b;b=y[b+14>>1];if(b>>>0>e>>>0){d=a;b=w[a>>2];if(b){continue}break b}if(b>>>0>=e>>>0){b=a;a=0;break a}b=w[a+4>>2];if(b){continue}break}d=a+4|0}b=Kb(20);e=y[w[c+16>>2]>>1];v[b+16>>1]=0;v[b+14>>1]=e;Xe(f,a,d,b);a=1}u[c+28|0]=a;w[c+24>>2]=b;jb=c+32|0;return w[c+24>>2]+16|0}function zP(a,b){a=a|0;b=+b;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+32>>2];w[114256]=0;sa(e|0,c|0,+b);c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3989,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;if((d|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function xP(a,b){a=a|0;b=+b;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+24>>2];w[114256]=0;sa(e|0,c|0,+b);c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3937,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;if((d|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function dx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0),g=D(0);e=w[a>>2];c=c>>>2|0;c=c>>>0>e>>>0?e:c;if(c){g=A[d>>2];a=w[a+20>>2];d=c;while(1){f=_b(D(D(H(D(G(D(g*(l(2,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24)),q())),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}return c<<2}function BP(a,b){a=a|0;b=+b;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+40>>2];w[114256]=0;sa(e|0,c|0,+b);c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7519,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);d=w[114256];w[114256]=0;if((d|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function VQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1350,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5367,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function RQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1353,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5336,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function OQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1356,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5530,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function NQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1357,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8739,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function MQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1358,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5452,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function LQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[114256]=0;X(1335,a|0);e=w[114256];w[114256]=0;a:{b:{if((e|0)!=1){e=w[a+24>>2];w[114256]=0;b=Z(1359,e|0,b|0,c|0,d|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8665,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Im(a){var b=0,c=0,d=0;a:{b:{if(!w[a+1384>>2]){b=w[a+1380>>2];if((b|0)==-1){w[a+1388>>2]=w[a+1116>>2]-1;if(!Pj(a)){w[a+1384>>2]=1;return 0}if(!(u[a+1375|0]&1)){break b}b=w[a+1380>>2]}d=b+1|0;w[a+1380>>2]=d;c=x[(a+b|0)+1120|0];if((c|0)!=255){w[a+1388>>2]=b;w[a+1384>>2]=1}if(w[a+1116>>2]<=(d|0)){w[a+1380>>2]=-1}if(x[a+1376|0]){break a}u[a+1376|0]=c}return c}w[a+100>>2]=32;return 0}ha(11656,9008,1564,2463);M()}function EP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+28>>2];e=w[w[c>>2]+52>>2];w[114256]=0;d=+eb(e|0,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7500,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return+d}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function IP(a,b){a=a|0;b=b|0;var c=0,d=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+28>>2];d=w[w[c>>2]+68>>2];w[114256]=0;b=Q(d|0,c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3016,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function GP(a,b){a=a|0;b=b|0;var c=0,d=0;w[114256]=0;X(1407,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+28>>2];d=w[w[c>>2]+60>>2];w[114256]=0;b=Q(d|0,c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3067,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Bv(a){var b=D(0),c=0,d=D(0);u[a+4264|0]=A[a+4236>>2]>D(.5);b=A[a+4224>>2];A[a+4260>>2]=L(D(D(1)-D(b*b)));d=D(z[a+4256>>2]);b=D(D(D(A[a+4228>>2]*D(1.999000072479248))+D(.0010000000474974513))*d);a:{if(b<D(4294967296)&b>=D(0)){c=~~b>>>0;break a}c=0}w[a+4248>>2]=c;c=a+4252|0;b=D(D(D(A[a+4232>>2]*D(1.999000072479248))+D(.0010000000474974513))*d);b:{if(b<D(4294967296)&b>=D(0)){a=~~b>>>0;break b}a=0}w[c>>2]=a}function Mn(a,b,c,d){a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(x[a+1074312|0]&8|d>>>0<224){break c}if(!(u[(C(b,896)+a|0)+1075856|0]&1)){break a}c=C((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(!(x[a+1074312|0]&8)&(u[(C(b,896)+a|0)+1075856|0]&1)){break a}c=c<<2}if(!c){break a}d=lk(a,b);if(!d){break a}a=w[(C(b,896)+a|0)+1075640>>2];if(a){a=x[a+33|0]}else{a=13}ob[w[w[d>>2]+80>>2]](d,c,a<<24>>24,b)}}function nP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Ve(d,0,c);w[114256]=0;c=w[d+8>>2];w[d+8>>2]=0;w[d+28>>2]=c;w[d+16>>2]=b;b=w[d>>2];c=w[d+4>>2];w[d>>2]=0;w[d+4>>2]=0;w[d+20>>2]=b;w[d+24>>2]=c;T(1440,a+4|0,d+16|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+31|0]<0){zb(w[d+20>>2])}if(u[d+11|0]<0){zb(w[d>>2])}jb=d+32|0;return}a=P()|0;if(u[d+31|0]<0){zb(w[d+20>>2])}if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}function Vx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=w[b+4>>2];c=w[a+4>>2];e=w[a>>2];if((c|0)!=(e|0)){while(1){d=d-12|0;c=c-12|0;w[d>>2]=w[c>>2];w[d+4>>2]=w[c+4>>2];w[d+8>>2]=w[c+8>>2];w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0;d=w[b+4>>2]-12|0;w[b+4>>2]=d;if((c|0)!=(e|0)){continue}break}e=w[a>>2]}w[a>>2]=d;w[b+4>>2]=e;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2]}function Qx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=w[b+4>>2];e=w[a>>2];d=c-e|0;g=f-d|0;w[b+4>>2]=g;if((d|0)>0){Fb(g,e,d)}e=w[a+4>>2];if((e|0)!=(c|0)){d=w[b+8>>2];while(1){v[d>>1]=y[c>>1];d=d+2|0;c=c+2|0;if((e|0)!=(c|0)){continue}break}w[b+8>>2]=d}c=w[a>>2];w[a>>2]=w[b+4>>2];w[b+4>>2]=c;c=w[a+4>>2];w[a+4>>2]=w[b+8>>2];w[b+8>>2]=c;c=w[a+8>>2];w[a+8>>2]=w[b+12>>2];w[b+12>>2]=c;w[b>>2]=w[b+4>>2];return f|0}function iK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=D(0),g=0,h=D(0);e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=w[114084];w[114084]=0;Cc();d=jb-16|0;jb=d;Xl(d,a,e+12|0,0);f=Gs(w[d>>2],w[d+4>>2],w[d+8>>2],w[d+12>>2]);jb=d+16|0;a=w[114084];if(!a){break c}if(w[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}w[c>>2]=4;break a}w[114084]=g;if(w[e+12>>2]==(b|0)){break a}}w[c>>2]=4;f=h}jb=e+16|0;return D(f)}function Xj(a){var b=0,c=0,d=0;b=Ed(+A[a+4228>>2]*8)*.25+-.25;B[a+4248>>3]=b;if(x[a+4240|0]){if(!(b<=45e-5)){b=$h(b)*1.4426950408889634;c=I(b);b=b-c;d=0;a:{if(b<.2075187496394219){break a}d=.4150374992788438;if(b<.5){break a}d=b<.792481250360578?.5849625007211562:1}c=Ed(d+c)*.5}B[a+4248>>3]=c;B[a+4264>>3]=c*.016666666666666666*B[a+4288>>3]/+z[w[a+16>>2]+24620>>2];return}B[a+4264>>3]=b/+z[w[a+16>>2]+24620>>2]}function pC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){if(b>>>0>=214748365){Mb(a);M()}d=C(b,20);c=Kb(d);w[a>>2]=c;w[a+4>>2]=c;w[a+8>>2]=c+d;c=w[a+4>>2];a:{b:{if(b){b=C(b,20)+c|0;d=a+8|0;while(1){w[114256]=0;T(493,d|0,c|0);e=w[114256];w[114256]=0;if((e|0)==1){break b}c=c+20|0;if((b|0)!=(c|0)){continue}break}}else{b=c}w[a+4>>2]=b;break a}b=P()|0;w[a+4>>2]=c;R(b|0);M()}}return a|0}function WQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;e=1;a:{b:{if((d|0)!=1){d=w[a+24>>2];w[114256]=0;U(1349,d|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,6261,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Kx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=w[a>>2]<<1;d=c>>>0>f>>>0?f:c;c=c-d|0;g=c>>>0<f>>>0?c:f;h=d>>>1|0;c=w[a+20>>2];if(d>>>0>=2){e=b;d=h;while(1){v[c>>1]=(x[e|0]|x[e+1|0]<<8)^32768;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}c=w[a+20>>2]}a=g>>>1|0;if(g>>>0>=2){e=b+f|0;c=c+2|0;d=a;while(1){v[c>>1]=(x[e|0]|x[e+1|0]<<8)^32768;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}}return a+h<<1}function GE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;f=w[a+12>>2];d=e+8|0;w[c+8>>2]=d;w[c+12>>2]=d+1954;d=ob[w[w[a>>2]+32>>2]](a,f,c+8|0)|0;if((d|0)==1954){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1954)|0){f=w[a+12>>2]+1954|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((d|0)!=1954){break b}c=0;if(!nq(e+8|0)){break b}c=Uc(a,b,1024,0)}jb=e+1968|0;return c|0}function xA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=4896?4896:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,4896-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function sD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],12)|0;a:{if(!e){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0;u[b+8|0]=0;u[b+9|0]=0;u[b+10|0]=0;u[b+11|0]=0;break a}f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+12;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h}jb=c+16|0;return e|0}function fB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-608|0;jb=d;c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=d;w[c+12>>2]=d+608;e=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((e|0)==608){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],608)|0){f=w[a+12>>2]+608|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=608){break b}c=0;if(!ap(d)){break b}c=Uc(a,b,BV(y[d+34>>1],0,80,0),nb)}jb=d+608|0;return c|0}function WG(a){a=a|0;if(x[460504]){return w[115125]}if(!x[460856]){a=460688;while(1){a=Wb(a)+12|0;if((a|0)!=460856){continue}break}u[460856]=1}dc(460688,1730);dc(460700,1737);dc(460712,1703);dc(460724,1711);dc(460736,1694);dc(460748,1744);dc(460760,1721);dc(460772,5629);dc(460784,5909);dc(460796,7133);dc(460808,8661);dc(460820,1989);dc(460832,6696);dc(460844,2916);u[460504]=1;w[115125]=460688;return 460688}function Cu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){d=ba(8)|0;w[114256]=0;a=Q(5,c|0,6646)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}a=w[a+32>>2]+C(b,896)|0;w[a+1075e3>>2]=0;w[a+1075060>>2]=0;jb=c+16|0;return}b=P()|0;ca(d|0)}R(b|0)}M()}function qM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=w[a+28>>2];g=w[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Md(u[b|0]),h=w[w[a>>2]+52>>2],ob[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{w[e+12>>2]=d-g;w[e+8>>2]=c-f;d=w[Og(e+12|0,e+8|0)>>2];Dd(w[a+24>>2],b,d);w[a+24>>2]=d+w[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function ZQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;a:{b:{if((d|0)!=1){d=w[a+24>>2];w[114256]=0;e=+ra(1345,d|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,1836,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();e=0}return+e}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function WN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(u[b+11|0]>=0){d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;w[a+8>>2]=w[b+8>>2];break a}Ge(a,w[b>>2],w[b+4>>2])}b=a+12|0;b:{if(u[c+11|0]>=0){d=w[c+4>>2];w[b>>2]=w[c>>2];w[b+4>>2]=d;w[b+8>>2]=w[c+8>>2];break b}d=w[c+4>>2];c=w[c>>2];w[114256]=0;U(76,b|0,c|0,d|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}return a|0}function Ah(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;w[d+8>>2]=0;w[d+12>>2]=0;w[d>>2]=0;w[d+4>>2]=0;a:{if(c){e=c;while(1){f=e>>>0>=16?16:e;if((f|0)!=(ob[w[w[a>>2]+28>>2]](a,d,w[a+12>>2]+g|0,f)|0)){break a}if(Jb(d,b+g|0,f)){break a}g=f+g|0;e=e-f|0;if(e){continue}break}}b:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],c)|0){b=w[a+12>>2]+c|0;break b}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b;h=1}jb=d+16|0;return h}function yQ(a,b){a=a|0;b=b|0;var c=0,d=D(0);w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;d=D(qa(1372,c|0,b|0));b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2523,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=D(0)}return D(d)}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function xQ(a,b){a=a|0;b=b|0;var c=0,d=D(0);w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;d=D(qa(1373,c|0,b|0));b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2659,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=D(0)}return D(d)}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function wQ(a,b){a=a|0;b=b|0;var c=0,d=D(0);w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;d=D(qa(1374,c|0,b|0));b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2567,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=D(0)}return D(d)}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function oP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){d=c-d>>4;jl(a,d);e=w[b>>2];f=w[b+4>>2];b=jb-16|0;jb=b;w[b>>2]=a;c=w[a+4>>2];w[114256]=0;w[b+4>>2]=c;w[b+8>>2]=c+(d<<4);Y(1439,a+8|0,e|0,f|0,b|4);c=w[114256];w[114256]=0;a:{if((c|0)!=1){w[w[b>>2]+4>>2]=w[b+4>>2];jb=b+16|0;break a}a=P()|0;w[w[b>>2]+4>>2]=w[b+4>>2];R(a|0);M()}}return a|0}function EF(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;w[114256]=0;a=Ja(1327,a|0,b|0,c|0,d|0)|0;b=w[114256];w[114256]=0;a:{b:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,7e3,e|0,f|0,g|0,h|0,0,0,i|0,j|0);a=w[114256];w[114256]=0;if((a|0)==1){break b}aa();a=-255}break a}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}return a|0}function BQ(a,b){a=a|0;b=b|0;var c=0,d=D(0);w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;d=D(qa(1370,c|0,b|0));b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5293,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=D(0)}return D(d)}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function AQ(a,b){a=a|0;b=b|0;var c=0,d=D(0);w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;d=D(qa(1371,c|0,b|0));b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2616,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=D(0)}return D(d)}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function yP(a){a=a|0;var b=0,c=0,d=0;w[114256]=0;X(1407,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+28>>2];d=w[w[b>>2]+28>>2];w[114256]=0;c=+pa(d|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3954,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function ls(a){var b=0,c=0,d=0,e=0;a:{b=w[a+4>>2];d=w[a>>2];c=b-d|0;b:{if(c>>>0>=w[a+8>>2]-d>>>0){break b}c:{d:{if((b|0)==(d|0)){b=c;break d}w[114256]=0;e=V(22,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=c+e|0;if((c|0)>0){Fb(e,d,c)}c=e}w[a+8>>2]=b;w[a+4>>2]=b;w[a>>2]=c;if(!d){break b}zb(d);return}$(W(0)|0)|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function CP(a){a=a|0;var b=0,c=0,d=0;w[114256]=0;X(1407,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+28>>2];d=w[w[b>>2]+44>>2];w[114256]=0;c=+pa(d|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,7537,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function CA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=263?263:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,263-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function AP(a){a=a|0;var b=0,c=0,d=0;w[114256]=0;X(1407,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+28>>2];d=w[w[b>>2]+36>>2];w[114256]=0;c=+pa(d|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,4006,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function rK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){g=w[114084];w[114084]=0;Cc();d=Zq(a,e+12|0,d);a=nb;f=w[114084];c:{if(f){if(w[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}w[114084]=g;if(w[e+12>>2]==(b|0)){break a}}}w[c>>2]=4;d=0;a=0;break a}w[c>>2]=4;if(!!d&(a|0)>=0|(a|0)>0){d=-1;a=2147483647;break a}d=0;a=-2147483648}jb=e+16|0;nb=a;return d|0}function JC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;c=jb-16|0;jb=c;f=w[a+12>>2];e=d+8|0;w[c+8>>2]=e;w[c+12>>2]=e+52;e=ob[w[w[a>>2]+32>>2]](a,f,c+8|0)|0;if((e|0)==52){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],52)|0){f=w[a+12>>2]+52|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=52){break b}c=0;if(!Ip(d+8|0)){break b}c=Uc(a,b,Hp(d+8|0),nb)}jb=d- -64|0;return c|0}function vk(a,b){var c=0,d=0,e=0;v[a+24>>1]=0;w[a+20>>2]=0;w[a>>2]=0;w[a+4>>2]=0;d=3546895/+(b>>>0);c=d*.25;a:{if(E(c)<2147483648){b=~~c;break a}b=-2147483648}w[a+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(E(c)<0x8000000000000000){e=~~c>>>0;b=E(c)>=1?~~(c>0?G(I(c*2.3283064365386963e-10),4294967295):J((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}w[a+8>>2]=e;w[a+12>>2]=b;return a}function oQ(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=Hb(e,11528);c=x[d+11|0];f=c<<24>>24;a=(f|0)<0?w[d+4>>2]:c;b=0;a:{if(!a){break a}b:{if((a|0)<=0){break b}c=(f|0)<0?w[d>>2]:d;g=c+a|0;b=c;while(1){a=uc(b,77,a);if(!a){break b}if(x[a|0]!=77){b=a+1|0;a=g-b|0;if((a|0)>0){continue}break b}break}if((a|0)==(g|0)){break b}b=1;if((a-c|0)!=-1){break a}}b=0}if((f|0)<0){zb(w[d>>2])}jb=e+16|0;return b|0}function rT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=33?33:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,33-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function eF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=65?65:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,65-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function FC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=22?22:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,22-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function EC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=40?40:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,40-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return d|0}function gK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=w[114084];w[114084]=0;Cc();d=jb-16|0;jb=d;Xl(d,a,e+12|0,1);f=xm(w[d>>2],w[d+4>>2],w[d+8>>2],w[d+12>>2]);jb=d+16|0;a=w[114084];if(!a){break c}if(w[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}w[c>>2]=4;break a}w[114084]=g;if(w[e+12>>2]==(b|0)){break a}}w[c>>2]=4;f=h}jb=e+16|0;return+f}function aA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];e=w[a+4>>2];if(d){h=w[a+8>>2];j=w[a+12>>2];b=w[a+24>>2];k=w[a+20>>2];l=w[a+16>>2];while(1){i=e+l|0;g=u[i|0];g=((C(u[i+1|0]-g|0,f>>>10&4194048)|0)/16384|0)+(g<<8)|0;w[c>>2]=w[c>>2]+C(g,k);w[c+4>>2]=w[c+4>>2]+C(b,g);e=e+j|0;f=f+h|0;e=f>>>0<h>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function Yd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=x[a+11|0];d=f<<24>>24;e=x[b+11|0];c=e<<24>>24;a:{g=(c|0)<0?w[b+4>>2]:e;e=(d|0)<0?w[a+4>>2]:f;b:{if((g|0)!=(e|0)){break b}b=(c|0)<0?w[b>>2]:b;c:{c=(d|0)<0;if(!c){if(d){break c}break a}if(!e){break a}return!Jb(c?w[a>>2]:a,b,e)}while(1){d=x[a|0];c=x[b|0];h=(d|0)==(c|0);if((c|0)!=(d|0)){break b}b=b+1|0;a=a+1|0;f=f-1|0;if(f){continue}break}}return h}return 1}function Fc(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=ci(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(mu(a,b)&3){case 0:c=ci(B[b>>3],B[b+8>>3]);break a;case 1:c=-bi(B[b>>3],B[b+8>>3],1);break a;case 2:c=-ci(B[b>>3],B[b+8>>3]);break a;default:break b}}c=bi(B[b>>3],B[b+8>>3],1)}a=c;jb=b+16|0;return a}function oA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];e=w[a+4>>2];if(d){g=w[a+8>>2];i=w[a+12>>2];b=w[a+24>>2];j=w[a+20>>2];k=w[a+16>>2];while(1){h=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;l=v[h+2>>1];w[c>>2]=w[c>>2]+C(v[h>>1],j);w[c+4>>2]=w[c+4>>2]+C(b,l);e=e+i|0;f=f+g|0;e=f>>>0<g>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function fR(a,b){a=a|0;b=b|0;var c=0,d=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1338,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,6799,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function dR(a,b){a=a|0;b=b|0;var c=0,d=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;d=1;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;T(1340,c|0,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2270,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function XO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-32|0;jb=b;w[b+24>>2]=c;w[b+28>>2]=c+d;a:{a=hk(a,b+24|0,0);if(a+1>>>0>=3){d=ba(8)|0;w[114256]=0;a=Q(5,b+8|0,4242)|0;b=w[114256];w[114256]=0;b:{if((b|0)!=1){b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}c=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}c=P()|0;ca(d|0)}R(c|0);M()}jb=b+32|0;return a|0}M()}function $z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];e=w[a+4>>2];if(d){h=w[a+8>>2];j=w[a+12>>2];b=w[a+24>>2];k=w[a+20>>2];l=w[a+16>>2];while(1){i=(e<<1)+l|0;g=v[i>>1];g=g+((C(v[i+2>>1]-g|0,f>>>18|0)|0)/16384|0)|0;w[c>>2]=w[c>>2]+C(g,k);w[c+4>>2]=w[c+4>>2]+C(b,g);e=e+j|0;f=f+h|0;e=f>>>0<h>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function xJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;f=Cc();w[a>>2]=e;g=a+176|0;i=Xc(g,20,f,5192,a);e=i+g|0;g=yd(g,e,c);f=a+8|0;Sb(f,c);w[114256]=0;f=V(1735,f|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){Ab(a+8|0);h=f;f=a+16|0;os(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Dg(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;Ab(a+8|0);R(b|0);M()}function tx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=D(0);d=w[a>>2];c=c>>>2|0;c=c>>>0>d>>>0?d:c;if(c){a=w[a+20>>2];d=c;while(1){f=_b(D(D(H(D(G((l(2,x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24)),q()),D(1))),D(-1)))*D(32768)));a:{if(D(E(f))<D(2147483648)){e=~~f;break a}e=-2147483648}e=(e|0)>=32767?32767:e;v[a>>1]=(e|0)<=-32768?-32768:e;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}return c<<2}function Vp(a){var b=0,c=0,d=0;a:{if((x[a+60|0]|x[a+61|0]<<8|(x[a+62|0]<<16|x[a+63|0]<<24))!=808537417|(x[a+32|0]|x[a+33|0]<<8)>>>0>256|(x[a+49|0]<32|(x[a+36|0]|x[a+37|0]<<8)>>>0>255)){break a}if(u[a+51|0]<4|x[a+50|0]>64){break a}c=a+576|0;a=a- -64|0;while(1){b=0;b:{switch(x[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}b=d;a=a+16|0;if((c|0)!=(a|0)){continue}break}}return b&1}function Ou(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-513>>>0<=4294966814){d=ba(8)|0;w[114256]=0;a=Q(5,c|0,5279)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}w[w[a+32>>2]+1074420>>2]=C(b,1e4);jb=c+16|0;return}b=P()|0;ca(d|0)}R(b|0)}M()}function iQ(a,b){a=a|0;b=b|0;var c=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;b=Q(1387,c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5672,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function hQ(a,b){a=a|0;b=b|0;var c=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;b=Q(1388,c|0,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2953,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function en(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a|0];f=x[c|0];a:{b:{if(!(x[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){u[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(x[b|0]|(e-5&255)>>>0>1){break a}u[a|0]=(e|0)==5?7:6;u[b|0]=x[d|0];break b}if(!((e|0)!=10|(f|0)!=20|x[d|0]!=159)){u[a|0]=39;break b}if(x[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}u[a|0]=39;u[b|0]=x[d|0]}u[c|0]=0;g=1}return g|0}function ak(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;if(-18-b>>>0>=c>>>0){i=-17;j=u[a+11|0]<0?w[a>>2]:a;if(b>>>0<=2147483622){c=b+c|0;i=b<<1;c=c>>>0>i>>>0?c:i;i=c>>>0<11?11:(c|15)+1|0}c=Kb(i);if(e){Fb(c,j,e)}if(g){Fb(c+e|0,h,g)}k=e+f|0;h=d-k|0;if((d|0)!=(k|0)){Fb((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){zb(j)}w[a>>2]=c;w[a+8>>2]=i|-2147483648;b=a;a=h+(e+g|0)|0;w[b+4>>2]=a;u[a+c|0]=0;return}zc(a);M()}function Lx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=w[a>>2]<<1;d=c>>>0>f>>>0?f:c;c=c-d|0;g=c>>>0<f>>>0?c:f;h=d>>>1|0;c=w[a+20>>2];if(d>>>0>=2){e=b;d=h;while(1){v[c>>1]=x[e|0]|x[e+1|0]<<8;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}c=w[a+20>>2]}a=g>>>1|0;if(g>>>0>=2){e=b+f|0;c=c+2|0;d=a;while(1){v[c>>1]=x[e|0]|x[e+1|0]<<8;c=c+4|0;e=e+2|0;d=d-1|0;if(d){continue}break}}return a+h<<1}function pA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=w[a>>2];e=w[a+4>>2];if(d){g=w[a+8>>2];i=w[a+12>>2];b=w[a+24>>2];j=w[a+20>>2];k=w[a+16>>2];while(1){h=(((e&2147483647)<<1|f>>>31)&-2)+k|0;l=u[h+1|0];w[c>>2]=w[c>>2]+(C(u[h|0],j)<<8);w[c+4>>2]=w[c+4>>2]+(C(b,l)<<8);e=e+i|0;f=f+g|0;e=f>>>0<g>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function ee(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=bi(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(mu(a,b)&3){case 0:a=bi(B[b>>3],B[b+8>>3],1);break a;case 1:a=ci(B[b>>3],B[b+8>>3]);break a;case 2:a=-bi(B[b>>3],B[b+8>>3],1);break a;default:break b}}a=-ci(B[b>>3],B[b+8>>3])}jb=b+16|0;return a}function QP(a){a=a|0;var b=0;w[114256]=0;X(1407,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){w[a+24>>2]=0;b=w[a+28>>2];if(b){ob[w[w[b>>2]+4>>2]](b)}w[a+28>>2]=0;b=w[a+20>>2];if(b){zb(b);w[a+20>>2]=0}zb(a);return}$(W(0)|0)|0;w[114256]=0;Y(1333,1558,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function we(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=w[a+32>>2];d=w[a+40>>2];a:{if(b>>>0>=d>>>0){w[a+96>>2]=1;break a}c=b+1|0;w[a+32>>2]=c;e=x[b|0];b=c}b:{if(b>>>0>=d>>>0){w[a+96>>2]=1;break b}c=b+1|0;w[a+32>>2]=c;f=x[b|0]<<8;b=c}c:{if(b>>>0>=d>>>0){w[a+96>>2]=1;break c}c=b+1|0;w[a+32>>2]=c;g=x[b|0]<<16;b=c}d:{if(b>>>0>=d>>>0){w[a+96>>2]=1;a=0;break d}w[a+32>>2]=b+1;a=x[b|0]<<24}return a|(e|f|g)}function cw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;d=w[b+4>>2];a:{b:{if(!d){f=b+4|0;c=f;break b}g=v[c>>1];while(1){c=d;d=v[d+16>>1];if((d|0)>(g|0)){f=c;d=w[c>>2];if(d){continue}break b}if((d|0)>=(g|0)){d=c;b=0;break a}d=w[c+4>>2];if(d){continue}break}f=c+4|0}d=Kb(32);e=y[w[e>>2]>>1];w[d+20>>2]=0;w[d+24>>2]=0;v[d+16>>1]=e;w[d+28>>2]=0;Xe(b,c,f,d);b=1}u[a+4|0]=b;w[a>>2]=d}function aD(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;d=w[b+4>>2];a:{b:{if(!d){f=b+4|0;c=f;break b}g=y[c>>1];while(1){c=d;d=y[d+16>>1];if(d>>>0>g>>>0){f=c;d=w[c>>2];if(d){continue}break b}if(d>>>0>=g>>>0){d=c;b=0;break a}d=w[c+4>>2];if(d){continue}break}f=c+4|0}d=Kb(32);e=y[w[e>>2]>>1];w[d+20>>2]=0;w[d+24>>2]=0;v[d+16>>1]=e;w[d+28>>2]=0;Xe(b,c,f,d);b=1}u[a+4|0]=b;w[a>>2]=d}function UB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-128|0;jb=d;c=jb-16|0;jb=c;e=w[a+12>>2];w[c+8>>2]=d;w[c+12>>2]=d+126;e=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((e|0)==126){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],126)|0){f=w[a+12>>2]+126|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;c=-1;b:{if((e|0)!=126){break b}c=0;if(!rp(d)){break b}c=Uc(a,b,256,0)}jb=d+128|0;return c|0}function Pu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){d=ba(8)|0;w[114256]=0;a=Q(5,c|0,2334)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}b=Pb(d,a);w[114256]=0;U(194,b|0,82064,1337);b=w[114256];w[114256]=0;if((b|0)!=1){break a}b=P()|0;if(u[a+11|0]>=0){break b}zb(w[a>>2]);break b}w[w[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}b=P()|0;ca(d|0)}R(b|0)}M()}function Pj(a){var b=0,c=0,d=0;a:{b:{b=w[a+32>>2];d=w[a+40>>2];if(b>>>0>=d>>>0){break b}c=b+1|0;w[a+32>>2]=c;if(x[b|0]!=79){break a}if(c>>>0>=d>>>0){break b}c=b+2|0;w[a+32>>2]=c;if(x[b+1|0]!=103){break a}if(c>>>0>=d>>>0){break b}c=b+3|0;w[a+32>>2]=c;if(x[b+2|0]!=103){break a}if(c>>>0>=d>>>0){break b}w[a+32>>2]=b+4;if(x[b+3|0]!=83){break a}return uu(a)}w[a+96>>2]=1}w[a+100>>2]=30;return 0}function HJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;f=Cc();w[a>>2]=e;g=a- -64|0;i=Xc(g,20,f,5192,a);e=i+g|0;g=yd(g,e,c);f=a+8|0;Sb(f,c);w[114256]=0;f=V(1561,f|0)|0;h=w[114256];w[114256]=0;if((h|0)!=1){Ab(a+8|0);h=f;f=a+16|0;ps(h,a- -64|0,e,f);h=b;b=f+i|0;b=Wg(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;Ab(a+8|0);R(b|0);M()}function $Q(a,b){a=a|0;b=+b;var c=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){c=w[a+24>>2];w[114256]=0;b=+hb(1343,c|0,+b);c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3818,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return+b}a=P()|0;w[114256]=0;_(18);c=w[114256];w[114256]=0;if((c|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function aw(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=0;a:{if(w[(w[w[a>>2]-12>>2]+a|0)+16>>2]){break a}w[c>>2]=0;w[c+12>>2]=c+4;w[c+8>>2]=c;Ob(a,c+8|0);e=w[c>>2];d=0;if(e>>>0>65535){break a}Fe(b,e);if(e){d=c|4;while(1){w[c>>2]=0;w[c+12>>2]=d;w[c+8>>2]=c;Ob(a,c+8|0);A[w[b>>2]+(f<<2)>>2]=A[c>>2];f=f+1|0;if((e|0)!=(f|0)){continue}break}}d=!w[(w[w[a>>2]-12>>2]+a|0)+16>>2]}jb=c+16|0;return d}function YM(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=w[(((x[b|0]^a)&255)<<2)+37648>>2]^a>>>8;a=a>>>8^w[(((a^x[b+1|0])&255)<<2)+37648>>2];a=a>>>8^w[(((a^x[b+2|0])&255)<<2)+37648>>2];a=a>>>8^w[(((a^x[b+3|0])&255)<<2)+37648>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=w[(((x[b|0]^a)&255)<<2)+37648>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function CL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Ni(c,b);w[a+44>>2]=0;b=w[a+48>>2];if(b&8){d=a,e=Qb(c)+Db(c)|0,w[d+44>>2]=e;Lg(a,Qb(c),Qb(c),w[a+44>>2]);b=w[a+48>>2]}a:{if(!(b&16)){break a}b=Db(c);d=a,e=b+Qb(c)|0,w[d+44>>2]=e;nt(c,Yb(c));lm(a,Qb(c),Qb(c)+Db(c)|0);if(!(x[a+48|0]&3)){break a}while(1){if((b|0)<0){yj(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}yj(a,b)}}function $v(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=0;a:{if(w[(w[w[a>>2]-12>>2]+a|0)+16>>2]){break a}v[c>>1]=0;w[c+12>>2]=c+2;w[c+8>>2]=c;Ob(a,c+8|0);e=y[c>>1];d=0;if(e>>>0>65535){break a}Fe(b,e);if(e){d=c|4;while(1){w[c>>2]=0;w[c+12>>2]=d;w[c+8>>2]=c;Ob(a,c+8|0);A[w[b>>2]+(f<<2)>>2]=A[c>>2];f=f+1|0;if((f|0)!=(e|0)){continue}break}}d=!w[(w[w[a>>2]-12>>2]+a|0)+16>>2]}jb=c+16|0;return d}function zm(a,b,c){var d=0,e=0,f=0;d=w[c+16>>2];a:{if(!d){if(Vt(c)){break a}d=w[c+16>>2]}f=w[c+20>>2];if(d-f>>>0<b>>>0){return ob[w[c+36>>2]](c,a,b)|0}b:{if(w[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(x[e+a|0]!=10){continue}break}e=ob[w[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=w[c+20>>2]}Fb(f,a,b);w[c+20>>2]=w[c+20>>2]+b;e=b+d|0}return e}function wl(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;e=jb-16|0;jb=e;w[e+12>>2]=d;d=Db(b);if(d>>>0<c>>>0){Bf();M()}b=Qb(b);w[e+4>>2]=d-c;g=b+c|0;c=w[ag(e+12|0,e+4|0)>>2];d=jb-16|0;jb=d;a:{if(c>>>0<=4294967279){b:{if(sj(c)){Zc(a,c);b=a;break b}f=_f(c)+1|0;b=nf(a,f);hd(a,b);Cd(a,f);Yc(a,c)}Dd(b,g,c);u[d+15|0]=0;Sc(b+c|0,d+15|0);jb=d+16|0;break a}zc(a);M()}jb=e+16|0;return a|0}function eR(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1339,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,6829,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function vQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1375,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3502,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function uQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1376,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3384,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function tQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1377,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3191,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function sQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1378,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3259,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function rQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1379,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3112,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function qQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1380,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3692,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function bR(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1341,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,2302,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function HQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1364,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,8596,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function GQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1365,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5246,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function FQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1366,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,4881,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function EQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1367,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,5637,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function DQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1368,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,1805,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function CQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;b=V(1369,b|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3416,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function nn(a,b,c){var d=0,e=0;d=w[b+656>>2];a:{if(!d){break a}b:{c:{switch(c-1|0){case 0:c=!(x[a+1074323|0]&32)&w[a+1074312>>2]>=0;a=b+736|0;b=d+68|0;break b;case 1:c=!(x[a+1074323|0]&32)&w[a+1074312>>2]>=0;a=b+748|0;b=d+88|0;break b;default:break c}}c=!(x[a+1074323|0]&32)&w[a+1074312>>2]>=0;a=b+724|0;b=d+48|0}if(!(!(u[b+12|0]&1)|c?u[a|0]&1:1)){break a}e=w[b>>2]!=w[b+4>>2]}return e}function RD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{d=w[b>>2];e=w[b+4>>2];if((d|0)!=(e|0)){while(1){b=x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))==(c|0)){w[114256]=0;T(336,a|0,d+8|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}}d=d+24|0;if((e|0)!=(d|0)){continue}break}}return}b=P()|0;gc(a);R(b|0);M()}function zO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=w[a+4>>2];a:{if((b|0)!=(c|0)){while(1){b:{if(u[b+11|0]>=0){e=w[b+4>>2];w[d>>2]=w[b>>2];w[d+4>>2]=e;w[d+8>>2]=w[b+8>>2];break b}e=w[b+4>>2];f=w[b>>2];w[114256]=0;U(76,d|0,f|0,e|0);e=w[114256];w[114256]=0;if((e|0)==1){break a}}d=d+12|0;b=b+12|0;if((c|0)!=(b|0)){continue}break}}w[a+4>>2]=d;return}b=P()|0;w[a+4>>2]=d;R(b|0);M()}function to(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=w[b+4>>2];d=w[a+4>>2];e=c>>>0<d>>>0?c:d;if(!e){break a}h=w[b>>2];i=w[a>>2];a=0;while(1){b=x[a+i|0];f=(b-65&255)>>>0<26?b+32|0:b;g=f&255;b=x[a+h|0];b=(b-65&255)>>>0<26?b+32|0:b;if((g|0)!=(b&255)){return(f&255)>>>0<(b&255)>>>0?-1:1}if(g){a=a+1|0;if((e|0)==(a|0)){break a}continue}break}return 0}return(c|0)!=(d|0)?c>>>0>d>>>0?-1:1:0}function tE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;a:{if(u[c+11|0]>=0){w[d+24>>2]=w[c+8>>2];e=w[c+4>>2];w[d+16>>2]=w[c>>2];w[d+20>>2]=e;break a}Ge(d+16|0,w[c>>2],w[c+4>>2])}w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=d+16;U(290,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function jT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;e=x[b+11|0];f=e<<24>>24<0;a:{e=f?w[b+4>>2]:e;if(e>>>0>=c>>>0){e=e-c|0;e=d>>>0>e>>>0?e:d;if(e>>>0>=4294967280){break a}h=w[b>>2];b:{c:{if(e>>>0>=11){g=(e|15)+1|0;d=Kb(g);w[a+8>>2]=g|-2147483648;w[a>>2]=d;w[a+4>>2]=e;break c}u[a+11|0]=e;d=a;if(!e){break b}}Fb(d,(f?h:b)+c|0,e)}u[d+e|0]=0;return a|0}Bf();M()}zc(a);M()}function aR(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;c=+pa(1342,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3890,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function _Q(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;c=+pa(1344,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,3854,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function IQ(a){a=a|0;var b=0,c=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){b=w[a+24>>2];w[114256]=0;c=+pa(1363,b|0);b=w[114256];w[114256]=0;if((b|0)!=1){break b}}$(W(0)|0)|0;w[114256]=0;Y(1333,6089,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function kk(a,b){var c=0,d=0,e=0;c=w[a>>2];w[a>>2]=b;if(c){a=w[c>>2];e=w[c+4>>2];if((a|0)!=(e|0)){while(1){b=w[a>>2];d=w[b>>2];if(d){b=w[w[d>>2]+8>>2];w[114256]=0;X(b|0,d|0);b=w[114256];w[114256]=0;if((b|0)!=1){continue}W(0)|0;Eb();M()}if(u[b+31|0]<0){zb(w[b+20>>2])}if(u[b+19|0]<0){zb(w[b+8>>2])}zb(b);a=a+4|0;if((e|0)!=(a|0)){continue}break}a=w[c>>2]}if(a){w[c+4>>2]=a;zb(a)}zb(c)}}function MB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;a:{if(u[c+11|0]>=0){w[d+24>>2]=w[c+8>>2];e=w[c+4>>2];w[d+16>>2]=w[c>>2];w[d+20>>2]=e;break a}me(d+16|0,w[c>>2],w[c+4>>2])}w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=d+16;U(51,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function IL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=w[a+24>>2];g=w[a+28>>2];if(f>>>0>=g>>>0){if((ob[w[w[a>>2]+52>>2]](a,w[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{w[d+12>>2]=g-f>>2;w[d+8>>2]=c-e;f=w[Og(d+12|0,d+8|0)>>2];de(w[a+24>>2],b,f);g=f<<2;w[a+24>>2]=g+w[a+24>>2];e=e+f|0;b=b+g|0}continue}break}jb=d+16|0;return e|0}function kG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;w[f+8>>2]=e;w[f+12>>2]=c;c=Db(a);if(!((e|0)==-1|c>>>0<b>>>0)){w[f>>2]=c-b;g=f,h=w[ag(f+12|0,f)>>2],w[g+4>>2]=h;c=Qb(a);e=w[ag(f+4|0,f+8|0)>>2];a=0;a:{if(!e){break a}a=Jb(b+c|0,d,e)}b=a;b:{if(b){break b}b=-1;a=w[f+4>>2];c=w[f+8>>2];if(a>>>0<c>>>0){break b}b=a>>>0>c>>>0}jb=f+16|0;return b|0}Bf();M()}function DK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=jb-16|0;jb=g;e=w[b>>2];a:{if(!e|!c){break a}d=a?d:0;while(1){f=Ij(d>>>0<4?g+12|0:a,w[e>>2],0);if((f|0)==-1){h=-1;break a}if(a){if(d>>>0<=3){if(d>>>0<f>>>0){break a}Fb(a,g+12|0,f)}d=d-f|0;a=a+f|0}else{a=0}if(!w[e>>2]){e=0;break a}h=f+h|0;e=e+4|0;c=c-1|0;if(c){continue}break}}if(a){w[b>>2]=e}jb=g+16|0;return h|0}function Jm(a){var b=0,c=0,d=0;b=w[a+4>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+24>>2]=0;w[b+28>>2]=0;w[b+16>>2]=0;w[b+20>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;w[114256]=0;c=V(22,16)|0;d=w[114256];w[114256]=0;if((d|0)!=1){w[c+4>>2]=0;w[c+8>>2]=0;w[c+12>>2]=75696;w[c>>2]=75656;w[b+28>>2]=0;w[b+20>>2]=0;w[b+24>>2]=0;w[b+16>>2]=c;w[b+12>>2]=c+12;w[a+4>>2]=b+32;return}c=P()|0;w[a+4>>2]=b;R(c|0);M()}function JS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4208>>2]=1060320051;w[a+4212>>2]=1041865114;w[a+4224>>2]=1049951732;b=a+4216|0;w[b>>2]=1065353216;w[b+4>>2]=1049951732;w[a>>2]=79220;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){break a}w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}return a|0}b=P()|0;Oc(a);R(b|0);M()}function Hq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Hb(d,c);w[114256]=0;U(2126,d+16|0,b|0,e|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[114256]=0;a=Q(2127,a|0,d+16|0)|0;c=w[114256];w[114256]=0;if((c|0)==1){break b}Gb(d+16|0);Gb(e);w[a>>2]=73964;c=w[b+4>>2];w[a+8>>2]=w[b>>2];w[a+12>>2]=c;jb=d+32|0;return a|0}c=P()|0;break a}c=P()|0;Gb(d+16|0)}Gb(e);R(c|0);M()}function AD(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;a:{if(b){Hb(c,b);break a}w[c+8>>2]=0;w[c>>2]=0;w[c+4>>2]=0}w[114256]=0;U(6,c+16|0,0,c|0);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[c+20>>2];w[a>>2]=w[c+16>>2];w[a+4>>2]=b;w[a+8>>2]=w[c+24>>2];w[c+24>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;if(u[c+11|0]<0){zb(w[c>>2])}jb=c+32|0;return a|0}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}
function qq(a,b,c){var d=0,e=0,f=0;e=w[a>>2];d=c>>>0>=192?192:c;a:{if(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],d)|0){e=w[a+8>>2];break a}d=w[a>>2];d=ob[w[w[d>>2]+24>>2]](d)|0;e=w[a+8>>2];d=d-e|0}f=w[a>>2];ob[w[w[f>>2]+28>>2]](f,b,e,d)|0;Cb(b+d|0,0,192-d|0);b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],c)|0){b=w[a+8>>2]+c|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}function NA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!w[a+20>>2]){break a}f=w[a>>2];if(!f|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}zi(b);b=Fb(b,a,34);v[b+34>>1]=y[a+34>>1];Fb(b+36|0,a+36|0,68);w[b+20>>2]=0;w[b>>2]=d;if(!Ck(b)){break a}if(w[a>>2]!=(d|0)){Cb(b+68|0,0,36)}Fb(w[b+20>>2],w[a+20>>2]+c|0,d);w[b+8>>2]=e?d:0;w[b+4>>2]=0;v[b+34>>1]=y[b+34>>1]&65533|(e?2:0)}}function Un(a,b){var c=0,d=0;a:{if(w[a+480180>>2]!=1){break a}d=x[b+866|0];if(!d){break a}c=w[b+104>>2];if(!c|!w[c+20>>2]|(!w[c>>2]|(y[c+34>>1]&3)!=2)){break a}d=x[b+867|0]+x[(d&15)+26352|0]|0;u[b+867|0]=d;if(d<<24>>24>=0){break a}u[b+867|0]=0;d=b;b=w[b+784>>2]+1|0;b=b>>>0<w[c+8>>2]-w[c+4>>2]>>>0?b:0;w[d+784>>2]=b;b=w[c+20>>2]+(b+w[c+4>>2]|0)|0;u[b|0]=x[b|0]^-1;Co(c,a,0)}}function vS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4296);if(d){w[114256]=0;a=Z(1101,d|0,a|0,b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}w[a+4208>>2]=1056964608;w[a+4212>>2]=1065353216;w[a+4232>>2]=1056964608;b=a+4224|0;w[b>>2]=1056964608;w[b+4>>2]=1048406533;b=a+4216|0;w[b>>2]=1020054733;w[b+4>>2]=1065353216;w[a>>2]=79628}return d|0}a=P()|0;zb(d);R(a|0);M()}function GT(a,b){a=a|0;b=b|0;var c=D(0);a:{switch(b|0){case 0:return D(A[a+4220>>2]);case 1:return D(A[a+4224>>2]);case 2:return D(A[a+4228>>2]);case 3:return D(x[a+4240|0]?D(1):D(0));case 4:return D(D(D(w[a+4232>>2])*D(.03125)));case 5:return D(x[a+4241|0]?D(1):D(0));case 6:return D(x[a+4242|0]?D(1):D(0));case 7:c=x[a+4244|0]?D(1):D(0);break;default:break a}}return D(c)}function lE(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Of(a,c+8|0);w[c+4>>2]=w[c+8>>2];Kf(c+4|0,b);jb=c+16|0;We(b);a=x[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=x[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}u[b+5|0]=159;u[b+3|0]=20;return}if((a|0)!=64){break a}u[b+3|0]=0;u[b|0]=254;return}u[b+3|0]=20;u[b+5|0]=a&15|160;return}u[b+3|0]=0}}function UH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=w[a+4>>2];if((c|0)>0){Cb(w[a>>2],0,c);c=w[a+4>>2]}e=x[b+11|0];h=e<<24>>24;f=(h|0)<0;d=c-1|0;i=w[b+4>>2];g=f?i:e;g=d>>>0<g>>>0?d:g;if(g){hc(w[a>>2],f?w[b>>2]:b,g);i=w[b+4>>2];e=x[b+11|0];h=e;c=w[a+4>>2];d=c-1|0}f=w[a>>2];b=h<<24>>24<0?i:e;d=b>>>0>d>>>0?d:b;b=f+d|0;if(((c+f|0)-b|0)>0){Cb(b,0,c-d|0)}return a|0}function Kf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=x[a|0];d=x[a+1|0]|(g&15)<<8;e=0;a:{if(!d|(d|0)==4095){break a}while(1){f=y[(c<<1)+25792>>1];if(f>>>0<=d>>>0){e=c+24|0;if(!(!c|(d|0)==(f|0)|(y[(c<<1)+25790>>1]-d|0)>=(d-f|0))){break a}e=c+25|0;break a}c=c+1|0;if((c|0)!=84){continue}break}e=108}u[b|0]=e;c=x[a+2|0];u[b+3|0]=c&15;u[b+1|0]=g&16|c>>>4;u[b+5|0]=x[a+3|0]}function YC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;f=-1;c=jb-16|0;jb=c;e=w[a+12>>2];d=b+8|0;w[c+8>>2]=d;w[c+12>>2]=d+5;d=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((d|0)==5){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],5)|0){e=w[a+12>>2]+5|0;break a}e=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=e}jb=c+16|0;jb=b+16|0;return((d|0)==5?w[b+8>>2]==1279544644&x[b+12|0]<32:f)|0}function Xp(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=w[a>>2];b:{if(!b){break b}c=w[a+8>>2];if(!c){break b}a=w[a+12>>2];if(!a){break b}e=ob[a|0](b)|0;d=nb;if((d|0)<0){break b}if((ob[c|0](b,0,0,0)|0)<0){break a}if((ob[c|0](b,0,0,2)|0)<0){break a}f=ob[a|0](b)|0;a=nb;ob[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=(f|0)==-1&(a|0)>=0|(a|0)>0?-1:f}return g}ob[c|0](b,e,d,0)|0;return 0}function Mx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=w[a>>2];g=c>>>0>e>>>0?e:c;c=c-g|0;h=c>>>0<e>>>0?c:e;c=w[a+20>>2];if(g){e=b;f=g;i=d;while(1){i=x[e|0]+i|0;u[c|0]=i;c=c+2|0;e=e+1|0;f=f-1|0;if(f){continue}break}e=w[a>>2];c=w[a+20>>2]}if(h){e=b+e|0;c=c+1|0;f=h;while(1){d=x[e|0]+d|0;u[c|0]=d;c=c+2|0;e=e+1|0;f=f-1|0;if(f){continue}break}}return g+h|0}function ig(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return u[a+47200|0]}if(a>>>0<=511){return u[(a>>>5|0)+47200|0]+5|0}return u[(a>>>10|0)+47200|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return u[(a>>>15|0)+47200|0]+15|0}return u[(a>>>20|0)+47200|0]+20|0}if(a>>>0<=536870911){return u[(a>>>25|0)+47200|0]+25|0}a=u[(a>>>30|0)+47200|0]+30|0}else{a=0}return a}function oR(a){a=a|0;var b=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[a+24>>2];if(b){zb(kg(b))}w[a+24>>2]=0;b=w[a+20>>2];if(b){zb(b);w[a+20>>2]=0}zb(a);return}$(W(0)|0)|0;w[114256]=0;Y(1333,1585,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Il(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=w[a+8>>2];c=w[a+4>>2];if(e-c>>>0>=b>>>0){if(b){c=Cb(c,0,b)+b|0}w[a+4>>2]=c;return}f=w[a>>2];g=c-f|0;d=g+b|0;if((d|0)>=0){c=0;e=e-f|0;h=e<<1;d=e>>>0>=1073741823?2147483647:d>>>0<h>>>0?h:d;if(d){c=Kb(d)}b=Cb(c+g|0,0,b)+b|0;if((g|0)>0){Fb(c,f,g)}w[a+8>>2]=c+d;w[a+4>>2]=b;w[a>>2]=c;if(f){zb(f)}return}Mb(a);M()}function ok(a,b,c,d){a:{if(w[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=C(b,896)+a|0;w[c+1075680>>2]=0;d=c+1074992|0;w[d>>2]=0;w[d+4>>2]=0;c=c+1075072|0;d=w[c>>2]|4096;w[c>>2]=d;break b}c=C(b,896)+a|0;w[c+1075672>>2]=0;d=w[c+1075072>>2]}c=C(b,896)+a|0;w[c+1075072>>2]=d|2097152;Ff(a,b,255,0);if(!(x[c+1075073|0]&2)){break a}a=w[a+1304392>>2];if(!a){break a}le(a,b,0)}}function ij(a,b,c){var d=0,e=0;if(c&2048){u[a|0]=43;a=a+1|0}if(c&1024){u[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){u[a|0]=46;u[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=x[b|0];if(e){u[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}u[a|0]=b;return(d|0)!=260}function Yr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=w[Lh(a)>>2];d=w[c>>2]-w[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=w[b>>2];i=w[a>>2];g=Hj((f|0)!=1769?w[a>>2]:0,d);if(g){if((f|0)!=1769){ej(a)}w[e+4>>2]=1708;f=vc(e+8|0,g,e+4|0);Ur(a,f);Ub(f);w[b>>2]=w[a>>2]+(h-i|0);w[c>>2]=w[a>>2]+(d&-4);jb=e+16|0;return}Al();M()}function qB(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;fp(a,c+11|0);d=c+16|0;if((x[c+11|0]|x[c+12|0]<<8|(x[c+13|0]<<16|x[c+14|0]<<24))==1414807888){fp(a,c+11|0);u[b|0]=1;a=0}else{a=1}a=Hb(d,a+(c+11|0)|0);w[114256]=0;b=V(553,a|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(u[a+11|0]<0){zb(w[a>>2])}jb=c+32|0;return b|0}b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}function il(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=w[a+4>>2];a:{if(b){b=(b<<4)+c|0;while(1){w[114256]=0;d=V(22,16)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}w[d+4>>2]=0;w[d+8>>2]=0;w[d+12>>2]=75696;w[d>>2]=75656;w[c+8>>2]=0;w[c+12>>2]=0;w[c+4>>2]=d;w[c>>2]=d+12;c=c+16|0;if((b|0)!=(c|0)){continue}break}}else{b=c}w[a+4>>2]=b;return}b=P()|0;w[a+4>>2]=c;R(b|0);M()}function KC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=w[a+8>>2];a:{if(b){b=(b<<4)+c|0;while(1){w[114256]=0;d=V(22,16)|0;e=w[114256];w[114256]=0;if((e|0)==1){break a}w[d+4>>2]=0;w[d+8>>2]=0;w[d+12>>2]=75696;w[d>>2]=75656;w[c+8>>2]=0;w[c+12>>2]=0;w[c+4>>2]=d;w[c>>2]=d+12;c=c+16|0;if((b|0)!=(c|0)){continue}break}}else{b=c}w[a+8>>2]=b;return}b=P()|0;w[a+8>>2]=c;R(b|0);M()}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{if(!b){break a}c=w[a>>2];if(!(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0)){break a}if(b>>>0<=1){e=Dl(a,1);break a}e=cd(a,d+8|0);e=e?y[d+8>>1]:0;c=w[a>>2];b=b-2|0;b:{if(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0){b=b+w[a+8>>2]|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=d+16|0;return e&65535}function hR(a,b){a=a|0;b=b|0;var c=0;w[114256]=0;X(1335,a|0);c=w[114256];w[114256]=0;a:{b:{if((c|0)!=1){w[a+16>>2]=b;b=w[a+20>>2];if(!b){break b}zb(b);w[a+20>>2]=0;return}$(W(0)|0)|0;w[114256]=0;Y(1333,2146,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function dh(a,b,c,d){a:{if(w[a+480180>>2]==4){if(c){u[b+830|0]=x[b+830|0]&15|c<<4;break a}c=x[b+830|0]>>>4|0;break a}if(d){if(c){u[b+854|0]=c;break a}c=x[b+854|0];break a}if(c){u[b+830|0]=c;break a}c=x[b+830|0]}b:{if(!(u[b+872|0]&1)){break b}c=w[b+688>>2]+((c&255)<<2)|0;w[b+688>>2]=(c|0)>=256?256:c;if(!(u[a+480180|0]&1)){break b}w[b+88>>2]=w[b+88>>2]|2097152}}function ap(a){var b=0;a:{if((x[a+44|0]|x[a+45|0]<<8|(x[a+46|0]<<16|x[a+47|0]<<24))!=1179472976|x[a+28|0]!=26|(x[a+40|0]|x[a+41|0]<<8|x[a+30|0]>2)){break a}if(((x[a+38|0]|x[a+39|0]<<8)-33&65535)>>>0<65504|((x[a+32|0]|x[a+33|0]<<8)-257&65535)>>>0<65280|((x[a+34|0]|x[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((x[a+36|0]|x[a+37|0]<<8)-1&65535)>>>0<128}return b}function pE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-624|0;jb=b;f=-1;c=jb-16|0;jb=c;e=w[a+12>>2];d=b+8|0;w[c+8>>2]=d;w[c+12>>2]=d+610;d=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((d|0)==610){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],610)|0){e=w[a+12>>2]+610|0;break a}e=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=e}jb=c+16|0;if((d|0)==610){f=hq(b+8|0)}jb=b+624|0;return f|0}function jq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],8)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+8;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;u[b+6|0]=0;u[b+7|0]=0}jb=c+16|0;return e|0}function iB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-160|0;jb=b;f=-1;c=jb-16|0;jb=c;e=w[a+12>>2];d=b+8|0;w[c+8>>2]=d;w[c+12>>2]=d+146;d=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((d|0)==146){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],146)|0){e=w[a+12>>2]+146|0;break a}e=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=e}jb=c+16|0;if((d|0)==146){f=cp(b+8|0)}jb=b+160|0;return f|0}function aJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=w[Lh(a)>>2];d=w[c>>2]-w[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=w[b>>2];i=w[a>>2];g=Hj((f|0)!=1769?w[a>>2]:0,d);if(g){if((f|0)!=1769){ej(a)}w[e+4>>2]=1708;f=vc(e+8|0,g,e+4|0);Ur(a,f);Ub(f);w[b>>2]=w[a>>2]+(h-i|0);w[c>>2]=d+w[a>>2];jb=e+16|0;return}Al();M()}function WL(a){a=a|0;var b=0,c=0,d=0;a:{if(!Kc(-1,w[a+76>>2])){a=w[a+76>>2];break a}d=a;c=jb-16|0;jb=c;b=c+8|0;Sb(b,a);w[114256]=0;a=V(1561,b|0)|0;b=w[114256];w[114256]=0;b:{c:{if((b|0)==1){break c}w[114256]=0;a=Q(1578,a|0,32)|0;b=w[114256];w[114256]=0;if((b|0)==1){break c}Ab(c+8|0);jb=c+16|0;break b}a=P()|0;Ab(c+8|0);R(a|0);M()}w[d+76>>2]=a}return a<<24>>24}function Hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{if(!b){break a}c=w[a>>2];if(!(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0)){break a}if(b>>>0<=3){e=Yi(a,b);break a}e=Nc(a,d+8|0);e=e?w[d+8>>2]:0;c=w[a>>2];b=b-4|0;b:{if(ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0){b=b+w[a+8>>2]|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=d+16|0;return e|0}function wT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;if(!(!d|(c-1&255)>>>0>119)){w[a+32>>2]=0;w[a+28>>2]=w[a+28>>2]&-7|2;Wj(a);w[a+4256>>2]=0;w[a+4260>>2]=0}f=w[w[a+20>>2]+28>>2];f=f>>>0<=127?-1:f^-128;g=f&255;a:{if(g>>>0<=x[a+4200|0]|g>>>0>249){break a}a=w[(w[a+16>>2]+C(f&255,160)|0)+906300>>2];if(!a){break a}ob[w[w[a>>2]+88>>2]](a,b,c,d,e)}}function Jg(a,b){a=a|0;b=b|0;var c=0,d=0;b=!w[a+24>>2]|b;w[a+16>>2]=b;if(b&w[a+20>>2]){c=jb-16|0;jb=c;b=ba(16)|0;a=jb-16|0;jb=a;if(!x[457032]){u[457032]=1}Sh(a+8|0,1,83024);d=w[a+12>>2];c=c+8|0;w[c>>2]=w[a+8>>2];w[c+4>>2]=d;jb=a+16|0;w[114256]=0;S(1660,b|0,5028,c|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){ka(b|0,60448,1661);M()}a=P()|0;ca(b|0);R(a|0);M()}}function ms(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=jb-16|0;jb=e;d=a;a:{if(b>>>0<=1073741807){b:{if(Wi(b)){Zc(d,b);break b}g=Rf(b)+1|0;a=br(g);hd(d,a);Cd(d,g);Yc(d,b)}c:{d:{if(b){w[114256]=0;Wq(a,c,b);c=w[114256];w[114256]=0;if((c|0)==1){break d}}break c}W(0)|0;Eb();M()}w[e+12>>2]=0;xd((b<<2)+a|0,e+12|0);jb=e+16|0;break a}Qf();M()}jb=f+16|0;return d}function $D(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-32|0;jb=b;c=-1;a:{if(!_k(a,b+16|0)){break a}c=0;if(!aq(b+16|0)){break a}b:{if(w[b+16>>2]==1179472708){if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],4)|0)){break b}w[a+12>>2]=w[a+12>>2]+4}a=lf(a,b+8|0);c=a?w[b+8>>2]==1196314451:-1;break a}d=a,e=ob[w[w[a>>2]+24>>2]](a)|0,w[d+12>>2]=e;c=-1}a=c;jb=b+32|0;return a|0}function gR(a){a=a|0;var b=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){w[a+16>>2]=0;b=w[a+20>>2];if(!b){break b}zb(b);w[a+20>>2]=0;return}$(W(0)|0)|0;w[114256]=0;Y(1333,5001,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa()}return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function yg(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;if(-17-b>>>0>=c>>>0){i=Qb(a);a:{if(b>>>0<2147483623){w[h+8>>2]=b<<1;w[h+12>>2]=b+c;c=_f(w[of(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=nf(a,j);if(e){Dd(c,i,e)}k=e+f|0;if((k|0)!=(d|0)){Dd((c+e|0)+g|0,(e+i|0)+f|0,d-k|0)}b=b+1|0;if((b|0)!=11){Th(i,b)}hd(a,c);Cd(a,j);jb=h+16|0;return}zc(a);M()}function XD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;f=-1;c=jb-16|0;jb=c;e=w[a+12>>2];d=b+8|0;w[c+8>>2]=d;w[c+12>>2]=d+22;d=ob[w[w[a>>2]+32>>2]](a,e,c+8|0)|0;if((d|0)==22){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],22)|0){e=w[a+12>>2]+22|0;break a}e=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=e}jb=c+16|0;if((d|0)==22){f=$p(b+8|0)}jb=b+32|0;return f|0}function Fg(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;Sb(d,b);w[114256]=0;b=V(1736,d|0)|0;d=w[114256];w[114256]=0;a:{if((d|0)==1){break a}w[114256]=0;d=V(1746,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}w[c>>2]=d;w[114256]=0;T(1747,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}Ab(e+8|0);jb=e+16|0;return}a=P()|0;Ab(e+8|0);R(a|0);M()}function WR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4272>>2]=1065353216;w[a+4208>>2]=1056880300;w[a+4212>>2]=1050733080;w[a>>2]=80268;w[a+4216>>2]=1056964608;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){break a}w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}return a|0}b=P()|0;Oc(a);R(b|0);M()}function Vw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;d=w[b+4>>2];a:{b:{if(!d){f=b+4|0;c=f;break b}g=B[c>>3];while(1){c=d;h=B[d+16>>3];if(!(g>=h)){f=c;d=w[c>>2];if(d){continue}break b}f=0;if(g<=h){break a}d=w[c+4>>2];if(d){continue}break}f=c+4|0}d=Kb(32);g=B[w[e>>2]>>3];w[d+24>>2]=0;B[d+16>>3]=g;Xe(b,c,f,d);f=1}u[a+4|0]=f;w[a>>2]=d}function Uc(a,b,c,d){var e=0,f=0,g=0;e=ob[w[w[a>>2]+24>>2]](a)|0;a:{b:{if(!b){ob[w[w[a>>2]+24>>2]](a)|0;break b}a=c+w[a+12>>2]|0;d=c>>>0>a>>>0?d+1|0:d;c=a;a=w[b+4>>2];f=a;b=w[b>>2];g=!a&b>>>0>=2048|(a|0)!=0;a=g?0:a;if(!a&e>>>0<(g?2048:b)>>>0|a){a=-1;if(!d&c>>>0<=e>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0<c>>>0|d>>>0>f>>>0){break a}}a=1}return a}function Hg(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;Sb(d,b);w[114256]=0;b=V(1704,d|0)|0;d=w[114256];w[114256]=0;a:{if((d|0)==1){break a}w[114256]=0;d=V(1719,b|0)|0;f=w[114256];w[114256]=0;if((f|0)==1){break a}u[c|0]=d;w[114256]=0;T(1720,a|0,b|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}Ab(e+8|0);jb=e+16|0;return}a=P()|0;Ab(e+8|0);R(a|0);M()}function pe(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;w[f+8>>2]=b;b=0;g=6;a:{b:{if(ue(a,f+8|0)){break b}g=4;h=tf(a);if(!Ld(d,64,h)){break b}b=Cg(d,h);while(1){c:{eg(a);b=b-48|0;if(!Wh(a,f+8|0)|(e|0)<2){break c}g=tf(a);if(!Ld(d,64,g)){break a}e=e-1|0;b=Cg(d,g)+C(b,10)|0;continue}break}g=2;if(!ue(a,f+8|0)){break a}}w[c>>2]=w[c>>2]|g}jb=f+16|0;return b}function oe(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;w[f+8>>2]=b;b=0;g=6;a:{b:{if(Le(a,f+8|0)){break b}g=4;h=bg(a);if(!pf(d,64,h)){break b}b=Bg(d,h);while(1){c:{Mg(a);b=b-48|0;if(!zj(a,f+8|0)|(e|0)<2){break c}g=bg(a);if(!pf(d,64,g)){break a}e=e-1|0;b=Bg(d,g)+C(b,10)|0;continue}break}g=2;if(!Le(a,f+8|0)){break a}}w[c>>2]=w[c>>2]|g}jb=f+16|0;return b}function iR(a){a=a|0;var b=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;a:{b:{if((b|0)!=1){a=w[a+20>>2];if(!a){break b}return rc(a)|0}$(W(0)|0)|0;w[114256]=0;Y(1333,7968,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();return 0}return rc(17256)|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function zw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;if(b){h=c;i=c>>31;c=0;while(1){d=w[a>>2];e=w[a+4>>2];g=(d+e|0)/2|0;d=d-e|0;e=CV(BV(d,d>>31,h,i),nb,256,0);f=e;d=nb;e=(d|0)>=0&e>>>0>=2147483647|(d|0)>0;f=e?2147483647:f;d=e?0:d;d=(d|0)<0&f>>>0<=2147483648|(d|0)<-1?-2147483648:f;w[a+4>>2]=g-d;w[a>>2]=d+g;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function ns(a){var b=0,c=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=1179340888|(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))!=1213419859){break a}b=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);if(!b|!(x[a+12|0]|x[a+13|0]<<8|(x[a+14|0]<<16|x[a+15|0]<<24))){break a}c=(b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))>>>0>27}return c}function Tq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=Db(a);if(e>>>0>=b>>>0){f=Yb(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Qb(a);i=f+b|0;if((b|0)!=(e|0)){h=b+f|0;Eh(h+d|0,h,e-b|0);c=(c>>>0>=h>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Eh(i,c,d);b=d+e|0;He(a,b);u[g+15|0]=0;Sc(b+f|0,g+15|0);break a}Dh(a,f,(d+e|0)-f|0,e,b,0,d,c)}jb=g+16|0;return a}Bf();M()}function UA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-208|0;jb=b;e=-1;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+204;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==204){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],204)|0){f=w[a+12>>2]+204|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;if((d|0)==204){e=Wo(b)}jb=b+208|0;return e|0}function KD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-160|0;jb=b;e=-1;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+157;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==157){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],157)|0){f=w[a+12>>2]+157|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;if((d|0)==157){e=Wp(b)}jb=b+160|0;return e|0}function tw(a){var b=0,c=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=1163089229){break a}b=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=x[a+16|0]|x[a+17|0]<<8|(x[a+18|0]<<16|x[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))}return c}function gS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;w[a+16>>2]=0;g=c;c=CV(BV(d,d>>31,b,b>>31),nb,1e3,0);d=c;b=nb;c=(b|0)>=0&c>>>0>=2147483647|(b|0)>0;d=c?2147483647:d;b=c?0:b;b=g+((b|0)<0&d>>>0<=2147483648|(b|0)<-1?-2147483648:d)|0;w[a+12>>2]=b;if((b|0)>0){w[a+20>>2]=(b+e|0)%(b|0)}w[f+12>>2]=0;bw(a,b,f+12|0);jb=f+16|0}function Xo(a){var b=0,c=0;a:{if(x[a+29|0]!=2){break a}b=x[a+28|0];if((b|0)!=26&(b|0)!=2|x[a+30|0]!=2){break a}b=x[a+31|0];if(b>>>0>21|!(1<<b&3146753)|x[a+33|0]>64){break a}b=x[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=x[a|0]-127|0;if((c&255)>>>0>=161){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0>160}return c}function Pp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){yh(a,b);d=w[a+4>>2];e=d+C(b,6)|0;while(1){b=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);u[d|0]=b;u[d+1|0]=b>>>8;u[d+2|0]=b>>>16;u[d+3|0]=b>>>24;b=x[c+4|0]|x[c+5|0]<<8;u[d+4|0]=b;u[d+5|0]=b>>>8;d=d+6|0;if((e|0)!=(d|0)){continue}break}w[a+4>>2]=e}return a|0}function HK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=w[a+84>>2];f=w[e+4>>2];g=w[a+28>>2];d=w[a+20>>2]-g|0;d=d>>>0>f>>>0?f:d;if(d){Fb(w[e>>2],g,d);w[e>>2]=d+w[e>>2];f=w[e+4>>2]-d|0;w[e+4>>2]=f}d=w[e>>2];f=c>>>0>f>>>0?f:c;if(f){Fb(d,b,f);d=f+w[e>>2]|0;w[e>>2]=d;w[e+4>>2]=w[e+4>>2]-f}u[d|0]=0;b=w[a+44>>2];w[a+28>>2]=b;w[a+20>>2]=b;return c|0}
function ch(a,b,c,d){a:{if(w[a+480180>>2]==4){d=x[b+830|0];if(c){u[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){u[b+854|0]=c;break a}c=x[b+854|0];break a}if(c){u[b+830|0]=c;break a}c=x[b+830|0]}b:{if(!(u[b+872|0]&1)){break b}c=w[b+688>>2]-((c&255)<<2)|0;w[b+688>>2]=(c|0)>0?c:0;if(!(u[a+480180|0]&1)){break b}w[b+88>>2]=w[b+88>>2]|2097152}}function Pf(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+14>>1]=65535;g=c>>>0>=256?256:c;$d(a,g,f+14|0);a:{if(g){i=w[a>>2];j=w[a+4>>2]-i>>1;c=0;while(1){if((c|0)==(j|0)){break a}h=x[b+c|0];v[(c<<1)+i>>1]=(d|0)==(h|0)?-1:(e|0)==(h|0)?-2:h;c=c+1|0;if((g|0)!=(c|0)){continue}break}}jb=f+16|0;return 1}Bc(a);M()}function NR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4208>>2]=1065353216;w[a+4212>>2]=1065353216;b=a+4216|0;w[b>>2]=1051372203;w[b+4>>2]=0;w[a>>2]=80472;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){break a}w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}return a|0}b=P()|0;Oc(a);R(b|0);M()}function ql(a,b,c,d){u[a+53|0]=1;a:{if(w[a+4>>2]!=(c|0)){break a}u[a+52|0]=1;c=w[a+16>>2];b:{if(!c){w[a+36>>2]=1;w[a+24>>2]=d;w[a+16>>2]=b;if((d|0)!=1){break a}if(w[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=w[a+24>>2];if((c|0)==2){w[a+24>>2]=d;c=d}if(w[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}w[a+36>>2]=w[a+36>>2]+1}u[a+54|0]=1}}function Mq(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;if(1073741807-b>>>0>=c>>>0){g=Qb(a);a:{if(b>>>0<536870887){w[f+8>>2]=b<<1;w[f+12>>2]=b+c;c=Rf(w[of(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=br(h);if(e){de(c,g,e)}if((d|0)!=(e|0)){i=e<<2;de(c+i|0,g+i|0,d-e|0)}b=b+1|0;if((b|0)!=2){Gh(g,b)}hd(a,c);Cd(a,h);jb=f+16|0;return}Qf();M()}function Cw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[c+4>>1]=0;w[c+12>>2]=c+6;w[c+8>>2]=c+4;d=c+8|0;Ob(a,d);e=y[c+4>>1];w[c+8>>2]=16777216;Dn(b,e,d);ni(b);if(e){f=c+8|0;d=0;while(1){g=w[b>>2];w[c+4>>2]=0;w[c+12>>2]=f;w[c+8>>2]=c+4;Ob(a,c+8|0);w[(d<<2)+g>>2]=w[c+4>>2];d=d+1|0;if((e|0)!=(d|0)){continue}break}}ni(b);jb=c+16|0}function vo(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;u[a+16|0]=0;c=w[a+12>>2];w[b+16>>2]=0;w[b+20>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;w[114256]=0;w[b>>2]=0;w[b+4>>2]=0;v[b+28>>1]=0;w[b+24>>2]=c;U(708,a|0,1,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[b+23|0]<0){zb(w[b+12>>2])}a=w[b>>2];if(a){w[b+4>>2]=a;zb(a)}jb=b+32|0;return}a=P()|0;mh(b);R(a|0);M()}function pB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;if(b){g=w[a+8>>2];d=x[a+11|0];e=d<<24>>24<0;f=e?(g&2147483647)-1|0:10;d=e?w[a+4>>2]:d;a:{if(f-d>>>0>=b>>>0){e=b+d|0;f=g>>>24|0;break a}e=b+d|0;Rt(a,f,e-f|0,d,d);f=u[a+11|0]}g=d;d=f<<24>>24<0?w[a>>2]:a;Cb(g+d|0,c,b);b:{if(u[a+11|0]<0){w[a+4>>2]=e;break b}u[a+11|0]=e}u[d+e|0]=0}return a|0}function hw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=w[a+4>>2];f=w[a>>2];g=(d-f|0)/52|0;a:{if((d|0)==(f|0)){d=0;break a}d=0;while(1){e=C(e,52)+f|0;if(w[e>>2]==w[e+4>>2]){break a}d=d+1|0;e=d&65535;if(g>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(y[w[w[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=ie(a,d&65535,b)?d:-1}return c&65535}function Nx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=w[a>>2];f=c>>>0>d>>>0?d:c;c=c-f|0;g=c>>>0<d>>>0?c:d;c=w[a+20>>2];if(f){d=b;e=f;while(1){u[c|0]=x[d|0]^128;c=c+2|0;d=d+1|0;e=e-1|0;if(e){continue}break}d=w[a>>2];c=w[a+20>>2]}if(g){d=b+d|0;c=c+1|0;e=g;while(1){u[c|0]=x[d|0]^128;c=c+2|0;d=d+1|0;e=e-1|0;if(e){continue}break}}return f+g|0}function aL(a){a=a|0;a:{w[114256]=0;V(13,459288)|0;a=w[114256];w[114256]=0;b:{if((a|0)==1){break b}w[114256]=0;V(13,459624)|0;a=w[114256];w[114256]=0;if((a|0)==1){break b}w[114256]=0;V(1680,459372)|0;a=w[114256];w[114256]=0;if((a|0)==1){break b}w[114256]=0;V(1680,459708)|0;a=w[114256];w[114256]=0;if((a|0)==1){break b}break a}W(0)|0;Eb();M()}}function qA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=w[a>>2];e=w[a+4>>2];if(d){g=w[a+8>>2];i=w[a+12>>2];b=w[a+24>>2];j=w[a+20>>2];k=w[a+16>>2];while(1){h=v[(e<<1)+k>>1];w[c>>2]=w[c>>2]+C(j,h);w[c+4>>2]=w[c+4>>2]+C(b,h);e=e+i|0;f=f+g|0;e=f>>>0<g>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function ip(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;a:{d=w[b>>2];b=w[b+4>>2];if((d|0)!=(b|0)){while(1){if((x[d|0]|x[d+1|0]<<8|(x[d+2|0]<<16|x[d+3|0]<<24))==(c|0)){w[114256]=0;T(336,a|0,d+8|0);e=w[114256];w[114256]=0;if((e|0)==1){break a}}d=d+24|0;if((b|0)!=(d|0)){continue}break}}return}b=P()|0;gc(a);R(b|0);M()}function mF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;e=-1;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+41;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==41){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],41)|0){f=w[a+12>>2]+41|0;break a}f=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=f}jb=c+16|0;if((d|0)==41){e=zq(b)}jb=b+48|0;return e|0}function qc(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;aj(b);d=jb-16|0;jb=d;w[d+12>>2]=b;b=Zf(e+8|0,d+12|0);jb=d+16|0;a:{a=a+8|0;if(ae(a)>>>0<=c>>>0){w[114256]=0;T(1837,a|0,c+1|0);d=w[114256];w[114256]=0;if((d|0)==1){break a}}if(w[Sf(a,c)>>2]){Kh(w[Sf(a,c)>>2])}d=ej(b);f=Sf(a,c),g=d,w[f>>2]=g;xr(b);jb=e+16|0;return}a=P()|0;xr(b);R(a|0);M()}function zL(a,b){a=a|0;b=b|0;var c=0;if(z[a+24>>2]>z[a+44>>2]){w[a+44>>2]=w[a+24>>2]}a:{if(z[a+8>>2]>=z[a+12>>2]){break a}if(Kc(b,-1)){Lg(a,w[a+8>>2],w[a+12>>2]-1|0,w[a+44>>2]);return vj(b)|0}if(!(x[a+48|0]&16)){if(!Kc(Ng(b),u[w[a+12>>2]-1|0])){break a}}Lg(a,w[a+8>>2],w[a+12>>2]-1|0,w[a+44>>2]);c=Ng(b);u[w[a+12>>2]]=c;return b|0}return-1}function vf(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function rA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=w[a>>2];e=w[a+4>>2];if(d){g=w[a+8>>2];i=w[a+12>>2];b=w[a+24>>2];j=w[a+20>>2];k=w[a+16>>2];while(1){h=u[e+k|0]<<8;w[c>>2]=w[c>>2]+C(h,j);w[c+4>>2]=w[c+4>>2]+C(b,h);e=e+i|0;f=f+g|0;e=f>>>0<g>>>0?e+1|0:e;c=c+8|0;d=d-1|0;if(d){continue}break}}w[a>>2]=f;w[a+4>>2]=e}function XF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb+-64|0;jb=e;d=1;a:{if(wd(a,b,0)){break a}d=0;if(!b){break a}b=tl(b,74216,74264);d=0;if(!b){break a}d=e+8|0;Cb(d|4,0,52);w[e+56>>2]=1;w[e+20>>2]=-1;w[e+16>>2]=a;w[e+8>>2]=b;ob[w[w[b>>2]+28>>2]](b,d,w[c>>2],1);a=w[e+32>>2];if((a|0)==1){w[c>>2]=w[e+24>>2]}d=(a|0)==1}jb=e- -64|0;return d|0}function QD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],6)|0;a:{if(!e){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0;break a}f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+6;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h}jb=c+16|0;return e|0}function rR(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;d=jb-16|0;jb=d;f=co(b,d+12|0,c);c=w[f>>2];if(c){b=0}else{c=Kb(40);e=w[e>>2];g=w[e+4>>2];w[c+16>>2]=w[e>>2];w[c+20>>2]=g;w[c+24>>2]=w[e+8>>2];w[e>>2]=0;w[e+4>>2]=0;w[e+8>>2]=0;w[c+36>>2]=0;w[c+28>>2]=0;w[c+32>>2]=0;Xe(b,w[d+12>>2],f,c);b=1}u[a+4|0]=b;w[a>>2]=c;jb=d+16|0}function Mo(a,b,c,d){var e=0,f=0,g=0,h=0;a:{if((d|0)==65536){break a}g=C(b,c);if(!g){break a}b=d;h=d>>31;d=0;while(1){c=w[a>>2];e=CV(BV(c,c>>31,b,h),nb,65536,0);f=e;c=nb;e=(c|0)>=0&e>>>0>=2147483647|(c|0)>0;f=e?2147483647:f;c=e?0:c;w[a>>2]=(c|0)<0&f>>>0<=2147483648|(c|0)<-1?-2147483648:f;a=a+4|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}}}function IB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],6)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+6;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;u[b+5|0]=0}jb=c+16|0;return e|0}function Do(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;w[a+4>>2]=0;w[a+8>>2]=0;w[a>>2]=a+4;e=b+492|0;b=b+236|0;a:{while(1){c=y[b>>1];v[d+6>>1]=c;if(c){w[114256]=0;c=d+6|0;Y(705,d+8|0,a|0,c|0,c|0);c=w[114256];w[114256]=0;if((c|0)==1){break a}}b=b+2|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;return}b=P()|0;th(a,w[a+4>>2]);R(b|0);M()}function Qs(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){d=w[a+36>>2];c=b+8|0;f=ob[w[w[d>>2]+20>>2]](d,w[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=w[b+4>>2]-c|0;if((Pe(g,1,c,w[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=wf(w[a+32>>2])?-1:0}jb=b+16|0;return d|0}function Ox(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=w[a>>2];f=c>>>0>d>>>0?d:c;c=c-f|0;g=c>>>0<d>>>0?c:d;c=w[a+20>>2];if(f){d=b;e=f;while(1){u[c|0]=x[d|0];c=c+2|0;d=d+1|0;e=e-1|0;if(e){continue}break}d=w[a>>2];c=w[a+20>>2]}if(g){d=b+d|0;c=c+1|0;e=g;while(1){u[c|0]=x[d|0];c=c+2|0;d=d+1|0;e=e-1|0;if(e){continue}break}}return f+g|0}function $F(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{if(w[b>>2]){if(!Id(c)){Oq(c,13499)}e=w[b+4>>2];ob[w[w[e>>2]+24>>2]](d,e,w[b>>2]);w[114256]=0;Q(2125,c|0,d|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}Gb(d)}b=w[c+4>>2];w[a>>2]=w[c>>2];w[a+4>>2]=b;w[a+8>>2]=w[c+8>>2];km(c);jb=d+16|0;return}a=P()|0;Gb(d);R(a|0);M()}function kR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;if((d|0)!=1){w[a+16>>2]=0;w[a+12>>2]=c;w[a+8>>2]=b;return}$(W(0)|0)|0;w[114256]=0;Y(1333,8867,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Vq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;f=Db(a);if(f>>>0>=b>>>0){if(c){e=Yb(a);a:{if(e-f>>>0>=c>>>0){e=Qb(a);if((b|0)==(f|0)){break a}h=b+e|0;Eh(h+c|0,h,f-b|0);break a}yg(a,e,(c+f|0)-e|0,f,b,0,c);e=w[a>>2]}Uq(b+e|0,c,d);b=c+f|0;He(a,b);u[g+15|0]=0;Sc(b+e|0,g+15|0)}jb=g+16|0;return a|0}Bf();M()}function Jc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Db(a)|(c-b|0)<5){break a}Nh(b,c);e=c-4|0;c=Qb(a);f=c+Db(a)|0;b:{while(1){c:{a=u[c|0];if(b>>>0>=e>>>0){break c}if(!((a|0)<=0|(a|0)>=127)&w[b>>2]!=u[c|0]){break b}b=b+4|0;c=((f-c|0)>1)+c|0;continue}break}if((a|0)<=0|(a|0)>=127|u[c|0]>>>0>w[e>>2]-1>>>0){break a}}w[d>>2]=4}}function xy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=w[b+4>>2];a:{b:{if(!e){f=b+4|0;c=f;break b}g=y[c>>1];while(1){c=e;e=y[e+14>>1];if(e>>>0>g>>>0){f=c;e=w[c>>2];if(e){continue}break b}if(e>>>0>=g>>>0){e=c;b=0;break a}e=w[c+4>>2];if(e){continue}break}f=c+4|0}e=Kb(16);v[e+14>>1]=y[d>>1];Xe(b,c,f,e);b=1}u[a+4|0]=b;w[a>>2]=e}function oi(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(!b){return 0}j=x[a+1074321|0]&2?c- -64|0:c;c=120;e=!(x[a+480208|0]&16)|!(x[a+1074312|0]&128)?e:w[a+480180>>2]!=4;k=e^-1;f=1;while(1){g=c>>>1|0;i=g+f|0;h=md(a,i,j,d);a:{if(!(!(h>>>0>b>>>0&k)&(!(!h|e)|b>>>0<=h>>>0))){f=i+1|0;c=(g^-1)+c|0;break a}c=g}if(c){continue}break}return f}function KE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=x[a+11|0];f=d<<24>>24;g=(f|0)<0;e=g?(w[a+8>>2]&2147483647)-1|0:10;d=g?w[a+4>>2]:d;a:{if(e-d>>>0>=c>>>0){if(!c){break a}e=(f|0)<0?w[a>>2]:a;Fb(e+d|0,b,c);b=c+d|0;b:{if(u[a+11|0]<0){w[a+4>>2]=b;break b}u[a+11|0]=b}u[b+e|0]=0;return a|0}ak(a,e,(c+d|0)-e|0,d,d,0,c,b)}return a|0}function II(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=jb-16|0;jb=d;a:{if(!dd(f)){w[a+8>>2]=w[f+8>>2];b=w[f+4>>2];w[a>>2]=w[f>>2];w[a+4>>2]=b;break a}e=w[f>>2];b:{c:{c=w[f+4>>2];d:{if(Wi(c)){b=a;Zc(a,c);break d}if(c>>>0>1073741807){break c}f=Rf(c)+1|0;b=br(f);hd(a,b);Cd(a,f);Yc(a,c)}de(b,e,c+1|0);break b}Qf();M()}}jb=d+16|0}function Wk(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;c=w[b>>2];d=w[w[c>>2]+24>>2];w[114256]=0;c=V(d|0,c|0)|0;d=w[114256];w[114256]=0;a:{if((d|0)!=1){d=w[b+8>>2];w[114256]=0;U(253,a|0,b|0,c-d|0);b=w[114256];w[114256]=0;if((b|0)!=1){break a}}c=P()|0;b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}R(c|0);M()}return a|0}function tG(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;w[c>>2]=w[a+8>>2];d=w[a+8>>2];w[c+8>>2]=a+8;w[c+4>>2]=d+(b<<2);b=w[c>>2];a:{while(1){if(w[c+4>>2]==(b|0)){break a}b=w[a+16>>2];d=w[c>>2];w[114256]=0;Fl(b,d);b=w[114256];w[114256]=0;if((b|0)!=1){b=w[c>>2]+4|0;w[c>>2]=b;continue}break}a=P()|0;_q(c);R(a|0);M()}_q(c);jb=c+16|0}function wD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+4896;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==4896){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],4896)|0){b=w[a+8>>2]+4896|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==4896|0}function wB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],5)|0;a:{if(!e){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;u[b+4|0]=0;break a}f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+5;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h}jb=c+16|0;return e|0}function JB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+1030;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==1030){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],1030)|0){b=w[a+8>>2]+1030|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==1030|0}function Am(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;w[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-w[(i<<2)+d>>2]|0;if((ob[b|0](a,f)|0)>=0){if((ob[b|0](a,e)|0)>=0){break a}}j=f;f=(ob[b|0](f,e)|0)>=0;e=f?j:e;w[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}Yt(g,h);jb=g+240|0}function zD(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(u[b+11|0]>=0){w[c+8>>2]=w[b+8>>2];d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;break a}me(c,w[b>>2],w[b+4>>2])}w[114256]=0;U(367,a|0,4,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}jb=c+16|0;return}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}function lR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[114256]=0;X(1335,a|0);d=w[114256];w[114256]=0;if((d|0)!=1){w[a+4>>2]=c;w[a>>2]=b?b:1321;return}$(W(0)|0)|0;w[114256]=0;Y(1333,8897,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function kg(a){var b=0;b=w[a+24>>2];w[114256]=0;V(816,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){bc(a+68|0);b=w[a+36>>2];if(b){w[a+40>>2]=b;zb(b)}b=w[a+32>>2];w[a+32>>2]=0;if(b){zb(b)}Tj(a+24|0,0);b=w[a+4>>2];w[a+4>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}b=w[a>>2];w[a>>2]=0;if(b){ob[w[w[b>>2]+4>>2]](b)}return a}W(0)|0;Eb();M()}function uC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+422;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==422){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],422)|0){b=w[a+8>>2]+422|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==422|0}function sE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+136;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==136){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],136)|0){b=w[a+8>>2]+136|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==136|0}function rC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+826;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==826){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],826)|0){b=w[a+8>>2]+826|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==826|0}function aV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+225;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==225){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],225)|0){b=w[a+8>>2]+225|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==225|0}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+326;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==326){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],326)|0){b=w[a+8>>2]+326|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==326|0}function RB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+274;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==274){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],274)|0){b=w[a+8>>2]+274|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==274|0}function OB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+106;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==106){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],106)|0){b=w[a+8>>2]+106|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==106|0}function IA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;f=w[b>>2];g=w[b+4>>2];d=Nk(e+8|0,c);u[d+16|0]=x[c+16|0];w[d+12>>2]=w[c+12>>2];w[114256]=0;ga(583,a|0,b|0,0,((g-f|0)/52|0)-1&65535,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){a=w[d>>2];if(a){zb(a)}jb=e+32|0;return}a=P()|0;b=w[d>>2];if(b){zb(b)}R(a|0);M()}function Fp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+284;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==284){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],284)|0){b=w[a+8>>2]+284|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==284|0}function xh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b- -64;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==64){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],64)|0){b=w[a+8>>2]- -64|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==64|0}function rp(a){var b=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=808604749|((x[a+8|0]|x[a+9|0]<<8)-768&65535)>>>0<65280|(((x[a+112|0]|x[a+113|0]<<8)-65&65535)>>>0<65472|(x[a+106|0]|x[a+107|0]<<8)>>>0>256)){break a}if((x[a+122|0]|x[a+123|0]<<8)>>>0>255){break a}b=(x[a+124|0]|x[a+125|0]<<8)>>>0<4e3}return b}function zv(a){var b=0,c=D(0),d=0;c=_b(D(A[a+4208>>2]*D(999)));d=w[w[a+16>>2]+24620>>2];a:{if(!(c>=D(4294967296))){if(c<=D(0)){break a}if(c<D(4294967296)&c>=D(0)){b=~~c>>>0}else{b=0}if((b|0)!=-1){break a}}b=-2}b=(d>>>0)/(b+1>>>0)|0;b=b>>>0<=2?2:b;w[a+4216>>2]=b;w[a+4220>>2]=b>>>1;if(b>>>0<z[a+4224>>2]){w[a+4224>>2]=b}}function _p(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=w[a>>2];a:{if(!b){break a}c=w[a+8>>2];if(!c){break a}d=w[a+12>>2];if(!d){break a}e=ob[d|0](b)|0;a=nb;f=a;if((a|0)<0){break a}a=0;b:{if((ob[c|0](b,0,0,0)|0)<0){break b}a=0;if((ob[c|0](b,0,0,2)|0)<0){break b}ob[d|0](b)|0;a=nb;a=(a|0)>0|(a|0)>=0}g=a;ob[c|0](b,e,f,0)|0}return g}function Jf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=w[a+8>>2];g=x[a+11|0];d=g<<24>>24<0;e=d?(f&2147483647)-1|0:10;if(e>>>0>=c>>>0){d=d?w[a>>2]:a;if(c){hc(d,b,c);b=u[a+11|0]}else{b=f>>>24|0}a:{if(b<<24>>24<0){w[a+4>>2]=c;break a}u[a+11|0]=c}u[c+d|0]=0;return a|0}d=d?w[a+4>>2]:g;ak(a,e,c-e|0,d,0,d,c,b);return a|0}function yq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+41;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==41){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],41)|0){b=w[a+8>>2]+41|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==41|0}function yB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+71;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==71){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],71)|0){b=w[a+8>>2]+71|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==71|0}function wg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+80;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==80){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],80)|0){b=w[a+8>>2]+80|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==80|0}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+50;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==50){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],50)|0){b=w[a+8>>2]+50|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==50|0}function iF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+65;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==65){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],65)|0){b=w[a+8>>2]+65|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==65|0}function hl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+11;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==11){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],11)|0){b=w[a+8>>2]+11|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==11|0}function gF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+59;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==59){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],59)|0){b=w[a+8>>2]+59|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==59|0}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+16;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==16){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],16)|0){b=w[a+8>>2]+16|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==16|0}function cy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+27;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==27){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],27)|0){b=w[a+8>>2]+27|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==27|0}function bV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+73;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==73){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],73)|0){b=w[a+8>>2]+73|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==73|0}function ZE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+17;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==17){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],17)|0){b=w[a+8>>2]+17|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==17|0}function Wo(a){var b=0,c=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=860902483){break a}b=x[a+4|0]|x[a+5|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|x[a+6|0]>128){break a}b=x[a+200|0]|x[a+201|0]<<8;if(!(x[a+140|0]|x[a+141|0]<<8)|((b<<8|b>>>8)&65535)>>>0>3999){break a}c=(x[a+148|0]|x[a+149|0]<<8)==12800}return c}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+60;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==60){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],60)|0){b=w[a+8>>2]+60|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==60|0}function Vu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+10;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==10){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],10)|0){b=w[a+8>>2]+10|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==10|0}function UC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+91;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==91){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],91)|0){b=w[a+8>>2]+91|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==91|0}function TD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+15;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==15){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],15)|0){b=w[a+8>>2]+15|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==15|0}function Sl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+36;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==36){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],36)|0){b=w[a+8>>2]+36|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==36|0}function SD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+34;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==34){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],34)|0){b=w[a+8>>2]+34|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==34|0}function RF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(wd(a,w[b+8>>2],e)){pl(b,c,d);return}a:{if(!wd(a,w[b>>2],e)){break a}if(!(w[b+16>>2]!=(c|0)&w[b+20>>2]!=(c|0))){if((d|0)!=1){break a}w[b+32>>2]=1;return}w[b+20>>2]=c;w[b+32>>2]=d;w[b+40>>2]=w[b+40>>2]+1;if(!(w[b+36>>2]!=1|w[b+24>>2]!=2)){u[b+54|0]=1}w[b+44>>2]=4}}function Qu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+14;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==14){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],14)|0){b=w[a+8>>2]+14|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==14|0}function QC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+18;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==18){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],18)|0){b=w[a+8>>2]+18|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==18|0}function Nm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+20;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==20){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],20)|0){b=w[a+8>>2]+20|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==20|0}function NB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+72;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==72){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],72)|0){b=w[a+8>>2]+72|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==72|0}function LC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+33;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==33){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],33)|0){b=w[a+8>>2]+33|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==33|0}function LB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+26;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==26){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],26)|0){b=w[a+8>>2]+26|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==26|0}function Ii(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+12;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==12){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],12)|0){b=w[a+8>>2]+12|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==12|0}function Gv(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=w[w[a+16>>2]+24620>>2]/5|0;w[a+4272>>2]=b;w[114256]=0;w[c+12>>2]=0;U(992,a+4256|0,b<<1,c+12|0);b=w[114256];w[114256]=0;a:{if((b|0)==1){b=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;w[a+4272>>2]=0;aa()}w[a+4276>>2]=0;w[a+4268>>2]=0;jb=c+16|0;return}R(b|0);M()}function Fi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+32;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==32){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],32)|0){b=w[a+8>>2]+32|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==32|0}function Ei(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+96;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==96){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],96)|0){b=w[a+8>>2]+96|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==96|0}function DC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+42;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==42){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],42)|0){b=w[a+8>>2]+42|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==42|0}function AA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+40;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==40){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],40)|0){b=w[a+8>>2]+40|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==40|0}function Of(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],4)|0;a:{if(!e){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0;break a}f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+4;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h}jb=c+16|0;return e|0}function vh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],4)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+4;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0}jb=c+16|0;return e|0}function BT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=1;d=w[w[a+20>>2]+28>>2];d=d>>>0<=127?-1:d^-128;f=d&255;a:{if(f>>>0<=x[a+4200|0]|f>>>0>249){break a}a=w[(w[a+16>>2]+C(d&255,160)|0)+906300>>2];if(!a){break a}w[c+8>>2]=w[b>>2];w[c+12>>2]=w[b+4>>2];e=ob[w[w[a>>2]+72>>2]](a,c+8|0)|0}jb=c+16|0;return e|0}function tv(a,b){var c=0,d=0,e=0;d=0;a:{if(a>D(.9999989867210388)){break a}a=D(a*a);e=+a;c=Fc(31415.926535897932/+b);c=Tb((32768-(L((1-c)*+D(a+a)+(c*c+-1)*+D(a*a))+c*e)*32768)/(1-e));d=2147483647;if(c>=2147483647){break a}d=-2147483648;if(c<=-2147483648){break a}if(E(c)<2147483648){return~~c}d=-2147483648}return d}function Ze(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+14>>1]=65535;g=c>>>0>=128?128:c;$d(a,g,f+14|0);a:{if(g){i=w[a>>2];j=w[a+4>>2]-i>>1;c=0;while(1){if((c|0)==(j|0)){break a}h=x[b+c|0];v[(c<<1)+i>>1]=(d|0)==(h|0)?-1:(e|0)==(h|0)?-2:h;c=c+1|0;if((g|0)!=(c|0)){continue}break}}jb=f+16|0;return}Bc(a);M()}function tq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+7;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==7){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],7)|0){b=w[a+8>>2]+7|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==7|0}function gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+5;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==5){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],5)|0){b=w[a+8>>2]+5|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==5|0}function gE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+3;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==3){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],3)|0){b=w[a+8>>2]+3|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==3|0}function cd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+2;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==2){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],2)|0){b=w[a+8>>2]+2|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==2|0}function Xb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+1;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==1){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],1)|0){b=w[a+8>>2]+1|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==1|0}function Nc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+4;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==4){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],4)|0){b=w[a+8>>2]+4|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==4|0}function Mc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+8;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==8){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],8)|0){b=w[a+8>>2]+8|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==8|0}function Jp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+6;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==6){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],6)|0){b=w[a+8>>2]+6|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==6|0}function cp(a){var b=0,c=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=-28486832|x[a+63|0]!=26){break a}b=x[a+65|0];if(x[a+64|0]&3|(x[a+66|0]|(b|0)!=16&(b|0)!=1)){break a}b=x[a+78|0]|x[a+79|0]<<8;if(b>>>0>127){break a}a=x[a+80|0]|x[a+81|0]<<8;if(a>>>0>127){break a}c=((a>>>0<b>>>0?b:a)|0)!=0}return c}function jH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=x[b+18|0];b=x[b+46|0];u[a+1|0]=1;u[a+2|0]=0;u[a+3|0]=(b^-1)&1;e=d&2;u[a|0]=e?16:8;if(!(!(d&4)|c>>>0<532)){u[a+1|0]=3}c=b&4?5:4;a:{b:{if(d&8){break b}if(!e){c=11;if((b|0)==255){break b}}if(b&2){u[a+2|0]=1}c=!(b&4);b=!(b&8)|!e;if(c&b){break a}c=b?2:9}u[a+3|0]=c}}function Rt(a,b,c,d,e){var f=0,g=0,h=0;f=-17;if(-17-b>>>0>=c>>>0){g=u[a+11|0]<0;h=w[a>>2];if(b>>>0<=2147483622){c=b+c|0;f=b<<1;c=c>>>0>f>>>0?c:f;f=c>>>0<11?11:(c|15)+1|0}c=g?h:a;g=Kb(f);if(e){Fb(g,c,e)}if((d|0)!=(e|0)){Fb(e+g|0,c+e|0,d-e|0)}if((b|0)!=10){zb(c)}w[a>>2]=g;w[a+8>>2]=f|-2147483648;return}zc(a);M()}function td(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=c+8|0;Cb(d,0,48);w[114256]=0;w[c+56>>2]=a;U(954,a|0,b|0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[c+55|0]<0){zb(w[c+44>>2])}a=w[c+32>>2];if(a){w[c+36>>2]=a;zb(a)}a=w[c+8>>2];if(a){w[c+12>>2]=a;zb(a)}jb=c- -64|0;return}a=P()|0;Cf(c+8|0);R(a|0);M()}function oJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=w[16251];w[g+24>>2]=w[16250];w[g+28>>2]=h;h=w[16249];w[g+16>>2]=w[16248];w[g+20>>2]=h;h=w[16247];w[g+8>>2]=w[16246];w[g+12>>2]=h;h=w[16245];w[g>>2]=w[16244];w[g+4>>2]=h;h=a;a=g+32|0;b=Ie(h,b,c,d,e,f,g,a);jb=a;return b|0}function nH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;w[e>>2]=c;a=Jl(f+12|0,0,b,w[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-w[e>>2]>>>0){break a}d=f+12|0;while(1){if(c){a=x[d|0];b=w[e>>2];w[e>>2]=b+1;u[b|0]=a;c=c-1|0;d=d+1|0;continue}break}b=0}a=b;jb=f+16|0;return a|0}function Vv(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=w[a+4232>>2];b=(b>>>1)+(b>>>6)|0;w[a+4220>>2]=b;w[114256]=0;w[c+12>>2]=0;U(992,a+4208|0,b<<1,c+12|0);b=w[114256];w[114256]=0;a:{if((b|0)==1){b=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;w[a+4220>>2]=0;aa()}w[a+4224>>2]=0;jb=c+16|0;return}R(b|0);M()}function Up(a){var b=0;a:{b:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=1297108297){if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=778924148){break a}if((x[a+34|0]|x[a+35|0]<<8)>>>0<=255){break b}break a}if((x[a+34|0]|x[a+35|0]<<8)>>>0>255){break a}}b=(x[a+36|0]|x[a+37|0]<<8)>>>0<4e3}return b}function Qk(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+130;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==130){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],130)|0){b=w[a+8>>2]+130|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==130}function jF(a){a=a|0;var b=0,c=0;if(!x[a+8|0]){if(x[a+24|0]){u[a+24|0]=0;c=a+40|0;while(1){u[(C(b,12)+c|0)+8|0]=0;b=b+1|0;if((b|0)!=16){continue}break}b=w[a+28>>2];if((b|0)!=w[a+32>>2]){w[a+32>>2]=b}ls(a+28|0)}$e(a+12|0,w[a+4>>2]);ob[w[w[a>>2]+44>>2]](a,w[a+12>>2],0,w[a+4>>2])|0;u[a+8|0]=1}return w[a+12>>2]}function Ui(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;u[d+15|0]=b;a:{b:{c:{if(!dd(a)){c=10;b=x[a+11|0];if((b|0)==10){break c}c=a;Zc(a,b+1|0);break a}c=Ke(a);b=w[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}yg(a,c,1,c,c,0,0);b=c}c=w[a>>2];Yc(a,b+1|0)}a=b+c|0;Sc(a,d+15|0);u[d+14|0]=0;Sc(a+1|0,d+14|0);jb=d+16|0}function sv(a){var b=D(0),c=0;b=D(32768);a:{if(!a){break a}b=D(0);if((a|0)<-99999){break a}c=+(a|0)*.0016609640474436812;b=D(D(Ed(c-K(c+.5)))*D(32768))}b=_b(b);a=2147483647;b:{if(b>=D(2147483648)){break b}a=-2147483648;if(b<=D(-2147483648)){break b}if(D(E(b))<D(2147483648)){return~~b}a=-2147483648}return a}function gG(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;w[d+12>>2]=b;a:{b:{c:{if(!dd(a)){c=1;b=x[a+11|0];if((b|0)==1){break c}c=a;Zc(a,b+1|0);break a}c=Ke(a);b=w[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}Mq(a,c,1,c,c);b=c}c=w[a>>2];Yc(a,b+1|0)}a=(b<<2)+c|0;xd(a,d+12|0);w[d+8>>2]=0;xd(a+4|0,d+8|0);jb=d+16|0}function VN(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;Wu(h+8|0,b,c,d,e,f,g);w[a+8>>2]=w[h+16>>2];b=w[h+12>>2];w[a>>2]=w[h+8>>2];w[a+4>>2]=b;w[h+16>>2]=0;w[h+8>>2]=0;w[h+12>>2]=0;a:{if(u[h+31|0]>=0){break a}zb(w[h+20>>2]);if(u[h+19|0]>=0){break a}zb(w[h+8>>2])}jb=h+32|0}function qj(a){var b=0,c=0;b=w[a+76>>2];a:{if(!((b|0)>=0&(!b|w[114108]!=(b&-1073741825)))){b=w[a+4>>2];if((b|0)!=w[a+8>>2]){w[a+4>>2]=b+1;a=x[b|0];break a}a=gm(a);break a}b=a+76|0;c=w[b>>2];w[b>>2]=c?c:1073741823;c=w[a+4>>2];b:{if((c|0)!=w[a+8>>2]){w[a+4>>2]=c+1;a=x[c|0];break b}a=gm(a)}w[b>>2]=0}return a}function nl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],3)|0;a:{if(!e){u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;break a}f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+3;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h}jb=c+16|0;return e|0}function Uj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(c>>>0<4294967280){a:{b:{if(c>>>0>=11){e=(c|15)+1|0;d=Kb(e);w[a+8>>2]=e|-2147483648;w[a>>2]=d;w[a+4>>2]=c;break b}u[a+11|0]=c;d=a;if(!c){break a}}c=b+c|0;while(1){u[d|0]=x[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}u[d|0]=0;return a|0}zc(a);M()}function HN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((b|0)!=(c|0)){a=w[d>>2];while(1){w[a>>2]=w[b>>2];a=a+4|0;a:{if(u[b+15|0]>=0){e=b+4|0;f=w[e+4>>2];w[a>>2]=w[e>>2];w[a+4>>2]=f;w[a+8>>2]=w[e+8>>2];break a}Ge(a,w[b+4>>2],w[b+8>>2])}a=w[d>>2]+16|0;w[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function vp(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+30;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==30){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],30)|0){b=w[a+8>>2]+30|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==30}function cl(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+66;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==66){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],66)|0){b=w[a+8>>2]+66|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==66}function Zk(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+48;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==48){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],48)|0){b=w[a+8>>2]+48|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==48}function Yt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=4;f=jb-256|0;jb=f;if((b|0)>=2){h=(b<<2)+a|0;w[h>>2]=f;while(1){e=c>>>0>=256?256:c;Fb(w[h>>2],w[a>>2],e);d=0;while(1){g=(d<<2)+a|0;d=d+1|0;Fb(w[g>>2],w[(d<<2)+a>>2],e);w[g>>2]=w[g>>2]+e;if((b|0)!=(d|0)){continue}break}c=c-e|0;if(c){continue}break}}jb=f+256|0}function Gp(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+52;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==52){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],52)|0){b=w[a+8>>2]+52|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==52}function Ax(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=w[a>>2];c=c>>>2|0;e=c>>>0>e>>>0?e:c;if(e){a=w[a+20>>2];c=e;f=d;while(1){g=f;f=x[b|0]|x[b+1|0]<<8;f=g+(f<<8|f>>>8)|0;v[a>>1]=f;g=d;d=x[b+2|0]|x[b+3|0]<<8;d=g+(d<<8|d>>>8)|0;v[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return e<<2}function Aq(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+37;d=ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0;if((d|0)==37){b=w[a>>2];a:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],37)|0){b=w[a+8>>2]+37|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b}jb=c+16|0;return(d|0)==37}function gf(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}u[a|0]=43;a=a+1|0}if(d&512){u[a|0]=35;a=a+1|0}while(1){e=x[b|0];if(e){u[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}u[a|0]=b}function ZT(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+20>>2];c=w[d+4>>2];a:{if(!((w[d+8>>2]-c|0)!=8|(x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24))!=1869112133)){b=x[c+4|0]|x[c+5|0]<<8|(x[c+6|0]<<16|x[c+7|0]<<24);w[a+4260>>2]=x[c|0]|x[c+1|0]<<8|(x[c+2|0]<<16|x[c+3|0]<<24);w[a+4264>>2]=b;break a}Qv(a,b)}Yj(a)}function Jr(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;w[c>>2]=a;d=w[a+4>>2];w[c+4>>2]=d;w[c+8>>2]=d+(b<<2);b=w[c+4>>2];e=w[c+8>>2];a:{while(1){if((b|0)==(e|0)){break a}d=Uf(a);w[114256]=0;Fl(d,b);d=w[114256];w[114256]=0;if((d|0)!=1){b=b+4|0;w[c+4>>2]=b;continue}break}a=P()|0;cr(c);R(a|0);M()}cr(c);jb=c+16|0}function vg(a,b,c,d){var e=0,f=0,g=0;if(w[c>>2]|w[d>>2]){if(b){while(1){e=w[d>>2];f=w[c>>2];w[c>>2]=f-(((-2147483648-f>>>31|0)-1&255)+f>>8);w[d>>2]=w[d>>2]-(e+((-2147483648-e>>>31|0)-1&255)>>8);e=(g<<3)+a|0;w[e>>2]=w[c>>2];w[e+4>>2]=w[d>>2];g=g+1|0;if((g|0)!=(b|0)){continue}break}}return}Cb(a,0,b<<3)}function ly(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[b+11|0];c=d<<24>>24<0;d=c?w[b+4>>2]:d;if(d){c=c?w[b>>2]:b;e=d+c|0;while(1){d=x[c|0];u[c|0]=(d-65&255)>>>0<26?d+32|0:d;c=c+1|0;if((e|0)!=(c|0)){continue}break}}c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0}function Dl(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a:{if(!b){break a}d=w[a>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],b)|0)){break a}f=1;while(1){u[c+13|0]=0;g=(c+14|0)+e|0;if(b>>>0>e>>>0){Xb(a,c+13|0);d=x[c+13|0]}else{d=0}u[g|0]=d;e=1;d=f;f=0;if(d){continue}break}e=y[c+14>>1]}jb=c+16|0;return e}function tR(){var a=0,b=0;w[114256]=0;a=ea(1325)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,7043,0,0,0,0,0,0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){R(b|0);M()}W(0)|0;Eb();M()}function Wp(a){var b=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=-28490681|x[a+68|0]!=13|(x[a+69|0]!=10|x[a+70|0]!=26)){break a}if(x[a+76|0]|((x[a+71|0]|x[a+72|0]<<8|(x[a+73|0]<<16|x[a+74|0]<<24))!=1397116231|x[a+75|0]!=1)){break a}b=((x[a+116|0]|x[a+117|0]<<8)-1&65535)>>>0<9}return b}function GR(){var a=0,b=0;w[114256]=0;a=ea(1313)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,5814,0,0,0,0,0,0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){R(b|0);M()}W(0)|0;Eb();M()}function ER(){var a=0,b=0;w[114256]=0;a=ea(1317)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;na(1314,5842,0,0,0,0,0,0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;w[114256]=0;_(18);a=w[114256];w[114256]=0;if((a|0)!=1){R(b|0);M()}W(0)|0;Eb();M()}function wq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;kl(b,c);e=w[a>>2];e=ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],c<<1)|0;if(e){f=w[a+8>>2];c=w[a>>2];g=w[b+4>>2];w[d+8>>2]=w[b>>2];w[d+12>>2]=g;h=a,i=(ob[w[w[c>>2]+32>>2]](c,f,d+8|0)|0)+w[a+8>>2]|0,w[h+8>>2]=i}jb=d+16|0;return e|0}function Xk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;Fe(b,c);e=w[a>>2];e=ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],c<<2)|0;if(e){f=w[a+8>>2];c=w[a>>2];g=w[b+4>>2];w[d+8>>2]=w[b>>2];w[d+12>>2]=g;h=a,i=(ob[w[w[c>>2]+32>>2]](c,f,d+8|0)|0)+w[a+8>>2]|0,w[h+8>>2]=i}jb=d+16|0;return e|0}function uD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(!w[a+300>>2]){return 0}if((ob[w[a+304>>2]](w[a+296>>2],c,0,0)|0)>=0){a:{if(!d){break a}while(1){c=ob[w[a+300>>2]](w[a+296>>2],b,d)|0;if(!c){break a}b=b+c|0;e=c+e|0;f=e>>>0<c>>>0?f+1|0:f;d=d-c|0;if(d){continue}break}}}else{e=0}return e|0}function Ln(a,b,c){var d=0,e=0,f=0,g=0;e=w[a+1074416>>2];a=w[a+1074392>>2];u[b+872|0]=x[b+872|0]|16;d=a?x[b+833|0]:0;g=(c|0)<0?d:0-d|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(E(f)<2147483648){d=~~f;break a}d=-2147483648}w[b+876>>2]=g+(d+w[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;u[b+833|0]=(a^c)-a}function Jh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=w[a+4>>2];a:{if(!c){c=w[a>>2];break a}d=32-c|0;f=b>>>0>d>>>0?d:b;e=w[a>>2];w[e>>2]=w[e>>2]&(-1<<c&-1>>>d-f^-1);c=e+4|0;w[a>>2]=c;b=b-f|0}d=c;c=b>>>5<<2;Cb(d,0,c);if((b&-32)!=(b|0)){d=a;a=c+w[a>>2]|0;w[d>>2]=a;w[a>>2]=w[a>>2]&(-1>>>32-(b&31)^-1)}}function oS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ze(a,b,c,d);w[a+4208>>2]=1017370378;w[a+4212>>2]=0;w[a>>2]=79860;w[114256]=0;S(985,a+44|0,2,2)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){break a}w[114256]=0;X(986,a|0);b=w[114256];w[114256]=0;if((b|0)==1){break a}return a|0}b=P()|0;Oc(a);R(b|0);M()}function Yi(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}e=w[a>>2];if(!(ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],b)|0)){break a}while(1){u[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Xb(a,c+11|0);e=x[c+11|0]}else{e=0}u[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}d=w[c+12>>2]}jb=c+16|0;return d}function TE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;$e(b,c);e=w[a>>2];e=ob[w[w[e>>2]+36>>2]](e,w[a+8>>2],c)|0;if(e){f=w[a+8>>2];c=w[a>>2];g=w[b+4>>2];w[d+8>>2]=w[b>>2];w[d+12>>2]=g;h=a,i=(ob[w[w[c>>2]+32>>2]](c,f,d+8|0)|0)+w[a+8>>2]|0,w[h+8>>2]=i}jb=d+16|0;return e|0}function el(a,b,c){var d=0,e=0;a:{if(x[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=w[a+16>>2];if(b>>>0<=c>>>0){break a}b=b+4095&-4096;uq(a,b-c|0);c=w[a+16>>2];d=a,e=(ob[w[w[a>>2]+48>>2]](a,c+w[a+4>>2]|0,b-c|0)|0)+w[a+16>>2]|0,w[d+16>>2]=e;if(!(ob[w[w[a>>2]+44>>2]](a)|0)){break a}u[a+20|0]=1}}function Qd(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;u[a+8|0]=0;w[a>>2]=0;w[a+4>>2]=4194432;c=Hb(b+8|0,17256);w[114256]=0;w[b+28>>2]=20;w[b+24>>2]=a+9;Q(200,b+24|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}jb=b+32|0;return}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}function Pi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],2)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+2;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}u[b|0]=0;u[b+1|0]=0}jb=c+16|0;return e|0}function Jb(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(w[a>>2]!=w[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=x[a|0];e=x[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function kF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;u[d+31|0]=x[c|0];c=d+16|0;bh(c,d+31|0);w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=c;U(51,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function jR(a){a=a|0;var b=0;w[114256]=0;X(1335,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){return w[a+16>>2]}$(W(0)|0)|0;w[114256]=0;Y(1333,2176,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)!=1){aa();return-1}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function cc(a,b){var c=0,d=0,e=0;a:{c=As(b);d=Ag(a);if(c>>>0<=d>>>0){d=Qb(a);b:{c:{if(c){w[114256]=0;Xq(d,b,c);b=w[114256];w[114256]=0;if((b|0)==1){break c}}break b}W(0)|0;Eb();M()}b=jb-16|0;jb=b;He(a,c);w[b+12>>2]=0;xd(d+(c<<2)|0,b+12|0);jb=b+16|0;break a}e=a;a=Db(a);Nq(e,d,c-d|0,a,0,a,c,b)}}function _d(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Xb(a,c+14|0);b=d?x[c+14|0]:0;d=b&63;f=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){e=Xb(a,c+15|0);e=e?x[c+15|0]:0;d=(e&127)<<b|d;if(e<<24>>24>=0){break a}e=b>>>0<25;b=b+7|0;if(e){continue}break}}jb=c+16|0;return((f|0)<0?0-d|0:d)|0}function Bd(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=F(e);$c(d,e,0,0,0,c+81|0);e=0+w[d+8>>2]|0;c=(w[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=w[d+4>>2];b=w[d>>2]}w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=e;w[a+12>>2]=f;jb=d+16|0}function kw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;g=yf(a,c);rd(e+8|0,w[a+28>>2]);f=w[e+20>>2];w[e+24>>2]=w[e+16>>2];w[e+28>>2]=f;h=w[a+28>>2];a:{b:{if(!g){f=-1;if(!(x[a+24|0]&32)){break b}break a}f=w[g+8>>2]}ob[d|0](h,b,f)}a=zf(a,g,c,e+24|0);jb=e+32|0;return a|0}function _C(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{if(x[a+40|0]){e=0}else{if(!w[a+28>>2]){break a}b:{if(!c){break b}while(1){d=ob[w[a+28>>2]](w[a+24>>2],b,c)|0;if(!d){u[a+40|0]=1;break b}b=b+d|0;e=d+e|0;f=e>>>0<d>>>0?f+1|0:f;c=c-d|0;if(c){continue}break}}}return e|0}u[a+40|0]=1;return 0}function PP(a){a=a|0;var b=0;w[114256]=0;X(1407,a|0);b=w[114256];w[114256]=0;a:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;Y(1333,7777,a|0,0,0);a=w[114256];w[114256]=0;if((a|0)==1){break a}aa();a=0}return a|0}a=P()|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;if((b|0)!=1){R(a|0);M()}W(0)|0;Eb();M()}function Av(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=w[a+4256>>2];w[a+4240>>2]=b<<1;w[114256]=0;w[c+12>>2]=0;U(992,a+4208|0,b<<2,c+12|0);b=w[114256];w[114256]=0;a:{if((b|0)==1){b=W(74720)|0;if((kb|0)!=(fa(74720)|0)){break a}$(b|0)|0;w[a+4240>>2]=0;aa()}w[a+4244>>2]=0;jb=c+16|0;return}R(b|0);M()}function Gg(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Sb(d,a);w[114256]=0;a=V(1735,d|0)|0;d=w[114256];w[114256]=0;a:{b:{if((d|0)==1){break b}w[114256]=0;Z(1749,a|0,64768,64794,b|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break b}Ab(c+8|0);jb=c+16|0;break a}a=P()|0;Ab(c+8|0);R(a|0);M()}return b}function Dc(a){var b=0;a:{b=x[a+1376|0];b:{if(!b){b=-1;if(w[a+1384>>2]){break b}if(!Im(a)){break b}b=x[a+1376|0];if(!b){break a}}u[a+1376|0]=b-1;w[a+1400>>2]=w[a+1400>>2]+1;b=w[a+32>>2];if(b>>>0>=z[a+40>>2]){w[a+96>>2]=1;return 0}w[a+32>>2]=b+1;b=x[b|0]}return b}ha(11613,9008,1578,1915);M()}function Xl(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;w[e+60>>2]=b;w[e+20>>2]=b;w[e+24>>2]=-1;f=e+16|0;ce(f,0,0);Is(e,f,d,1);d=w[e+8>>2];f=w[e+12>>2];g=w[e>>2];h=w[e+4>>2];if(c){w[c>>2]=((w[e+20>>2]+w[e+136>>2]|0)-w[e+60>>2]|0)+b}w[a+8>>2]=d;w[a+12>>2]=f;w[a>>2]=g;w[a+4>>2]=h;jb=e+160|0}function SR(a){a=a|0;var b=0;u[a+4202|0]=1;A[a+4272>>2]=H(D(G(D(D(D(z[w[a+16>>2]+24620>>2])*D(20938023226335645e-21))+D(-.005025125574320555)),D(1))),D(0));wv(a);b=a+4264|0;w[b>>2]=0;w[b+4>>2]=0;b=a+4256|0;w[b>>2]=0;w[b+4>>2]=0;b=a+4248|0;w[b>>2]=0;w[b+4>>2]=0;w[a+4240>>2]=0;w[a+4244>>2]=0}function ME(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],120)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+120;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}Cb(b,0,120)}jb=c+16|0;return e|0}function Lq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Wb(a);e=ec(b);f=Db(c);w[114256]=0;Y(2124,a|0,b|0,e|0,e+f|0);b=w[114256];w[114256]=0;a:{if((b|0)!=1){b=Qb(c);w[114256]=0;S(92,a|0,b|0,f|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){break a}}b=P()|0;Gb(a);R(b|0);M()}jb=d+16|0}function Ev(a,b,c){var d=0,e=0,f=0;if(D(E(a))<D(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return D((f?b^-1|f:b)|0)}function rO(a){a=a|0;var b=0,c=0;b=w[a+24>>2];c=y[b+1074438>>1];if(c>>>0>=If(w[b+484360>>2]+(x[b+484376|0]<<5)|0)>>>0){return y[w[a+24>>2]+1074436>>1]}a=w[a+24>>2];b=y[w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]+(c<<1)>>1];return(b>>>0>=((w[a+484348>>2]-w[a+484344>>2]|0)/52&65535)>>>0?-1:b)|0}function fq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=w[a>>2];e=ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],64)|0;a:{if(e){f=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b- -64;g=a,h=(ob[w[w[d>>2]+32>>2]](d,f,c+8|0)|0)+w[a+8>>2]|0,w[g+8>>2]=h;break a}Cb(b,0,64)}jb=c+16|0;return e|0}function yk(a){var b=0,c=0,d=0;b=y[a+20>>1];v[a+28>>1]=y[a+22>>1]<<1|(x[w[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=w[c>>2];if(d){sg(d);c=w[c>>2];d=w[c+4>>2];v[c+70>>1]=x[((y[d+22>>1]<<4|y[d+20>>1]>>>6)&65535)+25456|0]>>>y[c+68>>1]}b=b+1|0;if((b|0)!=4){continue}break}}function qR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=b;d=a+4|0;c=w[a+4>>2];a:{b:{if(!c){break b}b=d;while(1){f=si(c+16|0,e);b=f?b:c;c=w[(f?c+4|0:c)>>2];if(c){continue}break}if((b|0)==(d|0)){break b}if(!si(e,b+16|0)){break a}}b=d}if((a+4|0)==(b|0)){return 0}_v(a,b);fo(b+16|0);zb(b);return 1}function hJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;w[c+12>>2]=c+116;d=a+8|0;a=c+16|0;es(d,a,c+12|0,e,f,g);e=a;d=w[c+12>>2];a=jb-16|0;jb=a;w[a+8>>2]=b;while(1){if((d|0)!=(e|0)){xt(a+8|0,u[e|0]);e=e+1|0;continue}break}jb=a+16|0;jb=c+128|0;return w[a+8>>2]}function tg(a){a=a|0;var b=0,c=0,d=0;b=w[a>>2];c=w[a+16>>2];if(b>>>0<c>>>0){w[a+16>>2]=b;c=b}d=w[a+8>>2];if(d>>>0>b>>>0){w[a+8>>2]=b;d=b}if(z[a+12>>2]>=c>>>0){w[a+12>>2]=0;w[a+16>>2]=0;v[a+34>>1]=y[a+34>>1]&65511}if(z[a+4>>2]>=d>>>0){w[a+4>>2]=0;w[a+8>>2]=0;v[a+34>>1]=y[a+34>>1]&65529}}function QU(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>28){break c}d=1<<a;c=1;if(d&270014517){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function Yx(a,b,c){a=a|0;b=b|0;c=c|0;w[a>>2]=0;w[a+4>>2]=0;u[a+30|0]=c;v[a+28>>1]=0;w[a+24>>2]=b;w[a+16>>2]=0;w[a+20>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;w[114256]=0;T(732,a|0,1);b=w[114256];w[114256]=0;if((b|0)==1){c=P()|0;b=w[a+12>>2];if(b){w[a+16>>2]=b;zb(b)}ui(a);R(c|0);M()}return a|0}function Xq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((a|0)==(b|0)){break a}if(a-b>>>0>=c<<2>>>0){if(!c){break a}d=a;while(1){w[d>>2]=w[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break a}if(!c){break a}while(1){c=c-1|0;d=c<<2;w[d+a>>2]=w[b+d>>2];if(c){continue}break}}return a|0}function NN(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;w[a+4>>2]=0;w[a+8>>2]=0;w[a>>2]=82300;w[114256]=0;d=w[b+12>>2];w[c+8>>2]=w[b+8>>2];w[c+12>>2]=d;d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;Q(1478,a+12|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){jb=c+16|0;return a|0}R(P()|0);M()}function KN(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;w[a+4>>2]=0;w[a+8>>2]=0;w[a>>2]=82340;w[114256]=0;d=w[b+12>>2];w[c+8>>2]=w[b+8>>2];w[c+12>>2]=d;d=w[b+4>>2];w[c>>2]=w[b>>2];w[c+4>>2]=d;Q(1479,a+12|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){jb=c+16|0;return a|0}R(P()|0);M()}function Ff(a,b,c,d){var e=0,f=0;a:{f=w[(C(b,896)+a|0)+1075640>>2];if(!f|(x[f+31|0]-1&255)>>>0>16){break a}e=x[f+34|0];if((e-1&255)>>>0>249){break a}e=w[(C(e,160)+a|0)+906140>>2];if(!e){break a}ob[w[w[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}v[(C(b,896)+a|0)+1075846>>1]=65535}}function oj(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;f=-1;w[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;w[e+144>>2]=a;e=Cb(e,0,144);w[e+76>>2]=-1;w[e+36>>2]=1703;w[e+80>>2]=-1;w[e+44>>2]=e+159;w[e+84>>2]=e+144;a:{if((b|0)<0){w[114084]=61;break a}u[a|0]=0;f=Tt(e,c,d,1557,1558)}jb=e+160|0;return f}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-96|0;jb=d;c=-1;a:{if(!mp(a,d)){break a}c=0;if(!lp(d)){break a}e=a;f=b;c=y[d+94>>1];b=c+x[d+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+x[d+92|0]|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=c+x[d+4|0]|0;b=b-96|0;c=Uc(e,f,b,0)}jb=d+96|0;return c|0}function ot(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=dt(b,c);if(e>>>0<=4294967279){a:{if(sj(e)){Zc(a,e);d=a;break a}g=_f(e)+1|0;d=nf(a,g);hd(a,d);Cd(a,g);Yc(a,e)}while(1){if((b|0)!=(c|0)){Sc(d,b);d=d+1|0;b=b+1|0;continue}break}u[f+15|0]=0;Sc(d,f+15|0);jb=f+16|0;return}zc(a);M()}function mH(a){a=a|0;var b=0,c=0;b=w[a+8>>2];w[114256]=0;b=Z(1849,0,0,4,b|0)|0;c=w[114256];w[114256]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=w[a+8>>2];if(!a){return 1}w[114256]=0;a=V(1850,a|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}W(0)|0;Eb();M()}function iw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=65535;d=w[a>>2];a:{if(((w[a+4>>2]-d|0)/52&65535)>>>0<=b>>>0){break a}e=C(b,52)+d|0;if(w[e>>2]==w[e+4>>2]){break a}e=d;d=C(b,52);b=hw(a,w[(e+d|0)+12>>2],c);if((b|0)==65535){break a}a=w[a>>2];mw(a+C(b,52)|0,a+d|0);f=b}return f|0}function _s(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=Fj(a);w[a+32>>2]=b;w[a>>2]=60620;b=d+8|0;xj(b,a);w[114256]=0;b=V(1677,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){Ab(d+8|0);w[a+40>>2]=c;w[a+36>>2]=b;f=a,g=Kg(b),u[f+44|0]=g;jb=d+16|0;return}b=P()|0;Ab(d+8|0);wc(a);R(b|0);M()}function Zs(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=wt(a);w[a+32>>2]=b;w[a>>2]=60824;b=d+8|0;xj(b,a);w[114256]=0;b=V(1679,b|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){Ab(d+8|0);w[a+40>>2]=c;w[a+36>>2]=b;f=a,g=Kg(b),u[f+44|0]=g;jb=d+16|0;return}b=P()|0;Ab(d+8|0);Uh(a);R(b|0);M()}function ts(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=Sr(b,c);if(e>>>0<=1073741807){a:{if(Wi(e)){Zc(a,e);d=a;break a}g=Rf(e)+1|0;d=br(g);hd(a,d);Cd(a,g);Yc(a,e)}while(1){if((b|0)!=(c|0)){xd(d,b);d=d+4|0;b=b+4|0;continue}break}w[f+12>>2]=0;xd(d,f+12|0);jb=f+16|0;return}Qf();M()}function _b(a){var b=D(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return D(a*D(0))}a=(c|0)>=0?a:D(-a);b=D(D(D(a+D(8388608))+D(-8388608))-a);a:{if(b>D(.5)){a=D(D(a+b)+D(-1));break a}a=D(a+b);if(!(b<=D(-.5))){break a}a=D(a+D(1))}a=(c|0)>=0?a:D(-a)}return a}function xc(a,b){var c=0,d=0,e=0,f=0;c=w[a+4>>2];d=c+b|0;w[a+4>>2]=d;if((d|0)<=w[a+8>>2]){d=w[a>>2]+(c>>3)|0;a=c&7;c=x[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=x[d+1|0];d=d+1|0;a=b;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function gU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{switch(c+1|0){case 0:case 3:v[d+6>>1]=0;c=d+8|0;w[d+12>>2]=c;w[d+8>>2]=d+6;Ob(a,c);break a;default:break b}}v[d+6>>1]=0;e=d+6|0;w[d+12>>2]=e+(c>>>0>=2?2:c);w[d+8>>2]=e;Ob(a,d+8|0)}v[b>>1]=y[d+6>>1];jb=d+16|0}function Ti(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=ba(16)|0;if(!x[462281]){u[462281]=1}a=Sh(c+8|0,a,83328);w[114256]=0;e=w[a+4>>2];w[c>>2]=w[a>>2];w[c+4>>2]=e;S(2128,d|0,c|0,b|0)|0;a=w[114256];w[114256]=0;if((a|0)!=1){ka(d|0,74e3,2129);M()}a=P()|0;ca(d|0);R(a|0);M()}function lD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;sk(e,c);w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=e;U(290,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function RM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=x[a+11|0];e=c<<24>>24;a:{b:{c:{if((e|0)>=0){d=10;if((e|0)==10){break c}u[a+11|0]=e+1;break a}d=(w[a+8>>2]&2147483647)-1|0;c=w[a+4>>2];if((d|0)!=(c|0)){break b}}Rt(a,d,1,d,d);c=d}w[a+4>>2]=c+1;a=w[a>>2]}a=a+c|0;u[a+1|0]=0;u[a|0]=b}function QB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;eh(e,c);w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=e;U(290,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function Kl(a,b){var c=0,d=0,e=0,f=0;c=w[a+4>>2];a:{if(!c){c=w[a>>2];break a}d=32-c|0;f=b>>>0>d>>>0?d:b;e=w[a>>2];w[e>>2]=w[e>>2]|-1<<c&-1>>>d-f;c=e+4|0;w[a>>2]=c;b=b-f|0}d=c;c=b>>>5<<2;Cb(d,255,c);if((b&-32)!=(b|0)){d=a;a=c+w[a>>2]|0;w[d>>2]=a;w[a>>2]=w[a>>2]|-1>>>32-(b&31)}}function Bx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=w[a>>2];c=c>>>2|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){e=x[b|0]|x[b+1|0]<<8;v[a>>1]=(e<<8|e>>>8)^32768;e=x[b+2|0]|x[b+3|0]<<8;v[a+2>>1]=(e<<8|e>>>8)^32768;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return d<<2}function $w(a,b){a=a|0;b=+b;var c=0;b=(x[a+480209|0]&128?28.85390081777927:34.624680981335125)*($h(b)+-4.8737671609324025);a:{if(!(b<0)){c=127;if(b<=127){break a}}b=c}b=Tb(b);a=255;b:{if(b>=255){break b}a=0;if(b<=0){break b}if(b<4294967296&b>=0){return~~b>>>0|0}a=0}return a|0}function hE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;bh(e,c);w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=e;U(51,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function VO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;ah(e,c);w[114256]=0;w[d+12>>2]=d+28;w[d+8>>2]=e;U(51,a|0,b|0,d+8|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+27|0]<0){zb(w[d+16>>2])}jb=d+32|0;return}a=P()|0;if(u[d+27|0]<0){zb(w[d+16>>2])}R(a|0);M()}function Or(a,b,c,d){var e=0;b=w[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;w[a+1072>>2]=b;c=b+w[a+1076>>2]|0;w[a+1076>>2]=c;e=d;d=w[a+1064>>2];v[e+(d<<1)>>1]=x[a+1080|0]?c:b;w[a+1060>>2]=w[a+1060>>2]+1;b=y[w[a+1056>>2]+34>>1];w[a+1068>>2]=w[a+1068>>2]-1;w[a+1064>>2]=(b&64?2:1)+d}function xp(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+30;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==30){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],30)|0){b=w[a+12>>2]+30|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==30}function vw(a){var b=0;if(!(!(x[a+20|0]|x[a+21|0]<<8|(x[a+22|0]<<16|x[a+23|0]<<24))|(!(x[a+12|0]|x[a+13|0]<<8|(x[a+14|0]<<16|x[a+15|0]<<24))|(x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=-1641380927))){b=(x[a+28|0]|x[a+29|0]<<8|(x[a+30|0]<<16|x[a+31|0]<<24))!=0}return b}function rs(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+36;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==36){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],36)|0){b=w[a+12>>2]+36|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==36}function mp(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+96;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==96){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],96)|0){b=w[a+12>>2]+96|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==96}function eq(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+66;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==66){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],66)|0){b=w[a+12>>2]+66|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==66}function _k(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+12;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==12){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],12)|0){b=w[a+12>>2]+12|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==12}function Yo(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+48;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==48){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],48)|0){b=w[a+12>>2]+48|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==48}function yx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=w[a>>2];c=(c>>>0)/6|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){e=x[b|0]|x[b+1|0]<<8;v[a>>1]=e<<8|e>>>8;e=x[b+3|0]|x[b+4|0]<<8;v[a+2>>1]=e<<8|e>>>8;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}return C(d,6)|0}function Pz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-96|0;jb=c;Oo(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=c+d|0;d=w[f+4>>2];w[e>>2]=w[f>>2];w[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}w[a+104>>2]=0;w[a+96>>2]=!(w[a+88>>2]|w[a+92>>2]);w[a+100>>2]=0;jb=c+96|0}function CK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=u[b|0];g=u[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function cB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-96|0;jb=d;c=-1;a:{if(!mp(a,d)){break a}c=0;if(!$o(d)){break a}e=a;f=b;c=y[d+34>>1];a=c+y[d+36>>1]|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|c>>>31;c=c<<1;b=c+y[d+32>>1]|0;c=Uc(e,f,b,b>>>0<c>>>0?a+1|0:a)}jb=d+96|0;return c|0}function UT(a,b,c){a=a|0;b=b|0;c=c|0;c=w[b+4>>2];b=w[b>>2];if(!((c-b|0)!=8|(x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24))!=1869112133)){c=x[b+4|0]|x[b+5|0]<<8|(x[b+6|0]<<16|x[b+7|0]<<24);w[a+4260>>2]=x[b|0]|x[b+1|0]<<8|(x[b+2|0]<<16|x[b+3|0]<<24);w[a+4264>>2]=c;Yj(a)}}function Tb(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function zh(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+1;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==1){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],1)|0){b=w[a+12>>2]+1|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==1}function lf(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+8;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==8){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],8)|0){b=w[a+12>>2]+8|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==8}function _o(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+4;d=ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0;if((d|0)==4){a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],4)|0){b=w[a+12>>2]+4|0;break a}b=ob[w[w[a>>2]+24>>2]](a)|0}w[a+12>>2]=b}jb=c+16|0;return(d|0)==4}function Ig(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){b=0;break a}d=b;b=F(b);$c(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+w[c+8>>2]|0;e=e+(w[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=w[c>>2];b=w[c+4>>2]}w[a>>2]=d;w[a+4>>2]=b;w[a+8>>2]=f;w[a+12>>2]=e;jb=c+16|0}function bi(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function VK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!x[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Md(u[b|0]),e=w[w[a>>2]+52>>2],ob[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Pe(b,1,c,w[a+32>>2])}return c|0}function HI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;w[a>>2]=0;w[a+4>>2]=0;w[c+12>>2]=0;e=Ne(a+8|0),f=0,u[e+128|0]=f;if(b){if(gr(a)>>>0<b>>>0){fr();M()}d=er(Uf(a),b);w[a>>2]=d;w[a+4>>2]=d;e=Xi(a),f=(b<<2)+d|0,w[e>>2]=f;dr(a,0);Jr(a,b)}jb=c+16|0;return a|0}function Dx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=w[a>>2];c=c>>>2|0;e=c>>>0>e>>>0?e:c;if(e){a=w[a+20>>2];c=e;f=d;while(1){f=(x[b|0]|x[b+1|0]<<8)+f|0;v[a>>1]=f;d=(x[b+2|0]|x[b+3|0]<<8)+d|0;v[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return e<<2}function zp(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],4)|0){d=w[a+12>>2];w[c+8>>2]=b;w[c+12>>2]=b+4;e=a,f=(ob[w[w[a>>2]+32>>2]](a,d,c+8|0)|0)+w[a+12>>2]|0,w[e+12>>2]=f;break a}u[b|0]=0;u[b+1|0]=0;u[b+2|0]=0;u[b+3|0]=0}jb=c+16|0}function ux(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=w[a>>2];c=c>>>4|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){e=x[b|0]|x[b+1|0]<<8;v[a>>1]=e<<8|e>>>8;e=x[b+8|0]|x[b+9|0]<<8;v[a+2>>1]=e<<8|e>>>8;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}return d<<4}function Pg(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=EV(a,b,10,0);f=nb;e=BV(d,f,10,0);c=c-1|0;u[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;u[c|0]=d-C(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function wx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=w[a>>2];c=c>>>3|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){e=x[b|0]|x[b+1|0]<<8;v[a>>1]=e<<8|e>>>8;e=x[b+4|0]|x[b+5|0]<<8;v[a+2>>1]=e<<8|e>>>8;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}return d<<3}function Lr(a,b,c,d){b=w[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;w[a+1072>>2]=b;c=b+w[a+1076>>2]|0;w[a+1076>>2]=c;u[w[a+1064>>2]+d|0]=x[a+1080|0]?c:b;w[a+1060>>2]=w[a+1060>>2]+1;b=y[w[a+1056>>2]+34>>1];w[a+1068>>2]=w[a+1068>>2]-1;w[a+1064>>2]=w[a+1064>>2]+(b&64?2:1)}function Eb(){var a=0;a=w[20833];w[114256]=0;_(a|0);a=w[114256];w[114256]=0;a:{if((a|0)!=1){w[114256]=0;T(2139,8397,0);a=w[114256];w[114256]=0;if((a|0)!=1){break a}}$(W(0)|0)|0;w[114256]=0;T(2139,5731,0);a=w[114256];w[114256]=0;if((a|0)!=1){break a}W(0)|0;Eb()}M()}function rj(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=w[b+76>>2]>=0;b:{c=w[b+4>>2];c:{if(!c){vm(b);c=w[b+4>>2];if(!c){break c}}if(w[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;w[b+4>>2]=c;u[c|0]=a;w[b>>2]=w[b>>2]&-17;d=a&255}return d}function UF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(wd(a,w[b+8>>2],0)){sl(b,c,d);return}e=w[a+12>>2];f=a+16|0;Fq(f,b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){Fq(a,b,c,d);if(x[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function zg(a,b){var c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;c=As(b);d=jb-16|0;jb=d;a:{if(c>>>0<=1073741807){b:{if(Wi(c)){Zc(a,c);e=a;break b}g=Rf(c)+1|0;e=br(g);hd(a,e);Cd(a,g);Yc(a,c)}de(e,b,c);w[d+12>>2]=0;xd((c<<2)+e|0,d+12|0);jb=d+16|0;break a}Qf();M()}jb=f+16|0}function Vj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=w[a>>2];b:{if(w[a+8>>2]-c>>>0>=b>>>0){break b}if((b|0)<0){break a}d=w[a+4>>2];e=b;b=Kb(b);e=e+b|0;d=d-c|0;f=d+b|0;if((d|0)>0){Fb(b,c,d)}w[a+8>>2]=e;w[a+4>>2]=f;w[a>>2]=b;if(!c){break b}zb(c)}return}Mb(a);M()}function $p(a){var b=0,c=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=777268804){break a}b=x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))-257>>>0<4294967053){break a}c=!(x[a+8|0]|x[a+9|0]<<8)}return c}function Cx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=w[a>>2];c=c>>>2|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){e=x[b|0]|x[b+1|0]<<8;v[a>>1]=e<<8|e>>>8;e=x[b+2|0]|x[b+3|0]<<8;v[a+2>>1]=e<<8|e>>>8;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return d<<2}function Ce(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(u[a+480180|0]&1|b){e=w[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;v[c+480286>>1]=64;d=c+480280|0;w[d>>2]=w[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;v[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function ll(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=w[a>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],256)|0){e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+256;f=a,g=(ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0)+w[a+8>>2]|0,w[f+8>>2]=g;break a}Cb(b,0,256)}jb=c+16|0}function dl(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=w[a>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],512)|0){e=w[a+8>>2];d=w[a>>2];w[c+8>>2]=b;w[c+12>>2]=b+512;f=a,g=(ob[w[w[d>>2]+32>>2]](d,e,c+8|0)|0)+w[a+8>>2]|0,w[f+8>>2]=g;break a}Cb(b,0,512)}jb=c+16|0}function LA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-48|0;jb=c;d=-1;a:{if(!Yo(a,c)){break a}d=0;if((x[c+14|0]-53&255)>>>0<252){break a}if(Jb(c,11506,14)){break a}d=a;e=b;b=x[c+47|0];a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;d=Uc(d,e,b,a)}jb=c+48|0;return d|0}function hG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Ag(a);e=Db(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Qb(a);de(d+(e<<2)|0,b,c);b=c+e|0;He(a,b);w[f+12>>2]=0;xd(d+(b<<2)|0,f+12|0);break a}Nq(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function UN(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;Wu(h+8|0,b,c,d,e,f,g);w[a+8>>2]=w[h+28>>2];b=w[h+24>>2];w[a>>2]=w[h+20>>2];w[a+4>>2]=b;w[h+28>>2]=0;w[h+20>>2]=0;w[h+24>>2]=0;if(u[h+19|0]<0){zb(w[h+8>>2])}jb=h+32|0}function RN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=w[b+4>>2];if(c>>>0<4294967280){e=w[b>>2];a:{b:{if(c>>>0>=11){d=(c|15)+1|0;b=Kb(d);w[a+8>>2]=d|-2147483648;w[a>>2]=b;w[a+4>>2]=c;break b}u[a+11|0]=c;b=a;if(!c){break a}}Fb(b,e,c)}u[b+c|0]=0;return a|0}zc(a);M()}function zK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=w[b>>2];g=w[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Mr(a){a=a|0;var b=0,c=0,d=0;w[a>>2]=66120;b=w[a+8>>2];w[114256]=0;c=ea(1732)|0;d=w[114256];w[114256]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){b=w[a+8>>2];w[114256]=0;_l(b);b=w[114256];w[114256]=0;if((b|0)==1){break a}}return a|0}W(0)|0;Eb();M()}function TT(a,b,c){a=a|0;b=b|0;c=c|0;a=Fj(a);w[a+32>>2]=0;w[a+36>>2]=0;w[a>>2]=59272;w[a+48>>2]=c;w[a+40>>2]=0;w[a+44>>2]=0;w[114256]=0;T(100,a|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){b=P()|0;if(u[a+43|0]<0){zb(w[a+32>>2])}wc(a);R(b|0);M()}return a|0}function vm(a){var b=0,c=0;b=w[a+72>>2];w[a+72>>2]=b-1|b;if(w[a+20>>2]!=w[a+28>>2]){ob[w[a+36>>2]](a,0,0)|0}w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;b=w[a>>2];if(b&4){w[a>>2]=b|32;return-1}c=w[a+44>>2]+w[a+48>>2]|0;w[a+8>>2]=c;w[a+4>>2]=c;return b<<27>>31}function uq(a,b){var c=0,d=0,e=0,f=0;c=w[a+8>>2];e=w[a+4>>2];d=c-e|0;b=w[a+16>>2]+b|0;if(d>>>0<b>>>0){f=a+4|0;a:{if((c|0)==(e|0)){a=b+65535&-65536;break a}a=d>>>1|0;c=a+d|0;a=(d|0)==1?2:a>>>0>c>>>0?-1:c;if(b>>>0<=a>>>0){break a}a=b+65535&-65536}$e(f,a)}}function Hl(a){a=a|0;var b=0,c=0,d=0;b=w[a+8>>2];w[114256]=0;c=ea(1732)|0;d=w[114256];w[114256]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=w[a+8>>2];w[114256]=0;_l(b);b=w[114256];w[114256]=0;if((b|0)==1){break b}}break a}W(0)|0;Eb();M()}return a|0}function tJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;w[g+8>>2]=b;Sb(g,d);w[114256]=0;b=V(1561,g|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(g);ks(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return w[g+8>>2]}a=P()|0;Ab(g);R(a|0);M()}function sJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;w[g+8>>2]=b;Sb(g,d);w[114256]=0;b=V(1561,g|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(g);js(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return w[g+8>>2]}a=P()|0;Ab(g);R(a|0);M()}function mJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;w[g+8>>2]=b;Sb(g,d);w[114256]=0;b=V(1735,g|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(g);hs(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return w[g+8>>2]}a=P()|0;Ab(g);R(a|0);M()}function kJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;w[g+8>>2]=b;Sb(g,d);w[114256]=0;b=V(1735,g|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(g);gs(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return w[g+8>>2]}a=P()|0;Ab(g);R(a|0);M()}function Vn(a,b,c){var d=0,e=0;d=w[(C(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(y[a+480188>>1]<=b>>>0){c=y[(C(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=x[((b<<5)+a|0)+480288|0]}return e}function uT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=w[w[a+20>>2]+28>>2];d=d>>>0<=127?-1:d^-128;e=d&255;a:{if(e>>>0<=x[a+4200|0]|e>>>0>249){break a}a=w[(w[a+16>>2]+C(d&255,160)|0)+906300>>2];if(!a){break a}f=ob[w[w[a>>2]+96>>2]](a,b,c)|0}return f|0}function mg(a,b){a=a|0;b=b|0;w[a>>2]=0;w[a+4>>2]=0;w[a+28>>2]=b;w[a+20>>2]=0;w[a+24>>2]=11;v[a+16>>1]=65535;w[a+8>>2]=0;w[a+12>>2]=0;Cb(a+32|0,0,36);w[a+96>>2]=0;w[a+88>>2]=0;w[a+92>>2]=0;w[a+80>>2]=0;w[a+84>>2]=0;w[a+72>>2]=0;w[a+76>>2]=0;return a|0}function ec(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!x[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=w[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(x[b|0]){continue}break}}return b-a|0}function FB(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;b=-1;a:{if(!(ob[w[w[a>>2]+36>>2]](a,w[a+12>>2],8)|0)){break a}b=0;if(!Ah(a,9833,8)){break a}b=-1;if(!lf(a,c+8|0)){break a}b=0;if(!w[c+12>>2]){break a}b=!(w[c+8>>2]&-2139062144)}jb=c+16|0;return b|0}function uS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0),e=0;if((b|0)<=6){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}e=((b<<2)+a|0)+4208|0;b:{if((b|0)==1){d=D(0);if(c<D(1)){break b}}d=c;if((b|0)!=4){break b}d=D(_b(D(c*D(4)))*D(.25))}A[e>>2]=d;an(a)}}function Hk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;if((b|0)!=(c|0)){while(1){f=w[b>>2];w[d+12>>2]=f;e=w[a+4>>2];a:{if(e>>>0<z[a+8>>2]){w[e>>2]=f;w[a+4>>2]=e+4;break a}Di(a,d+12|0)}b=b+4|0;if((c|0)!=(b|0)){continue}break}}jb=d+16|0}function $S(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0),e=0;if((b|0)<=6){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}e=((b<<2)+a|0)+4208|0;b:{if((b|0)==3){d=D(0);if(c<D(1)){break b}}d=c;if((b|0)!=4){break b}d=D(_b(D(c*D(4)))*D(.25))}A[e>>2]=d;an(a)}}function sq(a){var b=0,c=0;if(!x[a+20|0]){if(!(ob[w[w[a>>2]+44>>2]](a)|0)){while(1){uq(a,65536);b=a,c=(ob[w[w[a>>2]+48>>2]](a,w[a+4>>2]+w[a+16>>2]|0,65536)|0)+w[a+16>>2]|0,w[b+16>>2]=c;if(!(ob[w[w[a>>2]+44>>2]](a)|0)){continue}break}}u[a+20|0]=1}}function Yn(a,b,c,d){var e=0;e=-2147483648;e=!c|!(u[c+15|0]&1)?e:w[c+8>>2];a:{b:{if(!(!d|!(x[d+34|0]&32))){e=y[d+28>>1];break b}if((e|0)==-2147483648){break a}}Bi(b,e,a);if(!(x[a+1074313|0]&4)|x[a+480209|0]&64){break a}w[b+88>>2]=w[b+88>>2]&-257}}function Vi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Yb(a);e=Db(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Qb(a);Dd(d+e|0,b,c);b=c+e|0;He(a,b);u[f+15|0]=0;Sc(b+d|0,f+15|0);break a}Dh(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function Ut(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=Ut(a*0x10000000000000000,b);c=w[b>>2]+-64|0}w[b>>2]=c;return a}w[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Ex(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=w[a>>2];c=c>>>2|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){v[a>>1]=(x[b|0]|x[b+1|0]<<8)^32768;v[a+2>>1]=(x[b+2|0]|x[b+3|0]<<8)^32768;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return d<<2}function kh(a){var b=0,c=0,d=0,e=0;a:{b=w[a>>2];d=w[a+4>>2];e=(b|0)==(d|0);if(e){break a}a=b;while(1){c=B[a>>3]+c;a=a+8|0;if((d|0)!=(a|0)){continue}break}if(e){break a}c=-c;while(1){c=B[b>>3]+c;B[b>>3]=c;b=b+8|0;if((d|0)!=(b|0)){continue}break}}}function fE(a,b){a=a|0;b=b|0;var c=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){yh(a,b);c=w[a+4>>2];b=c+C(b,6)|0;while(1){u[c+2|0]=8;u[c+3|0]=4;u[c+4|0]=6;u[c+5|0]=0;u[c|0]=0;u[c+1|0]=0;c=c+6|0;if((b|0)!=(c|0)){continue}break}w[a+4>>2]=b}return a|0}function by(a){a=a|0;var b=0,c=0,d=0,e=0;w[a>>2]=0;if(!(u[85552]&1)){while(1){c=b<<24;d=0;while(1){e=c<<1;c=(c|0)<0?e^79764919:e;d=d+1|0;if((d|0)!=8){continue}break}w[(b<<2)+85568>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}u[85552]=1}return a|0}function Mm(a,b){var c=0,d=0,e=0;c=x[a+1|0];d=c>>>3&1;a=x[a+2|0];e=(c&6)==6;a=(C(C(x[(C(c>>>1&3,15)+C(d,45)+(a>>>4)|0)+39217|0],e?384:1152>>>((c&14)==2)|0),250)>>>0)/(w[(a&12)+39220>>2]>>>!d>>>((c^-1)>>>4&1)>>>0)|0;a=e?a&134217724:a;return a?a:b}function CT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=1;c=w[w[a+20>>2]+28>>2];c=c>>>0<=127?-1:c^-128;e=c&255;a:{if(e>>>0<=x[a+4200|0]|e>>>0>249){break a}a=w[(w[a+16>>2]+C(c&255,160)|0)+906300>>2];if(!a){break a}d=ob[w[w[a>>2]+68>>2]](a,b)|0}return d|0}function nh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=w[a>>2];a:{if(w[a+4>>2]-c>>1>>>0<=b>>>0){break a}d=w[a+24>>2];a=w[d+484344>>2];b=y[(b<<1)+c>>1];if(b>>>0>=((w[d+484348>>2]-a|0)/52&65535)>>>0){break a}a=a+C(b,52)|0;e=w[a>>2]!=w[a+4>>2]}return e|0}function Rw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;a=w[a+1304560>>2];a:{if(a){ob[w[w[a>>2]+8>>2]](a,b,c);break a}if(w[18800]<(b|0)){break a}w[d+16>>2]=132;w[d+20>>2]=0;w[d+12>>2]=6790;w[d+8>>2]=5083;Aw(d+24|0,d+8|0,b,9064,c)}jb=d+32|0}function Lo(a){var b=0,c=0;b=w[a+16>>2];a=w[a+32>>2];b=BV(b,b>>31,a,a>>31)+5e5|0;a=nb;b=CV(b,b>>>0<5e5?a+1|0:a,1e6,0);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;a=b?0:a;return(a|0)<0&c>>>0<=2147483648|(a|0)<-1?-2147483648:c}function Ko(a){var b=0,c=0;b=w[a+16>>2];a=w[a+36>>2];b=BV(b,b>>31,a,a>>31)+5e5|0;a=nb;b=CV(b,b>>>0<5e5?a+1|0:a,1e6,0);c=b;a=nb;b=(a|0)>=0&b>>>0>=2147483647|(a|0)>0;c=b?2147483647:c;a=b?0:a;return(a|0)<0&c>>>0<=2147483648|(a|0)<-1?-2147483648:c}function yT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=w[w[a+20>>2]+28>>2];e=e>>>0<=127?-1:e^-128;f=e&255;if(f>>>0<=x[a+4200|0]|f>>>0>249){break a}a=w[(w[a+16>>2]+C(e&255,160)|0)+906300>>2];if(!a){break a}ob[w[w[a>>2]+80>>2]](a,b,c,d)}}function xT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=w[w[a+20>>2]+28>>2];e=e>>>0<=127?-1:e^-128;f=e&255;if(f>>>0<=x[a+4200|0]|f>>>0>249){break a}a=w[(w[a+16>>2]+C(e&255,160)|0)+906300>>2];if(!a){break a}ob[w[w[a>>2]+84>>2]](a,b,c,d)}}function oO(a,b){a=a|0;b=b|0;var c=D(0),d=D(0);a:{if((b|0)<0){break a}a=w[a+24>>2];if(y[a+480188>>1]<=b>>>0){break a}a=a+C(b,896)|0;c=D(D(x[a+1075847|0])*D(.0078125));d=D(c*c);c=D(D(x[a+1075846|0])*D(.0078125));c=D(L(D(d+D(c*c))))}return D(c)}function kP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=w[a+24>>2];Dk(d,0,c);w[114256]=0;U(367,a|0,b|0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}jb=d+16|0;return}a=P()|0;if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}function ih(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=y[a+24>>1]<<17;e=y[a+20>>1];if(e){d=y[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-C(w[(y[c+28>>1]<<2)+b>>2],v[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function Hb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=ec(b);if(c>>>0<4294967280){a:{b:{if(c>>>0>=11){e=(c|15)+1|0;d=Kb(e);w[a+8>>2]=e|-2147483648;w[a>>2]=d;w[a+4>>2]=c;break b}u[a+11|0]=c;d=a;if(!c){break a}}Fb(d,b,c)}u[c+d|0]=0;return a|0}zc(a);M()}function De(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=y[a+20>>1];if(c){d=y[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=y[e+28>>1]+b|0;v[e+28>>1]=f;if((f&65535)>>>0>=2048){v[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function AT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=w[w[a+20>>2]+28>>2];e=e>>>0<=127?-1:e^-128;f=e&255;if(f>>>0<=x[a+4200|0]|f>>>0>249){break a}a=w[(w[a+16>>2]+C(e&255,160)|0)+906300>>2];if(!a){break a}ob[w[w[a>>2]+76>>2]](a,b,c,d)}}function si(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=x[b+11|0];e=c<<24>>24<0;d=x[a+11|0];f=d<<24>>24<0;c=e?w[b+4>>2]:c;d=f?w[a+4>>2]:d;g=c>>>0<d>>>0;h=g?c:d;a:{if(h){a=Jb(f?w[a>>2]:a,e?w[b>>2]:b,h);if(a){break a}}a=c>>>0>d>>>0?-1:g}return a>>>31|0}function qJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;w[a+8>>2]=b;Sb(a,d);w[114256]=0;b=V(1561,a|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(a);is(f+20|0,a+8|0,c,e,b);jb=a+16|0;return w[a+8>>2]}b=P()|0;Ab(a);R(b|0);M()}function jJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;w[a+8>>2]=b;Sb(a,d);w[114256]=0;b=V(1735,a|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){Ab(a);fs(f+20|0,a+8|0,c,e,b);jb=a+16|0;return w[a+8>>2]}b=P()|0;Ab(a);R(b|0);M()}function ci(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function ZN(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(b>>>0>65535){break a}c=w[a+24>>2];a=w[c+484344>>2];if(((w[c+484348>>2]-a|0)/52&65535)>>>0<=(b&65535)>>>0){break a}c=a+C(b,52)|0;if(w[c>>2]==w[c+4>>2]){break a}d=w[(a+C(b,52)|0)+12>>2]}return d|0}function zx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=w[a>>2];c=(c>>>0)/6|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){v[a>>1]=x[b+1|0]|x[b+2|0]<<8;v[a+2>>1]=x[b+4|0]|x[b+5|0]<<8;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}return C(d,6)|0}function jh(a,b){var c=0,d=0,e=0,f=0,g=0;c=w[a>>2];f=1/(B[w[a+4>>2]-8>>3]-B[c>>3]);a=0;while(1){g=(a<<2)+b|0;d=-Tb(B[(a<<3)+c>>3]*131072*f);a:{if(E(d)<2147483648){e=~~d;break a}e=-2147483648}w[g>>2]=e;a=a+1|0;if((a|0)!=2048){continue}break}}function eC(a,b){a=a|0;b=b|0;a=Kb(16);w[a+4>>2]=0;w[a+8>>2]=0;w[a+12>>2]=75696;w[a>>2]=75656;w[b+4>>2]=a;w[b>>2]=a+12;w[a+4>>2]=w[a+4>>2]+1;w[b+16>>2]=0;w[b+8>>2]=0;w[b+12>>2]=0;b=w[a+4>>2];w[a+4>>2]=b-1;if(!b){ob[w[w[a>>2]+8>>2]](a);Ib(a)}}function $q(a){var b=0,c=0;b=w[a+4>>2];a:{while(1){if(w[a+8>>2]==(b|0)){break a}w[a+8>>2]=w[a+8>>2]-4;w[114256]=0;c=w[114256];w[114256]=0;if((c|0)!=1){continue}break}W(0)|0;Eb();M()}if(w[a>>2]){zr(w[a+16>>2],w[a>>2],w[El(a)>>2]-w[a>>2]>>2)}}function nG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<=4294967279){a:{if(sj(d)){Zc(a,c);d=a;break a}f=_f(d)+1|0;d=nf(a,f);hd(a,d);Cd(a,f);Yc(a,c)}Dd(d,b,c);u[e+15|0]=0;Sc(c+d|0,e+15|0);jb=e+16|0;return}zc(a);M()}function Xu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b>>>0<4294967280){a:{b:{if(b>>>0>=11){e=(b|15)+1|0;d=Kb(e);w[a+8>>2]=e|-2147483648;w[a>>2]=d;w[a+4>>2]=b;break b}u[a+11|0]=b;d=a;if(!b){break a}}Cb(d,c,b)}u[b+d|0]=0;return a|0}zc(a);M()}function KJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;w[e+12>>2]=b;w[e+8>>2]=d;b=be(e,e+12|0);w[114256]=0;a=S(1756,a|0,c|0,w[e+8>>2])|0;c=w[114256];w[114256]=0;if((c|0)!=1){Lc(b);jb=e+16|0;return a|0}a=P()|0;Lc(b);R(a|0);M()}function sn(a,b){var c=0,d=0;a:{if(!(x[a+89|0]&16)){break a}c=w[a+656>>2];if(!c){break a}c=w[c>>2];b:{if(c){d=a;a=w[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;w[d+696>>2]=a;a=(C(a,w[b>>2])|0)/65536|0;break b}if(w[a+696>>2]){break a}a=0}w[b>>2]=a}}function WA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-48|0;jb=d;c=-1;a:{if(!Yo(a,d)){break a}c=0;if(!Xo(d)){break a}e=a;f=b;a=x[d+33|0];b=a>>>24|0;c=a<<8;a=x[d+31|0]?1120:1056;c=c+a|0;c=Uc(e,f,c,a>>>0>c>>>0?b+1|0:b)}jb=d+48|0;return c|0}function yA(a,b){a=a|0;b=b|0;var c=0;c=jb-2496|0;jb=c;Oo(b,c,c+2496|0);a=Fb(a,c,2496);w[a+2496>>2]=0;a:{if(w[a>>2]<0){break a}b=1;while(1){if(w[a+(b<<2)>>2]){break a}b=b+1|0;if((b|0)!=624){continue}break}w[a>>2]=-2147483648}jb=c+2496|0}function vx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=w[a>>2];c=c>>>4|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){v[a>>1]=x[b+6|0]|x[b+7|0]<<8;v[a+2>>1]=x[b+14|0]|x[b+15|0]<<8;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}return d<<4}function ce(a,b,c){var d=0,e=0,f=0,g=0;w[a+112>>2]=b;w[a+116>>2]=c;e=w[a+4>>2];d=w[a+44>>2]-e|0;w[a+120>>2]=d;w[a+124>>2]=d>>31;d=a;a=w[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}w[d+104>>2]=a}function fV(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!lf(a,b+8|0)){break a}c=0;if(w[b+8>>2]!=1179011410|z[b+12>>2]<81){break a}c=-1;if(!_o(a,b)){break a}a=w[b>>2];c=(a|0)==1179012417|(a|0)==538987841}a=c;jb=b+16|0;return a|0}function Wj(a){var b=0,c=0,d=0,e=0;B[a+4272>>3]=B[a+4280>>3];b=w[a+4296>>2];while(1){c=b>>>16&32767|c<<15;b=C(b,214013)+2531011|0;e=d>>>0<17;d=d+15|0;if(e){continue}break}w[a+4296>>2]=b;B[a+4280>>3]=D(D(c|0)*D(-4.656612873077393e-10))}function _S(a){a=a|0;var b=0;ob[w[w[a>>2]+124>>2]](a);an(a);w[a+4236>>2]=0;u[a+4202|0]=1;b=ob[w[w[a>>2]+188>>2]](a)|0;w[a+4272>>2]=0;A[a+4240>>2]=b?D(.5):D(1);b=w[a+4256>>2];w[a+4292>>2]=b;w[a+4288>>2]=b;w[a+4284>>2]=b;w[a+4280>>2]=b}function AL(a){a=a|0;if(z[a+24>>2]>z[a+44>>2]){w[a+44>>2]=w[a+24>>2]}a:{if(!(x[a+48|0]&8)){break a}if(z[a+16>>2]<z[a+44>>2]){Lg(a,w[a+8>>2],w[a+12>>2],w[a+44>>2])}if(z[a+12>>2]>=z[a+16>>2]){break a}return Md(u[w[a+12>>2]])|0}return-1}function yd(a,b,c){c=w[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=x[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(x[a+1|0]|32)!=120){break a}a=a+2|0}return a}function xx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=w[a>>2];c=c>>>3|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){v[a>>1]=x[b+2|0]|x[b+3|0]<<8;v[a+2>>1]=x[b+6|0]|x[b+7|0]<<8;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}return d<<3}function rk(a,b,c){a:{if(!c){break a}w[b+40>>2]=c;if(w[a+480180>>2]!=256){break a}a=c>>>4|0;w[b+40>>2]=c>>>0<16?1:a;a=50-(C(x[(a&15)+25616|0],c&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;w[b+44>>2]=(a+119315e4>>>0)/(a<<1>>>0)}}function lP(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=w[a+24>>2];Dk(c,0,b);w[114256]=0;U(367,a|0,1,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}jb=c+16|0;return}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}function NK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!x[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ob[w[w[a>>2]+52>>2]](a,w[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Pe(b,4,c,w[a+32>>2])}return c|0}function yV(a){a=a|0;w[a+8>>2]=1061158912;w[a+12>>2]=1065353216;w[a+16>>2]=1132462080;v[a+36>>1]=1;w[a>>2]=838860800;w[a+4>>2]=1291845632;u[a+38|0]=1;w[a+28>>2]=1;w[a+32>>2]=2;w[a+20>>2]=1132462080;w[a+24>>2]=1132462080;return a|0}function Fx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=w[a>>2];c=c>>>2|0;d=c>>>0>d>>>0?d:c;if(d){a=w[a+20>>2];c=d;while(1){v[a>>1]=x[b|0]|x[b+1|0]<<8;v[a+2>>1]=x[b+2|0]|x[b+3|0]<<8;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return d<<2}function vB(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!_k(a,b+16|0)){break a}c=0;if(!kp(b+16|0)){break a}c=-1;if(!lf(a,b+8|0)){break a}c=0;if(!w[b+12>>2]){break a}a=w[b+8>>2];c=(a&2139062143)==(a|0)}jb=b+32|0;return c|0}function gw(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=w[a>>2];b=(w[a+4>>2]-d|0)/52&65535;a:{if(b){a=b;while(1){e=a-1|0;c=e&65535;if(c>>>0<b>>>0){f=C(c,52)+d|0;if(w[f>>2]!=w[f+4>>2]){break a}}a=e;if(c){continue}break}}a=0}return a&65535}function jB(a){a=a|0;var b=0,c=0,d=0;c=jb-16|0;jb=c;b=Hb(c,6205);w[114256]=0;a=Q(58,a|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){if(u[b+11|0]<0){zb(w[b>>2])}jb=c+16|0;return a|0}a=P()|0;if(u[b+11|0]<0){zb(w[b>>2])}R(a|0);M()}function Tr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;w[d+16>>2]=b;w[d+24>>2]=a;w[d+8>>2]=c;while(1){a=qe(d+24|0,d+16|0);if(!(!a|w[w[d+24>>2]>>2]!=w[w[d+8>>2]>>2])){Oh(d+24|0);Oh(d+8|0);continue}break}jb=d+32|0;return a^1}function ET(a){a=a|0;var b=0;u[a+4202|0]=1;b=B[a+4248>>3]/+z[w[a+16>>2]+24620>>2];B[a+4264>>3]=b;if(x[a+4240|0]){B[a+4264>>3]=b*.016666666666666666*B[a+4288>>3]}Wj(a);b=B[a+4264>>3]*+z[w[a+16>>2]+1074376>>2];B[a+4256>>3]=b-K(b)}function uA(a){a=a|0;var b=0,c=0,d=0;d=a+4896|0;while(1){u[a+31|0]=0;b=0;a:{while(1){c=a+b|0;if(x[c|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Cb(c,0,32-b|0)}a=a+32|0;if((d|0)!=(a|0)){continue}break}}function mD(a,b){a=a|0;b=b|0;var c=0;w[a+4>>2]=0;w[a+8>>2]=0;u[a+20|0]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a>>2]=75404;c=w[b+4>>2];w[a+24>>2]=w[b>>2];w[a+28>>2]=c;c=w[b+12>>2];w[a+32>>2]=w[b+8>>2];w[a+36>>2]=c;u[a+40|0]=0;return a|0}function xN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;f=w[b+12>>2];w[e+8>>2]=w[b+8>>2];w[e+12>>2]=f;f=w[b+4>>2];w[e>>2]=w[b>>2];w[e+4>>2]=f;$u(a+8|0,e,c,d);w[a+88>>2]=82720;w[a>>2]=82632;jb=e+16|0;return a|0}function vl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=Yb(a);d=Db(a);g=d+b|0;if(e-d>>>0<b>>>0){yg(a,e,g-e|0,d,d,0,0)}e=d;d=Qb(a);Uq(e+d|0,b,c);He(a,g);u[f+15|0]=0;Sc(d+g|0,f+15|0)}jb=f+16|0;return a|0}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;un(d,b,c);w[114256]=0;U(6,a|0,0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}jb=d+16|0;return}a=P()|0;if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}function co(a,b,c){var d=0,e=0;e=a+4|0;d=w[a+4>>2];a:{if(!d){a=e;break a}while(1){a=d;d=a+16|0;if(si(c,d)){e=a;d=w[a>>2];if(d){continue}break a}if(!si(d,c)){break a}e=a+4|0;d=w[a+4>>2];if(d){continue}break}}w[b>>2]=a;return e}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;ek(d,b,c);w[114256]=0;U(6,a|0,0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}jb=d+16|0;return}a=P()|0;if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}function OU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;mi(d,b,c);w[114256]=0;U(6,a|0,0,d|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[d+11|0]<0){zb(w[d>>2])}jb=d+16|0;return}a=P()|0;if(u[d+11|0]<0){zb(w[d>>2])}R(a|0);M()}function aq(a){if(!((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=1179011410|(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))!=1179472708)){return 1}return(x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))==1179472708}function _N(a,b){a=a|0;b=b|0;var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=w[a+24>>2];if(If(w[d+484360>>2]+(x[d+484376|0]<<5)|0)>>>0<=b>>>0){break a}a=w[a+24>>2];c=y[w[w[a+484360>>2]+(x[a+484376|0]<<5)>>2]+(b<<1)>>1]}return c|0}function GK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;w[d+12>>2]=c;w[d+8>>2]=c;e=-1;c=oj(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=fc(c);w[f>>2]=a;if(!a){break a}e=oj(a,c,b,w[d+12>>2])}jb=d+16|0;return e|0}function DL(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;d=w[b+48>>2];a:{if(d&16){if(z[b+24>>2]>z[b+44>>2]){w[b+44>>2]=w[b+24>>2]}jm(a,w[b+20>>2],w[b+44>>2]);break a}if(d&8){jm(a,w[b+8>>2],w[b+16>>2]);break a}Wb(a)}jb=c+32|0}function CV(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=EV(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;nb=(g^nb)-((a>>>0<f>>>0)+g|0)|0;return b}function Zr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;w[d+16>>2]=b;w[d+24>>2]=a;w[d+8>>2]=c;while(1){a=qe(d+24|0,d+16|0);if(!(!a|x[w[d+24>>2]]!=x[w[d+8>>2]])){Ph(d+24|0);Ph(d+8|0);continue}break}jb=d+32|0;return a^1}function Km(a){var b=0;a:{b:{while(1){if(w[a+1380>>2]!=-1){break b}b=0;if(!Pj(a)){break a}if(!(u[a+1375|0]&1)){continue}break}w[a+100>>2]=32;return 0}w[a+1396>>2]=0;w[a+1400>>2]=0;w[a+1384>>2]=0;u[a+1376|0]=0;b=1}return b}function me(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{if(c>>>0<=10){u[a+11|0]=c;break b}if(c>>>0>=4294967280){break a}d=(c|15)+1|0;e=Kb(d);w[a+8>>2]=d|-2147483648;w[a>>2]=e;w[a+4>>2]=c;a=e}Fb(a,b,c+1|0);return}zc(a);M()}function Ew(a,b){a=a|0;b=b|0;var c=0,d=0;c=65535;d=y[w[a+8>>2]+58>>1];a:{if(d>>>0<b>>>0){break a}while(1){if(!w[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if((b&65535)>>>0<=d>>>0){continue}break}}return c&65535}function An(a){var b=0,c=0,d=0;c=jb-544|0;jb=c;if(!(!(x[a+480210|0]&128)|!w[a+24668>>2])){d=a+1304360|0;b=a+1074984|0;a=vk(c,w[a+24620>>2]);while(1){Fb(b+112|0,a,538);b=b+896|0;if((d|0)!=(b|0)){continue}break}}jb=c+544|0}function Re(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=357913942){break a}e=Kb(C(b,12))}w[a>>2]=e;c=C(c,12)+e|0;w[a+8>>2]=c;w[a+12>>2]=C(b,12)+e;w[a+4>>2]=c;return a|0}vd();M()}function Nf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=178956971){break a}e=Kb(C(b,24))}w[a>>2]=e;c=C(c,24)+e|0;w[a+8>>2]=c;w[a+12>>2]=C(b,24)+e;w[a+4>>2]=c;return a|0}vd();M()}function MG(a){a=a|0;if(x[460544]){return w[115135]}if(!x[461704]){a=461680;while(1){a=Wb(a)+12|0;if((a|0)!=461704){continue}break}u[461704]=1}cc(461680,71552);cc(461692,71564);u[460544]=1;w[115135]=461680;return 461680}function Ho(a){a=a|0;var b=0;b=v[a+796>>1];if(b){w[a+692>>2]=(b&32767)-1;if((b|0)<0){w[a+88>>2]=w[a+88>>2]|256}v[a+796>>1]=0}b=x[a+817|0];if(b){u[a+817|0]=0;u[a+858|0]=b-1}b=x[a+818|0];if(b){u[a+818|0]=0;u[a+857|0]=b-1}}function so(a,b){a:{if(x[a+76|0]==(b|0)){break a}u[a+76|0]=b;if(b){b=0;if(y[a+24>>1]==15){v[a+20>>1]=0;b=1}w[a+8>>2]=0;w[a+16>>2]=b;return}b:{switch(w[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}w[a+16>>2]=3}}function lk(a,b){var c=0;b=C(b,896)+a|0;a:{if(w[b+1075072>>2]&134218752){break a}b=w[b+1075640>>2];if(!b|(x[b+31|0]-1&255)>>>0>16){break a}b=x[b+34|0];if((b+5&255)>>>0<6){break a}c=w[(C(b,160)+a|0)+906140>>2]}return c}function bd(a,b){var c=0,d=0;a:{c=ec(b);d=x[a+11|0];if((c|0)==((d<<24>>24<0?w[a+4>>2]:d)|0)){w[114256]=0;a=da(186,a|0,0,-1,b|0,c|0)|0;b=w[114256];w[114256]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}W(0)|0;Eb();M()}function Qt(a){var b=0,c=0,d=0;if(!Wd(u[w[a>>2]])){return 0}while(1){d=w[a>>2];b=-1;if(c>>>0<=214748364){b=u[d|0]-48|0;c=C(c,10);b=(c^2147483647)<(b|0)?-1:b+c|0}w[a>>2]=d+1;c=b;if(Wd(u[d+1|0])){continue}break}return b}function OG(a){a=a|0;if(x[460536]){return w[115133]}if(!x[461672]){a=461648;while(1){a=Wb(a)+12|0;if((a|0)!=461672){continue}break}u[461672]=1}dc(461648,9597);dc(461660,9576);u[460536]=1;w[115133]=461648;return 461648}function Io(a,b){var c=0,d=0;c=x[a+822|0];a:{if(c){break a}d=!b;b=x[a+819|0]-w[a+772>>2]|0;b=(b|0)>=255?255:b;c=(b|0)>0?b:0;if(d|c>>>0>128|!(c&255)){break a}a=w[a+656>>2];if(!a){break a}c=x[(a+c|0)+107|0]}return c&255}function bS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0),e=0;if((b|0)<=12){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}e=((b<<2)+a|0)+4208|0;if((b|0)==12){c=D(_b(D(c*D(3)))*D(.3333333432674408))}A[e>>2]=c;u[a+5046|0]=1}}function ud(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=1073741824){break a}e=Kb(b<<2)}w[a>>2]=e;c=(c<<2)+e|0;w[a+8>>2]=c;w[a+12>>2]=(b<<2)+e;w[a+4>>2]=c;return a|0}vd();M()}function rG(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(bd(b,6205)^1){Lq(c,13225,b);a=Qb(c);w[114256]=0;T(2118,44,a|0);a=w[114256];w[114256]=0;if((a|0)!=1){break a}a=P()|0;Gb(c);R(a|0);M()}jb=c+16|0;return a|0}M()}function nV(a,b){a=a|0;b=b|0;_d(a);_d(a);a:{if(b>>>0>=60){b=w[a>>2];b:{if(ob[w[w[b>>2]+36>>2]](b,w[a+8>>2],4)|0){b=w[a+8>>2]+4|0;break b}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;break a}_d(a)}return _d(a)|0}function ah(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;tk(c,b);w[114256]=0;U(6,a|0,0,c|0);a=w[114256];w[114256]=0;if((a|0)!=1){if(u[c+11|0]<0){zb(w[c>>2])}jb=c+16|0;return}a=P()|0;if(u[c+11|0]<0){zb(w[c>>2])}R(a|0);M()}function Zx(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){lu(a,c-d>>3);c=w[a+4>>2];d=w[b>>2];b=w[b+4>>2]-d|0;if((b|0)>0){c=Fb(c,d,b)+b|0}w[a+4>>2]=c}return a|0}function Uv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=2097152){break a}e=Kb(b<<11)}w[a>>2]=e;c=(c<<11)+e|0;w[a+8>>2]=c;w[a+12>>2]=(b<<11)+e;w[a+4>>2]=c;return a|0}vd();M()}function BV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=C(e,f);g=c&65535;h=a&65535;i=C(g,h);f=(i>>>16|0)+C(f,g)|0;e=(f&65535)+C(e,h)|0;nb=(C(b,c)+j|0)+C(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function BU(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){Bh(a,c-d>>2);c=w[a+4>>2];d=w[b>>2];b=w[b+4>>2]-d|0;if((b|0)>0){c=Fb(c,d,b)+b|0}w[a+4>>2]=c}return a|0}function gi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=268435456){break a}e=Kb(b<<4)}w[a>>2]=e;c=(c<<4)+e|0;w[a+8>>2]=c;w[a+12>>2]=(b<<4)+e;w[a+4>>2]=c;return a|0}vd();M()}function bp(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;c=w[b+4>>2];d=w[b>>2];if((c|0)!=(d|0)){Wf(a,c-d|0);c=w[a+4>>2];d=w[b>>2];b=w[b+4>>2]-d|0;if((b|0)>0){c=Fb(c,d,b)+b|0}w[a+4>>2]=c}return a|0}function XT(a,b,c){a=a|0;b=b|0;c=D(c);var d=0;if((b|0)<=3){d=(a+b|0)+4264|0;c=_b(D(c*D(255)));b=255;a:{if(c>=D(255)){break a}b=0;if(c<=D(0)){break a}b=~~c>>>0;if(c<D(4294967296)&c>=D(0)){break a}b=0}u[d|0]=b;Yj(a)}}function Vh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=134217728){break a}e=Kb(b<<5)}w[a>>2]=e;c=(c<<5)+e|0;w[a+8>>2]=c;w[a+12>>2]=(b<<5)+e;w[a+4>>2]=c;return a|0}vd();M()}function Qg(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return D(b?-1/a:a)}function vT(a){a=a|0;var b=0,c=0;a:{b=w[w[a+20>>2]+28>>2];b=b>>>0<=127?-1:b^-128;c=b&255;if(c>>>0<=x[a+4200|0]|c>>>0>249){break a}a=w[(w[a+16>>2]+C(b&255,160)|0)+906300>>2];if(!a){break a}ob[w[w[a>>2]+92>>2]](a)}}function pt(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a>>2];a:{if(!c){break a}d=w[c+24>>2];b:{if((d|0)==w[c+28>>2]){b=ob[w[w[c>>2]+52>>2]](c,b)|0;break b}w[c+24>>2]=d+4;w[d>>2]=b}if(!Kc(b,-1)){break a}w[a>>2]=0}return a|0}function mv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Kb(12);b=w[b>>2];d=w[a>>2];w[114256]=0;a=V(1324,c|0)|0;e=w[114256];w[114256]=0;if((e|0)!=1){w[a+8>>2]=b;w[a+4>>2]=d;w[a>>2]=81980;return a|0}a=P()|0;zb(c);R(a|0);M()}function lH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;w[e+12>>2]=d;d=be(e+8|0,e+12|0);w[114256]=0;a=ys(a,b,c);b=w[114256];w[114256]=0;if((b|0)!=1){Lc(d);jb=e+16|0;return a|0}a=P()|0;Lc(d);R(a|0);M()}function Ow(a){a=a|0;var b=0,c=0,d=0;a:{if(!w[a+1304392>>2]){c=Kb(532);b=w[a+24620>>2];w[114256]=0;b=Q(833,c|0,b|0)|0;d=w[114256];w[114256]=0;if((d|0)==1){break a}jk(a+1304392|0,b)}return}a=P()|0;zb(c);R(a|0);M()}function yS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0),e=0,f=D(0),g=D(0),h=D(0),i=0;if((b|0)<=4){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}e=((b<<2)+a|0)+4220|0,f=(g=_b(c),h=c,i=(b|0)==4,i?g:h),A[e>>2]=f;Bv(a)}}function kS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0),e=0,f=D(0),g=D(0),h=D(0),i=0;if((b|0)<=1){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}e=((b<<2)+a|0)+4208|0,f=(g=_b(c),h=c,i=(b|0)==1,i?g:h),A[e>>2]=f;zv(a)}}function dk(a,b){var c=0,d=0;c=w[b+4>>2];w[a+24648>>2]=w[b>>2];w[a+24652>>2]=c;d=w[b+20>>2];c=a+24664|0;w[c>>2]=w[b+16>>2];w[c+4>>2]=d;d=w[b+12>>2];c=a+24656|0;w[c>>2]=w[b+8>>2];w[c+4>>2]=d;Zj(a+24648|0,0);An(a)}function Uo(a){var b=0,c=0,d=0,e=0;c=w[a+8>>2];e=w[a+4>>2];if((c|0)!=(e|0)){while(1){b=c-12|0;w[a+8>>2]=b;d=w[b>>2];if(d){w[c-8>>2]=d;zb(d);b=w[a+8>>2]}c=b;if((b|0)!=(e|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function sG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Ar(a);Uf(a);c=b+4|0;e=w[a>>2];d=w[a+4>>2]-e|0;f=w[c>>2]-d|0;w[c>>2]=f;if((d|0)>0){Fb(f,e,d)}wj(a,c);wj(a+4|0,b+8|0);wj(Xi(a),El(b));w[b>>2]=w[b+4>>2];dr(a,ae(a))}function jC(a,b,c){a=a|0;b=b|0;c=c|0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[114256]=0;U(253,a|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){c=P()|0;b=w[a+8>>2];if(b){w[a+12>>2]=b;zb(b)}R(c|0);M()}return a|0}function yC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=c;c=x[b+11|0];d=c<<24>>24<0;b=Tq(e,0,d?w[b>>2]:b,d?w[b+4>>2]:c);c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;w[a+8>>2]=w[b+8>>2];w[b>>2]=0;w[b+4>>2]=0;w[b+8>>2]=0}function sl(a,b,c){var d=0;d=w[a+16>>2];if(!d){w[a+36>>2]=1;w[a+24>>2]=c;w[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(w[a+24>>2]!=2){break a}w[a+24>>2]=c;return}u[a+54|0]=1;w[a+24>>2]=2;w[a+36>>2]=w[a+36>>2]+1}}function qo(a){a=a|0;var b=0,c=0;if(x[a+530|0]){while(1){c=b&65535;le(a,c,1);b=b+1|0;if(c>>>0<255){continue}break}u[a+530|0]=0}v[a+20>>1]=0;w[a+12>>2]=0;w[a+16>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;Cb(a+22|0,255,292)}function li(a,b){var c=0;c=w[b+24>>2];w[a+24628>>2]=c?c>>>0>=512?512:c:1;a:{if(!(w[b+16>>2]!=w[a+24620>>2]|w[b+20>>2]!=w[a+24624>>2])){c=0;if(w[b+12>>2]==w[a+24616>>2]){break a}}c=1}Fb(a+24604|0,b,40);vn(a,c)}function YN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;Yu(g+8|0,b,c,d,e,f);w[a+8>>2]=w[g+16>>2];b=w[g+12>>2];w[a>>2]=w[g+8>>2];w[a+4>>2]=b;if(u[g+31|0]<0){zb(w[g+20>>2])}jb=g+32|0}function XN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;Yu(g+8|0,b,c,d,e,f);w[a+8>>2]=w[g+28>>2];b=w[g+24>>2];w[a>>2]=w[g+20>>2];w[a+4>>2]=b;if(u[g+19|0]<0){zb(w[g+8>>2])}jb=g+32|0}function Ee(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=y[a+24>>1];if((d|0)!=(b&65535)){c=y[a+22>>1]-1&127;v[a+22>>1]=c;e=y[a+20>>1];if(e>>>0<=127){v[a+20>>1]=e+1}c=(c<<2)+a|0;v[c+26>>1]=b-d;v[c+28>>1]=0;v[a+24>>1]=b}}function _L(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;g=w[w[b>>2]+20>>2];f=w[c+12>>2];w[e+8>>2]=w[c+8>>2];w[e+12>>2]=f;f=w[c+4>>2];w[e>>2]=w[c>>2];w[e+4>>2]=f;ob[g|0](a,b,e,d);jb=e+16|0}function sc(a){var b=0,c=0,d=0;b=w[a+8>>2];d=w[a+4>>2];if((b|0)!=(d|0)){while(1){c=b-12|0;w[a+8>>2]=c;if(u[b-1|0]>=0){b=c}else{zb(w[c>>2]);b=w[a+8>>2]}if((d|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function fl(a,b,c){var d=0;a=(x[a+3|0]|x[a+4|0]<<8)>>>C(c,3)|0;d=a>>>2&1|x[b+12|0]&-8;u[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=x[b+13|0]|x[b+14|0]<<8;u[b+15|0]=a;u[b+16|0]=a>>>8;u[b+12|0]=d|4}}function Ue(a,b){var c=0,d=0;a:{b=u[(a+b|0)+58|0];if((b|0)<0){break a}d=w[a>>2];if(!d){break a}c=a;a=(b|0)<0?-1:b;c=c+(a&255)|0;b=x[c+4|0]&223;u[c+4|0]=b;c=d;d=a&255;Pd(c,((a>>>0<9?d:d-9|256)|176)&65535,b)}}function hF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){Bh(a,b);d=w[a+4>>2];b=d+(b<<2)|0;while(1){w[d>>2]=w[c>>2];d=d+4|0;if((b|0)!=(d|0)){continue}break}w[a+4>>2]=b}return a|0}function es(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;u[g+15|0]=0;u[g+14|0]=f;u[g+13|0]=e;u[g+12|0]=37;if(f){ds(g+13|0,g+14|0)}h=c,i=(Ra(b|0,ct(b,w[c>>2])|0,g+12|0,d|0,w[a>>2])|0)+b|0,w[h>>2]=i;jb=g+16|0}function Vf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if((b|0)<0){break a}e=Kb(b<<1)}w[a>>2]=e;c=(c<<1)+e|0;w[a+8>>2]=c;w[a+12>>2]=(b<<1)+e;w[a+4>>2]=c;return a|0}vd();M()}function PB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){sh(a,b);d=w[a+4>>2];b=d+(b<<1)|0;while(1){v[d>>1]=y[c>>1];d=d+2|0;if((b|0)!=(d|0)){continue}break}w[a+4>>2]=b}return a|0}function qk(a,b,c,d){var e=0;e=w[b+480180>>2];a:{if(e&64671904){e=0;d=x[(x[c+4|0]&15)+25776|0];break a}e=x[c+3|0]==4&(e|0)==4;if(d){d=0;if(w[b+1074320>>2]&4){break a}}d=x[c+4|0]<<e<<4}u[a+4|0]=e;w[a>>2]=d}function vs(a){var b=0;if(!((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=808603728|(x[a+4|0]-16&255)>>>0<249|((x[a+5|0]-16&255)>>>0<249|(x[a+6|0]-16&255)>>>0<249))){b=(x[a+7|0]-9&255)>>>0<7}return b}function pc(a){a=a|0;var b=0;w[a>>2]=60384;w[114256]=0;T(1659,a|0,0);b=w[114256];w[114256]=0;if((b|0)!=1){Ab(a+28|0);zb(w[a+32>>2]);zb(w[a+36>>2]);zb(w[a+48>>2]);zb(w[a+60>>2]);return a|0}W(0)|0;Eb();M()}function lO(a,b){a=a|0;b=b|0;var c=D(0);a:{if((b|0)<0){break a}a=w[a+24>>2];if(y[a+480188>>1]<=b>>>0){break a}a=a+C(b,896)|0;if(!(u[a+1075073|0]&1)){break a}c=D(D(x[a+1075846|0])*D(.0078125))}return D(c)}function kO(a,b){a=a|0;b=b|0;var c=D(0);a:{if((b|0)<0){break a}a=w[a+24>>2];if(y[a+480188>>1]<=b>>>0){break a}a=a+C(b,896)|0;if(!(u[a+1075073|0]&1)){break a}c=D(D(x[a+1075847|0])*D(.0078125))}return D(c)}function jp(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){Bb(c-16|0);c=c-24|0;if((c|0)!=(b|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0}}function ad(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Cb(f,b&255,c?d:256);if(!c){while(1){Tc(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Tc(a,f,d)}jb=f+256|0}function yc(a,b){var c=0,d=0,e=0;b=b+7&-8;w[a+8>>2]=b+w[a+8>>2];d=w[a+80>>2];a:{if(d){c=b;b=w[a+88>>2];e=c+b|0;c=0;if((e|0)>w[a+92>>2]){break a}w[a+88>>2]=e;return b+d|0}if(!b){return 0}c=fc(b)}return c}function Mi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){Wf(a,b);d=b;b=w[a+4>>2];d=d+b|0;while(1){u[b|0]=x[c|0];b=b+1|0;if((d|0)!=(b|0)){continue}break}w[a+4>>2]=d}return a|0}function Pb(a,b){var c=0,d=0,e=0;w[a+4>>2]=0;w[a>>2]=82052;c=x[b+11|0];c=fc((c<<24>>24<0?w[b+4>>2]:c)+1|0);w[a+4>>2]=c;if(c){e=c;c=x[b+11|0];d=c<<24>>24<0;Fb(e,d?w[b>>2]:b,(d?w[b+4>>2]:c)+1|0)}return a}function JA(a,b,c){a=a|0;b=b|0;c=c|0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;U(62,a|0,b|0,c|0);b=w[114256];w[114256]=0;if((b|0)==1){c=P()|0;b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}R(c|0);M()}return a|0}function nO(a,b){a=a|0;b=b|0;var c=D(0);a:{if((b|0)<0){break a}a=w[a+24>>2];if(y[a+480188>>1]<=b>>>0){break a}a=a+C(b,896)|0;if(u[a+1075073|0]&1){break a}c=D(D(x[a+1075846|0])*D(.0078125))}return D(c)}function mO(a,b){a=a|0;b=b|0;var c=D(0);a:{if((b|0)<0){break a}a=w[a+24>>2];if(y[a+480188>>1]<=b>>>0){break a}a=a+C(b,896)|0;if(u[a+1075073|0]&1){break a}c=D(D(x[a+1075847|0])*D(.0078125))}return D(c)}function Yv(a){var b=0,c=0,d=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-4|0;w[a+8>>2]=b;d=w[b>>2];w[b>>2]=0;if(d){od(d)}b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function gr(a){var b=0,c=0;b=jb-16|0;jb=b;Uf(a);w[b+12>>2]=1073741823;w[114256]=0;w[b+8>>2]=2147483647;a=ag(b+12|0,b+8|0);c=w[114256];w[114256]=0;if((c|0)!=1){jb=b+16|0;return w[a>>2]}W(0)|0;Eb();M()}function Vo(a){var b=0,c=0,d=0,e=0;if(w[a>>2]){b=w[a+4>>2];c=w[a>>2];if((b|0)!=(c|0)){while(1){e=b-12|0;d=w[e>>2];if(d){w[b-8>>2]=d;zb(d)}b=e;if((c|0)!=(b|0)){continue}break}}w[a+4>>2]=c;zb(w[a>>2])}}function le(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=a+b|0;e=u[d+58|0];if((e|0)<0){break a}Ue(a,b);lh(a,b,0,0);if(!c){break a}v[(((((e|0)<0?-1:e)&255)<<1)+a|0)+22>>1]=65535;u[d+58|0]=x[d+58|0]|128}}function sp(a,b){var c=0;c=w[b>>2];b=w[b+4>>2];if(b){w[b+4>>2]=w[b+4>>2]+1}w[a>>2]=c;c=w[a+4>>2];w[a+4>>2]=b;a:{if(!c){break a}a=w[c+4>>2];w[c+4>>2]=a-1;if(a){break a}ob[w[w[c>>2]+8>>2]](c);Ib(c)}}function If(a){a=a|0;var b=0,c=0;b=w[a>>2];a=w[a+4>>2];if((b|0)==(a|0)){a=0}else{while(1){a:{c=a;if((a|0)==(b|0)){c=b;break a}a=c-2|0;if(y[a>>1]==65535){continue}}break}a=c-b>>>1|0}return a&65535}function he(a,b){var c=0,d=0;c=w[b>>2];d=w[b+4>>2];w[b>>2]=0;w[b+4>>2]=0;b=w[a+4>>2];w[a>>2]=c;w[a+4>>2]=d;a:{if(!b){break a}a=w[b+4>>2];w[b+4>>2]=a-1;if(a){break a}ob[w[w[b>>2]+8>>2]](b);Ib(b)}}function LK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=w[a+16>>2];if(e>>>0>c>>>0){f=w[a+4>>2];g=w[a+12>>2]+c|0;a=e-c|0;a=ob[w[w[f>>2]+28>>2]](f,b,g,a>>>0<d>>>0?a:d)|0}else{a=0}return a|0}function EL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=Kb(32);w[114256]=0;c=Z(137,b|0,c|0,d|0,e|0)|0;d=w[114256];w[114256]=0;if((d|0)!=1){w[a+4>>2]=c;w[a>>2]=c+12;return}a=P()|0;zb(b);R(a|0);M()}function oc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=w[b>>2];e=w[b+8>>2];a:{if(ob[w[w[d>>2]+36>>2]](d,e,c)|0){d=w[b+8>>2]+c|0;break a}d=w[b>>2];d=ob[w[w[d>>2]+24>>2]](d)|0}w[b+8>>2]=d;Hu(a,b,e,c)}function Jd(a,b){a=a|0;b=b|0;var c=0;c=w[a>>2];a=mc(b);b=c+8|0;if(ae(b)>>>0>a>>>0){b=w[Sf(b,a)>>2]!=0}else{b=0}if(!b){a=Fh(ba(4)|0);w[a>>2]=75136;ka(a|0,75184,1593);M()}return w[Sf(c+8|0,a)>>2]}function Gd(a){var b=0;w[114256]=0;a=V(22,a|0)|0;b=w[114256];w[114256]=0;a:{if((b|0)==1){$(W(0)|0)|0;w[114256]=0;_(18);b=w[114256];w[114256]=0;a=0;if((b|0)==1){break a}}return a}W(0)|0;Eb();M()}function bl(a,b,c,d){var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=89478486){break a}e=Kb(C(b,48))}w[a>>2]=e;c=C(c,48)+e|0;w[a+8>>2]=c;w[a+12>>2]=C(b,48)+e;w[a+4>>2]=c;return a}vd();M()}function CC(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+14>>1]=b;d=w[a+4>>2];a:{if(d-w[a>>2]>>>0>131068){break a}if(w[a+8>>2]!=(d|0)){v[d>>1]=b;w[a+4>>2]=d+2;break a}rq(a,c+14|0)}jb=c+16|0}function kH(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;w[b+12>>2]=a;a=be(b+8|0,b+12|0);w[114256]=0;c=xs();d=w[114256];w[114256]=0;if((d|0)!=1){Lc(a);jb=b+16|0;return c|0}b=P()|0;Lc(a);R(b|0);M()}function go(a){var b=0,c=0,d=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-12|0;w[a+8>>2]=b;d=w[b>>2];if(d){zb(d);b=w[a+8>>2]}if((b|0)!=(c|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function zf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=jb-16|0;jb=c;a:{if(!b){b=1;if(x[a+24|0]&32){break a}rd(c,w[a+28>>2])}w[a>>2]=w[a>>2]|134217728;w[a+20>>2]=w[a+20>>2]+1;b=0}jb=c+16|0;return b|0}function sr(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;w[f+12>>2]=e;e=be(f+8|0,f+12|0);w[114256]=0;a=Rh(a,b,c,d);b=w[114256];w[114256]=0;if((b|0)!=1){Lc(e);jb=f+16|0;return a}a=P()|0;Lc(e);R(a|0);M()}function Np(a,b,c,d){var e=0;w[a+12>>2]=0;w[a+16>>2]=d;a:{if(b){if(b>>>0>=715827883){break a}e=Kb(C(b,6))}w[a>>2]=e;c=C(c,6)+e|0;w[a+8>>2]=c;w[a+12>>2]=C(b,6)+e;w[a+4>>2]=c;return a}vd();M()}function Ge(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{if(sj(c)){d=a;Zc(a,c);break b}if(c>>>0>4294967279){break a}e=_f(c)+1|0;d=nf(a,e);hd(a,d);Cd(a,e);Yc(a,c)}Dd(d,b,c+1|0);return}zc(a);M()}function lw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!(!b|!c)){e=b+c|0;d=b;a:{while(1){if(!x[d|0]){break a}d=d+1|0;if((e|0)!=(d|0)){continue}break}d=e}no(a+36|0,b,d)}return(b|0)!=0&(c|0)!=0}function bc(a){var b=0,c=0,d=0;if(w[a>>2]){b=w[a+4>>2];c=w[a>>2];if((b|0)!=(c|0)){while(1){d=b-12|0;if(u[b-1|0]<0){zb(w[d>>2])}b=d;if((c|0)!=(b|0)){continue}break}}w[a+4>>2]=c;zb(w[a>>2])}}function Vt(a){var b=0;b=w[a+72>>2];w[a+72>>2]=b-1|b;b=w[a>>2];if(b&8){w[a>>2]=b|32;return-1}w[a+4>>2]=0;w[a+8>>2]=0;b=w[a+44>>2];w[a+28>>2]=b;w[a+20>>2]=b;w[a+16>>2]=b+w[a+48>>2];return 0}function Fs(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:u[a|0]=c;return;case 1:v[a>>1]=c;return;case 2:case 3:w[a>>2]=c;return;case 5:break b;default:break a}}w[a>>2]=c;w[a+4>>2]=d}}function cm(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;qd(j,b,c,d,e,f,g,h,i^-2147483648);d=w[j>>2];c=w[j+4>>2];b=w[j+12>>2];w[a+8>>2]=w[j+8>>2];w[a+12>>2]=b;w[a>>2]=d;w[a+4>>2]=c;jb=j+16|0}function iE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;el(a,c,d);e=w[a+16>>2];a:{if(e>>>0<=c>>>0){break a}e=e-c|0;d=d>>>0>e>>>0?e:d;if(!d){break a}hc(b,w[a+4>>2]+c|0,d);f=d}return f|0}
function So(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function Jl(a,b,c,d){var e=0;e=jb-16|0;jb=e;w[e+12>>2]=d;d=be(e+8|0,e+12|0);w[114256]=0;a=Ij(a,b,c);b=w[114256];w[114256]=0;if((b|0)!=1){Lc(d);jb=e+16|0;return a}a=P()|0;Lc(d);R(a|0);M()}function dy(a,b){a=a|0;b=b|0;var c=0;u[a+530|0]=0;w[a>>2]=0;w[114256]=0;T(720,a|0,b|0);b=w[114256];w[114256]=0;if((b|0)==1){c=P()|0;b=w[a>>2];w[a>>2]=0;if(b){zb(b)}R(c|0);M()}return a|0}function Qe(a,b){var c=0,d=0;c=x[a|0];d=x[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=x[b+1|0];c=x[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function OR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(86224);if(d){w[114256]=0;Z(1290,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function JK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=w[a+84>>2];d=c+256|0;f=uc(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;Fb(b,e,c);b=e+d|0;w[a+84>>2]=b;w[a+8>>2]=b;w[a+4>>2]=c+e;return c|0}function Bk(a,b){var c=0;c=Tb(Ed((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363);a=-1;a:{if(c>=4294967295){break a}a=0;if(c<=0){break a}if(c<4294967296&c>=0){return~~c>>>0}a=0}return a}function vJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;w[g+8>>2]=624576549;w[g+12>>2]=1394948685;h=a;a=g+16|0;b=Je(h,b,c,d,e,f,g+8|0,a);jb=a;return b|0}function sR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;w[f+8>>2]=w[a+8>>2];g=w[a+4>>2];w[f>>2]=w[a>>2];w[f+4>>2]=g;a=lv(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function pS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4228);if(d){w[114256]=0;Z(1217,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function ic(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(!b){break a}d=w[a>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],b)|0)){break a}u[c+15|0]=0;Xb(a,c+15|0);e=x[c+15|0]}jb=c+16|0;return e}function fS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(5048);if(d){w[114256]=0;Z(1240,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function dT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4296);if(d){w[114256]=0;Z(1101,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function Yq(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(!b){break a}d=w[a>>2];if(!(ob[w[w[d>>2]+36>>2]](d,w[a+8>>2],b)|0)){break a}u[c+15|0]=0;Xb(a,c+15|0);e=u[c+15|0]}jb=c+16|0;return e}function XR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4276);if(d){w[114256]=0;Z(1267,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function TS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4280);if(d){w[114256]=0;Z(1134,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function KT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4304);if(d){w[114256]=0;Z(1039,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function KS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4276);if(d){w[114256]=0;Z(1158,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function CS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4268);if(d){w[114256]=0;Z(1181,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function qy(a,b){a=a|0;b=b|0;u[a+16|0]=0;w[a+12>>2]=b;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[114256]=0;X(707,a|0);b=w[114256];w[114256]=0;if((b|0)!=1){return a|0}b=P()|0;Ak(a);R(b|0);M()}function eU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Gd(4268);if(d){w[114256]=0;Z(984,d|0,a|0,b|0,c|0)|0;a=w[114256];w[114256]=0;if((a|0)==1){break a}}return d|0}a=P()|0;zb(d);R(a|0);M()}function dq(a,b,c){var d=0;a=a>>>2|0;a=a>>>0<=1?1:a;d=b>>>0<2|a>>>0<15;if(!d){a=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0)&255;a=a>>>0<=1?1:a}return(c?a<<4|(d?15:0):a&15|(d?-16:0))&255}function ar(a,b){var c=0,d=0;c=w[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}Uf(a);w[114256]=0;c=c-4|0;d=w[114256];w[114256]=0;if((d|0)!=1){continue}break}W(0)|0;Eb();M()}w[a+4>>2]=b}function _n(a,b){var c=0,d=0;c=w[a+104>>2];if(!(!c|!w[a+76>>2])){w[a+88>>2]=w[a+88>>2]&-131|128;c=w[c>>2];w[a+76>>2]=c;w[a>>2]=0;d=a;a=c-1|0;b=b<<8;w[d+4>>2]=c+((a>>>0<b>>>0?a:b)^-1)}}function Ug(a){var b=0,c=0;if(w[a>>2]){b=w[a+4>>2];c=w[a>>2];if((b|0)!=(c|0)){while(1){if(u[b-1|0]<0){zb(w[b-12>>2])}b=b-16|0;if((c|0)!=(b|0)){continue}break}}w[a+4>>2]=c;zb(w[a>>2])}}function kD(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;w[c+24>>2]=0;w[c+28>>2]=0;w[c+16>>2]=0;w[c+20>>2]=0;w[c+8>>2]=0;w[c+12>>2]=0;w[c>>2]=0;w[c+4>>2]=0;Rp(b,c,32);lw(a,c,32);jb=c+32|0}function jv(a){a=a|0;var b=0,c=0;a:{if(!a){a=ba(8)|0;w[114256]=0;b=V(1336,a|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);R(b|0);M()}return}ka(b|0,81948,1337);M()}function Zm(a){a=a|0;var b=0,c=0;a:{if(!a){a=ba(8)|0;w[114256]=0;b=V(1348,a|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);R(b|0);M()}return}ka(b|0,81960,1337);M()}function ZC(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=-1;a:{if(!lf(a,d+8|0)){break a}c=0;if(w[d+8>>2]!=778663024|(w[d+12>>2]&-4)!=256){break a}c=Uc(a,b,36,0)}jb=d+16|0;return c|0}function Wx(a,b){a=a|0;b=b|0;if(w[a>>2]){ko(a);zb(w[a>>2]);w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0}w[a>>2]=w[b>>2];w[a+4>>2]=w[b+4>>2];w[a+8>>2]=w[b+8>>2];w[b+8>>2]=0;w[b>>2]=0;w[b+4>>2]=0}function yi(a,b){a=a|0;b=+b;var c=0;c=w[a+24>>2];b=Tb(Ed(b)*+(c>>>0));c=-1;a:{if(b>=4294967295){break a}c=0;if(b<=0){break a}c=~~b>>>0;if(b<4294967296&b>=0){break a}c=0}w[a+24>>2]=c}function sV(a){a=a|0;var b=0,c=0;b=w[a>>2];a=w[a+4>>2];if((b|0)!=(a|0)){c=1/+(a-b>>4>>>0);while(1){B[b>>3]=B[b>>3]*c;B[b+8>>3]=B[b+8>>3]*c;b=b+16|0;if((a|0)!=(b|0)){continue}break}}}function ov(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;w[f+8>>2]=w[a+8>>2];g=w[a+4>>2];w[f>>2]=w[a>>2];w[f+4>>2]=g;c=nv(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function vq(a,b){a=a|0;b=b|0;var c=0;c=w[a>>2];c=ob[w[w[c>>2]+36>>2]](c,w[a+8>>2],b)|0;a:{if(c){b=w[a+8>>2]+b|0;break a}b=w[a>>2];b=ob[w[w[b>>2]+24>>2]](b)|0}w[a+8>>2]=b;return c|0}function tP(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;b=u[b+11|0]<0?w[b>>2]:b;d=w[a+4>>2];a:{if(d){ob[d|0](b,w[a+8>>2]);break a}w[c>>2]=b;a=w[14612];Nj(a,13564,c);wf(a)}jb=c+16|0}function ev(a){a=a|0;var b=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[114256]=0;S(118,a|0,9442,36)|0;b=w[114256];w[114256]=0;if((b|0)==1){b=P()|0;if(u[a+11|0]<0){zb(w[a>>2])}R(b|0);M()}}function Fw(a){a=a|0;var b=0;b=1;a=w[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function iL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=w[c+4>>2];c=w[c>>2];w[d>>2]=c;w[d+4>>2]=e;w[d+8>>2]=c;w[d+12>>2]=e;a=Hq(a,d,b);w[a>>2]=60364;jb=d+16|0;return a|0}function Jv(a){a=a|0;var b=D(0);b=_b(D(A[a+4224>>2]*D(4)));a=-1;a:{if(b>=D(4294967296)){break a}a=0;if(b<=D(0)){break a}if(b<D(4294967296)&b>=D(0)){return~~b>>>0|0}a=0}return a|0}function gg(a){var b=0,c=0;b=w[20755];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>pb()<<16>>>0){if(!(Xa(a|0)|0)){break a}}w[20755]=a;return b}w[114084]=48;return-1}function KH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=w[b>>2];if(a>>>0<=127){a=w[(a<<2)+65088>>2]}else{a=0}w[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function zq(a){var b=0,c=0;a:{if(Jb(a,9851,3)){break a}b=x[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(x[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function eG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;ob[w[w[a>>2]+12>>2]](e,a,b);if(Kc(w[e+4>>2],w[c+4>>2])){a=w[e>>2]==w[c>>2]}else{a=0}jb=d+16|0;return a|0}function ne(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(dd(a)){Gh(w[a>>2],Ke(a))}w[a+8>>2]=w[b+8>>2];d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;Zc(b,0);w[c+12>>2]=0;xd(b,c+12|0);jb=c+16|0}function Tx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=x[b+31|0];a:{if(!(d&6|x[b+30|0]!=4)){b=11;e=8;c=1;break a}e=d&4?16:8;b=c^1;c=d&2|1}u[a+3|0]=b;u[a+2|0]=0;u[a+1|0]=c;u[a|0]=e}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=y[a+28>>1];v[d+8>>1]=e;v[d+10>>1]=((w[a+8>>2]-w[a+4>>2]>>>2|0)+e|0)-1;a=dw(a,b,c,d+8|0);jb=d+16|0;return a|0}function tM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=w[a+8>>2];a:{if(e>>>0<=c>>>0){break a}e=e-c|0;d=d>>>0>e>>>0?e:d;if(!d){break a}hc(b,w[a+4>>2]+c|0,d);f=d}return f|0}function _c(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(dd(a)){Th(w[a>>2],Ke(a))}w[a+8>>2]=w[b+8>>2];d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;Zc(b,0);u[c+15|0]=0;Sc(b,c+15|0);jb=c+16|0}function $n(a,b,c){var d=0;d=c&15;if(d){u[b+844|0]=d}c=c&240;if(c){u[b+843|0]=c>>>4}w[b+88>>2]=w[b+88>>2]|131072;if(!(!d|!(w[a+1074320>>2]&65536))){u[b+844|0]=x[b+844|0]<<2}}function gV(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[b+14|0];a:{if(!(c&48|x[b+17|0]!=173)){b=1;d=11;c=8;break a}b=c&32?3:1;d=2;c=c&16?16:8}u[a+3|0]=d;u[a+2|0]=0;u[a+1|0]=b;u[a|0]=c}function xi(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-32|0;w[a+8>>2]=b;mh(b);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function xg(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;w[a+8>>2]=b;Bb(b);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function wr(a){a=a|0;var b=0,c=0;w[a>>2]=65016;b=a+8|0;while(1){if(ae(b)>>>0>c>>>0){if(w[Sf(b,c)>>2]){Kh(w[Sf(b,c)>>2])}c=c+1|0;continue}break}Gb(a+152|0);Kr(b);return a|0}function fw(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-52|0;w[a+8>>2]=b;Cf(b);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function ep(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;w[a+8>>2]=b;dp(b);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function Yp(a){var b=0;a:{if((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=-28163770){break a}if(Jb(a+44|0,13556,3)){break a}b=(x[a+47|0]|x[a+48|0]<<8)>>>0>97}return b}function Bj(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){b=b-32|0;w[a+8>>2]=b;Tg(b);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function pd(a){var b=0,c=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){while(1){w[a+8>>2]=b-24;Bb(b-16|0);b=w[a+8>>2];if((c|0)!=(b|0)){continue}break}}a=w[a>>2];if(a){zb(a)}}function je(a){a=a|0;var b=0,c=0;while(1){b=c&65535;if(b>>>0<=126){Qd(((b<<5)+a|0)+480280|0);ug((C(b,896)+a|0)+1074984|0,7,a,b,1024)}c=c+1|0;if(b>>>0<126){continue}break}}function ZL(a,b){a=a|0;b=b|0;w[a+4>>2]=b;u[a|0]=0;if(dg(w[w[b>>2]-12>>2]+b|0)){if(w[(w[w[b>>2]-12>>2]+b|0)+72>>2]){sm(w[(w[w[b>>2]-12>>2]+b|0)+72>>2])}u[a|0]=1}return a|0}function IH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=w[c>>2];if(!(a>>>0>127|!(w[(a<<2)+65088>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function HC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ob[w[w[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}
function GL(a,b){a=a|0;b=b|0;w[a+4>>2]=b;u[a|0]=0;if(dg(w[w[b>>2]-12>>2]+b|0)){if(w[(w[w[b>>2]-12>>2]+b|0)+72>>2]){ut(w[(w[w[b>>2]-12>>2]+b|0)+72>>2])}u[a|0]=1}return a|0}function Nt(a,b){var c=D(0),d=0;c=b&1?a:D(1);if(b+1>>>0>=3){d=b;while(1){a=D(a*a);d=(d|0)/2|0;c=D(c*(d&1?a:D(1)));if(d+1>>>0>2){continue}break}}return(b|0)<0?D(D(1)/c):c}function Ac(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){Bb(c-16|0);c=c-24|0;if((c|0)!=(b|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function JH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=w[c>>2];if(a>>>0>127|!(w[(a<<2)+65088>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function Hm(a){var b=0,c=0,d=0,e=0;b=Dc(a);w[a+1396>>2]=0;c=Dc(a);w[a+1396>>2]=0;d=Dc(a);w[a+1396>>2]=0;e=Dc(a);w[a+1396>>2]=0;return(((c<<8)+b|0)+(d<<16)|0)+(e<<24)|0}function Au(a){var b=0,c=0;a:{if(x[a|0]!=255){break a}b=x[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=x[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function $R(a){a=a|0;var b=0,c=0,d=0,e=0;b=a+4960|0;e=a+4504|0;while(1){d=b-24|0;c=w[d>>2];if(c){w[b-20>>2]=c;zb(c)}b=d;if((e|0)!=(b|0)){continue}break}return Oc(a)|0}function Sq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Yb(a);if(d>>>0>=c>>>0){d=Qb(a);Eh(d,b,c);return Cl(a,d,c)|0}e=d;f=c-d|0;d=Db(a);Dh(a,e,f,d,0,d,c,b);return a|0}function FR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=w[b+24>>2];g=w[b+8>>2];h=w[b+4>>2];i=w[b>>2];e=w[b+12>>2]}else{e=0}rv(a,i,h,g,e,f,b,c,d)}function Bi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!(x[c+1074324|0]&64)){break a}c=y[a+692>>1]+1|0;v[a+796>>1]=c;if(!(u[a+89|0]&1)){break a}v[a+796>>1]=c|32768}w[a+692>>2]=b}function kp(a){if(!((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=541938512|(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))!=1162627398)){return 1}return 0}function hp(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-56|0;dp(c);if((b|0)!=(c|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function gk(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-32|0;Tg(c);if((b|0)!=(c|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function fL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Ic(d,a);Wc(a,c);w[114256]=0;T(1659,b|0,1);a=w[114256];w[114256]=0;if((a|0)==1){a=P()|0;Ab(d);R(a|0);M()}}function cE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;el(a,b,c);a=w[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Gn(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-52|0;Cf(c);if((b|0)!=(c|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function FM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=Jj(Fa(w[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;nb=a?-1:w[e+12>>2];return(a?-1:w[e+8>>2])|0}function Ak(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-32|0;mh(c);if((b|0)!=(c|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function Zo(a,b,c){var d=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){b=(y[(b<<1)+25742>>1]-y[(c<<1)+25742>>1]|0)/5&255;d=a>>>0>b>>>0?b:a}return d}function Bt(a,b){var c=0,d=0,e=0,f=0;c=w[a+24>>2];if((c|0)==w[a+28>>2]){return e=a,f=Md(b),d=w[w[a>>2]+52>>2],ob[d](e|0,f|0)|0}w[a+24>>2]=c+1;u[c|0]=b;return Md(b)}function vy(a,b){a=a|0;b=b|0;var c=0,d=0;d=a+236|0;a=a+108|0;while(1){c=x[a|0]+b|0;c=(c|0)>=120?120:c;u[a|0]=(c|0)<=1?1:c;a=a+1|0;if((d|0)!=(a|0)){continue}break}}function od(a){var b=0;if(a){Gi(a+52|0,w[a+56>>2]);if(u[a+51|0]<0){zb(w[a+40>>2])}b=w[a+16>>2];if(b){w[a+20>>2]=b;zb(b)}b=w[a+4>>2];if(b){w[a+8>>2]=b;zb(b)}zb(a)}}function gc(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=Bb(c-16|0);if((c|0)!=(b|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function Bp(a){var b=0,c=0,d=0;b=w[a>>2];if(b){d=b;c=w[a+4>>2];if((c|0)!=(b|0)){while(1){c=Bb(c-20|0);if((c|0)!=(b|0)){continue}break}d=w[a>>2]}w[a+4>>2]=b;zb(d)}}function xv(a){a=a|0;var b=0,c=0,d=0,e=0;b=a+4960|0;e=a+4504|0;while(1){d=b-24|0;c=w[d>>2];if(c){w[b-20>>2]=c;zb(c)}b=d;if((e|0)!=(b|0)){continue}break}zb(Oc(a))}function ph(a){w[a+8>>2]=0;w[a+12>>2]=0;w[a>>2]=128;w[a+4>>2]=256;w[a+32>>2]=363;w[a+36>>2]=952;w[a+16>>2]=48e3;w[a+20>>2]=2;w[a+24>>2]=128;w[a+28>>2]=0;return a}function fm(a,b){var c=0;c=Ys(a+4|0);w[a>>2]=59068;w[c>>2]=59088;w[114256]=0;T(1676,c|0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){return}a=P()|0;pc(c);R(a|0);M()}function em(a,b){var c=0;c=Vs(a+4|0);w[a>>2]=59228;w[c>>2]=59248;w[114256]=0;T(1678,c|0,b|0);a=w[114256];w[114256]=0;if((a|0)!=1){return}a=P()|0;pc(c);R(a|0);M()}function Sp(a){var b=0;b=jb-16|0;jb=b;w[114256]=0;w[b+12>>2]=0;w[b+8>>2]=a;T(388,b+8|0,110);a=w[114256];w[114256]=0;if((a|0)!=1){jb=b+16|0;return}W(0)|0;Eb();M()}function PT(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);c=D(D(ob[w[w[a>>2]+48>>2]](a,b))+c);a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}ob[w[w[a>>2]+44>>2]](a,b,c)}function NF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;w[d+12>>2]=w[c>>2];a=ob[w[w[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){w[c>>2]=w[d+12>>2]}jb=d+16|0;return a|0}function Ci(a,b,c,d){var e=0;a:{if(d==D(1)){break a}b=C(b,c);if(!b){break a}e=+d;c=0;while(1){B[a>>3]=B[a>>3]*e;a=a+8|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}}}function IT(a){a=a|0;var b=0,c=0;b=w[a+112>>2];if((b|0)>=11){b=378;while(1){Iv(a);c=c-!b|0;b=b-1|0;if(c|b){continue}break}b=0}w[a+112>>2]=b+1;a=Iv(a);return a|0}function tT(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;Tv(b+8|0,a,0);c=w[b+12>>2];d=w[b+8>>2];if((c|0)!=(d|0)){a=w[a+20>>2];w[a+148>>2]=-1;En(a+4|0,d,c)}jb=b+16|0}function iP(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Vg(c,a);a=w[b>>2];if(a){w[b+4>>2]=a;zb(a)}w[b>>2]=w[c>>2];w[b+4>>2]=w[c+4>>2];w[b+8>>2]=w[c+8>>2];jb=c+16|0}function hj(a){a=a|0;var b=0,c=0;b=ba(8)|0;w[114256]=0;a=Q(191,b|0,a|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){ka(a|0,75040,133);M()}a=P()|0;ca(b|0);R(a|0);M()}function Ol(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!dd(b)){w[a+8>>2]=w[b+8>>2];d=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=d;break a}Ge(a,w[b>>2],w[b+4>>2])}jb=c+16|0}function Hc(a,b){var c=0;c=w[a>>2];w[a>>2]=b;a:{if(c){a=w[Lh(a)>>2];w[114256]=0;X(a|0,c|0);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function Zd(a,b){var c=0;c=w[a+16>>2]+b|0;b=w[a+12>>2];c=(c|0)%(b|0)|0;b=(c>>31&b)+c|0;c=w[a>>2];if(b>>>0>=w[a+4>>2]-c>>2>>>0){Bc(a);M()}return A[c+(b<<2)>>2]}function Fq(a,b,c,d){var e=0,f=0;f=w[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=rl(w[c>>2],e)}a=w[a>>2];ob[w[w[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function xK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=w[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function hi(a){a=a|0;var b=0,c=0;b=ba(8)|0;w[114256]=0;a=Q(21,b|0,a|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){ka(a|0,74992,20);M()}a=P()|0;ca(b|0);R(a|0);M()}function RR(a){a=a|0;var b=0;w[a+4240>>2]=0;w[a+4244>>2]=0;b=a+4264|0;w[b>>2]=0;w[b+4>>2]=0;b=a+4256|0;w[b>>2]=0;w[b+4>>2]=0;a=a+4248|0;w[a>>2]=0;w[a+4>>2]=0}function GH(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=w[b>>2];if(a>>>0<=127){a=w[_i()+(w[b>>2]<<2)>>2]}w[b>>2]=a;b=b+4|0;continue}break}return c|0}function EH(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=w[b>>2];if(a>>>0<=127){a=w[Zi()+(w[b>>2]<<2)>>2]}w[b>>2]=a;b=b+4|0;continue}break}return c|0}function nJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=ob[w[w[a+8>>2]+20>>2]](a+8|0)|0;return Ie(g,b,c,d,e,f,Qb(a),Qb(a)+(Db(a)<<2)|0)|0}function Se(a){a=a|0;var b=0;b=w[15045];w[a>>2]=b;w[w[b-12>>2]+a>>2]=w[15048];w[a+8>>2]=59272;if(u[a+51|0]<0){zb(w[a+40>>2])}wc(a+8|0);pc(a+60|0);return a|0}function AK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=u[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function vc(a,b,c){var d=0;d=jb-16|0;jb=d;w[114256]=0;w[d+12>>2]=b;a=Mh(a,d+12|0,c);b=w[114256];w[114256]=0;if((b|0)!=1){jb=d+16|0;return a}W(0)|0;Eb();M()}function nd(a){a=a|0;var b=0;b=w[15e3];w[a>>2]=b;w[w[b-12>>2]+a>>2]=w[15003];w[a+4>>2]=59272;if(u[a+47|0]<0){zb(w[a+36>>2])}wc(a+4|0);pc(a+56|0);return a|0}function Qq(a){var b=0,c=0,d=0;c=Qb(a);a=Db(a);b=jb-16|0;jb=b;u[b+15|0]=0;d=-1;if(a){if(a){a=uc(c,Md(u[b+15|0]),a)}else{a=0}d=a?a-c|0:-1}jb=b+16|0;return d}function Kb(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=fc(a);if(b){break a}b=w[115571];if(b){ob[b|0]();continue}break}ka(Ye(ba(4)|0)|0,74720,68);M()}return b|0}function Gk(a,b,c,d,e){var f=0;if(d){while(1){A[b>>2]=D(w[a>>2])*e;A[c>>2]=D(w[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function AI(){var a=0,b=0,c=0;a:{a=nc(461760);w[a>>2]=66120;w[114256]=0;b=ea(1732)|0;c=w[114256];w[114256]=0;if((c|0)!=1){w[a+8>>2]=b;break a}R(P()|0);M()}}function ko(a){var b=0,c=0,d=0;b=w[a+4>>2];c=w[a>>2];if((b|0)!=(c|0)){while(1){b=b-12|0;d=w[b>>2];if(d){zb(d)}if((b|0)!=(c|0)){continue}break}}w[a+4>>2]=c}function fe(a){var b=0,c=0;b=a*a;c=b*a;return D(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function cK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;w[e+12>>2]=b;w[e+8>>2]=d;b=be(e,e+12|0);a=Es(a,c,w[e+8>>2]);Lc(b);jb=e+16|0;return a|0}function KK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=w[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=w[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ao(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(x[a+480180|0]&2){break a}}w[b+56>>2]=0;d=gh(a,y[b+60>>1],w[b+48>>2],c,0)}return d|0}function al(a){var b=0,c=0,d=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){d=b;b=(b-c|0)-48|0;w[a+8>>2]=(d+(((b>>>0)%48|0)-b|0)|0)-48}a=w[a>>2];if(a){zb(a)}}function Zh(a,b){var c=0,d=0;a:{if(!a){break a}c=BV(a,0,b,0);d=nb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=fc(c);if(!(!a|!(x[a-4|0]&3))){Cb(a,0,c)}return a}function Kk(a){var b=0,c=0,d=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){d=b;b=(b-c|0)-12|0;w[a+8>>2]=(d+(((b>>>0)%12|0)-b|0)|0)-12}a=w[a>>2];if(a){zb(a)}}function yH(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=u[b|0];if((a|0)>=0){a=w[_i()+(u[b|0]<<2)>>2]}u[b|0]=a;b=b+1|0;continue}break}return c|0}function wH(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=u[b|0];if((a|0)>=0){a=w[Zi()+(u[b|0]<<2)>>2]}u[b|0]=a;b=b+1|0;continue}break}return c|0}function tu(a,b){var c=0,d=0;b=b+7&-8;d=w[a+80>>2];a:{if(d){b=w[a+92>>2]-b|0;c=0;if((b|0)<w[a+88>>2]){break a}w[a+92>>2]=b;return b+d|0}c=fc(b)}return c}function lp(a){var b=0;if(!((x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))!=441273424|x[a+5|0]!=16|(x[a+54|0]-33&255)>>>0<224)){b=x[a+4|0]>95}return b}function $o(a){var b=0;return(x[a+44|0]|x[a+45|0]<<8|(x[a+46|0]<<16|x[a+47|0]<<24))!=1297236819|x[a+29|0]!=16?b:((x[a+42|0]|x[a+43|0]<<8)-1&65535)>>>0<2}function wi(a){var b=0,c=0;b=ba(8)|0;w[114256]=0;a=Q(19,b|0,a|0)|0;c=w[114256];w[114256]=0;if((c|0)!=1){ka(a|0,74940,20);M()}a=P()|0;ca(b|0);R(a|0);M()}function uJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=ob[w[w[a+8>>2]+20>>2]](a+8|0)|0;return Je(g,b,c,d,e,f,Qb(a),Qb(a)+Db(a)|0)|0}function oG(a,b){a=a|0;b=b|0;a=Fh(a);w[a>>2]=74772;b=Qb(b);w[114256]=0;Q(2119,a+4|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){return a|0}R(P()|0);M()}function TK(a,b){a=a|0;b=b|0;var c=0,d=0;b=dm(b);w[a+36>>2]=b;c=a,d=Cj(b),w[c+44>>2]=d;c=a,d=Kg(w[a+36>>2]),u[c+53|0]=d;if(w[a+44>>2]>=9){hj(2049);M()}}function BH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=w[b>>2];u[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function $K(a,b){a=a|0;b=b|0;var c=0,d=0;b=im(b);w[a+36>>2]=b;c=a,d=Cj(b),w[c+44>>2]=d;c=a,d=Kg(w[a+36>>2]),u[c+53|0]=d;if(w[a+44>>2]>=9){hj(2049);M()}}function Vk(a){var b=0,c=0,d=0;b=w[a+8>>2];c=w[a+4>>2];if((b|0)!=(c|0)){d=b;b=(b-c|0)-6|0;w[a+8>>2]=(d+(((b>>>0)%6|0)-b|0)|0)-6}a=w[a>>2];if(a){zb(a)}}function pG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ec(b);d=Kb(c+13|0);w[d+8>>2]=0;w[d+4>>2]=c;w[d>>2]=c;e=a,f=Fb(d+12|0,b,c+1|0),w[e>>2]=f;return a|0}function PN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Cb(w[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function ON(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Cb(w[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Cn(a){if(w[a+480224>>2]==2){return+z[a+1074420>>2]*1e-4}return+z[a+24620>>2]*60/(+z[a+1074404>>2]*+(C(w[a+1074408>>2],w[a+1074416>>2])>>>0))}function ym(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=c*(d&1?a:1);if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function tH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=u[b|0];u[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function hH(a){a=a|0;var b=0;a=w[a+8>>2];if(!a){return 1}w[114256]=0;a=V(1850,a|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){return a|0}W(0)|0;Eb();M()}function PF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(wd(a,w[b+8>>2],f)){ql(b,c,d,e);return}a=w[a+8>>2];ob[w[w[a>>2]+20>>2]](a,b,c,d,e,f)}function tp(a){return(x[a+8|0]|x[a+9|0]<<8|(x[a+10|0]<<16|x[a+11|0]<<24))==1279545165&(x[a|0]|x[a+1|0]<<8|(x[a+2|0]<<16|x[a+3|0]<<24))==1297239878}function gL(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ob[w[w[a+32>>2]+d>>2]](b,a,w[d+w[a+36>>2]>>2]);continue}break}}function Vd(a,b){var c=0;c=w[w[b>>2]-12>>2];w[114256]=0;b=w[(b+c|0)+24>>2];c=w[114256];w[114256]=0;if((c|0)!=1){w[a>>2]=b;return a}W(0)|0;Eb();M()}function Tk(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){Bh(a,b);b=b<<2;c=a,d=Cb(w[a+4>>2],0,b)+b|0,w[c+4>>2]=d}return a|0}function $t(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function ed(a,b,c){a:{switch(b-1|0){case 0:return c?a- -8192|0:a;case 1:if(c){return a+24576|0}return a+16384|0;default:break a}}return a+32768|0}function gm(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(vm(a)){break a}if((ob[w[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=x[b+15|0]}jb=b+16|0;return c}function ei(a,b){var c=0;a:{if(!Au(b)|(x[b+1|0]^x[a+1|0])>>>0>1){break a}b=x[b+2|0];a=x[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function DV(a,b,c){var d=0;d=b>>31;a=a^d;zV(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);nb=mb;a=d^lb;b=a-d|0;nb=(d^nb)-((a>>>0<d>>>0)+d|0)|0;return b}function yl(a,b){a=a|0;b=b|0;a=Fh(a);w[a>>2]=74772;w[114256]=0;Q(2119,a+4|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){return a|0}R(P()|0);M()}function TR(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);if((b|0)<=2){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}A[((b<<2)+a|0)+4208>>2]=c;wv(a)}}function Pe(a,b,c,d){var e=0;e=C(b,c);a:{if(w[d+76>>2]<0){a=zm(a,e,d);break a}a=zm(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function PS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);if((b|0)<=5){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}A[((b<<2)+a|0)+4208>>2]=c;Hv(a)}}function KR(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);if((b|0)<=3){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}A[((b<<2)+a|0)+4208>>2]=c;uv(a)}}function GS(a,b,c){a=a|0;b=b|0;c=D(c);var d=D(0);if((b|0)<=4){a:{if(!(c<D(0))){d=D(1);if(c<=D(1)){break a}}c=d}A[((b<<2)+a|0)+4208>>2]=c;Dv(a)}}function kE(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(eq(a,b+8|0)){c=w[b+8>>2]==1179468868&(x[b+12|0]-1&255)>>>0<10}jb=b+80|0;return c|0}function ZH(){var a=0,b=0;a:{a=nc(461992);w[114256]=0;V(1838,a+8|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){w[a>>2]=69056;break a}R(P()|0);M()}}function XH(){var a=0,b=0;a:{a=nc(462008);w[114256]=0;V(1838,a+8|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){w[a>>2]=69212;break a}R(P()|0);M()}}function Cp(a){var b=0;if(!(Jb(a,10509,3)|(x[a+4|0]|x[a+5|0]<<8|(x[a+6|0]<<16|x[a+7|0]<<24))-2147483647>>>0<2147484072)){b=x[a+3|0]<6}return b}function yE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(Xb(a,d+8|0)){e=a;a=x[d+8|0];e=Ki(e,b,a>>>0<c>>>0?a:c)}jb=d+16|0;return e|0}function jn(a,b,c){var d=0;if(b>>>0<110){d=1<<b;a=(b>>>3&536870908)+a|0;if(c){b=w[a>>2]|d}else{b=w[a>>2]&(d^-1)}w[a>>2]=b;return}hi(7935);M()}function ge(a){var b=0;a=a*a;b=a*a;return D(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function XE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(Xb(a,d+8|0)){e=a;a=x[d+8|0];e=Li(e,b,a>>>0<c>>>0?a:c)}jb=d+16|0;return e|0}function WE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(Xb(a,d+8|0)){e=a;a=x[d+8|0];e=pq(e,b,a>>>0<c>>>0?a:c)}jb=d+16|0;return e|0}function VE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(Xb(a,d+8|0)){e=a;a=x[d+8|0];e=oq(e,b,a>>>0<c>>>0?a:c)}jb=d+16|0;return e|0}function Ll(a){var b=0,c=0;w[114256]=0;c=ea(1841)|0;b=w[114256];w[114256]=0;if((b|0)!=1){b=a;a=w[c>>2];w[b>>2]=a;aj(a);return}W(0)|0;Eb();M()}function Qp(a,b){a=a|0;b=b|0;var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){Wf(a,b);c=a,d=Cb(w[a+4>>2],0,b)+b|0,w[c+4>>2]=d}return a|0}function rH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;w[a+12>>2]=e;w[a+8>>2]=d-c;b=ag(a+12|0,a+8|0);jb=a+16|0;return w[b>>2]}function sT(a,b){a=a|0;b=b|0;var c=0,d=0;b=jb-16|0;jb=b;c=w[a+20>>2];d=w[c+8>>2];w[b+8>>2]=w[c+4>>2];w[b+12>>2]=d;Sv(a,b+8|0,0);jb=b+16|0}function mR(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=a;a=Hb(c,8295);b=Pb(b,a);if(u[a+11|0]<0){zb(w[a>>2])}w[b>>2]=82012;jb=c+16|0;return b|0}function XQ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=a;a=Hb(c,4376);b=Pb(b,a);if(u[a+11|0]<0){zb(w[a>>2])}w[b>>2]=82032;jb=c+16|0;return b|0}function xk(a,b,c){var d=0,e=0,f=0;d=b;b=a+58|0;d=d+b|0;e=x[d|0];f=e<<24>>24;if((f|0)>=0){v[((e<<1)+a|0)+22>>1]=c;u[d|0]=255;u[b+c|0]=f}}function Kt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){w[d>>2]=w[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function CM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=w[b>>2]+7&-8;w[c>>2]=b+16;d=a,e=xm(w[b>>2],w[b+4>>2],w[b+8>>2],w[b+12>>2]),B[d>>3]=e}function $s(a,b){a=a|0;b=b|0;w[a+20>>2]=0;w[a+24>>2]=b;w[a+12>>2]=0;w[a+4>>2]=4098;w[a+8>>2]=6;w[a+16>>2]=!b;Cb(a+32|0,0,40);Ll(a+28|0)}function Bb(a){var b=0,c=0;b=w[a+4>>2];a:{if(!b){break a}c=w[b+4>>2];w[b+4>>2]=c-1;if(c){break a}ob[w[w[b>>2]+8>>2]](b);Ib(b)}return a}function ol(a,b,c,d,e,f){var g=0,h=0;g=w[a+4>>2];h=g>>8;if(g&1){h=rl(w[d>>2],h)}a=w[a>>2];ob[w[w[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function FS(a){a=a|0;u[a+4202|0]=1;Dv(a);w[a+4244>>2]=0;w[a+4248>>2]=0;w[a+4228>>2]=0;w[a+4232>>2]=0;a=a+4252|0;w[a>>2]=0;w[a+4>>2]=0}function xo(a,b){var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){sh(a,b);b=b<<1;c=a,d=Cb(w[a+4>>2],0,b)+b|0,w[c+4>>2]=d}return a}function pu(a,b){a:{if(x[a+23|0]){a=1;if((b|0)!=255){break a}ha(9862,9008,1180,2220);M()}if((b|0)==255){return 0}a=b>>>0>10}return a}function mo(a,b){var c=0,d=0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){jl(a,b);b=b<<4;c=a,d=Cb(w[a+4>>2],0,b)+b|0,w[c+4>>2]=d}return a}function Xc(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;w[f+12>>2]=c;w[f+8>>2]=e;c=be(f,f+12|0);a=oj(a,b,d,w[f+8>>2]);Lc(c);jb=f+16|0;return a}function Fj(a){a=a|0;w[a>>2]=58952;Ll(a+4|0);w[a+24>>2]=0;w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;return a|0}function $e(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a>>2];c=w[a+4>>2]-d|0;if(c>>>0<b>>>0){Il(a,b-c|0);return}if(b>>>0<c>>>0){w[a+4>>2]=b+d}}function qm(a){a=a|0;var b=0;b=w[a+12>>2];if((b|0)==w[a+16>>2]){return ob[w[w[a>>2]+40>>2]](a)|0}w[a+12>>2]=b+1;return Md(u[b|0])|0}function Wb(a){var b=0,c=0;b=jb-16|0;jb=b;w[114256]=0;c=w[114256];w[114256]=0;if((c|0)!=1){km(a);jb=b+16|0;return a}W(0)|0;Eb();M()}function Kj(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=w[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=w[c>>2];w[a>>2]=d<<b;w[a+4>>2]=c<<b|d>>>32-b}function oL(a,b,c){a=a|0;b=b|0;c=c|0;if(gt(c)){w[114256]=0;zb(a);a=w[114256];w[114256]=0;if((a|0)==1){W(0)|0;Eb();M()}return}zb(a)}function Mj(a,b){var c=0,d=0;c=w[a+4>>2];a:{if(b>>>0<=31){d=w[a>>2];break a}b=b-32|0;d=c;c=0}w[a+4>>2]=c>>>b;w[a>>2]=c<<32-b|d>>>b}function zl(a,b){a=Fh(a);w[a>>2]=74752;w[114256]=0;Q(2119,a+4|0,b|0)|0;b=w[114256];w[114256]=0;if((b|0)!=1){return a}R(P()|0);M()}function sC(a){a=a|0;var b=0;w[a>>2]=75232;b=w[a+28>>2];if(b){w[a+32>>2]=b;zb(b)}b=w[a+12>>2];if(b){w[a+16>>2]=b;zb(b)}return a|0}function Si(a,b,c,d,e){var f=0,g=0;f=w[a+4>>2];g=f>>8;if(f&1){g=rl(w[c>>2],g)}a=w[a>>2];ob[w[w[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function rN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Sm(a+8|0,b,c,d,2);if(a>>>0<=15){a=x[a+35744|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function qN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Sm(a+8|0,b,c,d,3);if(a>>>0<=42){a=x[a+35696|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function MH(a){a=a|0;var b=0,c=0;b=w[w[a>>2]>>2];c=w[b+8>>2];a=w[b+4>>2];b=w[b>>2]+(c>>1)|0;if(c&1){a=w[a+w[b>>2]>>2]}ob[a|0](b)}function EE(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(lf(a,b+8|0)){c=w[b+8>>2]==810369604&x[b+12|0]<4}jb=b+16|0;return c|0}function js(a,b,c,d,e,f){a=ob[w[w[a+8>>2]+4>>2]](a+8|0)|0;a=nj(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){w[b>>2]=((a|0)/12|0)%12}}function gs(a,b,c,d,e,f){a=ob[w[w[a+8>>2]+4>>2]](a+8|0)|0;a=lj(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){w[b>>2]=((a|0)/12|0)%12}}function YG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=FV(0-FV(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function DH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){w[d>>2]=u[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){u[d|0]=x[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function Cf(a){var b=0;if(u[a+47|0]<0){zb(w[a+36>>2])}b=w[a+24>>2];if(b){w[a+28>>2]=b;zb(b)}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}}function rM(a){a=a|0;var b=0;if((ob[w[w[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=w[a+12>>2];w[b+12>>2]=a+1;return Md(u[a|0])|0}function ef(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}ds(a,b);a=a+1|0;continue}}}function VF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(wd(a,w[b+8>>2],0)){sl(b,c,d);return}a=w[a+8>>2];ob[w[w[a>>2]+28>>2]](a,b,c,d)}function Nh(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}wj(a,b);a=a+4|0;continue}}}function wt(a){w[a>>2]=59112;Ll(a+4|0);w[a+24>>2]=0;w[a+28>>2]=0;w[a+16>>2]=0;w[a+20>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;return a}function ks(a,b,c,d,e,f){a=ob[w[w[a+8>>2]>>2]](a+8|0)|0;a=nj(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){w[b>>2]=((a|0)/12|0)%7}}function hs(a,b,c,d,e,f){a=ob[w[w[a+8>>2]>>2]](a+8|0)|0;a=lj(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){w[b>>2]=((a|0)/12|0)%7}}function gn(a){a=a|0;var b=0;a:{while(1){if(x[b+35760|0]==(a|0)){break a}b=b+1|0;if((b|0)!=43){continue}break}b=0}return b|0}function cC(a){a=a|0;var b=0;w[a>>2]=75232;b=w[a+28>>2];if(b){w[a+32>>2]=b;zb(b)}b=w[a+12>>2];if(b){w[a+16>>2]=b;zb(b)}zb(a)}function UM(a){a=a|0;var b=0;if(!a){return-2}b=w[a+28>>2];if(!b){return 0}ob[w[a+36>>2]](w[a+40>>2],b);w[a+28>>2]=0;return 0}function xw(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function Wq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){w[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Jo(a){a=a|0;w[a+700>>2]=0;v[a+862>>1]=0;w[a+688>>2]=0;w[a>>2]=0;w[a+4>>2]=0;w[a+8>>2]=0;w[a+12>>2]=0;w[a+16>>2]=0}function ir(a){var b=0;b=jb-16|0;jb=b;w[b+8>>2]=a;a=jb-16|0;jb=a;w[a+8>>2]=w[b+8>>2];jb=a+16|0;jb=b+16|0;return w[a+8>>2]}function QE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=b-(u[a+11|0]<0?w[a>>2]:a)|0;Vq(a,b,c,d);return b+(u[a+11|0]<0?w[a>>2]:a)|0}function Pl(a,b,c){c=w[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function AO(a,b){a=a|0;b=b|0;var c=0;if(b>>>0>=357913942){Mb(a);M()}c=C(b,12);b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function $i(a,b){a=a|0;b=b|0;var c=0;if((b|0)<0){Mb(a);M()}b=(b-1>>>5|0)+1|0;c=Kb(b<<2);w[a+8>>2]=b;w[a+4>>2]=0;w[a>>2]=c}function zC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ob[w[w[a>>2]+24>>2]](a)|0;d=a-b|0;return(a>>>0>b>>>0?c>>>0>d>>>0?d:c:0)|0}function rt(a){var b=0;b=w[a+12>>2];if((b|0)==w[a+16>>2]){return ob[w[w[a>>2]+40>>2]](a)|0}w[a+12>>2]=b+4;return w[b>>2]}function dp(a){var b=0;b=w[a+24>>2];if(b){zb(b)}b=w[a+12>>2];if(b){w[a+16>>2]=b;zb(b)}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}}function Lc(a){a:{a=w[a>>2];if(a){w[114256]=0;Yl(a);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function JL(a){a=a|0;var b=0;if((ob[w[w[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=w[a+12>>2];w[b+12>>2]=a+4;return w[a>>2]}function Bo(a,b,c,d,e,f,g){u[a+17|0]=g;u[a+16|0]=f;w[a+12>>2]=e;w[a+8>>2]=d;w[a+4>>2]=c;w[a>>2]=b;if(d){zo(a,1);zo(a,0)}}function Ao(a,b,c,d,e,f,g){u[a+17|0]=g;u[a+16|0]=f;w[a+12>>2]=e;w[a+8>>2]=d;w[a+4>>2]=c;w[a>>2]=b;if(d){yo(a,1);yo(a,0)}}function Tl(a,b,c){c=x[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=x[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function xF(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ob[a|0](h|b,c,d,e,b|f,g)|0}function de(a,b,c){a:{if(c){w[114256]=0;Kt(a,b,c);a=w[114256];w[114256]=0;if((a|0)==1){break a}}return}W(0)|0;Eb();M()}function pp(a){var b=0;if(!(Jb(a,9565,3)|x[a+3|0]>31|(u[a+27|0]<0|x[a+32|0]>64))){b=(x[a+33|0]-1&255)>>>0<32}return b}function er(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!(x[a+120|0]|b>>>0>30)){u[a+120|0]=1;break a}a=br(b)}jb=c+16|0;return a}function ZD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;el(a,b,c);a=w[a+16>>2];d=a-b|0;return(a>>>0>b>>>0?c>>>0>d>>>0?d:c:0)|0}function Ms(a,b,c,d,e,f,g,h,i){w[a>>2]=b;w[a+4>>2]=c;w[a+8>>2]=d;w[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function wE(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[b+11|0];d=c<<24>>24<0;uk(1,a,32,d?w[b>>2]:b,d?w[b+4>>2]:c);return a|0}function vE(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[b+11|0];d=c<<24>>24<0;uk(1,a,64,d?w[b>>2]:b,d?w[b+4>>2]:c);return a|0}function oT(a){a=a|0;var b=0,c=0;w[w[a+20>>2]>>2]=a;c=w[a+12>>2];b=w[c>>2];w[a+4>>2]=b;if(b){w[b+8>>2]=a}w[c>>2]=a}function du(a,b,c){var d=0,e=0,f=0;e=c*c;B[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;B[b>>3]=d*d+((c+c)*d+(c*c-e))}function xt(a,b){a=a|0;b=b|0;var c=0;c=w[a>>2];a:{if(!c){break a}if(!Kc(Bt(c,b),-1)){break a}w[a>>2]=0}return a|0}function ES(a){a=a|0;w[a+4244>>2]=0;w[a+4248>>2]=0;w[a+4228>>2]=0;w[a+4232>>2]=0;a=a+4252|0;w[a>>2]=0;w[a+4>>2]=0}function wN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;_u(a+8|0,b,c,d,e);w[a+88>>2]=82720;w[a>>2]=82632;return a|0}function kV(a,b){a=a|0;b=b|0;u[b+38|0]=x[a+202|0];u[b+39|0]=x[a+203|0];u[b+40|0]=x[a+204|0];u[b+41|0]=x[a+205|0]}function WK(a,b){a=a|0;b=b|0;var c=0,d=0;ob[w[w[a>>2]+24>>2]](a)|0;b=im(b);w[a+36>>2]=b;c=a,d=Kg(b),u[c+44|0]=d}function Th(a,b){a:{w[114256]=0;U(1594,a|0,b|0,1);a=w[114256];w[114256]=0;if((a|0)!=1){break a}W(0)|0;Eb();M()}}function Sd(a){a:{a=w[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Pr(a,b){var c=0;c=jb-16|0;jb=c;w[c+8>>2]=w[a>>2];w[c+8>>2]=w[c+8>>2]+(b<<2);jb=c+16|0;return w[c+8>>2]}function OK(a,b){a=a|0;b=b|0;var c=0,d=0;ob[w[w[a>>2]+24>>2]](a)|0;b=dm(b);w[a+36>>2]=b;c=a,d=Kg(b),u[c+44|0]=d}function wd(a,b,c){if(!c){return w[a+4>>2]==w[b+4>>2]}if((a|0)==(b|0)){return 1}return!Qe(w[a+4>>2],w[b+4>>2])}function Mw(a,b){a=a|0;b=b|0;if(b>>>0>255){return 17256}a=w[((b<<2)+a|0)+900380>>2];return(a?a+492|0:17256)|0}function yh(a,b){var c=0;if(b>>>0>=715827883){Mb(a);M()}c=C(b,6);b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function is(a,b,c,d,e){b=pe(b,c,d,e,4);if(!(x[d|0]&4)){w[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function fs(a,b,c,d,e){b=oe(b,c,d,e,4);if(!(x[d|0]&4)){w[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Ct(a){var b=0;b=w[a+12>>2];if((b|0)==w[a+16>>2]){return ob[w[w[a>>2]+36>>2]](a)|0}return Md(u[b|0])}function hr(a,b){w[114256]=0;U(1594,a|0,b<<2,4);a=w[114256];w[114256]=0;if((a|0)!=1){return}W(0)|0;Eb();M()}function Pv(a){a=a|0;var b=0;b=w[a>>2];if(b){ob[w[w[b>>2]+8>>2]](b);w[a>>2]=0}w[a+8>>2]=w[a+4>>2];ls(a+4|0)}function Bh(a,b){var c=0;if(b>>>0>=1073741824){Mb(a);M()}c=b<<2;b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function lu(a,b){var c=0;if(b>>>0>=536870912){Mb(a);M()}c=b<<3;b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function jl(a,b){var c=0;if(b>>>0>=268435456){Mb(a);M()}c=b<<4;b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function Vr(a,b){var c=0;c=jb-16|0;jb=c;w[c+8>>2]=w[a>>2];w[c+8>>2]=w[c+8>>2]+b;jb=c+16|0;return w[c+8>>2]}function xC(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(lf(a,b+8|0)){c=Cp(b+8|0)}jb=b+16|0;return c|0}function tr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;w[e>>2]=c;w[h>>2]=f;return 3}function st(a){var b=0;b=w[a+12>>2];if((b|0)==w[a+16>>2]){return ob[w[w[a>>2]+36>>2]](a)|0}return w[b>>2]}function qG(a){a=a|0;a=jb-16|0;jb=a;if(Qa(a+12|0,4)|0){Ti(w[114084],8441);M()}jb=a+16|0;return w[a+12>>2]}function Kp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=w[c>>2];return ob[w[w[a>>2]+28>>2]](a,d,b,w[c+4>>2]-d|0)|0}function IK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=w[a+16>>2];d=a-b|0;return(a>>>0>b>>>0?c>>>0>d>>>0?d:c:0)|0}function nM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=w[a+8>>2];d=a-b|0;return(a>>>0>b>>>0?c>>>0>d>>>0?d:c:0)|0}function Yl(a){a=a|0;var b=0;b=w[114126];if(a){w[114126]=(a|0)==-1?456392:a}return((b|0)==456392?-1:b)|0}function ul(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Db(a);if(d>>>0<b>>>0){vl(a,b-d|0,c);return}Cl(a,Qb(a),b)}function kM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[w[w[a>>2]+16>>2]](a,b,c,d,e,f)|0}function iM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[w[w[a>>2]+24>>2]](a,b,c,d,e,f)|0}function eM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[w[w[a>>2]+28>>2]](a,b,c,d,e,f)|0}function bM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[w[w[a>>2]+44>>2]](a,b,c,d,e,f)|0}function QL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[w[w[a>>2]+20>>2]](a,b,c,d,e,f)|0}function OH(){if(x[460412]){return w[115102]}Ic(460404,yr());u[460412]=1;w[115102]=460404;return 460404}function _i(){var a=0;w[114256]=0;a=w[114256];w[114256]=0;if((a|0)!=1){return w[15418]}W(0)|0;Eb();M()}function Zi(){var a=0;w[114256]=0;a=w[114256];w[114256]=0;if((a|0)!=1){return w[15804]}W(0)|0;Eb();M()}function Wf(a,b){a=a|0;b=b|0;var c=0;if((b|0)<0){Mb(a);M()}c=Kb(b);w[a>>2]=c;w[a+4>>2]=c;w[a+8>>2]=b+c}function zr(a,b,c){var d=0;d=jb-16|0;jb=d;a:{if((a|0)==(b|0)){u[b+120|0]=0;break a}hr(b,c)}jb=d+16|0}function Tg(a){var b=0;b=w[a+28>>2];w[a+28>>2]=0;if(b){kd(b)}Bb(a+12|0);if(u[a+11|0]<0){zb(w[a>>2])}}function Ob(a,b){a=a|0;b=b|0;var c=0;c=w[b>>2];sf(a,c,w[b+4>>2]-c|0);a=w[a+4>>2];nb=a>>31;return a|0}function YT(a,b){a=a|0;b=b|0;return D((b|0)<=3?D(D(x[(a+b|0)+4264|0])*D(.003921568859368563)):D(0))}function YS(a){a=a|0;var b=0;w[a>>2]=78784;b=w[a+4260>>2];if(b){w[a+4264>>2]=b;zb(b)}return Oc(a)|0}function Mf(a){var b=0;b=w[a+44>>2];if(b){w[a+48>>2]=b;zb(b)}b=w[a+32>>2];if(b){w[a+36>>2]=b;zb(b)}}function qF(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ob[a|0](b,c,d,e,f,g)|0}function XB(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(_k(a,b)){c=tp(b)}jb=b+16|0;return c|0}
function sh(a,b){var c=0;if((b|0)<0){Mb(a);M()}c=b<<1;b=Kb(c);w[a>>2]=b;w[a+4>>2]=b;w[a+8>>2]=b+c}function Ib(a){var b=0;a:{b=a+8|0;if(w[b>>2]){if((Ml(b)|0)!=-1){break a}}ob[w[w[a>>2]+16>>2]](a)}}function Cl(a,b,c){var d=0;d=jb-16|0;jb=d;He(a,c);u[d+15|0]=0;Sc(b+c|0,d+15|0);jb=d+16|0;return a}function OF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(wd(a,w[b+8>>2],f)){ql(b,c,d,e)}}
function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[w[w[b>>2]+16>>2]](a,b,w[c+8>>2],w[c+12>>2],0,d)}function qv(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;w[b>>2]=a;a=w[14612];Nj(a,13564,b);wf(a);jb=b+16|0}
function cF(a,b){a=a|0;b=b|0;w[a+8>>2]=0;w[a>>2]=0;w[a+4>>2]=0;if(b){jl(a,b);il(a,b)}return a|0}function Rv(a,b){A[w[a+20>>2]+144>>2]=D(D((b>>>0>=127?127:b)>>>0)*D(-.007874015718698502))+D(1)}function hq(a){var b=0;if(!(Jb(a,23332,20)|(x[a+25|0]-9&255)>>>0<248)){b=u[a+47|0]>=0}return b}function $m(a){a=a|0;var b=0;w[a>>2]=78784;b=w[a+4260>>2];if(b){w[a+4264>>2]=b;zb(b)}zb(Oc(a))}function $L(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[w[w[b>>2]+16>>2]](a,b,c,d,e,f)}function km(a){var b=0;b=a;a=0;while(1){if((a|0)!=3){w[(a<<2)+b>>2]=0;a=a+1|0;continue}break}}function ff(a){var b=0;b=jb-16|0;jb=b;a=w[Eg(b+8|0,Qb(a)+(Db(a)<<2)|0)>>2];jb=b+16|0;return a}function dG(a,b,c){a=a|0;b=b|0;c=c|0;if(Kc(a,w[b+4>>2])){a=w[b>>2]==(c|0)}else{a=0}return a|0}function UL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[w[w[a>>2]+16>>2]](a,b,c,d,e)|0}function TL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[w[w[a>>2]+24>>2]](a,b,c,d,e)|0}function ur(a){a=a|0;var b=0;w[a>>2]=65036;b=w[a+8>>2];if(!(!b|!x[a+12|0])){zb(b)}return a|0}function eo(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;w[c+12>>2]=x[b|0];tk(a,c+12|0);jb=c+16|0}function OL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ob[w[w[a>>2]+32>>2]](a,b,c,d,e)|0}function As(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(w[b>>2]){continue}break}return b-a>>2}function ag(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ht(b,a);jb=c+16|0;return(d?b:a)|0}function zF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=ob[a|0](b,c,d,e)|0;kb=nb;return a|0}function ft(a){var b=0;b=w[a>>2];if(b){if(!Kc(Ct(b),-1)){return!w[a>>2]}w[a>>2]=0}return 1}function et(a){var b=0;b=w[a>>2];if(b){if(!Kc(st(b),-1)){return!w[a>>2]}w[a>>2]=0}return 1}function cj(a,b,c){var d=0;a=ir(a);d=ir(b);b=d-a|0;if((a|0)!=(d|0)){hc(c,a,b)}return b+c|0}function _j(a,b){if(b){_j(a,w[b>>2]);_j(a,w[b+4>>2]);if(u[b+27|0]<0){zb(w[b+16>>2])}zb(b)}}function _f(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Hi(a,b){if(b){Hi(a,w[b>>2]);Hi(a,w[b+4>>2]);if(u[b+31|0]<0){zb(w[b+20>>2])}zb(b)}}function Gi(a,b){if(b){Gi(a,w[b>>2]);Gi(a,w[b+4>>2]);if(u[b+31|0]<0){zb(w[b+20>>2])}zb(b)}}function rF(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ob[a|0](b,c,d,e,f,g)}function ku(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;w[a>>2]=d;w[a+4>>2]=b-C(c,d)}function jk(a,b){var c=0;c=w[a>>2];w[a>>2]=b;if(c){a=w[c>>2];w[c>>2]=0;if(a){zb(a)}zb(c)}}function iv(a){a=a|0;var b=0;w[a>>2]=82052;b=w[a+4>>2];if(b){zb(b);w[a+4>>2]=0}return a|0}function iA(a){a=a|0;a=w[20842];w[20842]=0;if(a){zb(a)}Mk(0);if(u[83359]<0){zb(w[20837])}}function hC(a){a=a|0;var b=0;w[a>>2]=75288;b=w[a+4>>2];if(b){w[a+8>>2]=b;zb(b)}return a|0}function DT(a){a=a|0;var b=0;b=B[a+4264>>3]*+z[w[a+16>>2]+1074376>>2];B[a+4256>>3]=b-K(b)}function $l(a,b,c,d){var e=0;e=jb-16|0;jb=e;w[e+12>>2]=d;a=oj(a,b,c,d);jb=e+16|0;return a}function vr(){var a=0;a=nc(461728);u[a+12|0]=0;w[a+8>>2]=0;w[a>>2]=65036;w[a+8>>2]=65088}function mh(a){var b=0;if(u[a+23|0]<0){zb(w[a+12>>2])}b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}}function hf(a){var b=0;b=jb-16|0;jb=b;a=w[Eg(b+8|0,Qb(a)+Db(a)|0)>>2];jb=b+16|0;return a}function FV(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function YK(a){a=a|0;var b=0;b=w[a+4>>2];return(ob[w[w[b>>2]+20>>2]](b)|0)+w[a+12>>2]|0}function sI(){var a=0;a=nc(461832);w[a+8>>2]=46;w[a+12>>2]=44;w[a>>2]=66208;Wb(a+16|0)}function ji(a,b){if(!(u[b+872|0]&1&w[a+480180>>2]==8)){mn(a,b,0);mn(a,b,1);mn(a,b,2)}}
function Bs(a,b){var c=0;c=jb-16|0;jb=c;w[c+12>>2]=b;a=Es(a,6996,b);jb=c+16|0;return a}function dn(a){a=a|0;var b=0;b=w[a+4208>>2];if(b){w[a+4212>>2]=b;zb(b)}return Oc(a)|0}function bJ(a,b,c){a=a|0;b=b|0;c=c|0;c=qm(w[b>>2])<<24;w[a+4>>2]=w[b>>2];u[a|0]=c>>24}function Zt(a){var b=0;b=Xt(w[a>>2]-1|0);if(!b){a=Xt(w[a+4>>2]);b=a?a+32|0:0}return b}function VG(a){a=a|0;a=460856;while(1){a=Gb(a-12|0);if((a|0)!=460688){continue}break}}function TG(a){a=a|0;a=461032;while(1){a=$b(a-12|0);if((a|0)!=460864){continue}break}}function Rf(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function RG(a){a=a|0;a=461328;while(1){a=Gb(a-12|0);if((a|0)!=461040){continue}break}}function PG(a){a=a|0;a=461632;while(1){a=$b(a-12|0);if((a|0)!=461344){continue}break}}function NS(a){a=a|0;var b=0;b=w[a+4256>>2];if(b){w[a+4260>>2]=b;zb(b)}return Oc(a)|0}function NG(a){a=a|0;a=461672;while(1){a=Gb(a-12|0);if((a|0)!=461648){continue}break}}function MM(a,b){a=a|0;b=b|0;a=w[a>>2];b=w[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function LM(a,b){a=a|0;b=b|0;a=y[a>>1];b=y[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function LG(a){a=a|0;a=461704;while(1){a=$b(a-12|0);if((a|0)!=461680){continue}break}}function zH(a,b){a=a|0;b=b|0;if((b|0)>=0){b=w[_i()+((b&255)<<2)>>2]}return b<<24>>24}function xH(a,b){a=a|0;b=b|0;if((b|0)>=0){b=w[Zi()+((b&255)<<2)>>2]}return b<<24>>24}function GU(a,b){a=a|0;b=b|0;a=a+24|0;if((a|0)!=(b|0)){Uk(a,w[b>>2],w[b+4>>2])}ni(a)}function $B(a){a=a|0;var b=0;w[a>>2]=75288;b=w[a+4>>2];if(b){w[a+8>>2]=b;zb(b)}zb(a)}function ps(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[w[w[a>>2]+32>>2]](a,b,c,d)|0}function pR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kv(a,b,c,d,0,0,0,0,e)|0}function os(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[w[w[a>>2]+48>>2]](a,b,c,d)|0}function Cs(a){return(a|0)!=0&(a|0)!=61544&(a|0)!=61568&(a|0)!=460168&(a|0)!=460192}function xS(a){a=a|0;u[a+4202|0]=1;w[a+4256>>2]=w[w[a+16>>2]+24620>>2];Bv(a);Av(a)}function iO(a){a=a|0;a=w[a+24>>2];return If(w[a+484360>>2]+(x[a+484376|0]<<5)|0)|0}function WT(a){a=a|0;u[a+4202|0]=1;w[a+4232>>2]=w[w[a+16>>2]+24620>>2];Yj(a);Vv(a)}function zd(a){var b=0;b=jb-16|0;jb=b;a=w[Eg(b+8|0,Qb(a))>>2];jb=b+16|0;return a}function uF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ob[a|0](b,c,d)|0;kb=nb;return a|0}function Yg(a){a=a|0;var b=0;b=w[a+4208>>2];if(b){w[a+4212>>2]=b;zb(b)}zb(Oc(a))}function Fv(a){a=a|0;var b=0;b=w[a+4256>>2];if(b){w[a+4260>>2]=b;zb(b)}zb(Oc(a))}function yK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-16|0;jb=b;ts(a,c,d);jb=b+16|0}function tF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[a|0](b,c,d,e,f)}function hu(){var a=0;a=jb-16|0;w[a+8>>2]=0;w[a+12>>2]=1048576;return B[a+8>>3]}function LH(a,b,c){a=a|0;b=b|0;c=c|0;return(w[(c<<2)+65088>>2]&b)!=0&c>>>0<=127}function BK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-16|0;jb=b;ot(a,c,d);jb=b+16|0}function At(a,b){a=a|0;b=b|0;return w[b+8>>2]==w[a+8>>2]&w[a+12>>2]==w[b+12>>2]}function wG(a){a=a|0;if(!x[460672]){zg(460660,66440);u[460672]=1}return 460660}function wF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[a|0](b,c,d,e)|0}function cS(a,b){a=a|0;b=b|0;return D((b|0)<=12?A[((b<<2)+a|0)+4208>>2]:D(0))}
function _M(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return Du(a-88|0,b,c,d,e)|0}function Nj(a,b,c){var d=0;d=jb-16|0;jb=d;w[d+12>>2]=c;Tt(a,b,c,0,0);jb=d+16|0}function IG(a){a=a|0;if(!x[460576]){zg(460564,66284);u[460576]=1}return 460564}function EG(a){a=a|0;if(!x[460608]){zg(460596,66320);u[460608]=1}return 460596}function AG(a){a=a|0;if(!x[460640]){zg(460628,66356);u[460640]=1}return 460628}function yG(a){a=a|0;if(!x[460656]){Hb(460644,5183);u[460656]=1}return 460644}function aG(a,b,c){a=a|0;b=b|0;c=c|0;if(!x[462280]){u[462280]=1}Sh(a,c,83324)}function WF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(wd(a,w[b+8>>2],0)){sl(b,c,d)}}function Nw(a,b){a=a|0;b=b|0;return(b>>>0>=4e3?17256:((b<<5)+a|0)+946304|0)|0}function KG(a){a=a|0;if(!x[460560]){Hb(460548,1755);u[460560]=1}return 460548}function GG(a){a=a|0;if(!x[460592]){Hb(460580,9479);u[460592]=1}return 460580}function CG(a){a=a|0;if(!x[460624]){Hb(460612,9299);u[460624]=1}return 460612}function zk(a,b){a=a|0;b=b|0;if(w[a+4>>2]-w[a>>2]>>5>>>0>b>>>0){u[a+16|0]=b}}function zS(a,b){a=a|0;b=b|0;return D((b|0)<=4?A[((b<<2)+a|0)+4220>>2]:D(0))}function vU(a,b){a=a|0;b=b|0;b=w[b>>2];w[a+36>>2]=b>>>0>=65535?65535:b;ii(a)}function of(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=ht(a,b);jb=c+16|0;return d?b:a}function lS(a,b){a=a|0;b=b|0;return D((b|0)<=1?A[((b<<2)+a|0)+4208>>2]:D(0))}function aT(a,b){a=a|0;b=b|0;return D((b|0)<=6?A[((b<<2)+a|0)+4208>>2]:D(0))}function Ur(a,b){var c=0,d=0;Hc(a,ej(b));b=w[Lh(b)>>2];c=Lh(a),d=b,w[c>>2]=d}function UR(a,b){a=a|0;b=b|0;return D((b|0)<=2?A[((b<<2)+a|0)+4208>>2]:D(0))}function Ss(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=it(a,b);jb=c+16|0;return d?b:a}function QS(a,b){a=a|0;b=b|0;return D((b|0)<=5?A[((b<<2)+a|0)+4208>>2]:D(0))}function Og(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=it(b,a);jb=c+16|0;return d?b:a}function LR(a,b){a=a|0;b=b|0;return D((b|0)<=3?A[((b<<2)+a|0)+4208>>2]:D(0))}function HS(a,b){a=a|0;b=b|0;return D((b|0)<=4?A[((b<<2)+a|0)+4208>>2]:D(0))}function uj(a,b,c,d,e,f,g,h){return ob[w[w[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function uI(){var a=0;a=nc(461808);v[a+8>>1]=11310;w[a>>2]=66168;Wb(a+12|0)}function mt(a,b,c,d,e,f,g,h){return ob[w[w[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function jL(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){Jq(a,c);return}Hb(a,4132)}function qw(a,b){a=a|0;b=b|0;return(b>>>0>15?63:u[w[a+88>>2]+b|0])<<24>>24}function pw(a,b){a=a|0;b=b|0;return(b>>>0>42?63:u[w[a+84>>2]+b|0])<<24>>24}function fo(a){if(u[a+23|0]<0){zb(w[a+12>>2])}if(u[a+11|0]<0){zb(w[a>>2])}}function Xh(a,b,c){w[a+8>>2]=b;w[a+12>>2]=c;w[a>>2]=0;w[a+4>>2]=0;return a}function Xd(a){if(u[a+31|0]<0){zb(w[a+20>>2])}if(u[a+11|0]<0){zb(w[a>>2])}}function QM(a){a=a|0;a:{if(!a){break a}wu(a);if(w[a+80>>2]){break a}zb(a)}}function HH(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=w[_i()+(b<<2)>>2]}return b|0}function FH(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=w[Zi()+(b<<2)>>2]}return b|0}function uf(a,b){var c=0;c=w[b+4>>2];w[a>>2]=w[b>>2];w[a+4>>2]=c;return a}function pf(a,b,c){a=a|0;b=b|0;c=c|0;return ob[w[w[a>>2]+12>>2]](a,b,c)|0}function nT(a,b){a=a|0;b=b|0;a=w[a+20>>2];u[a+24|0]=x[a+24|0]&253|(b?2:0)}function mm(a,b,c){a=a|0;b=b|0;c=c|0;return ob[w[w[a>>2]+48>>2]](a,b,c)|0}function aM(a,b,c){a=a|0;b=b|0;c=c|0;return ob[w[w[a>>2]+32>>2]](a,b,c)|0}function zi(a){a=a|0;var b=0;b=w[a+20>>2];if(b){zb(b+-64|0)}w[a+20>>2]=0}function It(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Xh(a,-1,-1)}function jN(a){a=a|0;return+(+z[w[a+32>>2]+480240>>2]*152587890625e-16)}function iN(a){a=a|0;return+(+z[w[a-56>>2]+480240>>2]*152587890625e-16)}function Ih(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;w[e>>2]=c;return 3}function vd(){var a=0;a=Ye(ba(4)|0);w[a>>2]=74624;ka(a|0,74732,68);M()}function pl(a,b,c){if(!(w[a+28>>2]==1|w[a+4>>2]!=(b|0))){w[a+28>>2]=c}}function ke(a,b){if(b){ke(a,w[b>>2]);ke(a,w[b+4>>2]);fo(b+16|0);zb(b)}}function jm(a,b,c){var d=0;d=jb-16|0;jb=d;ot(a,b,c);jb=d+16|0;return a}function eL(a){a=a|0;w[a+16>>2]=w[a+16>>2]|1;if(u[a+20|0]&1){Ca();M()}}function df(a,b){a=a|0;b=b|0;u[a|0]=2;u[a+1|0]=3;u[a+2|0]=0;u[a+3|0]=4}function AF(a,b,c){a=a|0;b=b|0;c=c|0;a=ob[a|0](b,c)|0;kb=nb;return a|0}function kd(a){var b=0;if(a){b=w[a>>2];if(b){w[a+4>>2]=b;zb(b)}zb(a)}}function Mh(a,b,c){a=a|0;b=b|0;c=c|0;a=Zf(a,b);Zf(a+4|0,c);return a|0}function MF(a){a=a|0;if(!a){return 0}return(tl(a,74216,74360)|0)!=0|0}function Ld(a,b,c){return(w[w[a+8>>2]+((c&255)<<2)>>2]&b)!=0&(c|0)>=0}function vF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[a|0](b,c,d)|0}function Xf(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function VT(a,b,c){a=a|0;b=b|0;c=c|0;w[a+4>>2]=b+4268;w[a>>2]=b+4260}function NH(a){a=a|0;var b=0;b=w[115104]+1|0;w[115104]=b;w[a+4>>2]=b}function JI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Ol(a,f)}function BM(a,b){a=a|0;b=b|0;if(!w[114256]){w[114256]=a;w[114257]=b}}function rw(a,b){a=a|0;b=b|0;return x[w[a+88>>2]+b|0]!=63&b>>>0<=15}function SU(a,b){a=a|0;b=b|0;return x[w[a+84>>2]+b|0]!=63&b>>>0<=42}function PM(a){a=a|0;var b=0;b=w[a+100>>2];w[a+100>>2]=0;return b|0}function Cq(a,b,c,d,e,f,g){return Ka(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function ws(a,b,c){a=a|0;b=b|0;c=c|0;return Rh(0,a,b,c?c:460220)|0}function Zn(a){var b=0;b=w[a+12>>2];if(b){w[a+16>>2]=b;zb(b)}ui(a)}function CH(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function gN(a){a=a|0;return+(+w[w[a+32>>2]+1074444>>2]*.00390625)}function fN(a){a=a|0;return+(+w[w[a-56>>2]+1074444>>2]*.00390625)}function dL(a){a=a|0;a=w[a+4>>2];return ob[w[w[a>>2]+12>>2]](a)|0}function be(a,b){var c=0,d=0;c=a,d=Yl(w[b>>2]),w[c>>2]=d;return a}function bL(a){a=a|0;a=w[a+4>>2];return ob[w[w[a>>2]+16>>2]](a)|0}function Ch(a,b,c,d,e){b=La(a|0,b|0,c|0,d|0,e|0)|0;nb=kb;return b}function uG(a){a=a|0;var b=0,c=0;b=a,c=Cc(),w[b>>2]=c;return a|0}function hL(a){a=a|0;a=w[a+4>>2];return ob[w[w[a>>2]+8>>2]](a)|0}function vR(a,b){a=a|0;b=b|0;if(!b){return 3}w[b>>2]=a;return 0}function tj(a,b){a=a|0;b=b|0;return ob[w[w[a>>2]+44>>2]](a,b)|0}function nc(a){w[a+4>>2]=0;w[a>>2]=71656;w[a>>2]=66496;return a}function am(a,b){a=a|0;b=b|0;return(Wd(a)|0)!=0|(a|32)-97>>>0<6}function Xw(a,b){a=a|0;b=b|0;a=zl(a,b);w[a>>2]=74908;return a|0}function Xs(a,b){a=a|0;b=b|0;$s(a,b);w[a+72>>2]=0;w[a+76>>2]=-1}function Vl(a,b){a=a|0;b=b|0;return ob[w[w[a>>2]+12>>2]](a,b)|0}function Qw(a,b){a=a|0;b=b|0;a=zl(a,b);w[a>>2]=74852;return a|0}function Lv(a){a=a|0;return D(D(D(A[a+4228>>2]*D(198))+D(-99)))}function Kr(a){Ar(a);if(w[a>>2]){Ir(a);zr(Uf(a),w[a>>2],Tf(a))}}function Dm(a){var b=0;b=jb-16|0;A[b+12>>2]=a;return A[b+12>>2]}function BR(a,b){a=a|0;b=b|0;a=zl(a,b);w[a>>2]=74960;return a|0}function $f(a,b){a=a|0;b=b|0;return ob[w[w[a>>2]+28>>2]](a,b)|0}function br(a){if(a>>>0>1073741823){vd();M()}return bt(a<<2,4)}function VI(a,b,c){a=a|0;b=b|0;c=c|0;Sh(a,rt(w[b>>2]),w[b>>2])}function lG(a,b,c){a=a|0;b=b|0;c=c|0;return Tq(a,b,c,ec(c))|0}function iu(a){var b=0;b=jb-16|0;B[b+8>>3]=a;return B[b+8>>3]}function Tj(a,b){var c=0;c=w[a>>2];w[a>>2]=b;if(c){zb(Df(c))}}function Pq(a,b){if(Db(a)>>>0<=b>>>0){Bf();M()}return Rb(a,b)}function Mt(a,b){b=w[b>>2];w[a>>2]=b;w[a+4>>2]=b>>31;return a}function yF(a,b){a=a|0;b=b|0;a=ob[a|0](b)|0;kb=nb;return a|0}function wj(a,b){var c=0;c=w[a>>2];w[a>>2]=w[b>>2];w[b>>2]=c}function ve(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function mN(a){a=a|0;return+(65536/+z[w[a+32>>2]+480244>>2])}function lt(a){a=a|0;w[a>>2]=59272;Gb(a+32|0);return wc(a)|0}function ld(a){a=a|0;return y[w[w[a+48>>2]+12>>2]+480188>>1]}function lN(a){a=a|0;return+(65536/+z[w[a-56>>2]+480244>>2])}function Xt(a){return u[(C(0-a&a,124511785)>>>27|0)+58416|0]}function LT(a){a=a|0;w[a+32>>2]=0;w[a+28>>2]=w[a+28>>2]&-7|2}function Kh(a){if((Ml(a+4|0)|0)==-1){ob[w[w[a>>2]+8>>2]](a)}}function th(a,b){if(b){th(a,w[b>>2]);th(a,w[b+4>>2]);zb(b)}}function qg(a,b){if(b){qg(a,w[b>>2]);qg(a,w[b+4>>2]);zb(b)}}function po(a,b){a=u[(a+b|0)+58|0];return((a|0)<0?-1:a)&255}function pi(a,b){if(b){pi(a,w[b>>2]);pi(a,w[b+4>>2]);zb(b)}}function Ml(a){var b=0;b=a;a=w[a>>2]-1|0;w[b>>2]=a;return a}function Lf(a,b){if(b){Lf(a,w[b>>2]);Lf(a,w[b+4>>2]);zb(b)}}function uH(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function tO(a){a=a|0;return z[w[a+24>>2]+1074420>>2]/1e4|0}function lJ(a){a=a|0;a=yl(a,9145);w[a>>2]=75876;return a|0}function iT(a,b,c){a=a|0;b=b|0;c=c|0;w[a>>2]=0;w[a+4>>2]=0}function cL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb=0;return 0}function Lg(a,b,c,d){w[a+16>>2]=d;w[a+12>>2]=c;w[a+8>>2]=b}function KM(a){a=a|0;a=yl(a,4860);w[a>>2]=75532;return a|0}function Db(a){if(dd(a)){return w[a+4>>2]}return x[a+11|0]}function wo(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function lm(a,b,c){w[a+28>>2]=c;w[a+20>>2]=b;w[a+24>>2]=b}function Mk(a){var b=0;b=w[20840];w[20840]=a;if(b){zb(b)}}function lr(a){a=a|0;w[a>>2]=66168;Gb(a+12|0);return a|0}function kr(a){a=a|0;w[a>>2]=66208;Gb(a+16|0);return a|0}function ds(a,b){var c=0;c=x[a|0];u[a|0]=x[b|0];u[b|0]=c}function XM(a,b,c){a=a|0;b=b|0;c=c|0;return fc(C(b,c))|0}function Wc(a,b){aj(w[b>>2]);Kh(w[a>>2]);w[a>>2]=w[b>>2]}function Ht(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xh(a,-1,-1)}function Gr(){var a=0,b=0;a=nc(461896),b=69340,w[a>>2]=b}function Fr(){var a=0,b=0;a=nc(461928),b=69836,w[a>>2]=b}function Dr(){var a=0,b=0;a=nc(461944),b=70164,w[a>>2]=b}function Dq(a){a=w[a>>2]-12|0;if((Ml(a+8|0)|0)<0){zb(a)}}function Cr(){var a=0,b=0;a=nc(461952),b=70328,w[a>>2]=b}function Br(){var a=0,b=0;a=nc(462024),b=70492,w[a>>2]=b}function xr(a){var b=0;b=w[a>>2];w[a>>2]=0;if(b){Kh(b)}}function wc(a){a=a|0;w[a>>2]=58952;Ab(a+4|0);return a|0}function nL(a){a=a|0;w[a>>2]=75800;Bb(a+4|0);return a|0}function jS(a){a=a|0;zv(a);u[a+4202|0]=1;w[a+4224>>2]=0}function eP(a){a=a|0;w[a>>2]=82216;Ug(a+4|0);return a|0}function _F(a,b){a=a|0;b=b|0;return Vi(a,Qb(b),Db(b))|0}function Yb(a){if(dd(a)){a=Ke(a)-1|0}else{a=10}return a}function Uh(a){a=a|0;w[a>>2]=59112;Ab(a+4|0);return a|0}function Qi(a){a=a|0;w[a>>2]=74772;Dq(a+4|0);return a|0}function Eq(a){a=a|0;w[a>>2]=74752;Dq(a+4|0);return a|0}function zt(a){a=a|0;return Aj(w[w[a>>2]-12>>2]+a|0)|0}function sL(a){a=a|0;return nd(w[w[a>>2]-12>>2]+a|0)|0}function qL(a){a=a|0;return Se(w[w[a>>2]-12>>2]+a|0)|0}function Ud(a,b){a=a|0;b=b|0;ob[w[w[b>>2]+24>>2]](a,b)}function Td(a,b){a=a|0;b=b|0;ob[w[w[b>>2]+28>>2]](a,b)}function Me(a,b){w[a+16>>2]=!w[a+24>>2]|(w[a+16>>2]|b)}function GO(a,b){a=a|0;b=b|0;w[w[a+24>>2]+480272>>2]=b}function Ft(a){a=a|0;return Dj(w[w[a>>2]-12>>2]+a|0)|0}function Er(){var a=0,b=0;a=nc(461936),b=7e4,w[a>>2]=b}function Ag(a){if(dd(a)){a=Ke(a)-1|0}else{a=1}return a}function Ad(a,b){a=a|0;b=b|0;ob[w[w[b>>2]+20>>2]](a,b)}function vt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function se(a){a=a|0;return ob[w[w[a>>2]+12>>2]](a)|0}function re(a){a=a|0;return ob[w[w[a>>2]+16>>2]](a)|0}function fO(a){a=a|0;return gw(w[a+24>>2]+484344|0)|0}function Zq(a,b,c){a=us(a,b,c,0,-2147483648);return a}function Cj(a){a=a|0;return ob[w[w[a>>2]+24>>2]](a)|0}function Cg(a,b){return ob[w[w[a>>2]+36>>2]](a,b,0)|0}function Bg(a,b){return ob[w[w[a>>2]+52>>2]](a,b,0)|0}function uO(a){a=a|0;return w[w[a+24>>2]+1074416>>2]}function sO(a){a=a|0;return y[w[a+24>>2]+1074438>>1]}function qO(a){a=a|0;return w[w[a+24>>2]+1074424>>2]}function US(a){a=a|0;return D(D(A[a+4232>>2]*D(20)))}function RT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Kv(a){a=a|0;return D(D(A[a+4216>>2]*D(10)))}function sP(a){a=a|0;a=w[a+4>>2];return(a?a:1518)|0}function sF(a){a=a|0;a=ob[a|0]()|0;kb=nb;return a|0}function qS(a){a=a|0;return D(D(A[a+4232>>2]*D(4)))}function pO(a){a=a|0;return y[w[a+24>>2]+480214>>1]}function kc(a,b){b=Ma(409,a|0,b|0)|0;nb=kb;return b}function jg(a){a=a|0;return y[w[a+24>>2]+480192>>1]}function fi(a){a=a|0;return y[w[a+24>>2]+480188>>1]}function ej(a){var b=0;b=w[a>>2];w[a>>2]=0;return b}function cN(a,b,c){a=a|0;b=b|0;c=c|0;Iu(a-88|0,b,c)}function aN(a,b,c){a=a|0;b=b|0;c=c|0;Fu(a-88|0,b,c)}function _h(a){a=a|0;ob[w[w[a+12>>2]>>2]](a+12|0)|0}function Rq(a,b){a=a|0;b=b|0;return Sq(a,b,ec(b))|0}function Rj(a){a=a|0;return y[w[a+24>>2]+480190>>1]}function Oq(a,b){a=a|0;b=b|0;return Vi(a,b,ec(b))|0}function Jj(a){if(!a){return 0}w[114084]=a;return-1}function Ic(a,b){b=w[b>>2];w[a>>2]=b;aj(b);return a}function Gb(a){if(dd(a)){Th(w[a>>2],Ke(a))}return a}function FO(a){a=a|0;return w[w[a+24>>2]+480272>>2]}function Dp(a,b){a=a|0;b=b|0;return Jf(a,b,ec(b))|0}function Cm(a){return fu(a,D(15845632502852868e13))}function Bm(a){return fu(a,D(2524354896707238e-44))}function AV(a){if(a){return 31-F(a-1^a)|0}return 32}function $b(a){if(dd(a)){Gh(w[a>>2],Ke(a))}return a}function mL(a){a=a|0;w[a>>2]=75800;Bb(a+4|0);zb(a)}function eN(a,b,c){a=a|0;b=b|0;c=+c;Ku(a-88|0,b,c)}function bN(a,b){a=a|0;b=b|0;return Gu(a-88|0,b)|0}function QN(a){a=a|0;w[a>>2]=82216;Ug(a+4|0);zb(a)}function KU(a,b){a=a|0;b=b|0;Ni(a+36|0,b);return 1}function $M(a,b){a=a|0;b=b|0;return Eu(a-88|0,b)|0}function au(a){return(a<<1)+16777216>>>0<16777217}function Sh(a,b,c){w[a+4>>2]=c;w[a>>2]=b;return a}function Ot(a,b){if(!a){return 0}return Ij(a,b,0)}function He(a,b){if(dd(a)){Yc(a,b);return}Zc(a,b)}function dN(a,b){a=a|0;b=b|0;return+Ju(a-88|0,b)}function Qb(a){if(dd(a)){return w[a>>2]}return a}function zI(a,b){a=a|0;b=b|0;qc(a,b,mc(460444))}function yI(a,b){a=a|0;b=b|0;qc(a,b,mc(460452))}function xI(a,b){a=a|0;b=b|0;qc(a,b,mc(460468))}function wI(a,b){a=a|0;b=b|0;qc(a,b,mc(460460))}function vI(a,b){a=a|0;b=b|0;qc(a,b,mc(460476))}function tf(a){a=a|0;return Ct(w[a>>2])<<24>>24}function tI(a,b){a=a|0;b=b|0;qc(a,b,mc(460484))}function sS(a){a=a|0;return A[a+4212>>2]<D(1)|0}function rI(a,b){a=a|0;b=b|0;qc(a,b,mc(460492))}function qI(a,b){a=a|0;b=b|0;qc(a,b,mc(460240))}function pI(a,b){a=a|0;b=b|0;qc(a,b,mc(460248))}function oI(a,b){a=a|0;b=b|0;qc(a,b,mc(460256))}function nI(a,b){a=a|0;b=b|0;qc(a,b,mc(460264))}function lI(a,b){a=a|0;b=b|0;qc(a,b,mc(460304))}function kI(a,b){a=a|0;b=b|0;qc(a,b,mc(460312))}function jI(a,b){a=a|0;b=b|0;qc(a,b,mc(460320))}function iI(a,b){a=a|0;b=b|0;qc(a,b,mc(460328))}function gI(a,b){a=a|0;b=b|0;qc(a,b,mc(460336))}function eI(a,b){a=a|0;b=b|0;qc(a,b,mc(460344))}function cI(a,b){a=a|0;b=b|0;qc(a,b,mc(460352))}function af(a){return ob[w[w[a>>2]+36>>2]](a)|0}function aI(a,b){a=a|0;b=b|0;qc(a,b,mc(460360))}function _H(a,b){a=a|0;b=b|0;qc(a,b,mc(460280))}function Yh(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function YH(a,b){a=a|0;b=b|0;qc(a,b,mc(460288))}function WS(a){a=a|0;return A[a+4220>>2]<D(1)|0}function WH(a,b){a=a|0;b=b|0;qc(a,b,mc(460296))}function TH(a,b){a=a|0;b=b|0;qc(a,b,mc(460368))}function SH(a,b){a=a|0;b=b|0;qc(a,b,mc(460376))}function Kg(a){return ob[w[w[a>>2]+28>>2]](a)|0}function Kd(a,b){a=a|0;b=b|0;Jg(a,w[a+16>>2]|b)}function GI(a,b){a=a|0;b=b|0;qc(a,b,mc(460224))}function FI(a,b){a=a|0;b=b|0;qc(a,b,mc(460232))}function DI(a,b){a=a|0;b=b|0;qc(a,b,mc(460428))}function CI(a,b){a=a|0;b=b|0;qc(a,b,mc(460420))}function BI(a,b){a=a|0;b=b|0;qc(a,b,mc(460436))}function $H(a,b){a=a|0;b=b|0;qc(a,b,mc(460272))}function qV(a,b,c){a=a|0;b=b|0;c=c|0;mi(a,b,c)}function ln(a,b,c){a=a|0;b=b|0;c=c|0;ek(a,b,c)}function fG(a,b,c){a=a|0;b=b|0;c=c|0;Sh(a,c,b)}function aS(a){a=a|0;yv(a);_m(a);u[a+4202|0]=1}function Tc(a,b,c){if(!(x[a|0]&32)){zm(b,c,a)}}function OS(a){a=a|0;u[a+4202|0]=1;Gv(a);Hv(a)}function $j(a,b,c){a=a|0;b=b|0;c=c|0;un(a,b,c)}function zj(a,b){a=a|0;b=b|0;return tt(a,b)^1}function yt(a){a=a|0;pm(w[w[a>>2]-12>>2]+a|0)}function xL(a){a=a|0;w[a>>2]=75760;return a|0}function ui(a){if(w[a>>2]){ko(a);zb(w[a>>2])}}function ue(a,b){a=a|0;b=b|0;return Dt(a,b)|0}function uN(a){a=a|0;kg(a-80|0);return a-88|0}function rL(a){a=a|0;kt(w[w[a>>2]-12>>2]+a|0)}function pL(a){a=a|0;jt(w[w[a>>2]-12>>2]+a|0)}function nf(a,b){a=a|0;b=b|0;return bt(b,1)|0}function ml(a){a=Na(813,a|0)|0;nb=kb;return a}function Ys(a){a=Rs(a);w[a>>2]=59336;return a}function Ye(a){a=Fh(a);w[a>>2]=74604;return a}function YL(a){a=a|0;w[a>>2]=75656;return a|0}function Wh(a,b){a=a|0;b=b|0;return Dt(a,b)^1}function Vs(a){a=Rs(a);w[a>>2]=59612;return a}function Vm(a){a=a|0;w[a>>2]=82084;return a|0}function Nr(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Mp(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function MN(a){a=a|0;w[a>>2]=82300;return a|0}function Le(a,b){a=a|0;b=b|0;return tt(a,b)|0}function JN(a){a=a|0;w[a>>2]=82340;return a|0}function JM(a){a=a|0;w[a>>2]=75552;return a|0}function Iw(a,b){a=a|0;b=b|0;return zn(a,b)|0}function Et(a){a=a|0;tm(w[w[a>>2]-12>>2]+a|0)}function Bl(a,b,c){a=us(a,b,c,-1,-1);return a}function oE(a){a=a|0;sq(a);return w[a+16>>2]}function bn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Tf(a){return w[Xi(a)>>2]-w[a>>2]>>2}function Iq(a,b,c){a=a|0;b=b|0;c=c|0;Jq(a,c)}function HM(a){a=a|0;return Ya(w[a+60>>2])|0}function Al(){ka(Ye(ba(4)|0)|0,74720,68);M()}function xs(){return(w[w[114126]>>2]?4:1)|0}function vO(a){a=a|0;return+Cn(w[a+24>>2])}
function uE(a){a=a|0;sq(a);return w[a+4>>2]}function rS(a){a=a|0;return D(A[a+4220>>2])}function eg(a){a=a|0;qm(w[a>>2]);return a|0}function _e(a,b){a=a|0;b=b|0;return br(b)|0}function VS(a){a=a|0;return D(A[a+4212>>2])}function Ov(a){a=a|0;ob[w[w[a>>2]+4>>2]](a)}function Mv(a){a=a|0;return D(A[a+4208>>2])}function Mg(a){a=a|0;rt(w[a>>2]);return a|0}function EV(a,b,c,d){a=zV(a,b,c,d);return a}function EM(a,b){a=a|0;b=b|0;return Wd(a)|0}function Be(a,b){a=a|0;b=b|0;return D(D(0))}function zM(a){a=a|0;return w[a+4>>2]!=0|0}function sN(a){a=a|0;kg(a-80|0);zb(a-88|0)}function rm(a){a=a|0;return Jd(a,460428)|0}function nm(a){a=a|0;return Jd(a,460420)|0}function lM(a){a=a|0;return Jd(a,460240)|0}function im(a){a=a|0;return Jd(a,460436)|0}function fu(a,b){return D(Dm(a?D(-b):b)*b)}function dm(a){a=a|0;return Jd(a,460444)|0}function dj(a,b){ob[w[w[b>>2]+40>>2]](a,b)}function cf(a,b){ob[w[w[b>>2]+44>>2]](a,b)}function bf(a,b){ob[w[w[b>>2]+32>>2]](a,b)}function ae(a){return w[a+4>>2]-w[a>>2]>>2}function XL(a){a=a|0;return Jd(a,460256)|0}function Wl(a){a=a|0;return Jd(a,460484)|0}function Rl(a){a=a|0;return Jd(a,460492)|0}function OT(a,b){a=a|0;b=b|0;u[a+4201|0]=b}function Ke(a){return w[a+8>>2]&2147483647}function vN(a){a=a|0;kg(a+8|0);return a|0}function pN(a,b){a=a|0;b=b|0;Pu(a-88|0,b)}function oN(a,b){a=a|0;b=b|0;Ou(a-88|0,b)}function bg(a){a=a|0;return st(w[a>>2])|0}function bH(a,b){a=a|0;b=b|0;Ol(a,b+12|0)}function aH(a,b){a=a|0;b=b|0;Ol(a,b+16|0)}function Zf(a,b){w[a>>2]=w[b>>2];return a}function ZM(a,b){a=a|0;b=b|0;Cu(a-88|0,b)}function Sb(a,b){a=a|0;b=b|0;Ic(a,b+28|0)}function IR(a){a=a|0;Cb(a+4296|0,0,81928)}function Dj(a){a=a|0;pc(a+8|0);return a|0}function Bq(a){a=Ea(a|0)|0;nb=kb;return a}function Aj(a){a=a|0;pc(a+4|0);return a|0}function yj(a,b){w[a+24>>2]=w[a+24>>2]+b}function tL(a){a=a|0;w[a>>2]=75760;zb(a)}function qe(a,b){return w[a>>2]!=w[b>>2]}function nN(a,b){a=a|0;b=+b;Nu(a-88|0,b)}function mf(a){return(a|0)==32|a-9>>>0<5}function kN(a,b){a=a|0;b=+b;Mu(a-88|0,b)}function hN(a,b){a=a|0;b=+b;Lu(a-88|0,b)}function cr(a){w[w[a>>2]+4>>2]=w[a+4>>2]}function _G(a,b){a=a|0;b=b|0;zg(a,66240)}function ZR(a){a=a|0;return w[a+4260>>2]}function XG(a,b){a=a|0;b=b|0;zg(a,66260)}function Sf(a,b){return w[a>>2]+(b<<2)|0}function PL(a){a=a|0;w[a>>2]=75656;zb(a)}function LN(a){a=a|0;w[a>>2]=82300;zb(a)}function IN(a){a=a|0;w[a>>2]=82340;zb(a)}function IM(a){a=a|0;w[a>>2]=75552;zb(a)}function Cd(a,b){w[a+8>>2]=b|-2147483648}function zR(a){a=a|0;return(a|0)==277|0}function vA(a){a=a|0;Cb(a+288|0,0,4608)}function it(a,b){return w[a>>2]<w[b>>2]}function ht(a,b){return z[a>>2]<z[b>>2]}function cs(a,b){a=a|0;b=b|0;return b|0}function _r(a,b){a=a|0;b=b|0;ms(a,1,45)}function ZG(a,b){a=a|0;b=b|0;Hb(a,7236)}function Ws(a){w[a+4>>2]=w[a+4>>2]|8192}function Uq(a,b,c){if(b){Cb(a,Md(c),b)}}function Sg(a){return(p(a),j(2))>>>20|0}function NT(a){a=a|0;return x[a+4201|0]}function MT(a){a=a|0;return x[a+4202|0]}function $r(a,b){a=a|0;b=b|0;Xu(a,1,45)}function $G(a,b){a=a|0;b=b|0;Hb(a,7119)}function vM(a){a=a|0;return w[a+20>>2]}function nt(a,b){a=a|0;b=b|0;ul(a,b,0)}function mM(a){a=a|0;return w[a+24>>2]}function kj(a,b){return Qb(a)+(b<<2)|0}function fj(a){a=a|0;return 2147483647}function _q(a){w[w[a+8>>2]>>2]=w[a>>2]}function ST(a){a=a|0;return 1869112133}function RK(a){a=a|0;return w[a+16>>2]}function HR(a){a=a|0;return-2013527448}function FL(a){a=a|0;return w[a+12>>2]}function EO(a){a=a|0;return+B[a+16>>3]}function xR(a,b){a=a|0;b=b|0;return 3}function wm(a){a=a|0;return w[a+8>>2]}function wS(a){a=a|0;return-281111764}function wR(a,b){a=a|0;b=b|0;return 2}function tt(a,b){return et(a)^et(b)^1}function tS(a){a=a|0;return-271958638}function qT(a){a=a|0;return 542066252}function pv(a,b){a=a|0;b=b|0;return 0}function iS(a){a=a|0;return-620920304}function fD(a){a=a|0;return x[a+40|0]}function dd(a){return x[a+11|0]>>>7|0}function cn(a,b){a=a|0;b=b|0;return 1}function bu(a){a=D(a-a);return D(a/a)}function _l(a){a=a|0;if(Cs(a)){zb(a)}}function _R(a){a=a|0;return-275227023}function _K(a){a=a|0;return Ts(a,0)|0}function ZK(a){a=a|0;return Ts(a,1)|0}function XS(a){a=a|0;return-270114148}function SK(a){a=a|0;return Os(a,0)|0}function Rs(a){w[a>>2]=60384;return a}function QR(a){a=a|0;return 302837129}function QK(a){a=a|0;return Os(a,1)|0}function Oi(a){a=a|0;return w[a+4>>2]}function MS(a){a=a|0;return-285139079}function Gq(a,b){a=a|0;b=b|0;wa();M()}function Fh(a){w[a>>2]=74644;return a}function Ej(a,b){a=a|0;b=b|0;return-1}function Dt(a,b){return ft(a)^ft(b)^1}function DS(a){a=a|0;return-284078960}function tN(a){a=a|0;kg(a+8|0);zb(a)}function sk(a,b){a=a|0;b=b|0;bo(a,b)}function oF(a){a=a|0;return x[a+8|0]}function hT(a,b,c){a=a|0;b=b|0;c=c|0}function eh(a,b){a=a|0;b=b|0;tk(a,b)}function dH(a){a=a|0;return u[a+8|0]}function cH(a){a=a|0;return u[a+9|0]}function aj(a){w[a+4>>2]=w[a+4>>2]+1}function ss(a,b){return(b-a|0)/12|0}function rV(a){a=a|0;return _d(a)|0}function oM(a){a=a|0;return dg(a)|0}function lL(a){a=a|0;return Kb(a)|0}function hU(a){a=a|0;return jw(a)|0}function hS(a){a=a|0;w[a+4224>>2]=0}function at(a){a=a|0;return Qi(a)|0}function Kc(a,b){return(a|0)==(b|0)}function Jt(a){a=a|0;return pc(a)|0}function Eh(a,b,c){if(c){hc(a,b,c)}}function Eg(a,b){w[a>>2]=b;return a}function Dd(a,b,c){if(c){Fb(a,b,c)}}function vj(a){return Kc(a,-1)?0:a}function gu(a){B[(jb-16|0)+8>>3]=a}function Xr(a){return Jd(a,460312)}function Wr(a){return Jd(a,460304)}function WM(a,b){a=a|0;b=b|0;zb(b)}function TM(a){a=a|0;u[a+6152|0]=0}function Rr(a){return Jd(a,460328)}function Rd(a,b){a=a|0;b=b|0;Wb(a)}function Qr(a){return Jd(a,460320)}function Fl(a,b){a=a|0;b=b|0;Ne(b)}function Ae(a){a=a|0;u[a+4202|0]=0}function zc(a){a=a|0;wi(6933);M()}function rl(a,b){return w[a+b>>2]}function Wd(a){return a-48>>>0<10}function Rb(a,b){return Qb(a)+b|0}function Ne(a){w[a>>2]=0;return a}function Mb(a){a=a|0;wi(3930);M()}function Bc(a){a=a|0;hi(3930);M()}function xd(a,b){w[a>>2]=w[b>>2]}function um(a){a=a|0;pc(a);zb(a)}function uM(a){a=a|0;wc(a);zb(a)}function qH(a){a=a|0;Mr(a);zb(a)}function kL(a){a=a|0;return 6346}function hm(a){a=a|0;Qi(a);zb(a)}function gH(a){a=a|0;lr(a);zb(a)}function eH(a){a=a|0;kr(a);zb(a)}function dg(a){return!w[a+16>>2]}function cG(a){a=a|0;return 8966}function bG(a){a=a|0;return 6226}function Ri(a){a=a|0;Eq(a);zb(a)}function Ph(a){w[a>>2]=w[a>>2]+1}function PH(a){a=a|0;wr(a);zb(a)}function Oh(a){w[a>>2]=w[a>>2]+4}function LL(a){a=a|0;Uh(a);zb(a)}function LF(a){a=a|0;return 5716}function KF(a){a=a|0;return 8852}function JF(a){a=a|0;return 6708}function IF(a){a=a|0;return 2206}function Ar(a){Tf(a);ae(a);Tf(a)}function AH(a){a=a|0;ur(a);zb(a)}function zG(a){a=a|0;$b(460628)}function xG(a){a=a|0;Gb(460644)}function vG(a){a=a|0;$b(460660)}function sd(a){a=a|0;return a|0}function gj(a){a=a|0;return 127}function dt(a,b){return ct(a,b)}function cu(a,b){return vf(a,b)}function Sr(a,b){return as(a,b)}function Ng(a){return a<<24>>24}function JG(a){a=a|0;Gb(460548)}function HG(a){a=a|0;$b(460564)}function FG(a){a=a|0;Gb(460580)}function DG(a){a=a|0;$b(460596)}function BG(a){a=a|0;Gb(460612)}function vL(a){a=a|0;zb(lt(a))}function uP(a){a=a|0;zb(Vm(a))}function tm(a){a=a|0;zb(Dj(a))}function sj(a){return a>>>0<11}function pm(a){a=a|0;zb(Aj(a))}function kt(a){a=a|0;zb(nd(a))}function jt(a){a=a|0;zb(Se(a))}function jr(a){a=a|0;zb(Hl(a))}function eu(a){a=a|0;zb(Qi(a))}function as(a,b){return b-a>>2}function YR(a){a=a|0;return 13}function Xm(a){a=a|0;zb(iv(a))}function Us(a){a=a|0;zb(wc(a))}function Sc(a,b){u[a|0]=x[b|0]}function Ps(a){a=a|0;zb(Uh(a))}function Lt(){return(Wa()|0)>0}function Af(a){a=a|0;zb(Oc(a))}function qf(a){return!w[a>>2]}function qP(){return 19469585}function pj(a,b){w[a+72>>2]=b}function pT(a){a=a|0;return 9}function gt(a){return a>>>0>8}function ct(a,b){return b-a|0}function YF(){Gq(13123,0);M()}function Xg(a){a=a|0;return 4}function Wi(a){return a>>>0<2}function PR(a){a=a|0;return 3}function Oj(a){return iu(a)*a}function Nv(a){a=a|0;return 7}function Lb(a){a=a|0;return 0}function LS(a){a=a|0;return 6}function Gt(a){a=a|0;return-1}function Gc(a){a=a|0;return 2}function Ec(a){a=a|0;return 1}function Cv(a){a=a|0;return 5}function xj(a,b){Ic(a,b+4|0)}function dr(a,b){Tf(a);Tf(a)}function Zc(a,b){u[a+11|0]=b}function Yc(a,b){w[a+4>>2]=b}function Uf(a){return a+16|0}function Pc(a,b){a=a|0;b=b|0}function Ir(a){ar(a,w[a>>2])}function El(a){return a+12|0}function rP(){return 327700}function Xi(a){return a+8|0}function Md(a){return a&255}function Lh(a){return a+4|0}function Id(a){return!Db(a)}function hd(a,b){w[a>>2]=b}function fr(){wi(3930);M()}function Zb(a){a=a|0;zb(a)}function Qf(){wi(6933);M()}function Hr(a){Tf(a);ae(a)}function FK(){return 61672}function EK(){return 63216}function Bf(){hi(6933);M()}function Ab(a){Kh(w[a>>2])}function _O(){return 2048}function HF(){return jb|0}function GF(a){a=a|0;jb=a}function AM(a){a=a|0;kb=a}function uh(a){a=a|0;M()}function dc(a,b){Rq(a,b)}function Gh(a,b){hr(a,b)}function Ub(a){Hc(a,0)}function lg(a){Ym(a)}function Qc(a){a=a|0}function mI(){Gr()}function hI(){Fr()}function fI(){Er()}function dI(){Dr()}function bI(){Cr()}function VH(){Br()}function EI(){vr()}
// EMSCRIPTEN_END_FUNCS
e=x;var ob=c([null,Hb,KE,me,iC,Hb,Dk,OU,YA,Ve,Sb,Jd,ML,sm,ZL,Wg,Jg,eL,aa,Xw,Eq,BR,Kb,Wf,sC,uh,Ec,Ec,oF,jF,Oi,_E,Kp,HC,zC,YF,hC,uh,Ec,Lb,Ec,uE,oE,iE,cE,ZD,cC,uD,$B,fD,_C,DB,hO,pB,Fn,jB,Ca,XA,rG,Di,JA,yA,Hk,Hk,qG,iA,Pz,Hk,sd,gG,iG,Ui,xl,Sy,RM,no,Ge,Xx,Sq,yr,fL,SL,DL,$s,Fj,om,VL,om,om,RL,NL,mi,Vi,Vq,hM,TT,jM,dM,cM,fM,CL,RU,QT,zc,jT,Mb,Re,nR,cR,zT,aU,zQ,oQ,dQ,wl,hU,ah,Wm,Jf,bP,uR,VO,Ym,UP,MB,JP,ev,LO,BO,Mc,Hu,xf,KM,Qi,gM,HL,EL,BL,eu,Oi,JM,IM,_h,pv,Zb,sd,Zb,zM,Ec,Ec,Oi,wm,tM,Kp,pM,nM,YL,PL,_h,Zb,Zb,Lb,Ec,Ec,Lb,Lb,vt,xL,tL,_h,Zb,nL,mL,hL,dL,bL,YK,RK,LK,KK,IK,$e,Qh,nV,Di,mV,kG,rV,oc,RJ,Vj,yl,rJ,Mb,ka,lJ,eu,cd,ZI,SI,UH,Xb,Xb,kF,kl,iF,hF,gF,fF,Vb,eF,dF,wq,cF,Fd,td,ie,nl,ld,$E,ZE,YE,XE,WE,Qd,VE,UE,lw,TE,Ay,Ro,SE,Nc,RE,bh,tq,tc,Ni,Ce,hV,NE,Xb,vq,wn,ME,LE,gl,Nm,JE,rq,hl,QE,Ck,HE,CE,mq,Vu,je,Ki,BE,Rq,cd,ny,AE,zk,lq,lc,zE,Nc,yE,KU,ng,nw,QU,xE,jq,Pv,wE,vE,$e,qV,tE,iq,Mb,Nf,Ji,sE,Hd,Vf,rE,qE,vl,mE,lE,fq,hE,Mc,Mb,Nf,$k,gE,fE,Mc,hw,Mi,nh,Ik,pq,eE,dE,bE,bq,We,xh,YD,VD,mq,wh,fq,Ii,Jk,lq,UD,TD,SD,RD,QD,ku,Of,Kf,PD,xB,iq,Mb,Nf,Ji,OD,Zp,ND,Zp,rw,SU,ow,gd,ED,YU,Gw,AD,zD,yD,Xk,xD,Mc,fH,wD,uA,vA,vD,tD,GD,wg,sH,sD,Ai,jH,rD,qD,Rw,Tp,pD,Wf,oD,mG,nD,lD,Rp,kD,Qp,Pp,jD,Lk,FD,iD,YG,hD,gD,eD,sk,Jh,Hh,dD,Zg,Cw,cD,Gl,Li,mg,mS,Op,yf,rd,jU,zf,bD,ky,CU,fy,Nc,zc,Ob,aD,kU,Hw,fU,$C,WC,VC,UC,oq,TC,Qu,SC,RC,QC,en,gn,PC,OC,Mb,Nf,NC,MC,LC,KC,Fp,wg,GC,Xk,Jp,vy,Mc,FC,Uk,EC,Do,Pf,Xb,wq,DC,CC,BC,bj,Nc,AC,yC,Mc,cd,Mc,Sl,ry,Dp,Vj,vC,uC,ln,$j,tC,Pi,Tk,rC,qC,pC,yq,oC,cd,nC,mC,lC,kC,tA,Sx,vt,jC,NM,Wk,OM,PM,QM,Dw,gC,Fk,Mb,fC,eC,Mc,xh,VB,bC,SB,tq,Mi,RB,Ew,QB,PB,iw,vh,il,qp,OB,NB,Fi,$w,LB,KB,yi,Mc,JB,IB,Mc,op,Fi,gi,Mb,$d,Mb,CB,np,$i,BB,Xk,yB,tg,Fi,wB,PU,tB,sB,$k,ip,hl,rB,qB,oB,Ei,nB,Ei,mB,gp,Mb,Nf,Ji,RH,pU,lB,kB,bp,Nk,xh,gB,wg,dB,Pi,aB,wA,qp,wg,Ux,Tx,ZA,SA,RA,gq,Nm,QA,PA,OA,Mb,Re,zi,NA,MA,IA,HA,GA,sy,DA,CA,jV,Lw,Jw,BA,Tk,AA,gV,zA,iV,kV,$x,Nc,xA,UQ,ty,sA,Ee,De,ih,rA,qA,pA,oA,nA,mA,lA,kA,jA,hA,gA,fA,eA,dA,cA,bA,aA,$z,_z,Zz,Yz,Xz,Wz,Vz,Uz,Tz,Sz,Rz,Qz,Oz,Nz,Mz,Lz,Kz,Jz,Iz,Hz,Gz,Fz,Ez,Dz,Cz,Bz,Az,zz,yz,xz,wz,vz,uz,tz,sz,rz,qz,pz,oz,nz,mz,lz,kz,jz,iz,hz,gz,fz,ez,dz,cz,bz,az,$y,_y,Zy,Yy,Xy,Wy,Vy,Uy,Ty,Ry,Qy,Py,Oy,Ny,My,Ly,Ky,Jy,Iy,Hy,Gy,Fy,Ey,Dy,Cy,By,zy,yy,xy,Bc,vo,py,oy,Mb,Vh,my,jy,hy,uo,gy,Op,ey,iy,ro,cy,by,ay,oo,vV,_x,Zx,xw,uV,tV,sV,Te,Vx,TM,SM,Rx,Iw,uy,Co,Qx,xq,fJ,Vc,IE,aE,Ox,Nx,Mx,Lx,Kx,Jx,Ix,Hx,Gx,Fx,Ex,Dx,Cx,Bx,Ax,zx,yx,xx,wx,vx,ux,tx,sx,rx,qx,px,ox,nx,mx,lx,kx,jx,ix,hx,gx,fx,ex,dx,cx,bx,ax,Yx,io,ho,_w,Zw,Yw,Ho,Bi,gh,ao,rn,xn,ck,fh,qi,Ww,Fo,Jo,Vw,qo,wk,le,hi,Wx,qy,Po,IT,yV,Tw,Sw,Qw,En,wJ,vK,gO,jK,ug,Ow,wy,Dn,ni,If,gT,fk,ik,lV,dy,Kw,wU,zU,xU,vU,Eo,FA,EA,CD,BD,cB,bB,WA,VA,JC,IC,HB,GB,YC,XC,EE,DE,MD,LD,bF,aF,PE,OE,FB,EB,fB,eB,LA,KA,kE,jE,$D,_D,pF,nF,mF,lF,vB,uB,iB,hB,UB,TB,ZC,Mp,KD,JD,ID,HD,pE,nE,XD,WD,AB,zB,fV,eV,UU,TU,XB,WB,$A,_A,UA,TA,dC,ZB,YB,jG,ZF,GE,FE,xC,wC,aC,_B,fk,wV,_d,oV,pV,Mb,Re,uk,dV,cV,$k,bV,ip,aV,$U,xh,_U,Mc,ZU,XU,WU,VU,gp,Mb,Nf,Ji,YM,VM,UM,NU,MU,kw,IU,HU,GU,cg,FU,EU,BU,DU,LU,AU,JU,ew,ly,tU,sU,kw,rU,uo,qU,dw,yU,ii,ul,cw,nU,mU,lU,vv,Uj,rf,iU,gU,Zv,Mb,ud,oU,uU,dU,cU,oT,bU,Fe,Uv,ud,Il,bw,dn,Yg,Yg,ST,Lb,Qc,Lb,Lb,Lb,Pc,Xg,XT,YT,_T,ZT,$T,Be,cn,cn,bn,bn,bn,RT,Qc,Mp,PT,OT,NT,MT,WT,Ae,Vv,nT,Lb,Lb,Ec,LT,Gc,Gc,Ec,VT,UT,Pc,Qc,Pc,Qc,JT,rT,dn,Yg,Yg,qT,Lb,Qc,Lb,Lb,Lb,Pc,pT,FT,GT,tT,sT,HT,Be,CT,BT,AT,yT,xT,wT,vT,uT,ET,Ae,DT,Lb,Lb,Ec,Gc,Gc,Ec,Tv,Sv,kT,Oc,uh,lT,Qv,mT,Lb,iT,hT,fT,Qh,eT,fk,dT,TS,KS,CS,vS,pS,fS,XR,OR,eU,KT,cT,YS,$m,Ov,XS,Lb,Qc,Lb,Lb,Lb,Pc,Nv,$S,aT,bT,Be,_S,Ae,ZS,Lb,Lb,Ec,Gc,Gc,Pc,Qc,Mv,WS,VS,Lv,US,Kv,Jv,SS,NS,Fv,Fv,MS,Lb,Qc,Lb,Lb,Lb,Pc,LS,PS,QS,RS,Be,OS,Ae,Gv,Lb,Lb,Ec,Gc,Gc,JS,Af,Af,DS,Lb,Qc,Lb,Lb,Lb,Pc,Cv,GS,HS,IS,Be,FS,Ae,ES,Lb,Lb,Ec,Gc,Gc,BS,dn,Yg,Yg,wS,Lb,Qc,Lb,Lb,Lb,Pc,Cv,yS,zS,AS,Be,xS,Ae,Av,Lb,Lb,Ec,Gc,Gc,$m,$m,tS,Nv,uS,Mv,sS,rS,Lv,qS,Kv,Jv,oS,Af,Af,iS,Lb,Qc,Lb,Lb,Lb,Pc,Gc,kS,lS,nS,Be,jS,Ae,hS,Lb,Lb,Ec,Gc,Gc,eS,gS,$R,xv,xv,_R,Lb,Qc,Lb,Lb,ZR,Pc,YR,bS,cS,dS,Be,aS,Ae,_m,Lb,Lb,Ec,Gc,Gc,Pc,Qc,WR,Af,Af,QR,Lb,Qc,Lb,Lb,Lb,Pc,PR,TR,UR,VR,Be,SR,Ae,RR,Lb,Lb,Ec,Gc,Gc,NR,Af,Af,HR,Lb,Qc,Lb,Lb,Lb,Pc,Xg,KR,LR,MR,Be,JR,Ae,IR,Lb,Lb,Ec,Gc,Gc,rP,rv,Oq,lP,qP,pP,dP,aP,qv,mv,ZO,Vm,_O,av,XO,WO,rR,qR,mv,$u,FR,_u,jv,mR,iv,Zu,wm,GO,FO,IO,DO,EO,HO,Zm,UO,XQ,jP,TO,SO,RO,QO,PO,OO,NO,MO,KO,JO,CO,Zm,wO,vO,uO,tO,sO,rO,qO,pO,oO,nO,mO,lO,kO,jO,fi,iO,fO,jg,Rj,eO,dO,cO,bO,aO,$N,_N,ZN,Sm,YN,XN,VN,UN,TN,SN,Uu,Tu,Su,Ru,gP,hv,gv,fv,dv,xN,wN,jv,Zm,NP,MP,LP,KP,IP,HP,GP,FP,EP,DP,CP,BP,AP,zP,yP,xP,wP,vP,Vm,uP,tP,Xm,sP,Xm,Xm,Aw,eh,lG,Px,Sj,HN,mP,ri,Mb,Nf,Uw,Lq,eo,RN,Xn,Sn,Pw,iP,oP,kP,xV,cP,av,YO,$O,NN,KN,hP,fP,Bn,AO,zO,Mw,Nw,Fw,yO,xO,Vg,gw,WN,yn,qw,pw,Xu,DD,mD,uh,eP,QN,nP,sd,Zb,PN,ON,MN,LN,_h,Zb,JN,IN,_h,Zb,sd,Zb,GN,sd,Zb,FN,EN,Zb,DN,CN,Zb,BN,AN,Zb,zN,yN,vN,tN,rN,qN,Pu,Ou,Nu,mN,Mu,jN,Lu,gN,Ku,Ju,Iu,Gu,Fu,Eu,Du,Cu,uN,sN,pN,oN,nN,lN,kN,iN,hN,fN,eN,dN,cN,bN,aN,$M,_M,ZM,XM,WM,MM,LM,HM,GM,FM,DM,CM,yM,xM,rm,mM,Cj,Kd,lM,iM,vM,kM,eM,QL,bM,qm,aM,$L,_L,At,oM,$f,XL,WL,UL,TL,QL,OL,xt,Kt,GL,Cj,Kd,Yh,Yh,nt,sd,oL,wc,uM,Pc,Yh,It,Ht,Lb,Lb,sM,Gt,rM,Ej,qM,Ej,Dj,tm,Ft,Et,Aj,pm,zt,yt,Uh,LL,Pc,Yh,It,Ht,Lb,Lb,KL,Gt,JL,Ej,IL,Ej,Dj,tm,Ft,Et,Aj,pm,zt,yt,lt,vL,wL,uL,AL,zL,yL,Jt,um,Jt,um,nd,kt,sL,rL,Se,jt,qL,pL,Qc,gL,iL,at,sd,Zb,kL,fG,eG,dG,jL,hm,pc,um,wM,Lb,cL,Qc,Xs,im,Xs,dm,ut,aL,Us,$K,_K,ZK,XK,Us,WK,Qs,VK,UK,Ps,TK,SK,QK,PK,Ps,OK,Qs,NK,MK,JK,HK,Wl,Ud,Td,nj,zb,Al,Wh,ue,tf,Vl,eg,Mh,kf,tK,Jc,re,Ad,rK,pK,qs,qs,lK,mj,iK,ps,se,gK,eK,Cc,cK,Yl,nm,Rl,Ud,Td,lj,zj,Le,bg,$f,Mg,jf,re,Ad,jj,os,se,PJ,ef,KJ,JJ,Mh,GK,am,EM,pt,EJ,tj,Nh,mm,zJ,Dg,Mh,Zl,Yh,Qc,dJ,hj,cJ,bJ,Zr,aJ,Yr,Mh,_I,XI,WI,pf,VI,Tr,Yr,TI,hG,QI,PI,MI,LI,_l,HI,GI,FI,EI,DI,CI,BI,AI,zI,yI,xI,wI,vI,uI,tI,sI,rI,qI,pI,oI,nI,mI,lI,kI,jI,iI,hI,gI,fI,eI,dI,cI,bI,aI,$H,_H,ZH,YH,XH,WH,VH,TH,SH,Fl,NH,QH,uG,tG,sG,OH,MH,FK,EK,DK,Ij,zs,Rh,lH,kH,ys,xs,ws,VG,TG,RG,PG,NG,LG,JG,HG,FG,DG,BG,zG,xG,vG,ag,Pc,wr,PH,Ov,ur,AH,zH,yH,xH,wH,cs,vH,uH,tH,Mr,qH,pH,oH,nH,mH,Lb,iH,hH,lr,gH,dH,cH,bH,$G,ZG,kr,eH,wm,FL,aH,_G,XG,sd,Zb,Zb,LH,KH,JH,IH,HH,GH,FH,EH,cs,DH,CH,BH,Zb,tr,tr,Ih,Ec,Ec,rH,Ec,Zb,rr,qr,Ih,Lb,Lb,pr,Xg,Zb,rr,qr,Ih,Lb,Lb,pr,Xg,Zb,or,nr,Ih,Lb,Lb,mr,Xg,Zb,or,nr,Ih,Lb,Lb,mr,Xg,sd,Zb,CK,BK,AK,sd,Zb,zK,yK,xK,Zb,wK,uK,sK,qK,oK,nK,mK,kK,hK,fK,dK,Zb,bK,aK,$J,_J,ZJ,YJ,XJ,WJ,VJ,UJ,TJ,Zb,SJ,QJ,OJ,NJ,MJ,LJ,IJ,HJ,Zb,GJ,FJ,DJ,CJ,BJ,AJ,yJ,xJ,sd,Zb,Gc,vJ,uJ,tJ,sJ,qJ,pJ,WG,SG,OG,CG,yG,KG,GG,sd,Zb,Gc,oJ,nJ,mJ,kJ,jJ,iJ,UG,QG,MG,AG,wG,IG,EG,Hl,jr,hJ,Hl,jr,gJ,Zb,gj,gj,Rd,Rd,Rd,$r,Lb,df,df,Zb,gj,gj,Rd,Rd,Rd,$r,Lb,df,df,Zb,fj,fj,Rd,Rd,Rd,_r,Lb,df,df,Zb,fj,fj,Rd,Rd,Rd,_r,Lb,df,df,Zb,eJ,$I,Zb,YI,UI,Zb,RI,OI,Zb,NI,KI,Zb,Nr,JI,Pc,Zb,Nr,II,Pc,sd,uh,Lb,Lb,Lb,lL,Zb,Ti,pG,nf,Xq,Wq,_e,nG,_F,$F,oG,Hq,at,Zb,cG,Iq,Zb,bG,aG,Iq,hm,wa,Gq,sd,Zb,Qc,Qc,XF,OF,RF,WF,Zb,PF,SF,VF,Zb,QF,TF,UF,Zb,KF,Zb,JF,Zb,LF,Ri,Oi,hm,Ri,Ri,Ri,Zb,IF]);function pb(){return t.byteLength/65536|0}function ub(vb){vb=vb|0;var qb=pb()|0;var rb=qb+vb|0;if(qb<rb&&rb<65536){var sb=new ArrayBuffer(C(rb,65536));var tb=new Int8Array(sb);tb.set(u);u=new Int8Array(sb);v=new Int16Array(sb);w=new Int32Array(sb);x=new Uint8Array(sb);y=new Uint16Array(sb);z=new Uint32Array(sb);A=new Float32Array(sb);B=new Float64Array(sb);t=sb;s.buffer=t;e=x}return qb}return{"xa":Bw,"ya":ob,"za":GR,"Aa":ER,"Ba":Zb,"Ca":zb,"Da":DR,"Ea":CR,"Fa":AR,"Ga":qv,"Ha":Pc,"Ia":zR,"Ja":yR,"Ka":xR,"La":cn,"Ma":wR,"Na":pv,"Oa":vR,"Pa":sd,"Qa":ov,"Ra":nv,"Sa":ov,"Ta":tR,"Ua":FF,"Va":EF,"Wa":DF,"Xa":sR,"Ya":lv,"Za":pR,"_a":kv,"$a":oR,"ab":lR,"bb":kR,"cb":jR,"db":iR,"eb":hR,"fb":gR,"gb":fR,"hb":eR,"ib":dR,"jb":bR,"kb":aR,"lb":$Q,"mb":_Q,"nb":ZQ,"ob":YQ,"pb":WQ,"qb":VQ,"rb":TQ,"sb":SQ,"tb":RQ,"ub":QQ,"vb":PQ,"wb":OQ,"xb":NQ,"yb":MQ,"zb":LQ,"Ab":KQ,"Bb":JQ,"Cb":IQ,"Db":HQ,"Eb":GQ,"Fb":FQ,"Gb":EQ,"Hb":DQ,"Ib":CQ,"Jb":BQ,"Kb":AQ,"Lb":yQ,"Mb":xQ,"Nb":wQ,"Ob":vQ,"Pb":uQ,"Qb":tQ,"Rb":sQ,"Sb":rQ,"Tb":qQ,"Ub":pQ,"Vb":nQ,"Wb":mQ,"Xb":lQ,"Yb":kQ,"Zb":jQ,"_b":iQ,"$b":hQ,"ac":gQ,"bc":fQ,"cc":eQ,"dc":cQ,"ec":bQ,"fc":aQ,"gc":$P,"hc":_P,"ic":CF,"jc":ZP,"kc":YP,"lc":XP,"mc":WP,"nc":BF,"oc":VP,"pc":TP,"qc":SP,"rc":RP,"sc":QP,"tc":PP,"uc":OP,"vc":fc,"wc":BM,"xc":AM,"yc":HF,"zc":GF,"Ac":NF,"Bc":MF,"Cc":vF,"Dc":AF,"Ec":zF,"Fc":yF,"Gc":xF,"Hc":wF,"Ic":vF,"Jc":uF,"Kc":tF,"Lc":sF,"Mc":rF,"Nc":qF}}return wb(yb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


